import {Request} from '../lib/request';
import {Response} from '../lib/response';
import {AWSError} from '../lib/error';
import {Service} from '../lib/service';
import {WaiterConfiguration} from '../lib/service';
import {ServiceConfigurationOptions} from '../lib/service';
import {ConfigBase as Config} from '../lib/config-base';
interface Blob {}
declare class EC2 extends Service {
  /**
   * Constructs a service object. This object has one method for each API operation.
   */
  constructor(options?: EC2.Types.ClientConfiguration)
  config: Config & EC2.Types.ClientConfiguration;
  /**
   * Accepts an Elastic IP address transfer. For more information, see Accept a transferred Elastic IP address in the Amazon Virtual Private Cloud User Guide.
   */
  acceptAddressTransfer(params: EC2.Types.AcceptAddressTransferRequest, callback?: (err: AWSError, data: EC2.Types.AcceptAddressTransferResult) => void): Request<EC2.Types.AcceptAddressTransferResult, AWSError>;
  /**
   * Accepts an Elastic IP address transfer. For more information, see Accept a transferred Elastic IP address in the Amazon Virtual Private Cloud User Guide.
   */
  acceptAddressTransfer(callback?: (err: AWSError, data: EC2.Types.AcceptAddressTransferResult) => void): Request<EC2.Types.AcceptAddressTransferResult, AWSError>;
  /**
   * Accepts the Convertible Reserved Instance exchange quote described in the GetReservedInstancesExchangeQuote call.
   */
  acceptReservedInstancesExchangeQuote(params: EC2.Types.AcceptReservedInstancesExchangeQuoteRequest, callback?: (err: AWSError, data: EC2.Types.AcceptReservedInstancesExchangeQuoteResult) => void): Request<EC2.Types.AcceptReservedInstancesExchangeQuoteResult, AWSError>;
  /**
   * Accepts the Convertible Reserved Instance exchange quote described in the GetReservedInstancesExchangeQuote call.
   */
  acceptReservedInstancesExchangeQuote(callback?: (err: AWSError, data: EC2.Types.AcceptReservedInstancesExchangeQuoteResult) => void): Request<EC2.Types.AcceptReservedInstancesExchangeQuoteResult, AWSError>;
  /**
   * Accepts a request to associate subnets with a transit gateway multicast domain.
   */
  acceptTransitGatewayMulticastDomainAssociations(params: EC2.Types.AcceptTransitGatewayMulticastDomainAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.AcceptTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Accepts a request to associate subnets with a transit gateway multicast domain.
   */
  acceptTransitGatewayMulticastDomainAssociations(callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.AcceptTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Accepts a transit gateway peering attachment request. The peering attachment must be in the pendingAcceptance state.
   */
  acceptTransitGatewayPeeringAttachment(params: EC2.Types.AcceptTransitGatewayPeeringAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.AcceptTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Accepts a transit gateway peering attachment request. The peering attachment must be in the pendingAcceptance state.
   */
  acceptTransitGatewayPeeringAttachment(callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.AcceptTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Accepts a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use RejectTransitGatewayVpcAttachment to reject a VPC attachment request.
   */
  acceptTransitGatewayVpcAttachment(params: EC2.Types.AcceptTransitGatewayVpcAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.AcceptTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Accepts a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use RejectTransitGatewayVpcAttachment to reject a VPC attachment request.
   */
  acceptTransitGatewayVpcAttachment(callback?: (err: AWSError, data: EC2.Types.AcceptTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.AcceptTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Accepts connection requests to your VPC endpoint service.
   */
  acceptVpcEndpointConnections(params: EC2.Types.AcceptVpcEndpointConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.AcceptVpcEndpointConnectionsResult) => void): Request<EC2.Types.AcceptVpcEndpointConnectionsResult, AWSError>;
  /**
   * Accepts connection requests to your VPC endpoint service.
   */
  acceptVpcEndpointConnections(callback?: (err: AWSError, data: EC2.Types.AcceptVpcEndpointConnectionsResult) => void): Request<EC2.Types.AcceptVpcEndpointConnectionsResult, AWSError>;
  /**
   * Accept a VPC peering connection request. To accept a request, the VPC peering connection must be in the pending-acceptance state, and you must be the owner of the peer VPC. Use DescribeVpcPeeringConnections to view your outstanding VPC peering connection requests. For an inter-Region VPC peering connection request, you must accept the VPC peering connection in the Region of the accepter VPC.
   */
  acceptVpcPeeringConnection(params: EC2.Types.AcceptVpcPeeringConnectionRequest, callback?: (err: AWSError, data: EC2.Types.AcceptVpcPeeringConnectionResult) => void): Request<EC2.Types.AcceptVpcPeeringConnectionResult, AWSError>;
  /**
   * Accept a VPC peering connection request. To accept a request, the VPC peering connection must be in the pending-acceptance state, and you must be the owner of the peer VPC. Use DescribeVpcPeeringConnections to view your outstanding VPC peering connection requests. For an inter-Region VPC peering connection request, you must accept the VPC peering connection in the Region of the accepter VPC.
   */
  acceptVpcPeeringConnection(callback?: (err: AWSError, data: EC2.Types.AcceptVpcPeeringConnectionResult) => void): Request<EC2.Types.AcceptVpcPeeringConnectionResult, AWSError>;
  /**
   * Advertises an IPv4 or IPv6 address range that is provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP). You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. We recommend that you stop advertising the BYOIP CIDR from other locations when you advertise it from Amazon Web Services. To minimize down time, you can configure your Amazon Web Services resources to use an address from a BYOIP CIDR before it is advertised, and then simultaneously stop advertising it from the current location and start advertising it through Amazon Web Services. It can take a few minutes before traffic to the specified addresses starts routing to Amazon Web Services because of BGP propagation delays. To stop advertising the BYOIP CIDR, use WithdrawByoipCidr.
   */
  advertiseByoipCidr(params: EC2.Types.AdvertiseByoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.AdvertiseByoipCidrResult) => void): Request<EC2.Types.AdvertiseByoipCidrResult, AWSError>;
  /**
   * Advertises an IPv4 or IPv6 address range that is provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP). You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. We recommend that you stop advertising the BYOIP CIDR from other locations when you advertise it from Amazon Web Services. To minimize down time, you can configure your Amazon Web Services resources to use an address from a BYOIP CIDR before it is advertised, and then simultaneously stop advertising it from the current location and start advertising it through Amazon Web Services. It can take a few minutes before traffic to the specified addresses starts routing to Amazon Web Services because of BGP propagation delays. To stop advertising the BYOIP CIDR, use WithdrawByoipCidr.
   */
  advertiseByoipCidr(callback?: (err: AWSError, data: EC2.Types.AdvertiseByoipCidrResult) => void): Request<EC2.Types.AdvertiseByoipCidrResult, AWSError>;
  /**
   * Allocates an Elastic IP address to your Amazon Web Services account. After you allocate the Elastic IP address you can associate it with an instance or network interface. After you release an Elastic IP address, it is released to the IP address pool and can be allocated to a different Amazon Web Services account. You can allocate an Elastic IP address from an address pool owned by Amazon Web Services or from an address pool created from a public IPv4 address range that you have brought to Amazon Web Services for use with your Amazon Web Services resources using bring your own IP addresses (BYOIP). For more information, see Bring Your Own IP Addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. [EC2-VPC] If you release an Elastic IP address, you might be able to recover it. You cannot recover an Elastic IP address that you released after it is allocated to another Amazon Web Services account. You cannot recover an Elastic IP address for EC2-Classic. To attempt to recover an Elastic IP address that you released, specify it in this operation. An Elastic IP address is for use either in the EC2-Classic platform or in a VPC. By default, you can allocate 5 Elastic IP addresses for EC2-Classic per Region and 5 Elastic IP addresses for EC2-VPC per Region. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. You can allocate a carrier IP address which is a public IP address from a telecommunication carrier, to a network interface which resides in a subnet in a Wavelength Zone (for example an EC2 instance).   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  allocateAddress(params: EC2.Types.AllocateAddressRequest, callback?: (err: AWSError, data: EC2.Types.AllocateAddressResult) => void): Request<EC2.Types.AllocateAddressResult, AWSError>;
  /**
   * Allocates an Elastic IP address to your Amazon Web Services account. After you allocate the Elastic IP address you can associate it with an instance or network interface. After you release an Elastic IP address, it is released to the IP address pool and can be allocated to a different Amazon Web Services account. You can allocate an Elastic IP address from an address pool owned by Amazon Web Services or from an address pool created from a public IPv4 address range that you have brought to Amazon Web Services for use with your Amazon Web Services resources using bring your own IP addresses (BYOIP). For more information, see Bring Your Own IP Addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. [EC2-VPC] If you release an Elastic IP address, you might be able to recover it. You cannot recover an Elastic IP address that you released after it is allocated to another Amazon Web Services account. You cannot recover an Elastic IP address for EC2-Classic. To attempt to recover an Elastic IP address that you released, specify it in this operation. An Elastic IP address is for use either in the EC2-Classic platform or in a VPC. By default, you can allocate 5 Elastic IP addresses for EC2-Classic per Region and 5 Elastic IP addresses for EC2-VPC per Region. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. You can allocate a carrier IP address which is a public IP address from a telecommunication carrier, to a network interface which resides in a subnet in a Wavelength Zone (for example an EC2 instance).   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  allocateAddress(callback?: (err: AWSError, data: EC2.Types.AllocateAddressResult) => void): Request<EC2.Types.AllocateAddressResult, AWSError>;
  /**
   * Allocates a Dedicated Host to your account. At a minimum, specify the supported instance type or instance family, the Availability Zone in which to allocate the host, and the number of hosts to allocate.
   */
  allocateHosts(params: EC2.Types.AllocateHostsRequest, callback?: (err: AWSError, data: EC2.Types.AllocateHostsResult) => void): Request<EC2.Types.AllocateHostsResult, AWSError>;
  /**
   * Allocates a Dedicated Host to your account. At a minimum, specify the supported instance type or instance family, the Availability Zone in which to allocate the host, and the number of hosts to allocate.
   */
  allocateHosts(callback?: (err: AWSError, data: EC2.Types.AllocateHostsResult) => void): Request<EC2.Types.AllocateHostsResult, AWSError>;
  /**
   * Allocate a CIDR from an IPAM pool. In IPAM, an allocation is a CIDR assignment from an IPAM pool to another IPAM pool or to a resource. For more information, see Allocate CIDRs in the Amazon VPC IPAM User Guide.  This action creates an allocation with strong consistency. The returned CIDR will not overlap with any other allocations from the same pool. 
   */
  allocateIpamPoolCidr(params: EC2.Types.AllocateIpamPoolCidrRequest, callback?: (err: AWSError, data: EC2.Types.AllocateIpamPoolCidrResult) => void): Request<EC2.Types.AllocateIpamPoolCidrResult, AWSError>;
  /**
   * Allocate a CIDR from an IPAM pool. In IPAM, an allocation is a CIDR assignment from an IPAM pool to another IPAM pool or to a resource. For more information, see Allocate CIDRs in the Amazon VPC IPAM User Guide.  This action creates an allocation with strong consistency. The returned CIDR will not overlap with any other allocations from the same pool. 
   */
  allocateIpamPoolCidr(callback?: (err: AWSError, data: EC2.Types.AllocateIpamPoolCidrResult) => void): Request<EC2.Types.AllocateIpamPoolCidrResult, AWSError>;
  /**
   * Applies a security group to the association between the target network and the Client VPN endpoint. This action replaces the existing security groups with the specified security groups.
   */
  applySecurityGroupsToClientVpnTargetNetwork(params: EC2.Types.ApplySecurityGroupsToClientVpnTargetNetworkRequest, callback?: (err: AWSError, data: EC2.Types.ApplySecurityGroupsToClientVpnTargetNetworkResult) => void): Request<EC2.Types.ApplySecurityGroupsToClientVpnTargetNetworkResult, AWSError>;
  /**
   * Applies a security group to the association between the target network and the Client VPN endpoint. This action replaces the existing security groups with the specified security groups.
   */
  applySecurityGroupsToClientVpnTargetNetwork(callback?: (err: AWSError, data: EC2.Types.ApplySecurityGroupsToClientVpnTargetNetworkResult) => void): Request<EC2.Types.ApplySecurityGroupsToClientVpnTargetNetworkResult, AWSError>;
  /**
   * Assigns one or more IPv6 addresses to the specified network interface. You can specify one or more specific IPv6 addresses, or you can specify the number of IPv6 addresses to be automatically assigned from within the subnet's IPv6 CIDR block range. You can assign as many IPv6 addresses to a network interface as you can assign private IPv4 addresses, and the limit varies per instance type. For information, see IP Addresses Per Network Interface Per Instance Type in the Amazon Elastic Compute Cloud User Guide. You must specify either the IPv6 addresses or the IPv6 address count in the request.  You can optionally use Prefix Delegation on the network interface. You must specify either the IPV6 Prefix Delegation prefixes, or the IPv6 Prefix Delegation count. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  assignIpv6Addresses(params: EC2.Types.AssignIpv6AddressesRequest, callback?: (err: AWSError, data: EC2.Types.AssignIpv6AddressesResult) => void): Request<EC2.Types.AssignIpv6AddressesResult, AWSError>;
  /**
   * Assigns one or more IPv6 addresses to the specified network interface. You can specify one or more specific IPv6 addresses, or you can specify the number of IPv6 addresses to be automatically assigned from within the subnet's IPv6 CIDR block range. You can assign as many IPv6 addresses to a network interface as you can assign private IPv4 addresses, and the limit varies per instance type. For information, see IP Addresses Per Network Interface Per Instance Type in the Amazon Elastic Compute Cloud User Guide. You must specify either the IPv6 addresses or the IPv6 address count in the request.  You can optionally use Prefix Delegation on the network interface. You must specify either the IPV6 Prefix Delegation prefixes, or the IPv6 Prefix Delegation count. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  assignIpv6Addresses(callback?: (err: AWSError, data: EC2.Types.AssignIpv6AddressesResult) => void): Request<EC2.Types.AssignIpv6AddressesResult, AWSError>;
  /**
   * Assigns one or more secondary private IP addresses to the specified network interface. You can specify one or more specific secondary IP addresses, or you can specify the number of secondary IP addresses to be automatically assigned within the subnet's CIDR block range. The number of secondary IP addresses that you can assign to an instance varies by instance type. For information about instance types, see Instance Types in the Amazon Elastic Compute Cloud User Guide. For more information about Elastic IP addresses, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. When you move a secondary private IP address to another network interface, any Elastic IP address that is associated with the IP address is also moved. Remapping an IP address is an asynchronous operation. When you move an IP address from one network interface to another, check network/interfaces/macs/mac/local-ipv4s in the instance metadata to confirm that the remapping is complete. You must specify either the IP addresses or the IP address count in the request. You can optionally use Prefix Delegation on the network interface. You must specify either the IPv4 Prefix Delegation prefixes, or the IPv4 Prefix Delegation count. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  assignPrivateIpAddresses(params: EC2.Types.AssignPrivateIpAddressesRequest, callback?: (err: AWSError, data: EC2.Types.AssignPrivateIpAddressesResult) => void): Request<EC2.Types.AssignPrivateIpAddressesResult, AWSError>;
  /**
   * Assigns one or more secondary private IP addresses to the specified network interface. You can specify one or more specific secondary IP addresses, or you can specify the number of secondary IP addresses to be automatically assigned within the subnet's CIDR block range. The number of secondary IP addresses that you can assign to an instance varies by instance type. For information about instance types, see Instance Types in the Amazon Elastic Compute Cloud User Guide. For more information about Elastic IP addresses, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. When you move a secondary private IP address to another network interface, any Elastic IP address that is associated with the IP address is also moved. Remapping an IP address is an asynchronous operation. When you move an IP address from one network interface to another, check network/interfaces/macs/mac/local-ipv4s in the instance metadata to confirm that the remapping is complete. You must specify either the IP addresses or the IP address count in the request. You can optionally use Prefix Delegation on the network interface. You must specify either the IPv4 Prefix Delegation prefixes, or the IPv4 Prefix Delegation count. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  assignPrivateIpAddresses(callback?: (err: AWSError, data: EC2.Types.AssignPrivateIpAddressesResult) => void): Request<EC2.Types.AssignPrivateIpAddressesResult, AWSError>;
  /**
   * Assigns one or more private IPv4 addresses to a private NAT gateway. For more information, see Work with NAT gateways in the Amazon Virtual Private Cloud User Guide.
   */
  assignPrivateNatGatewayAddress(params: EC2.Types.AssignPrivateNatGatewayAddressRequest, callback?: (err: AWSError, data: EC2.Types.AssignPrivateNatGatewayAddressResult) => void): Request<EC2.Types.AssignPrivateNatGatewayAddressResult, AWSError>;
  /**
   * Assigns one or more private IPv4 addresses to a private NAT gateway. For more information, see Work with NAT gateways in the Amazon Virtual Private Cloud User Guide.
   */
  assignPrivateNatGatewayAddress(callback?: (err: AWSError, data: EC2.Types.AssignPrivateNatGatewayAddressResult) => void): Request<EC2.Types.AssignPrivateNatGatewayAddressResult, AWSError>;
  /**
   * Associates an Elastic IP address, or carrier IP address (for instances that are in subnets in Wavelength Zones) with an instance or a network interface. Before you can use an Elastic IP address, you must allocate it to your account. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. [EC2-Classic, VPC in an EC2-VPC-only account] If the Elastic IP address is already associated with a different instance, it is disassociated from that instance and associated with the specified instance. If you associate an Elastic IP address with an instance that has an existing Elastic IP address, the existing address is disassociated from the instance, but remains allocated to your account. [VPC in an EC2-Classic account] If you don't specify a private IP address, the Elastic IP address is associated with the primary IP address. If the Elastic IP address is already associated with a different instance or a network interface, you get an error unless you allow reassociation. You cannot associate an Elastic IP address with an instance or network interface that has an existing Elastic IP address. [Subnets in Wavelength Zones] You can associate an IP address from the telecommunication carrier to the instance or network interface.  You cannot associate an Elastic IP address with an interface in a different network border group.  This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error, and you may be charged for each time the Elastic IP address is remapped to the same instance. For more information, see the Elastic IP Addresses section of Amazon EC2 Pricing.   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  associateAddress(params: EC2.Types.AssociateAddressRequest, callback?: (err: AWSError, data: EC2.Types.AssociateAddressResult) => void): Request<EC2.Types.AssociateAddressResult, AWSError>;
  /**
   * Associates an Elastic IP address, or carrier IP address (for instances that are in subnets in Wavelength Zones) with an instance or a network interface. Before you can use an Elastic IP address, you must allocate it to your account. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide. [EC2-Classic, VPC in an EC2-VPC-only account] If the Elastic IP address is already associated with a different instance, it is disassociated from that instance and associated with the specified instance. If you associate an Elastic IP address with an instance that has an existing Elastic IP address, the existing address is disassociated from the instance, but remains allocated to your account. [VPC in an EC2-Classic account] If you don't specify a private IP address, the Elastic IP address is associated with the primary IP address. If the Elastic IP address is already associated with a different instance or a network interface, you get an error unless you allow reassociation. You cannot associate an Elastic IP address with an instance or network interface that has an existing Elastic IP address. [Subnets in Wavelength Zones] You can associate an IP address from the telecommunication carrier to the instance or network interface.  You cannot associate an Elastic IP address with an interface in a different network border group.  This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error, and you may be charged for each time the Elastic IP address is remapped to the same instance. For more information, see the Elastic IP Addresses section of Amazon EC2 Pricing.   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  associateAddress(callback?: (err: AWSError, data: EC2.Types.AssociateAddressResult) => void): Request<EC2.Types.AssociateAddressResult, AWSError>;
  /**
   * Associates a target network with a Client VPN endpoint. A target network is a subnet in a VPC. You can associate multiple subnets from the same VPC with a Client VPN endpoint. You can associate only one subnet in each Availability Zone. We recommend that you associate at least two subnets to provide Availability Zone redundancy. If you specified a VPC when you created the Client VPN endpoint or if you have previous subnet associations, the specified subnet must be in the same VPC. To specify a subnet that's in a different VPC, you must first modify the Client VPN endpoint (ModifyClientVpnEndpoint) and change the VPC that's associated with it.
   */
  associateClientVpnTargetNetwork(params: EC2.Types.AssociateClientVpnTargetNetworkRequest, callback?: (err: AWSError, data: EC2.Types.AssociateClientVpnTargetNetworkResult) => void): Request<EC2.Types.AssociateClientVpnTargetNetworkResult, AWSError>;
  /**
   * Associates a target network with a Client VPN endpoint. A target network is a subnet in a VPC. You can associate multiple subnets from the same VPC with a Client VPN endpoint. You can associate only one subnet in each Availability Zone. We recommend that you associate at least two subnets to provide Availability Zone redundancy. If you specified a VPC when you created the Client VPN endpoint or if you have previous subnet associations, the specified subnet must be in the same VPC. To specify a subnet that's in a different VPC, you must first modify the Client VPN endpoint (ModifyClientVpnEndpoint) and change the VPC that's associated with it.
   */
  associateClientVpnTargetNetwork(callback?: (err: AWSError, data: EC2.Types.AssociateClientVpnTargetNetworkResult) => void): Request<EC2.Types.AssociateClientVpnTargetNetworkResult, AWSError>;
  /**
   * Associates a set of DHCP options (that you've previously created) with the specified VPC, or associates no DHCP options with the VPC. After you associate the options with the VPC, any existing instances and all new instances that you launch in that VPC use the options. You don't need to restart or relaunch the instances. They automatically pick up the changes within a few hours, depending on how frequently the instance renews its DHCP lease. You can explicitly renew the lease using the operating system on the instance. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  associateDhcpOptions(params: EC2.Types.AssociateDhcpOptionsRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Associates a set of DHCP options (that you've previously created) with the specified VPC, or associates no DHCP options with the VPC. After you associate the options with the VPC, any existing instances and all new instances that you launch in that VPC use the options. You don't need to restart or relaunch the instances. They automatically pick up the changes within a few hours, depending on how frequently the instance renews its DHCP lease. You can explicitly renew the lease using the operating system on the instance. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  associateDhcpOptions(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Associates an Identity and Access Management (IAM) role with an Certificate Manager (ACM) certificate. This enables the certificate to be used by the ACM for Nitro Enclaves application inside an enclave. For more information, see Certificate Manager for Nitro Enclaves in the Amazon Web Services Nitro Enclaves User Guide. When the IAM role is associated with the ACM certificate, the certificate, certificate chain, and encrypted private key are placed in an Amazon S3 location that only the associated IAM role can access. The private key of the certificate is encrypted with an Amazon Web Services managed key that has an attached attestation-based key policy. To enable the IAM role to access the Amazon S3 object, you must grant it permission to call s3:GetObject on the Amazon S3 bucket returned by the command. To enable the IAM role to access the KMS key, you must grant it permission to call kms:Decrypt on the KMS key returned by the command. For more information, see  Grant the role permission to access the certificate and encryption key in the Amazon Web Services Nitro Enclaves User Guide.
   */
  associateEnclaveCertificateIamRole(params: EC2.Types.AssociateEnclaveCertificateIamRoleRequest, callback?: (err: AWSError, data: EC2.Types.AssociateEnclaveCertificateIamRoleResult) => void): Request<EC2.Types.AssociateEnclaveCertificateIamRoleResult, AWSError>;
  /**
   * Associates an Identity and Access Management (IAM) role with an Certificate Manager (ACM) certificate. This enables the certificate to be used by the ACM for Nitro Enclaves application inside an enclave. For more information, see Certificate Manager for Nitro Enclaves in the Amazon Web Services Nitro Enclaves User Guide. When the IAM role is associated with the ACM certificate, the certificate, certificate chain, and encrypted private key are placed in an Amazon S3 location that only the associated IAM role can access. The private key of the certificate is encrypted with an Amazon Web Services managed key that has an attached attestation-based key policy. To enable the IAM role to access the Amazon S3 object, you must grant it permission to call s3:GetObject on the Amazon S3 bucket returned by the command. To enable the IAM role to access the KMS key, you must grant it permission to call kms:Decrypt on the KMS key returned by the command. For more information, see  Grant the role permission to access the certificate and encryption key in the Amazon Web Services Nitro Enclaves User Guide.
   */
  associateEnclaveCertificateIamRole(callback?: (err: AWSError, data: EC2.Types.AssociateEnclaveCertificateIamRoleResult) => void): Request<EC2.Types.AssociateEnclaveCertificateIamRoleResult, AWSError>;
  /**
   * Associates an IAM instance profile with a running or stopped instance. You cannot associate more than one IAM instance profile with an instance.
   */
  associateIamInstanceProfile(params: EC2.Types.AssociateIamInstanceProfileRequest, callback?: (err: AWSError, data: EC2.Types.AssociateIamInstanceProfileResult) => void): Request<EC2.Types.AssociateIamInstanceProfileResult, AWSError>;
  /**
   * Associates an IAM instance profile with a running or stopped instance. You cannot associate more than one IAM instance profile with an instance.
   */
  associateIamInstanceProfile(callback?: (err: AWSError, data: EC2.Types.AssociateIamInstanceProfileResult) => void): Request<EC2.Types.AssociateIamInstanceProfileResult, AWSError>;
  /**
   * Associates one or more targets with an event window. Only one type of target (instance IDs, Dedicated Host IDs, or tags) can be specified with an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  associateInstanceEventWindow(params: EC2.Types.AssociateInstanceEventWindowRequest, callback?: (err: AWSError, data: EC2.Types.AssociateInstanceEventWindowResult) => void): Request<EC2.Types.AssociateInstanceEventWindowResult, AWSError>;
  /**
   * Associates one or more targets with an event window. Only one type of target (instance IDs, Dedicated Host IDs, or tags) can be specified with an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  associateInstanceEventWindow(callback?: (err: AWSError, data: EC2.Types.AssociateInstanceEventWindowResult) => void): Request<EC2.Types.AssociateInstanceEventWindowResult, AWSError>;
  /**
   * Associates an IPAM resource discovery with an Amazon VPC IPAM. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  associateIpamResourceDiscovery(params: EC2.Types.AssociateIpamResourceDiscoveryRequest, callback?: (err: AWSError, data: EC2.Types.AssociateIpamResourceDiscoveryResult) => void): Request<EC2.Types.AssociateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Associates an IPAM resource discovery with an Amazon VPC IPAM. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  associateIpamResourceDiscovery(callback?: (err: AWSError, data: EC2.Types.AssociateIpamResourceDiscoveryResult) => void): Request<EC2.Types.AssociateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Associates Elastic IP addresses (EIPs) and private IPv4 addresses with a public NAT gateway. For more information, see Work with NAT gateways in the Amazon Virtual Private Cloud User Guide. By default, you can associate up to 2 Elastic IP addresses per public NAT gateway. You can increase the limit by requesting a quota adjustment. For more information, see Elastic IP address quotas in the Amazon Virtual Private Cloud User Guide.
   */
  associateNatGatewayAddress(params: EC2.Types.AssociateNatGatewayAddressRequest, callback?: (err: AWSError, data: EC2.Types.AssociateNatGatewayAddressResult) => void): Request<EC2.Types.AssociateNatGatewayAddressResult, AWSError>;
  /**
   * Associates Elastic IP addresses (EIPs) and private IPv4 addresses with a public NAT gateway. For more information, see Work with NAT gateways in the Amazon Virtual Private Cloud User Guide. By default, you can associate up to 2 Elastic IP addresses per public NAT gateway. You can increase the limit by requesting a quota adjustment. For more information, see Elastic IP address quotas in the Amazon Virtual Private Cloud User Guide.
   */
  associateNatGatewayAddress(callback?: (err: AWSError, data: EC2.Types.AssociateNatGatewayAddressResult) => void): Request<EC2.Types.AssociateNatGatewayAddressResult, AWSError>;
  /**
   * Associates a subnet in your VPC or an internet gateway or virtual private gateway attached to your VPC with a route table in your VPC. This association causes traffic from the subnet or gateway to be routed according to the routes in the route table. The action returns an association ID, which you need in order to disassociate the route table later. A route table can be associated with multiple subnets. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  associateRouteTable(params: EC2.Types.AssociateRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.AssociateRouteTableResult) => void): Request<EC2.Types.AssociateRouteTableResult, AWSError>;
  /**
   * Associates a subnet in your VPC or an internet gateway or virtual private gateway attached to your VPC with a route table in your VPC. This association causes traffic from the subnet or gateway to be routed according to the routes in the route table. The action returns an association ID, which you need in order to disassociate the route table later. A route table can be associated with multiple subnets. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  associateRouteTable(callback?: (err: AWSError, data: EC2.Types.AssociateRouteTableResult) => void): Request<EC2.Types.AssociateRouteTableResult, AWSError>;
  /**
   * Associates a CIDR block with your subnet. You can only associate a single IPv6 CIDR block with your subnet. An IPv6 CIDR block must have a prefix length of /64.
   */
  associateSubnetCidrBlock(params: EC2.Types.AssociateSubnetCidrBlockRequest, callback?: (err: AWSError, data: EC2.Types.AssociateSubnetCidrBlockResult) => void): Request<EC2.Types.AssociateSubnetCidrBlockResult, AWSError>;
  /**
   * Associates a CIDR block with your subnet. You can only associate a single IPv6 CIDR block with your subnet. An IPv6 CIDR block must have a prefix length of /64.
   */
  associateSubnetCidrBlock(callback?: (err: AWSError, data: EC2.Types.AssociateSubnetCidrBlockResult) => void): Request<EC2.Types.AssociateSubnetCidrBlockResult, AWSError>;
  /**
   * Associates the specified subnets and transit gateway attachments with the specified transit gateway multicast domain. The transit gateway attachment must be in the available state before you can add a resource. Use DescribeTransitGatewayAttachments to see the state of the attachment.
   */
  associateTransitGatewayMulticastDomain(params: EC2.Types.AssociateTransitGatewayMulticastDomainRequest, callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.AssociateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Associates the specified subnets and transit gateway attachments with the specified transit gateway multicast domain. The transit gateway attachment must be in the available state before you can add a resource. Use DescribeTransitGatewayAttachments to see the state of the attachment.
   */
  associateTransitGatewayMulticastDomain(callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.AssociateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Associates the specified transit gateway attachment with a transit gateway policy table.
   */
  associateTransitGatewayPolicyTable(params: EC2.Types.AssociateTransitGatewayPolicyTableRequest, callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.AssociateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Associates the specified transit gateway attachment with a transit gateway policy table.
   */
  associateTransitGatewayPolicyTable(callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.AssociateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Associates the specified attachment with the specified transit gateway route table. You can associate only one route table with an attachment.
   */
  associateTransitGatewayRouteTable(params: EC2.Types.AssociateTransitGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayRouteTableResult) => void): Request<EC2.Types.AssociateTransitGatewayRouteTableResult, AWSError>;
  /**
   * Associates the specified attachment with the specified transit gateway route table. You can associate only one route table with an attachment.
   */
  associateTransitGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.AssociateTransitGatewayRouteTableResult) => void): Request<EC2.Types.AssociateTransitGatewayRouteTableResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Associates a branch network interface with a trunk network interface. Before you create the association, run the create-network-interface command and set --interface-type to trunk. You must also create a network interface for each branch network interface that you want to associate with the trunk network interface.
   */
  associateTrunkInterface(params: EC2.Types.AssociateTrunkInterfaceRequest, callback?: (err: AWSError, data: EC2.Types.AssociateTrunkInterfaceResult) => void): Request<EC2.Types.AssociateTrunkInterfaceResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Associates a branch network interface with a trunk network interface. Before you create the association, run the create-network-interface command and set --interface-type to trunk. You must also create a network interface for each branch network interface that you want to associate with the trunk network interface.
   */
  associateTrunkInterface(callback?: (err: AWSError, data: EC2.Types.AssociateTrunkInterfaceResult) => void): Request<EC2.Types.AssociateTrunkInterfaceResult, AWSError>;
  /**
   * Associates a CIDR block with your VPC. You can associate a secondary IPv4 CIDR block, an Amazon-provided IPv6 CIDR block, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). The IPv6 CIDR block size is fixed at /56. You must specify one of the following in the request: an IPv4 CIDR block, an IPv6 pool, or an Amazon-provided IPv6 CIDR block. For more information about associating CIDR blocks with your VPC and applicable restrictions, see VPC and subnet sizing in the Amazon Virtual Private Cloud User Guide.
   */
  associateVpcCidrBlock(params: EC2.Types.AssociateVpcCidrBlockRequest, callback?: (err: AWSError, data: EC2.Types.AssociateVpcCidrBlockResult) => void): Request<EC2.Types.AssociateVpcCidrBlockResult, AWSError>;
  /**
   * Associates a CIDR block with your VPC. You can associate a secondary IPv4 CIDR block, an Amazon-provided IPv6 CIDR block, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). The IPv6 CIDR block size is fixed at /56. You must specify one of the following in the request: an IPv4 CIDR block, an IPv6 pool, or an Amazon-provided IPv6 CIDR block. For more information about associating CIDR blocks with your VPC and applicable restrictions, see VPC and subnet sizing in the Amazon Virtual Private Cloud User Guide.
   */
  associateVpcCidrBlock(callback?: (err: AWSError, data: EC2.Types.AssociateVpcCidrBlockResult) => void): Request<EC2.Types.AssociateVpcCidrBlockResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Links an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups. You cannot link an EC2-Classic instance to more than one VPC at a time. You can only link an instance that's in the running state. An instance is automatically unlinked from a VPC when it's stopped - you can link it to the VPC again when you restart it. After you've linked an instance, you cannot change the VPC security groups that are associated with it. To change the security groups, you must first unlink the instance, and then link it again. Linking your instance to a VPC is sometimes referred to as attaching your instance.
   */
  attachClassicLinkVpc(params: EC2.Types.AttachClassicLinkVpcRequest, callback?: (err: AWSError, data: EC2.Types.AttachClassicLinkVpcResult) => void): Request<EC2.Types.AttachClassicLinkVpcResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Links an EC2-Classic instance to a ClassicLink-enabled VPC through one or more of the VPC's security groups. You cannot link an EC2-Classic instance to more than one VPC at a time. You can only link an instance that's in the running state. An instance is automatically unlinked from a VPC when it's stopped - you can link it to the VPC again when you restart it. After you've linked an instance, you cannot change the VPC security groups that are associated with it. To change the security groups, you must first unlink the instance, and then link it again. Linking your instance to a VPC is sometimes referred to as attaching your instance.
   */
  attachClassicLinkVpc(callback?: (err: AWSError, data: EC2.Types.AttachClassicLinkVpcResult) => void): Request<EC2.Types.AttachClassicLinkVpcResult, AWSError>;
  /**
   * Attaches an internet gateway or a virtual private gateway to a VPC, enabling connectivity between the internet and the VPC. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.
   */
  attachInternetGateway(params: EC2.Types.AttachInternetGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Attaches an internet gateway or a virtual private gateway to a VPC, enabling connectivity between the internet and the VPC. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.
   */
  attachInternetGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Attaches a network interface to an instance.
   */
  attachNetworkInterface(params: EC2.Types.AttachNetworkInterfaceRequest, callback?: (err: AWSError, data: EC2.Types.AttachNetworkInterfaceResult) => void): Request<EC2.Types.AttachNetworkInterfaceResult, AWSError>;
  /**
   * Attaches a network interface to an instance.
   */
  attachNetworkInterface(callback?: (err: AWSError, data: EC2.Types.AttachNetworkInterfaceResult) => void): Request<EC2.Types.AttachNetworkInterfaceResult, AWSError>;
  /**
   * A trust provider is a third-party entity that creates, maintains, and manages identity information for users and devices. One or more trust providers can be attached to an Amazon Web Services Verified Access instance.
   */
  attachVerifiedAccessTrustProvider(params: EC2.Types.AttachVerifiedAccessTrustProviderRequest, callback?: (err: AWSError, data: EC2.Types.AttachVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.AttachVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * A trust provider is a third-party entity that creates, maintains, and manages identity information for users and devices. One or more trust providers can be attached to an Amazon Web Services Verified Access instance.
   */
  attachVerifiedAccessTrustProvider(callback?: (err: AWSError, data: EC2.Types.AttachVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.AttachVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Attaches an EBS volume to a running or stopped instance and exposes it to the instance with the specified device name. Encrypted EBS volumes must be attached to instances that support Amazon EBS encryption. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. After you attach an EBS volume, you must make it available. For more information, see Make an EBS volume available for use. If a volume has an Amazon Web Services Marketplace product code:   The volume can be attached only to a stopped instance.   Amazon Web Services Marketplace product codes are copied from the volume to the instance.   You must be subscribed to the product.   The instance type and operating system of the instance must support the product. For example, you can't detach a volume from a Windows instance and attach it to a Linux instance.   For more information, see Attach an Amazon EBS volume to an instance in the Amazon Elastic Compute Cloud User Guide.
   */
  attachVolume(params: EC2.Types.AttachVolumeRequest, callback?: (err: AWSError, data: EC2.Types.VolumeAttachment) => void): Request<EC2.Types.VolumeAttachment, AWSError>;
  /**
   * Attaches an EBS volume to a running or stopped instance and exposes it to the instance with the specified device name. Encrypted EBS volumes must be attached to instances that support Amazon EBS encryption. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. After you attach an EBS volume, you must make it available. For more information, see Make an EBS volume available for use. If a volume has an Amazon Web Services Marketplace product code:   The volume can be attached only to a stopped instance.   Amazon Web Services Marketplace product codes are copied from the volume to the instance.   You must be subscribed to the product.   The instance type and operating system of the instance must support the product. For example, you can't detach a volume from a Windows instance and attach it to a Linux instance.   For more information, see Attach an Amazon EBS volume to an instance in the Amazon Elastic Compute Cloud User Guide.
   */
  attachVolume(callback?: (err: AWSError, data: EC2.Types.VolumeAttachment) => void): Request<EC2.Types.VolumeAttachment, AWSError>;
  /**
   * Attaches a virtual private gateway to a VPC. You can attach one virtual private gateway to one VPC at a time. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  attachVpnGateway(params: EC2.Types.AttachVpnGatewayRequest, callback?: (err: AWSError, data: EC2.Types.AttachVpnGatewayResult) => void): Request<EC2.Types.AttachVpnGatewayResult, AWSError>;
  /**
   * Attaches a virtual private gateway to a VPC. You can attach one virtual private gateway to one VPC at a time. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  attachVpnGateway(callback?: (err: AWSError, data: EC2.Types.AttachVpnGatewayResult) => void): Request<EC2.Types.AttachVpnGatewayResult, AWSError>;
  /**
   * Adds an ingress authorization rule to a Client VPN endpoint. Ingress authorization rules act as firewall rules that grant access to networks. You must configure ingress authorization rules to enable clients to access resources in Amazon Web Services or on-premises networks.
   */
  authorizeClientVpnIngress(params: EC2.Types.AuthorizeClientVpnIngressRequest, callback?: (err: AWSError, data: EC2.Types.AuthorizeClientVpnIngressResult) => void): Request<EC2.Types.AuthorizeClientVpnIngressResult, AWSError>;
  /**
   * Adds an ingress authorization rule to a Client VPN endpoint. Ingress authorization rules act as firewall rules that grant access to networks. You must configure ingress authorization rules to enable clients to access resources in Amazon Web Services or on-premises networks.
   */
  authorizeClientVpnIngress(callback?: (err: AWSError, data: EC2.Types.AuthorizeClientVpnIngressResult) => void): Request<EC2.Types.AuthorizeClientVpnIngressResult, AWSError>;
  /**
   * [VPC only] Adds the specified outbound (egress) rules to a security group for use with a VPC. An outbound rule permits instances to send traffic to the specified IPv4 or IPv6 CIDR address ranges, or to the instances that are associated with the specified source security groups. When specifying an outbound rule for your security group in a VPC, the IpPermissions must include a destination for the traffic. You specify a protocol for each rule (for example, TCP). For the TCP and UDP protocols, you must also specify the destination port or port range. For the ICMP protocol, you must also specify the ICMP type and code. You can use -1 for the type or code to mean all types or all codes. Rule changes are propagated to affected instances as quickly as possible. However, a small delay might occur. For information about VPC security group quotas, see Amazon VPC quotas.
   */
  authorizeSecurityGroupEgress(params: EC2.Types.AuthorizeSecurityGroupEgressRequest, callback?: (err: AWSError, data: EC2.Types.AuthorizeSecurityGroupEgressResult) => void): Request<EC2.Types.AuthorizeSecurityGroupEgressResult, AWSError>;
  /**
   * [VPC only] Adds the specified outbound (egress) rules to a security group for use with a VPC. An outbound rule permits instances to send traffic to the specified IPv4 or IPv6 CIDR address ranges, or to the instances that are associated with the specified source security groups. When specifying an outbound rule for your security group in a VPC, the IpPermissions must include a destination for the traffic. You specify a protocol for each rule (for example, TCP). For the TCP and UDP protocols, you must also specify the destination port or port range. For the ICMP protocol, you must also specify the ICMP type and code. You can use -1 for the type or code to mean all types or all codes. Rule changes are propagated to affected instances as quickly as possible. However, a small delay might occur. For information about VPC security group quotas, see Amazon VPC quotas.
   */
  authorizeSecurityGroupEgress(callback?: (err: AWSError, data: EC2.Types.AuthorizeSecurityGroupEgressResult) => void): Request<EC2.Types.AuthorizeSecurityGroupEgressResult, AWSError>;
  /**
   * Adds the specified inbound (ingress) rules to a security group. An inbound rule permits instances to receive traffic from the specified IPv4 or IPv6 CIDR address range, or from the instances that are associated with the specified destination security groups. When specifying an inbound rule for your security group in a VPC, the IpPermissions must include a source for the traffic. You specify a protocol for each rule (for example, TCP). For TCP and UDP, you must also specify the destination port or port range. For ICMP/ICMPv6, you must also specify the ICMP/ICMPv6 type and code. You can use -1 to mean all types or all codes. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur. For more information about VPC security group quotas, see Amazon VPC quotas.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  authorizeSecurityGroupIngress(params: EC2.Types.AuthorizeSecurityGroupIngressRequest, callback?: (err: AWSError, data: EC2.Types.AuthorizeSecurityGroupIngressResult) => void): Request<EC2.Types.AuthorizeSecurityGroupIngressResult, AWSError>;
  /**
   * Adds the specified inbound (ingress) rules to a security group. An inbound rule permits instances to receive traffic from the specified IPv4 or IPv6 CIDR address range, or from the instances that are associated with the specified destination security groups. When specifying an inbound rule for your security group in a VPC, the IpPermissions must include a source for the traffic. You specify a protocol for each rule (for example, TCP). For TCP and UDP, you must also specify the destination port or port range. For ICMP/ICMPv6, you must also specify the ICMP/ICMPv6 type and code. You can use -1 to mean all types or all codes. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur. For more information about VPC security group quotas, see Amazon VPC quotas.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  authorizeSecurityGroupIngress(callback?: (err: AWSError, data: EC2.Types.AuthorizeSecurityGroupIngressResult) => void): Request<EC2.Types.AuthorizeSecurityGroupIngressResult, AWSError>;
  /**
   * Bundles an Amazon instance store-backed Windows instance. During bundling, only the root device volume (C:\) is bundled. Data on other instance store volumes is not preserved.  This action is not applicable for Linux/Unix instances or Windows instances that are backed by Amazon EBS. 
   */
  bundleInstance(params: EC2.Types.BundleInstanceRequest, callback?: (err: AWSError, data: EC2.Types.BundleInstanceResult) => void): Request<EC2.Types.BundleInstanceResult, AWSError>;
  /**
   * Bundles an Amazon instance store-backed Windows instance. During bundling, only the root device volume (C:\) is bundled. Data on other instance store volumes is not preserved.  This action is not applicable for Linux/Unix instances or Windows instances that are backed by Amazon EBS. 
   */
  bundleInstance(callback?: (err: AWSError, data: EC2.Types.BundleInstanceResult) => void): Request<EC2.Types.BundleInstanceResult, AWSError>;
  /**
   * Cancels a bundling operation for an instance store-backed Windows instance.
   */
  cancelBundleTask(params: EC2.Types.CancelBundleTaskRequest, callback?: (err: AWSError, data: EC2.Types.CancelBundleTaskResult) => void): Request<EC2.Types.CancelBundleTaskResult, AWSError>;
  /**
   * Cancels a bundling operation for an instance store-backed Windows instance.
   */
  cancelBundleTask(callback?: (err: AWSError, data: EC2.Types.CancelBundleTaskResult) => void): Request<EC2.Types.CancelBundleTaskResult, AWSError>;
  /**
   * Cancels the specified Capacity Reservation, releases the reserved capacity, and changes the Capacity Reservation's state to cancelled. Instances running in the reserved capacity continue running until you stop them. Stopped instances that target the Capacity Reservation can no longer launch. Modify these instances to either target a different Capacity Reservation, launch On-Demand Instance capacity, or run in any open Capacity Reservation that has matching attributes and sufficient capacity.
   */
  cancelCapacityReservation(params: EC2.Types.CancelCapacityReservationRequest, callback?: (err: AWSError, data: EC2.Types.CancelCapacityReservationResult) => void): Request<EC2.Types.CancelCapacityReservationResult, AWSError>;
  /**
   * Cancels the specified Capacity Reservation, releases the reserved capacity, and changes the Capacity Reservation's state to cancelled. Instances running in the reserved capacity continue running until you stop them. Stopped instances that target the Capacity Reservation can no longer launch. Modify these instances to either target a different Capacity Reservation, launch On-Demand Instance capacity, or run in any open Capacity Reservation that has matching attributes and sufficient capacity.
   */
  cancelCapacityReservation(callback?: (err: AWSError, data: EC2.Types.CancelCapacityReservationResult) => void): Request<EC2.Types.CancelCapacityReservationResult, AWSError>;
  /**
   * Cancels one or more Capacity Reservation Fleets. When you cancel a Capacity Reservation Fleet, the following happens:   The Capacity Reservation Fleet's status changes to cancelled.   The individual Capacity Reservations in the Fleet are cancelled. Instances running in the Capacity Reservations at the time of cancelling the Fleet continue to run in shared capacity.   The Fleet stops creating new Capacity Reservations.  
   */
  cancelCapacityReservationFleets(params: EC2.Types.CancelCapacityReservationFleetsRequest, callback?: (err: AWSError, data: EC2.Types.CancelCapacityReservationFleetsResult) => void): Request<EC2.Types.CancelCapacityReservationFleetsResult, AWSError>;
  /**
   * Cancels one or more Capacity Reservation Fleets. When you cancel a Capacity Reservation Fleet, the following happens:   The Capacity Reservation Fleet's status changes to cancelled.   The individual Capacity Reservations in the Fleet are cancelled. Instances running in the Capacity Reservations at the time of cancelling the Fleet continue to run in shared capacity.   The Fleet stops creating new Capacity Reservations.  
   */
  cancelCapacityReservationFleets(callback?: (err: AWSError, data: EC2.Types.CancelCapacityReservationFleetsResult) => void): Request<EC2.Types.CancelCapacityReservationFleetsResult, AWSError>;
  /**
   * Cancels an active conversion task. The task can be the import of an instance or volume. The action removes all artifacts of the conversion, including a partially uploaded volume or instance. If the conversion is complete or is in the process of transferring the final disk image, the command fails and returns an exception. For more information, see Importing a Virtual Machine Using the Amazon EC2 CLI.
   */
  cancelConversionTask(params: EC2.Types.CancelConversionRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Cancels an active conversion task. The task can be the import of an instance or volume. The action removes all artifacts of the conversion, including a partially uploaded volume or instance. If the conversion is complete or is in the process of transferring the final disk image, the command fails and returns an exception. For more information, see Importing a Virtual Machine Using the Amazon EC2 CLI.
   */
  cancelConversionTask(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Cancels an active export task. The request removes all artifacts of the export, including any partially-created Amazon S3 objects. If the export task is complete or is in the process of transferring the final disk image, the command fails and returns an error.
   */
  cancelExportTask(params: EC2.Types.CancelExportTaskRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Cancels an active export task. The request removes all artifacts of the export, including any partially-created Amazon S3 objects. If the export task is complete or is in the process of transferring the final disk image, the command fails and returns an error.
   */
  cancelExportTask(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Removes your Amazon Web Services account from the launch permissions for the specified AMI. For more information, see  Cancel having an AMI shared with your Amazon Web Services account in the Amazon EC2 User Guide.
   */
  cancelImageLaunchPermission(params: EC2.Types.CancelImageLaunchPermissionRequest, callback?: (err: AWSError, data: EC2.Types.CancelImageLaunchPermissionResult) => void): Request<EC2.Types.CancelImageLaunchPermissionResult, AWSError>;
  /**
   * Removes your Amazon Web Services account from the launch permissions for the specified AMI. For more information, see  Cancel having an AMI shared with your Amazon Web Services account in the Amazon EC2 User Guide.
   */
  cancelImageLaunchPermission(callback?: (err: AWSError, data: EC2.Types.CancelImageLaunchPermissionResult) => void): Request<EC2.Types.CancelImageLaunchPermissionResult, AWSError>;
  /**
   * Cancels an in-process import virtual machine or import snapshot task.
   */
  cancelImportTask(params: EC2.Types.CancelImportTaskRequest, callback?: (err: AWSError, data: EC2.Types.CancelImportTaskResult) => void): Request<EC2.Types.CancelImportTaskResult, AWSError>;
  /**
   * Cancels an in-process import virtual machine or import snapshot task.
   */
  cancelImportTask(callback?: (err: AWSError, data: EC2.Types.CancelImportTaskResult) => void): Request<EC2.Types.CancelImportTaskResult, AWSError>;
  /**
   * Cancels the specified Reserved Instance listing in the Reserved Instance Marketplace. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  cancelReservedInstancesListing(params: EC2.Types.CancelReservedInstancesListingRequest, callback?: (err: AWSError, data: EC2.Types.CancelReservedInstancesListingResult) => void): Request<EC2.Types.CancelReservedInstancesListingResult, AWSError>;
  /**
   * Cancels the specified Reserved Instance listing in the Reserved Instance Marketplace. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  cancelReservedInstancesListing(callback?: (err: AWSError, data: EC2.Types.CancelReservedInstancesListingResult) => void): Request<EC2.Types.CancelReservedInstancesListingResult, AWSError>;
  /**
   * Cancels the specified Spot Fleet requests. After you cancel a Spot Fleet request, the Spot Fleet launches no new instances. You must also specify whether a canceled Spot Fleet request should terminate its instances. If you choose to terminate the instances, the Spot Fleet request enters the cancelled_terminating state. Otherwise, the Spot Fleet request enters the cancelled_running state and the instances continue to run until they are interrupted or you terminate them manually.
   */
  cancelSpotFleetRequests(params: EC2.Types.CancelSpotFleetRequestsRequest, callback?: (err: AWSError, data: EC2.Types.CancelSpotFleetRequestsResponse) => void): Request<EC2.Types.CancelSpotFleetRequestsResponse, AWSError>;
  /**
   * Cancels the specified Spot Fleet requests. After you cancel a Spot Fleet request, the Spot Fleet launches no new instances. You must also specify whether a canceled Spot Fleet request should terminate its instances. If you choose to terminate the instances, the Spot Fleet request enters the cancelled_terminating state. Otherwise, the Spot Fleet request enters the cancelled_running state and the instances continue to run until they are interrupted or you terminate them manually.
   */
  cancelSpotFleetRequests(callback?: (err: AWSError, data: EC2.Types.CancelSpotFleetRequestsResponse) => void): Request<EC2.Types.CancelSpotFleetRequestsResponse, AWSError>;
  /**
   * Cancels one or more Spot Instance requests.  Canceling a Spot Instance request does not terminate running Spot Instances associated with the request. 
   */
  cancelSpotInstanceRequests(params: EC2.Types.CancelSpotInstanceRequestsRequest, callback?: (err: AWSError, data: EC2.Types.CancelSpotInstanceRequestsResult) => void): Request<EC2.Types.CancelSpotInstanceRequestsResult, AWSError>;
  /**
   * Cancels one or more Spot Instance requests.  Canceling a Spot Instance request does not terminate running Spot Instances associated with the request. 
   */
  cancelSpotInstanceRequests(callback?: (err: AWSError, data: EC2.Types.CancelSpotInstanceRequestsResult) => void): Request<EC2.Types.CancelSpotInstanceRequestsResult, AWSError>;
  /**
   * Determines whether a product code is associated with an instance. This action can only be used by the owner of the product code. It is useful when a product code owner must verify whether another user's instance is eligible for support.
   */
  confirmProductInstance(params: EC2.Types.ConfirmProductInstanceRequest, callback?: (err: AWSError, data: EC2.Types.ConfirmProductInstanceResult) => void): Request<EC2.Types.ConfirmProductInstanceResult, AWSError>;
  /**
   * Determines whether a product code is associated with an instance. This action can only be used by the owner of the product code. It is useful when a product code owner must verify whether another user's instance is eligible for support.
   */
  confirmProductInstance(callback?: (err: AWSError, data: EC2.Types.ConfirmProductInstanceResult) => void): Request<EC2.Types.ConfirmProductInstanceResult, AWSError>;
  /**
   * Copies the specified Amazon FPGA Image (AFI) to the current Region.
   */
  copyFpgaImage(params: EC2.Types.CopyFpgaImageRequest, callback?: (err: AWSError, data: EC2.Types.CopyFpgaImageResult) => void): Request<EC2.Types.CopyFpgaImageResult, AWSError>;
  /**
   * Copies the specified Amazon FPGA Image (AFI) to the current Region.
   */
  copyFpgaImage(callback?: (err: AWSError, data: EC2.Types.CopyFpgaImageResult) => void): Request<EC2.Types.CopyFpgaImageResult, AWSError>;
  /**
   * Initiates the copy of an AMI. You can copy an AMI from one Region to another, or from a Region to an Outpost. You can't copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost. To copy an AMI to another partition, see CreateStoreImageTask. To copy an AMI from one Region to another, specify the source Region using the SourceRegion parameter, and specify the destination Region using its endpoint. Copies of encrypted backing snapshots for the AMI are encrypted. Copies of unencrypted backing snapshots remain unencrypted, unless you set Encrypted during the copy operation. You cannot create an unencrypted copy of an encrypted backing snapshot. To copy an AMI from a Region to an Outpost, specify the source Region using the SourceRegion parameter, and specify the ARN of the destination Outpost using DestinationOutpostArn. Backing snapshots copied to an Outpost are encrypted by default using the default encryption key for the Region, or a different key that you specify in the request using KmsKeyId. Outposts do not support unencrypted snapshots. For more information,  Amazon EBS local snapshots on Outposts in the Amazon EC2 User Guide. For more information about the prerequisites and limits when copying an AMI, see Copy an AMI in the Amazon EC2 User Guide.
   */
  copyImage(params: EC2.Types.CopyImageRequest, callback?: (err: AWSError, data: EC2.Types.CopyImageResult) => void): Request<EC2.Types.CopyImageResult, AWSError>;
  /**
   * Initiates the copy of an AMI. You can copy an AMI from one Region to another, or from a Region to an Outpost. You can't copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost. To copy an AMI to another partition, see CreateStoreImageTask. To copy an AMI from one Region to another, specify the source Region using the SourceRegion parameter, and specify the destination Region using its endpoint. Copies of encrypted backing snapshots for the AMI are encrypted. Copies of unencrypted backing snapshots remain unencrypted, unless you set Encrypted during the copy operation. You cannot create an unencrypted copy of an encrypted backing snapshot. To copy an AMI from a Region to an Outpost, specify the source Region using the SourceRegion parameter, and specify the ARN of the destination Outpost using DestinationOutpostArn. Backing snapshots copied to an Outpost are encrypted by default using the default encryption key for the Region, or a different key that you specify in the request using KmsKeyId. Outposts do not support unencrypted snapshots. For more information,  Amazon EBS local snapshots on Outposts in the Amazon EC2 User Guide. For more information about the prerequisites and limits when copying an AMI, see Copy an AMI in the Amazon EC2 User Guide.
   */
  copyImage(callback?: (err: AWSError, data: EC2.Types.CopyImageResult) => void): Request<EC2.Types.CopyImageResult, AWSError>;
  /**
   * Copies a point-in-time snapshot of an EBS volume and stores it in Amazon S3. You can copy a snapshot within the same Region, from one Region to another, or from a Region to an Outpost. You can't copy a snapshot from an Outpost to a Region, from one Outpost to another, or within the same Outpost. You can use the snapshot to create EBS volumes or Amazon Machine Images (AMIs). When copying snapshots to a Region, copies of encrypted EBS snapshots remain encrypted. Copies of unencrypted snapshots remain unencrypted, unless you enable encryption for the snapshot copy operation. By default, encrypted snapshot copies use the default Key Management Service (KMS) KMS key; however, you can specify a different KMS key. To copy an encrypted snapshot that has been shared from another account, you must have permissions for the KMS key used to encrypt the snapshot. Snapshots copied to an Outpost are encrypted by default using the default encryption key for the Region, or a different key that you specify in the request using KmsKeyId. Outposts do not support unencrypted snapshots. For more information,  Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide. Snapshots created by copying another snapshot have an arbitrary volume ID that should not be used for any purpose. For more information, see Copy an Amazon EBS snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  copySnapshot(params: EC2.Types.CopySnapshotRequest, callback?: (err: AWSError, data: EC2.Types.CopySnapshotResult) => void): Request<EC2.Types.CopySnapshotResult, AWSError>;
  /**
   * Copies a point-in-time snapshot of an EBS volume and stores it in Amazon S3. You can copy a snapshot within the same Region, from one Region to another, or from a Region to an Outpost. You can't copy a snapshot from an Outpost to a Region, from one Outpost to another, or within the same Outpost. You can use the snapshot to create EBS volumes or Amazon Machine Images (AMIs). When copying snapshots to a Region, copies of encrypted EBS snapshots remain encrypted. Copies of unencrypted snapshots remain unencrypted, unless you enable encryption for the snapshot copy operation. By default, encrypted snapshot copies use the default Key Management Service (KMS) KMS key; however, you can specify a different KMS key. To copy an encrypted snapshot that has been shared from another account, you must have permissions for the KMS key used to encrypt the snapshot. Snapshots copied to an Outpost are encrypted by default using the default encryption key for the Region, or a different key that you specify in the request using KmsKeyId. Outposts do not support unencrypted snapshots. For more information,  Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide. Snapshots created by copying another snapshot have an arbitrary volume ID that should not be used for any purpose. For more information, see Copy an Amazon EBS snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  copySnapshot(callback?: (err: AWSError, data: EC2.Types.CopySnapshotResult) => void): Request<EC2.Types.CopySnapshotResult, AWSError>;
  /**
   * Creates a new Capacity Reservation with the specified attributes. Capacity Reservations enable you to reserve capacity for your Amazon EC2 instances in a specific Availability Zone for any duration. This gives you the flexibility to selectively add capacity reservations and still get the Regional RI discounts for that usage. By creating Capacity Reservations, you ensure that you always have access to Amazon EC2 capacity when you need it, for as long as you need it. For more information, see Capacity Reservations in the Amazon EC2 User Guide. Your request to create a Capacity Reservation could fail if Amazon EC2 does not have sufficient capacity to fulfill the request. If your request fails due to Amazon EC2 capacity constraints, either try again at a later time, try in a different Availability Zone, or request a smaller capacity reservation. If your application is flexible across instance types and sizes, try to create a Capacity Reservation with different instance attributes. Your request could also fail if the requested quantity exceeds your On-Demand Instance limit for the selected instance type. If your request fails due to limit constraints, increase your On-Demand Instance limit for the required instance type and try again. For more information about increasing your instance limits, see Amazon EC2 Service Quotas in the Amazon EC2 User Guide.
   */
  createCapacityReservation(params: EC2.Types.CreateCapacityReservationRequest, callback?: (err: AWSError, data: EC2.Types.CreateCapacityReservationResult) => void): Request<EC2.Types.CreateCapacityReservationResult, AWSError>;
  /**
   * Creates a new Capacity Reservation with the specified attributes. Capacity Reservations enable you to reserve capacity for your Amazon EC2 instances in a specific Availability Zone for any duration. This gives you the flexibility to selectively add capacity reservations and still get the Regional RI discounts for that usage. By creating Capacity Reservations, you ensure that you always have access to Amazon EC2 capacity when you need it, for as long as you need it. For more information, see Capacity Reservations in the Amazon EC2 User Guide. Your request to create a Capacity Reservation could fail if Amazon EC2 does not have sufficient capacity to fulfill the request. If your request fails due to Amazon EC2 capacity constraints, either try again at a later time, try in a different Availability Zone, or request a smaller capacity reservation. If your application is flexible across instance types and sizes, try to create a Capacity Reservation with different instance attributes. Your request could also fail if the requested quantity exceeds your On-Demand Instance limit for the selected instance type. If your request fails due to limit constraints, increase your On-Demand Instance limit for the required instance type and try again. For more information about increasing your instance limits, see Amazon EC2 Service Quotas in the Amazon EC2 User Guide.
   */
  createCapacityReservation(callback?: (err: AWSError, data: EC2.Types.CreateCapacityReservationResult) => void): Request<EC2.Types.CreateCapacityReservationResult, AWSError>;
  /**
   * Creates a Capacity Reservation Fleet. For more information, see Create a Capacity Reservation Fleet in the Amazon EC2 User Guide.
   */
  createCapacityReservationFleet(params: EC2.Types.CreateCapacityReservationFleetRequest, callback?: (err: AWSError, data: EC2.Types.CreateCapacityReservationFleetResult) => void): Request<EC2.Types.CreateCapacityReservationFleetResult, AWSError>;
  /**
   * Creates a Capacity Reservation Fleet. For more information, see Create a Capacity Reservation Fleet in the Amazon EC2 User Guide.
   */
  createCapacityReservationFleet(callback?: (err: AWSError, data: EC2.Types.CreateCapacityReservationFleetResult) => void): Request<EC2.Types.CreateCapacityReservationFleetResult, AWSError>;
  /**
   * Creates a carrier gateway. For more information about carrier gateways, see Carrier gateways in the Amazon Web Services Wavelength Developer Guide.
   */
  createCarrierGateway(params: EC2.Types.CreateCarrierGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateCarrierGatewayResult) => void): Request<EC2.Types.CreateCarrierGatewayResult, AWSError>;
  /**
   * Creates a carrier gateway. For more information about carrier gateways, see Carrier gateways in the Amazon Web Services Wavelength Developer Guide.
   */
  createCarrierGateway(callback?: (err: AWSError, data: EC2.Types.CreateCarrierGatewayResult) => void): Request<EC2.Types.CreateCarrierGatewayResult, AWSError>;
  /**
   * Creates a Client VPN endpoint. A Client VPN endpoint is the resource you create and configure to enable and manage client VPN sessions. It is the destination endpoint at which all client VPN sessions are terminated.
   */
  createClientVpnEndpoint(params: EC2.Types.CreateClientVpnEndpointRequest, callback?: (err: AWSError, data: EC2.Types.CreateClientVpnEndpointResult) => void): Request<EC2.Types.CreateClientVpnEndpointResult, AWSError>;
  /**
   * Creates a Client VPN endpoint. A Client VPN endpoint is the resource you create and configure to enable and manage client VPN sessions. It is the destination endpoint at which all client VPN sessions are terminated.
   */
  createClientVpnEndpoint(callback?: (err: AWSError, data: EC2.Types.CreateClientVpnEndpointResult) => void): Request<EC2.Types.CreateClientVpnEndpointResult, AWSError>;
  /**
   * Adds a route to a network to a Client VPN endpoint. Each Client VPN endpoint has a route table that describes the available destination network routes. Each route in the route table specifies the path for traﬃc to speciﬁc resources or networks.
   */
  createClientVpnRoute(params: EC2.Types.CreateClientVpnRouteRequest, callback?: (err: AWSError, data: EC2.Types.CreateClientVpnRouteResult) => void): Request<EC2.Types.CreateClientVpnRouteResult, AWSError>;
  /**
   * Adds a route to a network to a Client VPN endpoint. Each Client VPN endpoint has a route table that describes the available destination network routes. Each route in the route table specifies the path for traﬃc to speciﬁc resources or networks.
   */
  createClientVpnRoute(callback?: (err: AWSError, data: EC2.Types.CreateClientVpnRouteResult) => void): Request<EC2.Types.CreateClientVpnRouteResult, AWSError>;
  /**
   *  Creates a range of customer-owned IP addresses. 
   */
  createCoipCidr(params: EC2.Types.CreateCoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.CreateCoipCidrResult) => void): Request<EC2.Types.CreateCoipCidrResult, AWSError>;
  /**
   *  Creates a range of customer-owned IP addresses. 
   */
  createCoipCidr(callback?: (err: AWSError, data: EC2.Types.CreateCoipCidrResult) => void): Request<EC2.Types.CreateCoipCidrResult, AWSError>;
  /**
   *  Creates a pool of customer-owned IP (CoIP) addresses. 
   */
  createCoipPool(params: EC2.Types.CreateCoipPoolRequest, callback?: (err: AWSError, data: EC2.Types.CreateCoipPoolResult) => void): Request<EC2.Types.CreateCoipPoolResult, AWSError>;
  /**
   *  Creates a pool of customer-owned IP (CoIP) addresses. 
   */
  createCoipPool(callback?: (err: AWSError, data: EC2.Types.CreateCoipPoolResult) => void): Request<EC2.Types.CreateCoipPoolResult, AWSError>;
  /**
   * Provides information to Amazon Web Services about your customer gateway device. The customer gateway device is the appliance at your end of the VPN connection. You must provide the IP address of the customer gateway device’s external interface. The IP address must be static and can be behind a device performing network address translation (NAT). For devices that use Border Gateway Protocol (BGP), you can also provide the device's BGP Autonomous System Number (ASN). You can use an existing ASN assigned to your network. If you don't have an ASN already, you can use a private ASN. For more information, see Customer gateway options for your Site-to-Site VPN connection in the Amazon Web Services Site-to-Site VPN User Guide. To create more than one customer gateway with the same VPN type, IP address, and BGP ASN, specify a unique device name for each customer gateway. An identical request returns information about the existing customer gateway; it doesn't create a new customer gateway.
   */
  createCustomerGateway(params: EC2.Types.CreateCustomerGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateCustomerGatewayResult) => void): Request<EC2.Types.CreateCustomerGatewayResult, AWSError>;
  /**
   * Provides information to Amazon Web Services about your customer gateway device. The customer gateway device is the appliance at your end of the VPN connection. You must provide the IP address of the customer gateway device’s external interface. The IP address must be static and can be behind a device performing network address translation (NAT). For devices that use Border Gateway Protocol (BGP), you can also provide the device's BGP Autonomous System Number (ASN). You can use an existing ASN assigned to your network. If you don't have an ASN already, you can use a private ASN. For more information, see Customer gateway options for your Site-to-Site VPN connection in the Amazon Web Services Site-to-Site VPN User Guide. To create more than one customer gateway with the same VPN type, IP address, and BGP ASN, specify a unique device name for each customer gateway. An identical request returns information about the existing customer gateway; it doesn't create a new customer gateway.
   */
  createCustomerGateway(callback?: (err: AWSError, data: EC2.Types.CreateCustomerGatewayResult) => void): Request<EC2.Types.CreateCustomerGatewayResult, AWSError>;
  /**
   * Creates a default subnet with a size /20 IPv4 CIDR block in the specified Availability Zone in your default VPC. You can have only one default subnet per Availability Zone. For more information, see Creating a default subnet in the Amazon Virtual Private Cloud User Guide.
   */
  createDefaultSubnet(params: EC2.Types.CreateDefaultSubnetRequest, callback?: (err: AWSError, data: EC2.Types.CreateDefaultSubnetResult) => void): Request<EC2.Types.CreateDefaultSubnetResult, AWSError>;
  /**
   * Creates a default subnet with a size /20 IPv4 CIDR block in the specified Availability Zone in your default VPC. You can have only one default subnet per Availability Zone. For more information, see Creating a default subnet in the Amazon Virtual Private Cloud User Guide.
   */
  createDefaultSubnet(callback?: (err: AWSError, data: EC2.Types.CreateDefaultSubnetResult) => void): Request<EC2.Types.CreateDefaultSubnetResult, AWSError>;
  /**
   * Creates a default VPC with a size /16 IPv4 CIDR block and a default subnet in each Availability Zone. For more information about the components of a default VPC, see Default VPC and default subnets in the Amazon Virtual Private Cloud User Guide. You cannot specify the components of the default VPC yourself. If you deleted your previous default VPC, you can create a default VPC. You cannot have more than one default VPC per Region. If your account supports EC2-Classic, you cannot use this action to create a default VPC in a Region that supports EC2-Classic. If you want a default VPC in a Region that supports EC2-Classic, see "I really want a default VPC for my existing EC2 account. Is that possible?" in the Default VPCs FAQ.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  createDefaultVpc(params: EC2.Types.CreateDefaultVpcRequest, callback?: (err: AWSError, data: EC2.Types.CreateDefaultVpcResult) => void): Request<EC2.Types.CreateDefaultVpcResult, AWSError>;
  /**
   * Creates a default VPC with a size /16 IPv4 CIDR block and a default subnet in each Availability Zone. For more information about the components of a default VPC, see Default VPC and default subnets in the Amazon Virtual Private Cloud User Guide. You cannot specify the components of the default VPC yourself. If you deleted your previous default VPC, you can create a default VPC. You cannot have more than one default VPC per Region. If your account supports EC2-Classic, you cannot use this action to create a default VPC in a Region that supports EC2-Classic. If you want a default VPC in a Region that supports EC2-Classic, see "I really want a default VPC for my existing EC2 account. Is that possible?" in the Default VPCs FAQ.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  createDefaultVpc(callback?: (err: AWSError, data: EC2.Types.CreateDefaultVpcResult) => void): Request<EC2.Types.CreateDefaultVpcResult, AWSError>;
  /**
   * Creates a set of DHCP options for your VPC. After creating the set, you must associate it with the VPC, causing all existing and new instances that you launch in the VPC to use this set of DHCP options. The following are the individual DHCP options you can specify. For more information about the options, see RFC 2132.    domain-name-servers - The IP addresses of up to four domain name servers, or AmazonProvidedDNS. The default DHCP option set specifies AmazonProvidedDNS. If specifying more than one domain name server, specify the IP addresses in a single parameter, separated by commas. To have your instance receive a custom DNS hostname as specified in domain-name, you must set domain-name-servers to a custom DNS server.    domain-name - If you're using AmazonProvidedDNS in us-east-1, specify ec2.internal. If you're using AmazonProvidedDNS in another Region, specify region.compute.internal (for example, ap-northeast-1.compute.internal). Otherwise, specify a domain name (for example, ExampleCompany.com). This value is used to complete unqualified DNS hostnames. Important: Some Linux operating systems accept multiple domain names separated by spaces. However, Windows and other Linux operating systems treat the value as a single domain, which results in unexpected behavior. If your DHCP options set is associated with a VPC that has instances with multiple operating systems, specify only one domain name.    ntp-servers - The IP addresses of up to four Network Time Protocol (NTP) servers.    netbios-name-servers - The IP addresses of up to four NetBIOS name servers.    netbios-node-type - The NetBIOS node type (1, 2, 4, or 8). We recommend that you specify 2 (broadcast and multicast are not currently supported). For more information about these node types, see RFC 2132.   Your VPC automatically starts out with a set of DHCP options that includes only a DNS server that we provide (AmazonProvidedDNS). If you create a set of options, and if your VPC has an internet gateway, make sure to set the domain-name-servers option either to AmazonProvidedDNS or to a domain name server of your choice. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  createDhcpOptions(params: EC2.Types.CreateDhcpOptionsRequest, callback?: (err: AWSError, data: EC2.Types.CreateDhcpOptionsResult) => void): Request<EC2.Types.CreateDhcpOptionsResult, AWSError>;
  /**
   * Creates a set of DHCP options for your VPC. After creating the set, you must associate it with the VPC, causing all existing and new instances that you launch in the VPC to use this set of DHCP options. The following are the individual DHCP options you can specify. For more information about the options, see RFC 2132.    domain-name-servers - The IP addresses of up to four domain name servers, or AmazonProvidedDNS. The default DHCP option set specifies AmazonProvidedDNS. If specifying more than one domain name server, specify the IP addresses in a single parameter, separated by commas. To have your instance receive a custom DNS hostname as specified in domain-name, you must set domain-name-servers to a custom DNS server.    domain-name - If you're using AmazonProvidedDNS in us-east-1, specify ec2.internal. If you're using AmazonProvidedDNS in another Region, specify region.compute.internal (for example, ap-northeast-1.compute.internal). Otherwise, specify a domain name (for example, ExampleCompany.com). This value is used to complete unqualified DNS hostnames. Important: Some Linux operating systems accept multiple domain names separated by spaces. However, Windows and other Linux operating systems treat the value as a single domain, which results in unexpected behavior. If your DHCP options set is associated with a VPC that has instances with multiple operating systems, specify only one domain name.    ntp-servers - The IP addresses of up to four Network Time Protocol (NTP) servers.    netbios-name-servers - The IP addresses of up to four NetBIOS name servers.    netbios-node-type - The NetBIOS node type (1, 2, 4, or 8). We recommend that you specify 2 (broadcast and multicast are not currently supported). For more information about these node types, see RFC 2132.   Your VPC automatically starts out with a set of DHCP options that includes only a DNS server that we provide (AmazonProvidedDNS). If you create a set of options, and if your VPC has an internet gateway, make sure to set the domain-name-servers option either to AmazonProvidedDNS or to a domain name server of your choice. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  createDhcpOptions(callback?: (err: AWSError, data: EC2.Types.CreateDhcpOptionsResult) => void): Request<EC2.Types.CreateDhcpOptionsResult, AWSError>;
  /**
   * [IPv6 only] Creates an egress-only internet gateway for your VPC. An egress-only internet gateway is used to enable outbound communication over IPv6 from instances in your VPC to the internet, and prevents hosts outside of your VPC from initiating an IPv6 connection with your instance.
   */
  createEgressOnlyInternetGateway(params: EC2.Types.CreateEgressOnlyInternetGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateEgressOnlyInternetGatewayResult) => void): Request<EC2.Types.CreateEgressOnlyInternetGatewayResult, AWSError>;
  /**
   * [IPv6 only] Creates an egress-only internet gateway for your VPC. An egress-only internet gateway is used to enable outbound communication over IPv6 from instances in your VPC to the internet, and prevents hosts outside of your VPC from initiating an IPv6 connection with your instance.
   */
  createEgressOnlyInternetGateway(callback?: (err: AWSError, data: EC2.Types.CreateEgressOnlyInternetGatewayResult) => void): Request<EC2.Types.CreateEgressOnlyInternetGatewayResult, AWSError>;
  /**
   * Launches an EC2 Fleet. You can create a single EC2 Fleet that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. For more information, see EC2 Fleet in the Amazon EC2 User Guide.
   */
  createFleet(params: EC2.Types.CreateFleetRequest, callback?: (err: AWSError, data: EC2.Types.CreateFleetResult) => void): Request<EC2.Types.CreateFleetResult, AWSError>;
  /**
   * Launches an EC2 Fleet. You can create a single EC2 Fleet that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. For more information, see EC2 Fleet in the Amazon EC2 User Guide.
   */
  createFleet(callback?: (err: AWSError, data: EC2.Types.CreateFleetResult) => void): Request<EC2.Types.CreateFleetResult, AWSError>;
  /**
   * Creates one or more flow logs to capture information about IP traffic for a specific network interface, subnet, or VPC.  Flow log data for a monitored network interface is recorded as flow log records, which are log events consisting of fields that describe the traffic flow. For more information, see Flow log records in the Amazon Virtual Private Cloud User Guide. When publishing to CloudWatch Logs, flow log records are published to a log group, and each network interface has a unique log stream in the log group. When publishing to Amazon S3, flow log records for all of the monitored network interfaces are published to a single log file object that is stored in the specified bucket. For more information, see VPC Flow Logs in the Amazon Virtual Private Cloud User Guide.
   */
  createFlowLogs(params: EC2.Types.CreateFlowLogsRequest, callback?: (err: AWSError, data: EC2.Types.CreateFlowLogsResult) => void): Request<EC2.Types.CreateFlowLogsResult, AWSError>;
  /**
   * Creates one or more flow logs to capture information about IP traffic for a specific network interface, subnet, or VPC.  Flow log data for a monitored network interface is recorded as flow log records, which are log events consisting of fields that describe the traffic flow. For more information, see Flow log records in the Amazon Virtual Private Cloud User Guide. When publishing to CloudWatch Logs, flow log records are published to a log group, and each network interface has a unique log stream in the log group. When publishing to Amazon S3, flow log records for all of the monitored network interfaces are published to a single log file object that is stored in the specified bucket. For more information, see VPC Flow Logs in the Amazon Virtual Private Cloud User Guide.
   */
  createFlowLogs(callback?: (err: AWSError, data: EC2.Types.CreateFlowLogsResult) => void): Request<EC2.Types.CreateFlowLogsResult, AWSError>;
  /**
   * Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP). The create operation is asynchronous. To verify that the AFI is ready for use, check the output logs. An AFI contains the FPGA bitstream that is ready to download to an FPGA. You can securely deploy an AFI on multiple FPGA-accelerated instances. For more information, see the Amazon Web Services FPGA Hardware Development Kit.
   */
  createFpgaImage(params: EC2.Types.CreateFpgaImageRequest, callback?: (err: AWSError, data: EC2.Types.CreateFpgaImageResult) => void): Request<EC2.Types.CreateFpgaImageResult, AWSError>;
  /**
   * Creates an Amazon FPGA Image (AFI) from the specified design checkpoint (DCP). The create operation is asynchronous. To verify that the AFI is ready for use, check the output logs. An AFI contains the FPGA bitstream that is ready to download to an FPGA. You can securely deploy an AFI on multiple FPGA-accelerated instances. For more information, see the Amazon Web Services FPGA Hardware Development Kit.
   */
  createFpgaImage(callback?: (err: AWSError, data: EC2.Types.CreateFpgaImageResult) => void): Request<EC2.Types.CreateFpgaImageResult, AWSError>;
  /**
   * Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped. By default, when Amazon EC2 creates the new AMI, it reboots the instance so that it can take snapshots of the attached volumes while data is at rest, in order to ensure a consistent state. You can set the NoReboot parameter to true in the API request, or use the --no-reboot option in the CLI to prevent Amazon EC2 from shutting down and rebooting the instance.  If you choose to bypass the shutdown and reboot process by setting the NoReboot parameter to true in the API request, or by using the --no-reboot option in the CLI, we can't guarantee the file system integrity of the created image.  If you customized your instance with instance store volumes or Amazon EBS volumes in addition to the root device volume, the new AMI contains block device mapping information for those volumes. When you launch an instance from this new AMI, the instance automatically launches with those additional volumes. For more information, see Create an Amazon EBS-backed Linux AMI in the Amazon Elastic Compute Cloud User Guide.
   */
  createImage(params: EC2.Types.CreateImageRequest, callback?: (err: AWSError, data: EC2.Types.CreateImageResult) => void): Request<EC2.Types.CreateImageResult, AWSError>;
  /**
   * Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped. By default, when Amazon EC2 creates the new AMI, it reboots the instance so that it can take snapshots of the attached volumes while data is at rest, in order to ensure a consistent state. You can set the NoReboot parameter to true in the API request, or use the --no-reboot option in the CLI to prevent Amazon EC2 from shutting down and rebooting the instance.  If you choose to bypass the shutdown and reboot process by setting the NoReboot parameter to true in the API request, or by using the --no-reboot option in the CLI, we can't guarantee the file system integrity of the created image.  If you customized your instance with instance store volumes or Amazon EBS volumes in addition to the root device volume, the new AMI contains block device mapping information for those volumes. When you launch an instance from this new AMI, the instance automatically launches with those additional volumes. For more information, see Create an Amazon EBS-backed Linux AMI in the Amazon Elastic Compute Cloud User Guide.
   */
  createImage(callback?: (err: AWSError, data: EC2.Types.CreateImageResult) => void): Request<EC2.Types.CreateImageResult, AWSError>;
  /**
   * Creates an event window in which scheduled events for the associated Amazon EC2 instances can run. You can define either a set of time ranges or a cron expression when creating the event window, but not both. All event window times are in UTC. You can create up to 200 event windows per Amazon Web Services Region. When you create the event window, targets (instance IDs, Dedicated Host IDs, or tags) are not yet associated with it. To ensure that the event window can be used, you must associate one or more targets with it by using the AssociateInstanceEventWindow API.  Event windows are applicable only for scheduled events that stop, reboot, or terminate instances. Event windows are not applicable for:   Expedited scheduled events and network maintenance events.    Unscheduled maintenance such as AutoRecovery and unplanned reboots.    For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  createInstanceEventWindow(params: EC2.Types.CreateInstanceEventWindowRequest, callback?: (err: AWSError, data: EC2.Types.CreateInstanceEventWindowResult) => void): Request<EC2.Types.CreateInstanceEventWindowResult, AWSError>;
  /**
   * Creates an event window in which scheduled events for the associated Amazon EC2 instances can run. You can define either a set of time ranges or a cron expression when creating the event window, but not both. All event window times are in UTC. You can create up to 200 event windows per Amazon Web Services Region. When you create the event window, targets (instance IDs, Dedicated Host IDs, or tags) are not yet associated with it. To ensure that the event window can be used, you must associate one or more targets with it by using the AssociateInstanceEventWindow API.  Event windows are applicable only for scheduled events that stop, reboot, or terminate instances. Event windows are not applicable for:   Expedited scheduled events and network maintenance events.    Unscheduled maintenance such as AutoRecovery and unplanned reboots.    For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  createInstanceEventWindow(callback?: (err: AWSError, data: EC2.Types.CreateInstanceEventWindowResult) => void): Request<EC2.Types.CreateInstanceEventWindowResult, AWSError>;
  /**
   * Exports a running or stopped instance to an Amazon S3 bucket. For information about the supported operating systems, image formats, and known limitations for the types of instances you can export, see Exporting an instance as a VM Using VM Import/Export in the VM Import/Export User Guide.
   */
  createInstanceExportTask(params: EC2.Types.CreateInstanceExportTaskRequest, callback?: (err: AWSError, data: EC2.Types.CreateInstanceExportTaskResult) => void): Request<EC2.Types.CreateInstanceExportTaskResult, AWSError>;
  /**
   * Exports a running or stopped instance to an Amazon S3 bucket. For information about the supported operating systems, image formats, and known limitations for the types of instances you can export, see Exporting an instance as a VM Using VM Import/Export in the VM Import/Export User Guide.
   */
  createInstanceExportTask(callback?: (err: AWSError, data: EC2.Types.CreateInstanceExportTaskResult) => void): Request<EC2.Types.CreateInstanceExportTaskResult, AWSError>;
  /**
   * Creates an internet gateway for use with a VPC. After creating the internet gateway, you attach it to a VPC using AttachInternetGateway. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.
   */
  createInternetGateway(params: EC2.Types.CreateInternetGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateInternetGatewayResult) => void): Request<EC2.Types.CreateInternetGatewayResult, AWSError>;
  /**
   * Creates an internet gateway for use with a VPC. After creating the internet gateway, you attach it to a VPC using AttachInternetGateway. For more information about your VPC and internet gateway, see the Amazon Virtual Private Cloud User Guide.
   */
  createInternetGateway(callback?: (err: AWSError, data: EC2.Types.CreateInternetGatewayResult) => void): Request<EC2.Types.CreateInternetGatewayResult, AWSError>;
  /**
   * Create an IPAM. Amazon VPC IP Address Manager (IPAM) is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see Create an IPAM in the Amazon VPC IPAM User Guide. 
   */
  createIpam(params: EC2.Types.CreateIpamRequest, callback?: (err: AWSError, data: EC2.Types.CreateIpamResult) => void): Request<EC2.Types.CreateIpamResult, AWSError>;
  /**
   * Create an IPAM. Amazon VPC IP Address Manager (IPAM) is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see Create an IPAM in the Amazon VPC IPAM User Guide. 
   */
  createIpam(callback?: (err: AWSError, data: EC2.Types.CreateIpamResult) => void): Request<EC2.Types.CreateIpamResult, AWSError>;
  /**
   * Create an IP address pool for Amazon VPC IP Address Manager (IPAM). In IPAM, a pool is a collection of contiguous IP addresses CIDRs. Pools enable you to organize your IP addresses according to your routing and security needs. For example, if you have separate routing and security needs for development and production applications, you can create a pool for each. For more information, see Create a top-level pool in the Amazon VPC IPAM User Guide. 
   */
  createIpamPool(params: EC2.Types.CreateIpamPoolRequest, callback?: (err: AWSError, data: EC2.Types.CreateIpamPoolResult) => void): Request<EC2.Types.CreateIpamPoolResult, AWSError>;
  /**
   * Create an IP address pool for Amazon VPC IP Address Manager (IPAM). In IPAM, a pool is a collection of contiguous IP addresses CIDRs. Pools enable you to organize your IP addresses according to your routing and security needs. For example, if you have separate routing and security needs for development and production applications, you can create a pool for each. For more information, see Create a top-level pool in the Amazon VPC IPAM User Guide. 
   */
  createIpamPool(callback?: (err: AWSError, data: EC2.Types.CreateIpamPoolResult) => void): Request<EC2.Types.CreateIpamPoolResult, AWSError>;
  /**
   * Creates an IPAM resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  createIpamResourceDiscovery(params: EC2.Types.CreateIpamResourceDiscoveryRequest, callback?: (err: AWSError, data: EC2.Types.CreateIpamResourceDiscoveryResult) => void): Request<EC2.Types.CreateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Creates an IPAM resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  createIpamResourceDiscovery(callback?: (err: AWSError, data: EC2.Types.CreateIpamResourceDiscoveryResult) => void): Request<EC2.Types.CreateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Create an IPAM scope. In IPAM, a scope is the highest-level container within IPAM. An IPAM contains two default scopes. Each scope represents the IP space for a single network. The private scope is intended for all private IP address space. The public scope is intended for all public IP address space. Scopes enable you to reuse IP addresses across multiple unconnected networks without causing IP address overlap or conflict. For more information, see Add a scope in the Amazon VPC IPAM User Guide.
   */
  createIpamScope(params: EC2.Types.CreateIpamScopeRequest, callback?: (err: AWSError, data: EC2.Types.CreateIpamScopeResult) => void): Request<EC2.Types.CreateIpamScopeResult, AWSError>;
  /**
   * Create an IPAM scope. In IPAM, a scope is the highest-level container within IPAM. An IPAM contains two default scopes. Each scope represents the IP space for a single network. The private scope is intended for all private IP address space. The public scope is intended for all public IP address space. Scopes enable you to reuse IP addresses across multiple unconnected networks without causing IP address overlap or conflict. For more information, see Add a scope in the Amazon VPC IPAM User Guide.
   */
  createIpamScope(callback?: (err: AWSError, data: EC2.Types.CreateIpamScopeResult) => void): Request<EC2.Types.CreateIpamScopeResult, AWSError>;
  /**
   * Creates an ED25519 or 2048-bit RSA key pair with the specified name and in the specified PEM or PPK format. Amazon EC2 stores the public key and displays the private key for you to save to a file. The private key is returned as an unencrypted PEM encoded PKCS#1 private key or an unencrypted PPK formatted private key for use with PuTTY. If a key with the specified name already exists, Amazon EC2 returns an error. The key pair returned to you is available only in the Amazon Web Services Region in which you create it. If you prefer, you can create your own key pair using a third-party tool and upload it to any Region using ImportKeyPair. You can have up to 5,000 key pairs per Amazon Web Services Region. For more information, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  createKeyPair(params: EC2.Types.CreateKeyPairRequest, callback?: (err: AWSError, data: EC2.Types.KeyPair) => void): Request<EC2.Types.KeyPair, AWSError>;
  /**
   * Creates an ED25519 or 2048-bit RSA key pair with the specified name and in the specified PEM or PPK format. Amazon EC2 stores the public key and displays the private key for you to save to a file. The private key is returned as an unencrypted PEM encoded PKCS#1 private key or an unencrypted PPK formatted private key for use with PuTTY. If a key with the specified name already exists, Amazon EC2 returns an error. The key pair returned to you is available only in the Amazon Web Services Region in which you create it. If you prefer, you can create your own key pair using a third-party tool and upload it to any Region using ImportKeyPair. You can have up to 5,000 key pairs per Amazon Web Services Region. For more information, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  createKeyPair(callback?: (err: AWSError, data: EC2.Types.KeyPair) => void): Request<EC2.Types.KeyPair, AWSError>;
  /**
   * Creates a launch template. A launch template contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify a launch template instead of providing the launch parameters in the request. For more information, see Launch an instance from a launch template in the Amazon Elastic Compute Cloud User Guide. If you want to clone an existing launch template as the basis for creating a new launch template, you can use the Amazon EC2 console. The API, SDKs, and CLI do not support cloning a template. For more information, see Create a launch template from an existing launch template in the Amazon Elastic Compute Cloud User Guide.
   */
  createLaunchTemplate(params: EC2.Types.CreateLaunchTemplateRequest, callback?: (err: AWSError, data: EC2.Types.CreateLaunchTemplateResult) => void): Request<EC2.Types.CreateLaunchTemplateResult, AWSError>;
  /**
   * Creates a launch template. A launch template contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify a launch template instead of providing the launch parameters in the request. For more information, see Launch an instance from a launch template in the Amazon Elastic Compute Cloud User Guide. If you want to clone an existing launch template as the basis for creating a new launch template, you can use the Amazon EC2 console. The API, SDKs, and CLI do not support cloning a template. For more information, see Create a launch template from an existing launch template in the Amazon Elastic Compute Cloud User Guide.
   */
  createLaunchTemplate(callback?: (err: AWSError, data: EC2.Types.CreateLaunchTemplateResult) => void): Request<EC2.Types.CreateLaunchTemplateResult, AWSError>;
  /**
   * Creates a new version of a launch template. You can specify an existing version of launch template from which to base the new version. Launch template versions are numbered in the order in which they are created. You cannot specify, change, or replace the numbering of launch template versions. Launch templates are immutable; after you create a launch template, you can't modify it. Instead, you can create a new version of the launch template that includes any changes you require. For more information, see Modify a launch template (manage launch template versions) in the Amazon Elastic Compute Cloud User Guide.
   */
  createLaunchTemplateVersion(params: EC2.Types.CreateLaunchTemplateVersionRequest, callback?: (err: AWSError, data: EC2.Types.CreateLaunchTemplateVersionResult) => void): Request<EC2.Types.CreateLaunchTemplateVersionResult, AWSError>;
  /**
   * Creates a new version of a launch template. You can specify an existing version of launch template from which to base the new version. Launch template versions are numbered in the order in which they are created. You cannot specify, change, or replace the numbering of launch template versions. Launch templates are immutable; after you create a launch template, you can't modify it. Instead, you can create a new version of the launch template that includes any changes you require. For more information, see Modify a launch template (manage launch template versions) in the Amazon Elastic Compute Cloud User Guide.
   */
  createLaunchTemplateVersion(callback?: (err: AWSError, data: EC2.Types.CreateLaunchTemplateVersionResult) => void): Request<EC2.Types.CreateLaunchTemplateVersionResult, AWSError>;
  /**
   * Creates a static route for the specified local gateway route table. You must specify one of the following targets:     LocalGatewayVirtualInterfaceGroupId     NetworkInterfaceId   
   */
  createLocalGatewayRoute(params: EC2.Types.CreateLocalGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteResult) => void): Request<EC2.Types.CreateLocalGatewayRouteResult, AWSError>;
  /**
   * Creates a static route for the specified local gateway route table. You must specify one of the following targets:     LocalGatewayVirtualInterfaceGroupId     NetworkInterfaceId   
   */
  createLocalGatewayRoute(callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteResult) => void): Request<EC2.Types.CreateLocalGatewayRouteResult, AWSError>;
  /**
   *  Creates a local gateway route table. 
   */
  createLocalGatewayRouteTable(params: EC2.Types.CreateLocalGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableResult, AWSError>;
  /**
   *  Creates a local gateway route table. 
   */
  createLocalGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableResult, AWSError>;
  /**
   *  Creates a local gateway route table virtual interface group association. 
   */
  createLocalGatewayRouteTableVirtualInterfaceGroupAssociation(params: EC2.Types.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest, callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult, AWSError>;
  /**
   *  Creates a local gateway route table virtual interface group association. 
   */
  createLocalGatewayRouteTableVirtualInterfaceGroupAssociation(callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult, AWSError>;
  /**
   * Associates the specified VPC with the specified local gateway route table.
   */
  createLocalGatewayRouteTableVpcAssociation(params: EC2.Types.CreateLocalGatewayRouteTableVpcAssociationRequest, callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableVpcAssociationResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableVpcAssociationResult, AWSError>;
  /**
   * Associates the specified VPC with the specified local gateway route table.
   */
  createLocalGatewayRouteTableVpcAssociation(callback?: (err: AWSError, data: EC2.Types.CreateLocalGatewayRouteTableVpcAssociationResult) => void): Request<EC2.Types.CreateLocalGatewayRouteTableVpcAssociationResult, AWSError>;
  /**
   * Creates a managed prefix list. You can specify one or more entries for the prefix list. Each entry consists of a CIDR block and an optional description.
   */
  createManagedPrefixList(params: EC2.Types.CreateManagedPrefixListRequest, callback?: (err: AWSError, data: EC2.Types.CreateManagedPrefixListResult) => void): Request<EC2.Types.CreateManagedPrefixListResult, AWSError>;
  /**
   * Creates a managed prefix list. You can specify one or more entries for the prefix list. Each entry consists of a CIDR block and an optional description.
   */
  createManagedPrefixList(callback?: (err: AWSError, data: EC2.Types.CreateManagedPrefixListResult) => void): Request<EC2.Types.CreateManagedPrefixListResult, AWSError>;
  /**
   * Creates a NAT gateway in the specified subnet. This action creates a network interface in the specified subnet with a private IP address from the IP address range of the subnet. You can create either a public NAT gateway or a private NAT gateway. With a public NAT gateway, internet-bound traffic from a private subnet can be routed to the NAT gateway, so that instances in a private subnet can connect to the internet. With a private NAT gateway, private communication is routed across VPCs and on-premises networks through a transit gateway or virtual private gateway. Common use cases include running large workloads behind a small pool of allowlisted IPv4 addresses, preserving private IPv4 addresses, and communicating between overlapping networks. For more information, see NAT gateways in the Amazon Virtual Private Cloud User Guide.
   */
  createNatGateway(params: EC2.Types.CreateNatGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateNatGatewayResult) => void): Request<EC2.Types.CreateNatGatewayResult, AWSError>;
  /**
   * Creates a NAT gateway in the specified subnet. This action creates a network interface in the specified subnet with a private IP address from the IP address range of the subnet. You can create either a public NAT gateway or a private NAT gateway. With a public NAT gateway, internet-bound traffic from a private subnet can be routed to the NAT gateway, so that instances in a private subnet can connect to the internet. With a private NAT gateway, private communication is routed across VPCs and on-premises networks through a transit gateway or virtual private gateway. Common use cases include running large workloads behind a small pool of allowlisted IPv4 addresses, preserving private IPv4 addresses, and communicating between overlapping networks. For more information, see NAT gateways in the Amazon Virtual Private Cloud User Guide.
   */
  createNatGateway(callback?: (err: AWSError, data: EC2.Types.CreateNatGatewayResult) => void): Request<EC2.Types.CreateNatGatewayResult, AWSError>;
  /**
   * Creates a network ACL in a VPC. Network ACLs provide an optional layer of security (in addition to security groups) for the instances in your VPC. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  createNetworkAcl(params: EC2.Types.CreateNetworkAclRequest, callback?: (err: AWSError, data: EC2.Types.CreateNetworkAclResult) => void): Request<EC2.Types.CreateNetworkAclResult, AWSError>;
  /**
   * Creates a network ACL in a VPC. Network ACLs provide an optional layer of security (in addition to security groups) for the instances in your VPC. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  createNetworkAcl(callback?: (err: AWSError, data: EC2.Types.CreateNetworkAclResult) => void): Request<EC2.Types.CreateNetworkAclResult, AWSError>;
  /**
   * Creates an entry (a rule) in a network ACL with the specified rule number. Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the ACL, we process the entries in the ACL according to the rule numbers, in ascending order. Each network ACL has a set of ingress rules and a separate set of egress rules. We recommend that you leave room between the rule numbers (for example, 100, 110, 120, ...), and not number them one right after the other (for example, 101, 102, 103, ...). This makes it easier to add a rule between existing ones without having to renumber the rules. After you add an entry, you can't modify it; you must either replace it, or create an entry and delete the old one. For more information about network ACLs, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  createNetworkAclEntry(params: EC2.Types.CreateNetworkAclEntryRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates an entry (a rule) in a network ACL with the specified rule number. Each network ACL has a set of numbered ingress rules and a separate set of numbered egress rules. When determining whether a packet should be allowed in or out of a subnet associated with the ACL, we process the entries in the ACL according to the rule numbers, in ascending order. Each network ACL has a set of ingress rules and a separate set of egress rules. We recommend that you leave room between the rule numbers (for example, 100, 110, 120, ...), and not number them one right after the other (for example, 101, 102, 103, ...). This makes it easier to add a rule between existing ones without having to renumber the rules. After you add an entry, you can't modify it; you must either replace it, or create an entry and delete the old one. For more information about network ACLs, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  createNetworkAclEntry(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates a Network Access Scope. Amazon Web Services Network Access Analyzer enables cloud networking and cloud operations teams to verify that their networks on Amazon Web Services conform to their network security and governance objectives. For more information, see the Amazon Web Services Network Access Analyzer Guide.
   */
  createNetworkInsightsAccessScope(params: EC2.Types.CreateNetworkInsightsAccessScopeRequest, callback?: (err: AWSError, data: EC2.Types.CreateNetworkInsightsAccessScopeResult) => void): Request<EC2.Types.CreateNetworkInsightsAccessScopeResult, AWSError>;
  /**
   * Creates a Network Access Scope. Amazon Web Services Network Access Analyzer enables cloud networking and cloud operations teams to verify that their networks on Amazon Web Services conform to their network security and governance objectives. For more information, see the Amazon Web Services Network Access Analyzer Guide.
   */
  createNetworkInsightsAccessScope(callback?: (err: AWSError, data: EC2.Types.CreateNetworkInsightsAccessScopeResult) => void): Request<EC2.Types.CreateNetworkInsightsAccessScopeResult, AWSError>;
  /**
   * Creates a path to analyze for reachability. Reachability Analyzer enables you to analyze and debug network reachability between two resources in your virtual private cloud (VPC). For more information, see the Reachability Analyzer Guide.
   */
  createNetworkInsightsPath(params: EC2.Types.CreateNetworkInsightsPathRequest, callback?: (err: AWSError, data: EC2.Types.CreateNetworkInsightsPathResult) => void): Request<EC2.Types.CreateNetworkInsightsPathResult, AWSError>;
  /**
   * Creates a path to analyze for reachability. Reachability Analyzer enables you to analyze and debug network reachability between two resources in your virtual private cloud (VPC). For more information, see the Reachability Analyzer Guide.
   */
  createNetworkInsightsPath(callback?: (err: AWSError, data: EC2.Types.CreateNetworkInsightsPathResult) => void): Request<EC2.Types.CreateNetworkInsightsPathResult, AWSError>;
  /**
   * Creates a network interface in the specified subnet. The number of IP addresses you can assign to a network interface varies by instance type. For more information, see IP Addresses Per ENI Per Instance Type in the Amazon Virtual Private Cloud User Guide. For more information about network interfaces, see Elastic network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  createNetworkInterface(params: EC2.Types.CreateNetworkInterfaceRequest, callback?: (err: AWSError, data: EC2.Types.CreateNetworkInterfaceResult) => void): Request<EC2.Types.CreateNetworkInterfaceResult, AWSError>;
  /**
   * Creates a network interface in the specified subnet. The number of IP addresses you can assign to a network interface varies by instance type. For more information, see IP Addresses Per ENI Per Instance Type in the Amazon Virtual Private Cloud User Guide. For more information about network interfaces, see Elastic network interfaces in the Amazon Elastic Compute Cloud User Guide.
   */
  createNetworkInterface(callback?: (err: AWSError, data: EC2.Types.CreateNetworkInterfaceResult) => void): Request<EC2.Types.CreateNetworkInterfaceResult, AWSError>;
  /**
   * Grants an Amazon Web Services-authorized account permission to attach the specified network interface to an instance in their account. You can grant permission to a single Amazon Web Services account only, and only one account at a time.
   */
  createNetworkInterfacePermission(params: EC2.Types.CreateNetworkInterfacePermissionRequest, callback?: (err: AWSError, data: EC2.Types.CreateNetworkInterfacePermissionResult) => void): Request<EC2.Types.CreateNetworkInterfacePermissionResult, AWSError>;
  /**
   * Grants an Amazon Web Services-authorized account permission to attach the specified network interface to an instance in their account. You can grant permission to a single Amazon Web Services account only, and only one account at a time.
   */
  createNetworkInterfacePermission(callback?: (err: AWSError, data: EC2.Types.CreateNetworkInterfacePermissionResult) => void): Request<EC2.Types.CreateNetworkInterfacePermissionResult, AWSError>;
  /**
   * Creates a placement group in which to launch instances. The strategy of the placement group determines how the instances are organized within the group.  A cluster placement group is a logical grouping of instances within a single Availability Zone that benefit from low network latency, high network throughput. A spread placement group places instances on distinct hardware. A partition placement group places groups of instances in different partitions, where instances in one partition do not share the same hardware with instances in another partition. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  createPlacementGroup(params: EC2.Types.CreatePlacementGroupRequest, callback?: (err: AWSError, data: EC2.Types.CreatePlacementGroupResult) => void): Request<EC2.Types.CreatePlacementGroupResult, AWSError>;
  /**
   * Creates a placement group in which to launch instances. The strategy of the placement group determines how the instances are organized within the group.  A cluster placement group is a logical grouping of instances within a single Availability Zone that benefit from low network latency, high network throughput. A spread placement group places instances on distinct hardware. A partition placement group places groups of instances in different partitions, where instances in one partition do not share the same hardware with instances in another partition. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  createPlacementGroup(callback?: (err: AWSError, data: EC2.Types.CreatePlacementGroupResult) => void): Request<EC2.Types.CreatePlacementGroupResult, AWSError>;
  /**
   * Creates a public IPv4 address pool. A public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs that you own and bring to Amazon Web Services to manage with IPAM. IPv6 addresses you bring to Amazon Web Services, however, use IPAM pools only. To monitor the status of pool creation, use DescribePublicIpv4Pools.
   */
  createPublicIpv4Pool(params: EC2.Types.CreatePublicIpv4PoolRequest, callback?: (err: AWSError, data: EC2.Types.CreatePublicIpv4PoolResult) => void): Request<EC2.Types.CreatePublicIpv4PoolResult, AWSError>;
  /**
   * Creates a public IPv4 address pool. A public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs that you own and bring to Amazon Web Services to manage with IPAM. IPv6 addresses you bring to Amazon Web Services, however, use IPAM pools only. To monitor the status of pool creation, use DescribePublicIpv4Pools.
   */
  createPublicIpv4Pool(callback?: (err: AWSError, data: EC2.Types.CreatePublicIpv4PoolResult) => void): Request<EC2.Types.CreatePublicIpv4PoolResult, AWSError>;
  /**
   * Replaces the EBS-backed root volume for a running instance with a new volume that is restored to the original root volume's launch state, that is restored to a specific snapshot taken from the original root volume, or that is restored from an AMI that has the same key characteristics as that of the instance. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.
   */
  createReplaceRootVolumeTask(params: EC2.Types.CreateReplaceRootVolumeTaskRequest, callback?: (err: AWSError, data: EC2.Types.CreateReplaceRootVolumeTaskResult) => void): Request<EC2.Types.CreateReplaceRootVolumeTaskResult, AWSError>;
  /**
   * Replaces the EBS-backed root volume for a running instance with a new volume that is restored to the original root volume's launch state, that is restored to a specific snapshot taken from the original root volume, or that is restored from an AMI that has the same key characteristics as that of the instance. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.
   */
  createReplaceRootVolumeTask(callback?: (err: AWSError, data: EC2.Types.CreateReplaceRootVolumeTaskResult) => void): Request<EC2.Types.CreateReplaceRootVolumeTaskResult, AWSError>;
  /**
   * Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the Reserved Instance Marketplace. You can submit one Standard Reserved Instance listing at a time. To get a list of your Standard Reserved Instances, you can use the DescribeReservedInstances operation.  Only Standard Reserved Instances can be sold in the Reserved Instance Marketplace. Convertible Reserved Instances cannot be sold.  The Reserved Instance Marketplace matches sellers who want to resell Standard Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. To sell your Standard Reserved Instances, you must first register as a seller in the Reserved Instance Marketplace. After completing the registration process, you can create a Reserved Instance Marketplace listing of some or all of your Standard Reserved Instances, and specify the upfront price to receive for them. Your Standard Reserved Instance listings then become available for purchase. To view the details of your Standard Reserved Instance listing, you can use the DescribeReservedInstancesListings operation. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  createReservedInstancesListing(params: EC2.Types.CreateReservedInstancesListingRequest, callback?: (err: AWSError, data: EC2.Types.CreateReservedInstancesListingResult) => void): Request<EC2.Types.CreateReservedInstancesListingResult, AWSError>;
  /**
   * Creates a listing for Amazon EC2 Standard Reserved Instances to be sold in the Reserved Instance Marketplace. You can submit one Standard Reserved Instance listing at a time. To get a list of your Standard Reserved Instances, you can use the DescribeReservedInstances operation.  Only Standard Reserved Instances can be sold in the Reserved Instance Marketplace. Convertible Reserved Instances cannot be sold.  The Reserved Instance Marketplace matches sellers who want to resell Standard Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. To sell your Standard Reserved Instances, you must first register as a seller in the Reserved Instance Marketplace. After completing the registration process, you can create a Reserved Instance Marketplace listing of some or all of your Standard Reserved Instances, and specify the upfront price to receive for them. Your Standard Reserved Instance listings then become available for purchase. To view the details of your Standard Reserved Instance listing, you can use the DescribeReservedInstancesListings operation. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  createReservedInstancesListing(callback?: (err: AWSError, data: EC2.Types.CreateReservedInstancesListingResult) => void): Request<EC2.Types.CreateReservedInstancesListingResult, AWSError>;
  /**
   * Starts a task that restores an AMI from an Amazon S3 object that was previously created by using CreateStoreImageTask. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  createRestoreImageTask(params: EC2.Types.CreateRestoreImageTaskRequest, callback?: (err: AWSError, data: EC2.Types.CreateRestoreImageTaskResult) => void): Request<EC2.Types.CreateRestoreImageTaskResult, AWSError>;
  /**
   * Starts a task that restores an AMI from an Amazon S3 object that was previously created by using CreateStoreImageTask. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  createRestoreImageTask(callback?: (err: AWSError, data: EC2.Types.CreateRestoreImageTaskResult) => void): Request<EC2.Types.CreateRestoreImageTaskResult, AWSError>;
  /**
   * Creates a route in a route table within a VPC. You must specify either a destination CIDR block or a prefix list ID. You must also specify exactly one of the resources from the parameter list. When determining how to route traffic, we use the route with the most specific match. For example, traffic is destined for the IPv4 address 192.0.2.3, and the route table includes the following two IPv4 routes:    192.0.2.0/24 (goes to some target A)    192.0.2.0/28 (goes to some target B)   Both routes apply to the traffic destined for 192.0.2.3. However, the second route in the list covers a smaller number of IP addresses and is therefore more specific, so we use that route to determine where to target the traffic. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  createRoute(params: EC2.Types.CreateRouteRequest, callback?: (err: AWSError, data: EC2.Types.CreateRouteResult) => void): Request<EC2.Types.CreateRouteResult, AWSError>;
  /**
   * Creates a route in a route table within a VPC. You must specify either a destination CIDR block or a prefix list ID. You must also specify exactly one of the resources from the parameter list. When determining how to route traffic, we use the route with the most specific match. For example, traffic is destined for the IPv4 address 192.0.2.3, and the route table includes the following two IPv4 routes:    192.0.2.0/24 (goes to some target A)    192.0.2.0/28 (goes to some target B)   Both routes apply to the traffic destined for 192.0.2.3. However, the second route in the list covers a smaller number of IP addresses and is therefore more specific, so we use that route to determine where to target the traffic. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  createRoute(callback?: (err: AWSError, data: EC2.Types.CreateRouteResult) => void): Request<EC2.Types.CreateRouteResult, AWSError>;
  /**
   * Creates a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  createRouteTable(params: EC2.Types.CreateRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.CreateRouteTableResult) => void): Request<EC2.Types.CreateRouteTableResult, AWSError>;
  /**
   * Creates a route table for the specified VPC. After you create a route table, you can add routes and associate the table with a subnet. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  createRouteTable(callback?: (err: AWSError, data: EC2.Types.CreateRouteTableResult) => void): Request<EC2.Types.CreateRouteTableResult, AWSError>;
  /**
   * Creates a security group. A security group acts as a virtual firewall for your instance to control inbound and outbound traffic. For more information, see Amazon EC2 security groups in the Amazon Elastic Compute Cloud User Guide and Security groups for your VPC in the Amazon Virtual Private Cloud User Guide. When you create a security group, you specify a friendly name of your choice. You can have a security group for use in EC2-Classic with the same name as a security group for use in a VPC. However, you can't have two security groups for use in EC2-Classic with the same name or two security groups for use in a VPC with the same name. You have a default security group for use in EC2-Classic and a default security group for use in your VPC. If you don't specify a security group when you launch an instance, the instance is launched into the appropriate default security group. A default security group includes a default rule that grants instances unrestricted network access to each other. You can add or remove rules from your security groups using AuthorizeSecurityGroupIngress, AuthorizeSecurityGroupEgress, RevokeSecurityGroupIngress, and RevokeSecurityGroupEgress. For more information about VPC security group limits, see Amazon VPC Limits.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  createSecurityGroup(params: EC2.Types.CreateSecurityGroupRequest, callback?: (err: AWSError, data: EC2.Types.CreateSecurityGroupResult) => void): Request<EC2.Types.CreateSecurityGroupResult, AWSError>;
  /**
   * Creates a security group. A security group acts as a virtual firewall for your instance to control inbound and outbound traffic. For more information, see Amazon EC2 security groups in the Amazon Elastic Compute Cloud User Guide and Security groups for your VPC in the Amazon Virtual Private Cloud User Guide. When you create a security group, you specify a friendly name of your choice. You can have a security group for use in EC2-Classic with the same name as a security group for use in a VPC. However, you can't have two security groups for use in EC2-Classic with the same name or two security groups for use in a VPC with the same name. You have a default security group for use in EC2-Classic and a default security group for use in your VPC. If you don't specify a security group when you launch an instance, the instance is launched into the appropriate default security group. A default security group includes a default rule that grants instances unrestricted network access to each other. You can add or remove rules from your security groups using AuthorizeSecurityGroupIngress, AuthorizeSecurityGroupEgress, RevokeSecurityGroupIngress, and RevokeSecurityGroupEgress. For more information about VPC security group limits, see Amazon VPC Limits.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  createSecurityGroup(callback?: (err: AWSError, data: EC2.Types.CreateSecurityGroupResult) => void): Request<EC2.Types.CreateSecurityGroupResult, AWSError>;
  /**
   * Creates a snapshot of an EBS volume and stores it in Amazon S3. You can use snapshots for backups, to make copies of EBS volumes, and to save data before shutting down an instance. You can create snapshots of volumes in a Region and volumes on an Outpost. If you create a snapshot of a volume in a Region, the snapshot must be stored in the same Region as the volume. If you create a snapshot of a volume on an Outpost, the snapshot can be stored on the same Outpost as the volume, or in the Region for that Outpost. When a snapshot is created, any Amazon Web Services Marketplace product codes that are associated with the source volume are propagated to the snapshot. You can take a snapshot of an attached volume that is in use. However, snapshots only capture data that has been written to your Amazon EBS volume at the time the snapshot command is issued; this might exclude any data that has been cached by any applications or the operating system. If you can pause any file systems on the volume long enough to take a snapshot, your snapshot should be complete. However, if you cannot pause all file writes to the volume, you should unmount the volume from within the instance, issue the snapshot command, and then remount the volume to ensure a consistent and complete snapshot. You may remount and use your volume while the snapshot status is pending. When you create a snapshot for an EBS volume that serves as a root device, we recommend that you stop the instance before taking the snapshot. Snapshots that are taken from encrypted volumes are automatically encrypted. Volumes that are created from encrypted snapshots are also automatically encrypted. Your encrypted volumes and any associated snapshots always remain protected. You can tag your snapshots during creation. For more information, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information, see Amazon Elastic Block Store and Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  createSnapshot(params: EC2.Types.CreateSnapshotRequest, callback?: (err: AWSError, data: EC2.Types.Snapshot) => void): Request<EC2.Types.Snapshot, AWSError>;
  /**
   * Creates a snapshot of an EBS volume and stores it in Amazon S3. You can use snapshots for backups, to make copies of EBS volumes, and to save data before shutting down an instance. You can create snapshots of volumes in a Region and volumes on an Outpost. If you create a snapshot of a volume in a Region, the snapshot must be stored in the same Region as the volume. If you create a snapshot of a volume on an Outpost, the snapshot can be stored on the same Outpost as the volume, or in the Region for that Outpost. When a snapshot is created, any Amazon Web Services Marketplace product codes that are associated with the source volume are propagated to the snapshot. You can take a snapshot of an attached volume that is in use. However, snapshots only capture data that has been written to your Amazon EBS volume at the time the snapshot command is issued; this might exclude any data that has been cached by any applications or the operating system. If you can pause any file systems on the volume long enough to take a snapshot, your snapshot should be complete. However, if you cannot pause all file writes to the volume, you should unmount the volume from within the instance, issue the snapshot command, and then remount the volume to ensure a consistent and complete snapshot. You may remount and use your volume while the snapshot status is pending. When you create a snapshot for an EBS volume that serves as a root device, we recommend that you stop the instance before taking the snapshot. Snapshots that are taken from encrypted volumes are automatically encrypted. Volumes that are created from encrypted snapshots are also automatically encrypted. Your encrypted volumes and any associated snapshots always remain protected. You can tag your snapshots during creation. For more information, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information, see Amazon Elastic Block Store and Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  createSnapshot(callback?: (err: AWSError, data: EC2.Types.Snapshot) => void): Request<EC2.Types.Snapshot, AWSError>;
  /**
   * Creates crash-consistent snapshots of multiple EBS volumes and stores the data in S3. Volumes are chosen by specifying an instance. Any attached volumes will produce one snapshot each that is crash-consistent across the instance. You can include all of the volumes currently attached to the instance, or you can exclude the root volume or specific data (non-root) volumes from the multi-volume snapshot set. You can create multi-volume snapshots of instances in a Region and instances on an Outpost. If you create snapshots from an instance in a Region, the snapshots must be stored in the same Region as the instance. If you create snapshots from an instance on an Outpost, the snapshots can be stored on the same Outpost as the instance, or in the Region for that Outpost.
   */
  createSnapshots(params: EC2.Types.CreateSnapshotsRequest, callback?: (err: AWSError, data: EC2.Types.CreateSnapshotsResult) => void): Request<EC2.Types.CreateSnapshotsResult, AWSError>;
  /**
   * Creates crash-consistent snapshots of multiple EBS volumes and stores the data in S3. Volumes are chosen by specifying an instance. Any attached volumes will produce one snapshot each that is crash-consistent across the instance. You can include all of the volumes currently attached to the instance, or you can exclude the root volume or specific data (non-root) volumes from the multi-volume snapshot set. You can create multi-volume snapshots of instances in a Region and instances on an Outpost. If you create snapshots from an instance in a Region, the snapshots must be stored in the same Region as the instance. If you create snapshots from an instance on an Outpost, the snapshots can be stored on the same Outpost as the instance, or in the Region for that Outpost.
   */
  createSnapshots(callback?: (err: AWSError, data: EC2.Types.CreateSnapshotsResult) => void): Request<EC2.Types.CreateSnapshotsResult, AWSError>;
  /**
   * Creates a data feed for Spot Instances, enabling you to view Spot Instance usage logs. You can create one data feed per Amazon Web Services account. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.
   */
  createSpotDatafeedSubscription(params: EC2.Types.CreateSpotDatafeedSubscriptionRequest, callback?: (err: AWSError, data: EC2.Types.CreateSpotDatafeedSubscriptionResult) => void): Request<EC2.Types.CreateSpotDatafeedSubscriptionResult, AWSError>;
  /**
   * Creates a data feed for Spot Instances, enabling you to view Spot Instance usage logs. You can create one data feed per Amazon Web Services account. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.
   */
  createSpotDatafeedSubscription(callback?: (err: AWSError, data: EC2.Types.CreateSpotDatafeedSubscriptionResult) => void): Request<EC2.Types.CreateSpotDatafeedSubscriptionResult, AWSError>;
  /**
   * Stores an AMI as a single object in an Amazon S3 bucket. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  createStoreImageTask(params: EC2.Types.CreateStoreImageTaskRequest, callback?: (err: AWSError, data: EC2.Types.CreateStoreImageTaskResult) => void): Request<EC2.Types.CreateStoreImageTaskResult, AWSError>;
  /**
   * Stores an AMI as a single object in an Amazon S3 bucket. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  createStoreImageTask(callback?: (err: AWSError, data: EC2.Types.CreateStoreImageTaskResult) => void): Request<EC2.Types.CreateStoreImageTaskResult, AWSError>;
  /**
   * Creates a subnet in the specified VPC. For an IPv4 only subnet, specify an IPv4 CIDR block. If the VPC has an IPv6 CIDR block, you can create an IPv6 only subnet or a dual stack subnet instead. For an IPv6 only subnet, specify an IPv6 CIDR block. For a dual stack subnet, specify both an IPv4 CIDR block and an IPv6 CIDR block. A subnet CIDR block must not overlap the CIDR block of an existing subnet in the VPC. After you create a subnet, you can't change its CIDR block. The allowed size for an IPv4 subnet is between a /28 netmask (16 IP addresses) and a /16 netmask (65,536 IP addresses). Amazon Web Services reserves both the first four and the last IPv4 address in each subnet's CIDR block. They're not available for your use. If you've associated an IPv6 CIDR block with your VPC, you can associate an IPv6 CIDR block with a subnet when you create it. The allowed block size for an IPv6 subnet is a /64 netmask. If you add more than one subnet to a VPC, they're set up in a star topology with a logical router in the middle. When you stop an instance in a subnet, it retains its private IPv4 address. It's therefore possible to have a subnet with no running instances (they're all stopped), but no remaining IP addresses available. For more information, see Subnets in the Amazon Virtual Private Cloud User Guide.
   */
  createSubnet(params: EC2.Types.CreateSubnetRequest, callback?: (err: AWSError, data: EC2.Types.CreateSubnetResult) => void): Request<EC2.Types.CreateSubnetResult, AWSError>;
  /**
   * Creates a subnet in the specified VPC. For an IPv4 only subnet, specify an IPv4 CIDR block. If the VPC has an IPv6 CIDR block, you can create an IPv6 only subnet or a dual stack subnet instead. For an IPv6 only subnet, specify an IPv6 CIDR block. For a dual stack subnet, specify both an IPv4 CIDR block and an IPv6 CIDR block. A subnet CIDR block must not overlap the CIDR block of an existing subnet in the VPC. After you create a subnet, you can't change its CIDR block. The allowed size for an IPv4 subnet is between a /28 netmask (16 IP addresses) and a /16 netmask (65,536 IP addresses). Amazon Web Services reserves both the first four and the last IPv4 address in each subnet's CIDR block. They're not available for your use. If you've associated an IPv6 CIDR block with your VPC, you can associate an IPv6 CIDR block with a subnet when you create it. The allowed block size for an IPv6 subnet is a /64 netmask. If you add more than one subnet to a VPC, they're set up in a star topology with a logical router in the middle. When you stop an instance in a subnet, it retains its private IPv4 address. It's therefore possible to have a subnet with no running instances (they're all stopped), but no remaining IP addresses available. For more information, see Subnets in the Amazon Virtual Private Cloud User Guide.
   */
  createSubnet(callback?: (err: AWSError, data: EC2.Types.CreateSubnetResult) => void): Request<EC2.Types.CreateSubnetResult, AWSError>;
  /**
   * Creates a subnet CIDR reservation. For information about subnet CIDR reservations, see Subnet CIDR reservations in the Amazon Virtual Private Cloud User Guide.
   */
  createSubnetCidrReservation(params: EC2.Types.CreateSubnetCidrReservationRequest, callback?: (err: AWSError, data: EC2.Types.CreateSubnetCidrReservationResult) => void): Request<EC2.Types.CreateSubnetCidrReservationResult, AWSError>;
  /**
   * Creates a subnet CIDR reservation. For information about subnet CIDR reservations, see Subnet CIDR reservations in the Amazon Virtual Private Cloud User Guide.
   */
  createSubnetCidrReservation(callback?: (err: AWSError, data: EC2.Types.CreateSubnetCidrReservationResult) => void): Request<EC2.Types.CreateSubnetCidrReservationResult, AWSError>;
  /**
   * Adds or overwrites only the specified tags for the specified Amazon EC2 resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique per resource. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information about creating IAM policies that control users' access to resources based on tags, see Supported resource-level permissions for Amazon EC2 API actions in the Amazon Elastic Compute Cloud User Guide.
   */
  createTags(params: EC2.Types.CreateTagsRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Adds or overwrites only the specified tags for the specified Amazon EC2 resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value. Tag keys must be unique per resource. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information about creating IAM policies that control users' access to resources based on tags, see Supported resource-level permissions for Amazon EC2 API actions in the Amazon Elastic Compute Cloud User Guide.
   */
  createTags(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates a Traffic Mirror filter. A Traffic Mirror filter is a set of rules that defines the traffic to mirror. By default, no traffic is mirrored. To mirror traffic, use CreateTrafficMirrorFilterRule to add Traffic Mirror rules to the filter. The rules you add define what traffic gets mirrored. You can also use ModifyTrafficMirrorFilterNetworkServices to mirror supported network services.
   */
  createTrafficMirrorFilter(params: EC2.Types.CreateTrafficMirrorFilterRequest, callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorFilterResult) => void): Request<EC2.Types.CreateTrafficMirrorFilterResult, AWSError>;
  /**
   * Creates a Traffic Mirror filter. A Traffic Mirror filter is a set of rules that defines the traffic to mirror. By default, no traffic is mirrored. To mirror traffic, use CreateTrafficMirrorFilterRule to add Traffic Mirror rules to the filter. The rules you add define what traffic gets mirrored. You can also use ModifyTrafficMirrorFilterNetworkServices to mirror supported network services.
   */
  createTrafficMirrorFilter(callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorFilterResult) => void): Request<EC2.Types.CreateTrafficMirrorFilterResult, AWSError>;
  /**
   * Creates a Traffic Mirror filter rule. A Traffic Mirror rule defines the Traffic Mirror source traffic to mirror. You need the Traffic Mirror filter ID when you create the rule.
   */
  createTrafficMirrorFilterRule(params: EC2.Types.CreateTrafficMirrorFilterRuleRequest, callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.CreateTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Creates a Traffic Mirror filter rule. A Traffic Mirror rule defines the Traffic Mirror source traffic to mirror. You need the Traffic Mirror filter ID when you create the rule.
   */
  createTrafficMirrorFilterRule(callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.CreateTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Creates a Traffic Mirror session. A Traffic Mirror session actively copies packets from a Traffic Mirror source to a Traffic Mirror target. Create a filter, and then assign it to the session to define a subset of the traffic to mirror, for example all TCP traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in a different VPC connected via VPC peering or a transit gateway.  By default, no traffic is mirrored. Use CreateTrafficMirrorFilter to create filter rules that specify the traffic to mirror.
   */
  createTrafficMirrorSession(params: EC2.Types.CreateTrafficMirrorSessionRequest, callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorSessionResult) => void): Request<EC2.Types.CreateTrafficMirrorSessionResult, AWSError>;
  /**
   * Creates a Traffic Mirror session. A Traffic Mirror session actively copies packets from a Traffic Mirror source to a Traffic Mirror target. Create a filter, and then assign it to the session to define a subset of the traffic to mirror, for example all TCP traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in a different VPC connected via VPC peering or a transit gateway.  By default, no traffic is mirrored. Use CreateTrafficMirrorFilter to create filter rules that specify the traffic to mirror.
   */
  createTrafficMirrorSession(callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorSessionResult) => void): Request<EC2.Types.CreateTrafficMirrorSessionResult, AWSError>;
  /**
   * Creates a target for your Traffic Mirror session. A Traffic Mirror target is the destination for mirrored traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in different VPCs connected via VPC peering or a transit gateway. A Traffic Mirror target can be a network interface, a Network Load Balancer, or a Gateway Load Balancer endpoint. To use the target in a Traffic Mirror session, use CreateTrafficMirrorSession.
   */
  createTrafficMirrorTarget(params: EC2.Types.CreateTrafficMirrorTargetRequest, callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorTargetResult) => void): Request<EC2.Types.CreateTrafficMirrorTargetResult, AWSError>;
  /**
   * Creates a target for your Traffic Mirror session. A Traffic Mirror target is the destination for mirrored traffic. The Traffic Mirror source and the Traffic Mirror target (monitoring appliances) can be in the same VPC, or in different VPCs connected via VPC peering or a transit gateway. A Traffic Mirror target can be a network interface, a Network Load Balancer, or a Gateway Load Balancer endpoint. To use the target in a Traffic Mirror session, use CreateTrafficMirrorSession.
   */
  createTrafficMirrorTarget(callback?: (err: AWSError, data: EC2.Types.CreateTrafficMirrorTargetResult) => void): Request<EC2.Types.CreateTrafficMirrorTargetResult, AWSError>;
  /**
   * Creates a transit gateway. You can use a transit gateway to interconnect your virtual private clouds (VPC) and on-premises networks. After the transit gateway enters the available state, you can attach your VPCs and VPN connections to the transit gateway. To attach your VPCs, use CreateTransitGatewayVpcAttachment. To attach a VPN connection, use CreateCustomerGateway to create a customer gateway and specify the ID of the customer gateway and the ID of the transit gateway in a call to CreateVpnConnection. When you create a transit gateway, we create a default transit gateway route table and use it as the default association route table and the default propagation route table. You can use CreateTransitGatewayRouteTable to create additional transit gateway route tables. If you disable automatic route propagation, we do not create a default transit gateway route table. You can use EnableTransitGatewayRouteTablePropagation to propagate routes from a resource attachment to a transit gateway route table. If you disable automatic associations, you can use AssociateTransitGatewayRouteTable to associate a resource attachment with a transit gateway route table.
   */
  createTransitGateway(params: EC2.Types.CreateTransitGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayResult) => void): Request<EC2.Types.CreateTransitGatewayResult, AWSError>;
  /**
   * Creates a transit gateway. You can use a transit gateway to interconnect your virtual private clouds (VPC) and on-premises networks. After the transit gateway enters the available state, you can attach your VPCs and VPN connections to the transit gateway. To attach your VPCs, use CreateTransitGatewayVpcAttachment. To attach a VPN connection, use CreateCustomerGateway to create a customer gateway and specify the ID of the customer gateway and the ID of the transit gateway in a call to CreateVpnConnection. When you create a transit gateway, we create a default transit gateway route table and use it as the default association route table and the default propagation route table. You can use CreateTransitGatewayRouteTable to create additional transit gateway route tables. If you disable automatic route propagation, we do not create a default transit gateway route table. You can use EnableTransitGatewayRouteTablePropagation to propagate routes from a resource attachment to a transit gateway route table. If you disable automatic associations, you can use AssociateTransitGatewayRouteTable to associate a resource attachment with a transit gateway route table.
   */
  createTransitGateway(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayResult) => void): Request<EC2.Types.CreateTransitGatewayResult, AWSError>;
  /**
   * Creates a Connect attachment from a specified transit gateway attachment. A Connect attachment is a GRE-based tunnel attachment that you can use to establish a connection between a transit gateway and an appliance. A Connect attachment uses an existing VPC or Amazon Web Services Direct Connect attachment as the underlying transport mechanism.
   */
  createTransitGatewayConnect(params: EC2.Types.CreateTransitGatewayConnectRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayConnectResult) => void): Request<EC2.Types.CreateTransitGatewayConnectResult, AWSError>;
  /**
   * Creates a Connect attachment from a specified transit gateway attachment. A Connect attachment is a GRE-based tunnel attachment that you can use to establish a connection between a transit gateway and an appliance. A Connect attachment uses an existing VPC or Amazon Web Services Direct Connect attachment as the underlying transport mechanism.
   */
  createTransitGatewayConnect(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayConnectResult) => void): Request<EC2.Types.CreateTransitGatewayConnectResult, AWSError>;
  /**
   * Creates a Connect peer for a specified transit gateway Connect attachment between a transit gateway and an appliance. The peer address and transit gateway address must be the same IP address family (IPv4 or IPv6). For more information, see Connect peers in the Transit Gateways Guide.
   */
  createTransitGatewayConnectPeer(params: EC2.Types.CreateTransitGatewayConnectPeerRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayConnectPeerResult) => void): Request<EC2.Types.CreateTransitGatewayConnectPeerResult, AWSError>;
  /**
   * Creates a Connect peer for a specified transit gateway Connect attachment between a transit gateway and an appliance. The peer address and transit gateway address must be the same IP address family (IPv4 or IPv6). For more information, see Connect peers in the Transit Gateways Guide.
   */
  createTransitGatewayConnectPeer(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayConnectPeerResult) => void): Request<EC2.Types.CreateTransitGatewayConnectPeerResult, AWSError>;
  /**
   * Creates a multicast domain using the specified transit gateway. The transit gateway must be in the available state before you create a domain. Use DescribeTransitGateways to see the state of transit gateway.
   */
  createTransitGatewayMulticastDomain(params: EC2.Types.CreateTransitGatewayMulticastDomainRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.CreateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Creates a multicast domain using the specified transit gateway. The transit gateway must be in the available state before you create a domain. Use DescribeTransitGateways to see the state of transit gateway.
   */
  createTransitGatewayMulticastDomain(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.CreateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Requests a transit gateway peering attachment between the specified transit gateway (requester) and a peer transit gateway (accepter). The peer transit gateway can be in your account or a different Amazon Web Services account. After you create the peering attachment, the owner of the accepter transit gateway must accept the attachment request.
   */
  createTransitGatewayPeeringAttachment(params: EC2.Types.CreateTransitGatewayPeeringAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.CreateTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Requests a transit gateway peering attachment between the specified transit gateway (requester) and a peer transit gateway (accepter). The peer transit gateway can be in your account or a different Amazon Web Services account. After you create the peering attachment, the owner of the accepter transit gateway must accept the attachment request.
   */
  createTransitGatewayPeeringAttachment(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.CreateTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Creates a transit gateway policy table.
   */
  createTransitGatewayPolicyTable(params: EC2.Types.CreateTransitGatewayPolicyTableRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.CreateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Creates a transit gateway policy table.
   */
  createTransitGatewayPolicyTable(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.CreateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Creates a reference (route) to a prefix list in a specified transit gateway route table.
   */
  createTransitGatewayPrefixListReference(params: EC2.Types.CreateTransitGatewayPrefixListReferenceRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.CreateTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Creates a reference (route) to a prefix list in a specified transit gateway route table.
   */
  createTransitGatewayPrefixListReference(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.CreateTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Creates a static route for the specified transit gateway route table.
   */
  createTransitGatewayRoute(params: EC2.Types.CreateTransitGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteResult) => void): Request<EC2.Types.CreateTransitGatewayRouteResult, AWSError>;
  /**
   * Creates a static route for the specified transit gateway route table.
   */
  createTransitGatewayRoute(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteResult) => void): Request<EC2.Types.CreateTransitGatewayRouteResult, AWSError>;
  /**
   * Creates a route table for the specified transit gateway.
   */
  createTransitGatewayRouteTable(params: EC2.Types.CreateTransitGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteTableResult) => void): Request<EC2.Types.CreateTransitGatewayRouteTableResult, AWSError>;
  /**
   * Creates a route table for the specified transit gateway.
   */
  createTransitGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteTableResult) => void): Request<EC2.Types.CreateTransitGatewayRouteTableResult, AWSError>;
  /**
   * Advertises a new transit gateway route table.
   */
  createTransitGatewayRouteTableAnnouncement(params: EC2.Types.CreateTransitGatewayRouteTableAnnouncementRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteTableAnnouncementResult) => void): Request<EC2.Types.CreateTransitGatewayRouteTableAnnouncementResult, AWSError>;
  /**
   * Advertises a new transit gateway route table.
   */
  createTransitGatewayRouteTableAnnouncement(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayRouteTableAnnouncementResult) => void): Request<EC2.Types.CreateTransitGatewayRouteTableAnnouncementResult, AWSError>;
  /**
   * Attaches the specified VPC to the specified transit gateway. If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that is already attached, the new VPC CIDR range is not propagated to the default propagation route table. To send VPC traffic to an attached transit gateway, add a route to the VPC route table using CreateRoute.
   */
  createTransitGatewayVpcAttachment(params: EC2.Types.CreateTransitGatewayVpcAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.CreateTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Attaches the specified VPC to the specified transit gateway. If you attach a VPC with a CIDR range that overlaps the CIDR range of a VPC that is already attached, the new VPC CIDR range is not propagated to the default propagation route table. To send VPC traffic to an attached transit gateway, add a route to the VPC route table using CreateRoute.
   */
  createTransitGatewayVpcAttachment(callback?: (err: AWSError, data: EC2.Types.CreateTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.CreateTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access endpoint is where you define your application along with an optional endpoint-level access policy.
   */
  createVerifiedAccessEndpoint(params: EC2.Types.CreateVerifiedAccessEndpointRequest, callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessEndpointResult) => void): Request<EC2.Types.CreateVerifiedAccessEndpointResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access endpoint is where you define your application along with an optional endpoint-level access policy.
   */
  createVerifiedAccessEndpoint(callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessEndpointResult) => void): Request<EC2.Types.CreateVerifiedAccessEndpointResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access group is a collection of Amazon Web Services Verified Access endpoints who's associated applications have similar security requirements. Each instance within an Amazon Web Services Verified Access group shares an Amazon Web Services Verified Access policy. For example, you can group all Amazon Web Services Verified Access instances associated with “sales” applications together and use one common Amazon Web Services Verified Access policy.
   */
  createVerifiedAccessGroup(params: EC2.Types.CreateVerifiedAccessGroupRequest, callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessGroupResult) => void): Request<EC2.Types.CreateVerifiedAccessGroupResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access group is a collection of Amazon Web Services Verified Access endpoints who's associated applications have similar security requirements. Each instance within an Amazon Web Services Verified Access group shares an Amazon Web Services Verified Access policy. For example, you can group all Amazon Web Services Verified Access instances associated with “sales” applications together and use one common Amazon Web Services Verified Access policy.
   */
  createVerifiedAccessGroup(callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessGroupResult) => void): Request<EC2.Types.CreateVerifiedAccessGroupResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access instance is a regional entity that evaluates application requests and grants access only when your security requirements are met.
   */
  createVerifiedAccessInstance(params: EC2.Types.CreateVerifiedAccessInstanceRequest, callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessInstanceResult) => void): Request<EC2.Types.CreateVerifiedAccessInstanceResult, AWSError>;
  /**
   * An Amazon Web Services Verified Access instance is a regional entity that evaluates application requests and grants access only when your security requirements are met.
   */
  createVerifiedAccessInstance(callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessInstanceResult) => void): Request<EC2.Types.CreateVerifiedAccessInstanceResult, AWSError>;
  /**
   * A trust provider is a third-party entity that creates, maintains, and manages identity information for users and devices. When an application request is made, the identity information sent by the trust provider will be evaluated by Amazon Web Services Verified Access, before allowing or denying the application request.
   */
  createVerifiedAccessTrustProvider(params: EC2.Types.CreateVerifiedAccessTrustProviderRequest, callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.CreateVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * A trust provider is a third-party entity that creates, maintains, and manages identity information for users and devices. When an application request is made, the identity information sent by the trust provider will be evaluated by Amazon Web Services Verified Access, before allowing or denying the application request.
   */
  createVerifiedAccessTrustProvider(callback?: (err: AWSError, data: EC2.Types.CreateVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.CreateVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Creates an EBS volume that can be attached to an instance in the same Availability Zone. You can create a new empty volume or restore a volume from an EBS snapshot. Any Amazon Web Services Marketplace product codes from the snapshot are propagated to the volume. You can create encrypted volumes. Encrypted volumes must be attached to instances that support Amazon EBS encryption. Volumes that are created from encrypted snapshots are also automatically encrypted. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. You can tag your volumes during creation. For more information, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information, see Create an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  createVolume(params: EC2.Types.CreateVolumeRequest, callback?: (err: AWSError, data: EC2.Types.Volume) => void): Request<EC2.Types.Volume, AWSError>;
  /**
   * Creates an EBS volume that can be attached to an instance in the same Availability Zone. You can create a new empty volume or restore a volume from an EBS snapshot. Any Amazon Web Services Marketplace product codes from the snapshot are propagated to the volume. You can create encrypted volumes. Encrypted volumes must be attached to instances that support Amazon EBS encryption. Volumes that are created from encrypted snapshots are also automatically encrypted. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. You can tag your volumes during creation. For more information, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide. For more information, see Create an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  createVolume(callback?: (err: AWSError, data: EC2.Types.Volume) => void): Request<EC2.Types.Volume, AWSError>;
  /**
   * Creates a VPC with the specified CIDR blocks. For more information, see VPC CIDR blocks in the Amazon Virtual Private Cloud User Guide. You can optionally request an IPv6 CIDR block for the VPC. You can request an Amazon-provided IPv6 CIDR block from Amazon's pool of IPv6 addresses, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). By default, each instance that you launch in the VPC has the default DHCP options, which include only a default DNS server that we provide (AmazonProvidedDNS). For more information, see DHCP option sets in the Amazon Virtual Private Cloud User Guide. You can specify the instance tenancy value for the VPC when you create it. You can't change this value for the VPC after you create it. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.
   */
  createVpc(params: EC2.Types.CreateVpcRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpcResult) => void): Request<EC2.Types.CreateVpcResult, AWSError>;
  /**
   * Creates a VPC with the specified CIDR blocks. For more information, see VPC CIDR blocks in the Amazon Virtual Private Cloud User Guide. You can optionally request an IPv6 CIDR block for the VPC. You can request an Amazon-provided IPv6 CIDR block from Amazon's pool of IPv6 addresses, or an IPv6 CIDR block from an IPv6 address pool that you provisioned through bring your own IP addresses (BYOIP). By default, each instance that you launch in the VPC has the default DHCP options, which include only a default DNS server that we provide (AmazonProvidedDNS). For more information, see DHCP option sets in the Amazon Virtual Private Cloud User Guide. You can specify the instance tenancy value for the VPC when you create it. You can't change this value for the VPC after you create it. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.
   */
  createVpc(callback?: (err: AWSError, data: EC2.Types.CreateVpcResult) => void): Request<EC2.Types.CreateVpcResult, AWSError>;
  /**
   * Creates a VPC endpoint for a specified service. An endpoint enables you to create a private connection between your VPC and the service. The service may be provided by Amazon Web Services, an Amazon Web Services Marketplace Partner, or another Amazon Web Services account. For more information, see the Amazon Web Services PrivateLink Guide.
   */
  createVpcEndpoint(params: EC2.Types.CreateVpcEndpointRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointResult) => void): Request<EC2.Types.CreateVpcEndpointResult, AWSError>;
  /**
   * Creates a VPC endpoint for a specified service. An endpoint enables you to create a private connection between your VPC and the service. The service may be provided by Amazon Web Services, an Amazon Web Services Marketplace Partner, or another Amazon Web Services account. For more information, see the Amazon Web Services PrivateLink Guide.
   */
  createVpcEndpoint(callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointResult) => void): Request<EC2.Types.CreateVpcEndpointResult, AWSError>;
  /**
   * Creates a connection notification for a specified VPC endpoint or VPC endpoint service. A connection notification notifies you of specific endpoint events. You must create an SNS topic to receive notifications. For more information, see Create a Topic in the Amazon Simple Notification Service Developer Guide. You can create a connection notification for interface endpoints only.
   */
  createVpcEndpointConnectionNotification(params: EC2.Types.CreateVpcEndpointConnectionNotificationRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointConnectionNotificationResult) => void): Request<EC2.Types.CreateVpcEndpointConnectionNotificationResult, AWSError>;
  /**
   * Creates a connection notification for a specified VPC endpoint or VPC endpoint service. A connection notification notifies you of specific endpoint events. You must create an SNS topic to receive notifications. For more information, see Create a Topic in the Amazon Simple Notification Service Developer Guide. You can create a connection notification for interface endpoints only.
   */
  createVpcEndpointConnectionNotification(callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointConnectionNotificationResult) => void): Request<EC2.Types.CreateVpcEndpointConnectionNotificationResult, AWSError>;
  /**
   * Creates a VPC endpoint service to which service consumers (Amazon Web Services accounts, users, and IAM roles) can connect. Before you create an endpoint service, you must create one of the following for your service:   A Network Load Balancer. Service consumers connect to your service using an interface endpoint.   A Gateway Load Balancer. Service consumers connect to your service using a Gateway Load Balancer endpoint.   If you set the private DNS name, you must prove that you own the private DNS domain name. For more information, see the Amazon Web Services PrivateLink Guide.
   */
  createVpcEndpointServiceConfiguration(params: EC2.Types.CreateVpcEndpointServiceConfigurationRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointServiceConfigurationResult) => void): Request<EC2.Types.CreateVpcEndpointServiceConfigurationResult, AWSError>;
  /**
   * Creates a VPC endpoint service to which service consumers (Amazon Web Services accounts, users, and IAM roles) can connect. Before you create an endpoint service, you must create one of the following for your service:   A Network Load Balancer. Service consumers connect to your service using an interface endpoint.   A Gateway Load Balancer. Service consumers connect to your service using a Gateway Load Balancer endpoint.   If you set the private DNS name, you must prove that you own the private DNS domain name. For more information, see the Amazon Web Services PrivateLink Guide.
   */
  createVpcEndpointServiceConfiguration(callback?: (err: AWSError, data: EC2.Types.CreateVpcEndpointServiceConfigurationResult) => void): Request<EC2.Types.CreateVpcEndpointServiceConfigurationResult, AWSError>;
  /**
   * Requests a VPC peering connection between two VPCs: a requester VPC that you own and an accepter VPC with which to create the connection. The accepter VPC can belong to another Amazon Web Services account and can be in a different Region to the requester VPC. The requester VPC and accepter VPC cannot have overlapping CIDR blocks.  Limitations and rules apply to a VPC peering connection. For more information, see the limitations section in the VPC Peering Guide.  The owner of the accepter VPC must accept the peering request to activate the peering connection. The VPC peering connection request expires after 7 days, after which it cannot be accepted or rejected. If you create a VPC peering connection request between VPCs with overlapping CIDR blocks, the VPC peering connection has a status of failed.
   */
  createVpcPeeringConnection(params: EC2.Types.CreateVpcPeeringConnectionRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpcPeeringConnectionResult) => void): Request<EC2.Types.CreateVpcPeeringConnectionResult, AWSError>;
  /**
   * Requests a VPC peering connection between two VPCs: a requester VPC that you own and an accepter VPC with which to create the connection. The accepter VPC can belong to another Amazon Web Services account and can be in a different Region to the requester VPC. The requester VPC and accepter VPC cannot have overlapping CIDR blocks.  Limitations and rules apply to a VPC peering connection. For more information, see the limitations section in the VPC Peering Guide.  The owner of the accepter VPC must accept the peering request to activate the peering connection. The VPC peering connection request expires after 7 days, after which it cannot be accepted or rejected. If you create a VPC peering connection request between VPCs with overlapping CIDR blocks, the VPC peering connection has a status of failed.
   */
  createVpcPeeringConnection(callback?: (err: AWSError, data: EC2.Types.CreateVpcPeeringConnectionResult) => void): Request<EC2.Types.CreateVpcPeeringConnectionResult, AWSError>;
  /**
   * Creates a VPN connection between an existing virtual private gateway or transit gateway and a customer gateway. The supported connection type is ipsec.1. The response includes information that you need to give to your network administrator to configure your customer gateway.  We strongly recommend that you use HTTPS when calling this operation because the response contains sensitive cryptographic information for configuring your customer gateway device.  If you decide to shut down your VPN connection for any reason and later create a new VPN connection, you must reconfigure your customer gateway with the new information returned from this call. This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnConnection(params: EC2.Types.CreateVpnConnectionRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpnConnectionResult) => void): Request<EC2.Types.CreateVpnConnectionResult, AWSError>;
  /**
   * Creates a VPN connection between an existing virtual private gateway or transit gateway and a customer gateway. The supported connection type is ipsec.1. The response includes information that you need to give to your network administrator to configure your customer gateway.  We strongly recommend that you use HTTPS when calling this operation because the response contains sensitive cryptographic information for configuring your customer gateway device.  If you decide to shut down your VPN connection for any reason and later create a new VPN connection, you must reconfigure your customer gateway with the new information returned from this call. This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnConnection(callback?: (err: AWSError, data: EC2.Types.CreateVpnConnectionResult) => void): Request<EC2.Types.CreateVpnConnectionResult, AWSError>;
  /**
   * Creates a static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnConnectionRoute(params: EC2.Types.CreateVpnConnectionRouteRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates a static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnConnectionRoute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates a virtual private gateway. A virtual private gateway is the endpoint on the VPC side of your VPN connection. You can create a virtual private gateway before creating the VPC itself. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnGateway(params: EC2.Types.CreateVpnGatewayRequest, callback?: (err: AWSError, data: EC2.Types.CreateVpnGatewayResult) => void): Request<EC2.Types.CreateVpnGatewayResult, AWSError>;
  /**
   * Creates a virtual private gateway. A virtual private gateway is the endpoint on the VPC side of your VPN connection. You can create a virtual private gateway before creating the VPC itself. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  createVpnGateway(callback?: (err: AWSError, data: EC2.Types.CreateVpnGatewayResult) => void): Request<EC2.Types.CreateVpnGatewayResult, AWSError>;
  /**
   * Deletes a carrier gateway.  If you do not delete the route that contains the carrier gateway as the Target, the route is a blackhole route. For information about how to delete a route, see DeleteRoute. 
   */
  deleteCarrierGateway(params: EC2.Types.DeleteCarrierGatewayRequest, callback?: (err: AWSError, data: EC2.Types.DeleteCarrierGatewayResult) => void): Request<EC2.Types.DeleteCarrierGatewayResult, AWSError>;
  /**
   * Deletes a carrier gateway.  If you do not delete the route that contains the carrier gateway as the Target, the route is a blackhole route. For information about how to delete a route, see DeleteRoute. 
   */
  deleteCarrierGateway(callback?: (err: AWSError, data: EC2.Types.DeleteCarrierGatewayResult) => void): Request<EC2.Types.DeleteCarrierGatewayResult, AWSError>;
  /**
   * Deletes the specified Client VPN endpoint. You must disassociate all target networks before you can delete a Client VPN endpoint.
   */
  deleteClientVpnEndpoint(params: EC2.Types.DeleteClientVpnEndpointRequest, callback?: (err: AWSError, data: EC2.Types.DeleteClientVpnEndpointResult) => void): Request<EC2.Types.DeleteClientVpnEndpointResult, AWSError>;
  /**
   * Deletes the specified Client VPN endpoint. You must disassociate all target networks before you can delete a Client VPN endpoint.
   */
  deleteClientVpnEndpoint(callback?: (err: AWSError, data: EC2.Types.DeleteClientVpnEndpointResult) => void): Request<EC2.Types.DeleteClientVpnEndpointResult, AWSError>;
  /**
   * Deletes a route from a Client VPN endpoint. You can only delete routes that you manually added using the CreateClientVpnRoute action. You cannot delete routes that were automatically added when associating a subnet. To remove routes that have been automatically added, disassociate the target subnet from the Client VPN endpoint.
   */
  deleteClientVpnRoute(params: EC2.Types.DeleteClientVpnRouteRequest, callback?: (err: AWSError, data: EC2.Types.DeleteClientVpnRouteResult) => void): Request<EC2.Types.DeleteClientVpnRouteResult, AWSError>;
  /**
   * Deletes a route from a Client VPN endpoint. You can only delete routes that you manually added using the CreateClientVpnRoute action. You cannot delete routes that were automatically added when associating a subnet. To remove routes that have been automatically added, disassociate the target subnet from the Client VPN endpoint.
   */
  deleteClientVpnRoute(callback?: (err: AWSError, data: EC2.Types.DeleteClientVpnRouteResult) => void): Request<EC2.Types.DeleteClientVpnRouteResult, AWSError>;
  /**
   *  Deletes a range of customer-owned IP addresses. 
   */
  deleteCoipCidr(params: EC2.Types.DeleteCoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.DeleteCoipCidrResult) => void): Request<EC2.Types.DeleteCoipCidrResult, AWSError>;
  /**
   *  Deletes a range of customer-owned IP addresses. 
   */
  deleteCoipCidr(callback?: (err: AWSError, data: EC2.Types.DeleteCoipCidrResult) => void): Request<EC2.Types.DeleteCoipCidrResult, AWSError>;
  /**
   * Deletes a pool of customer-owned IP (CoIP) addresses. 
   */
  deleteCoipPool(params: EC2.Types.DeleteCoipPoolRequest, callback?: (err: AWSError, data: EC2.Types.DeleteCoipPoolResult) => void): Request<EC2.Types.DeleteCoipPoolResult, AWSError>;
  /**
   * Deletes a pool of customer-owned IP (CoIP) addresses. 
   */
  deleteCoipPool(callback?: (err: AWSError, data: EC2.Types.DeleteCoipPoolResult) => void): Request<EC2.Types.DeleteCoipPoolResult, AWSError>;
  /**
   * Deletes the specified customer gateway. You must delete the VPN connection before you can delete the customer gateway.
   */
  deleteCustomerGateway(params: EC2.Types.DeleteCustomerGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified customer gateway. You must delete the VPN connection before you can delete the customer gateway.
   */
  deleteCustomerGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified set of DHCP options. You must disassociate the set of DHCP options before you can delete it. You can disassociate the set of DHCP options by associating either a new set of options or the default set of options with the VPC.
   */
  deleteDhcpOptions(params: EC2.Types.DeleteDhcpOptionsRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified set of DHCP options. You must disassociate the set of DHCP options before you can delete it. You can disassociate the set of DHCP options by associating either a new set of options or the default set of options with the VPC.
   */
  deleteDhcpOptions(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes an egress-only internet gateway.
   */
  deleteEgressOnlyInternetGateway(params: EC2.Types.DeleteEgressOnlyInternetGatewayRequest, callback?: (err: AWSError, data: EC2.Types.DeleteEgressOnlyInternetGatewayResult) => void): Request<EC2.Types.DeleteEgressOnlyInternetGatewayResult, AWSError>;
  /**
   * Deletes an egress-only internet gateway.
   */
  deleteEgressOnlyInternetGateway(callback?: (err: AWSError, data: EC2.Types.DeleteEgressOnlyInternetGatewayResult) => void): Request<EC2.Types.DeleteEgressOnlyInternetGatewayResult, AWSError>;
  /**
   * Deletes the specified EC2 Fleets. After you delete an EC2 Fleet, it launches no new instances. You must also specify whether a deleted EC2 Fleet should terminate its instances. If you choose to terminate the instances, the EC2 Fleet enters the deleted_terminating state. Otherwise, the EC2 Fleet enters the deleted_running state, and the instances continue to run until they are interrupted or you terminate them manually. For instant fleets, EC2 Fleet must terminate the instances when the fleet is deleted. A deleted instant fleet with running instances is not supported.  Restrictions    You can delete up to 25 instant fleets in a single request. If you exceed this number, no instant fleets are deleted and an error is returned. There is no restriction on the number of fleets of type maintain or request that can be deleted in a single request.   Up to 1000 instances can be terminated in a single request to delete instant fleets.   For more information, see Delete an EC2 Fleet in the Amazon EC2 User Guide.
   */
  deleteFleets(params: EC2.Types.DeleteFleetsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteFleetsResult) => void): Request<EC2.Types.DeleteFleetsResult, AWSError>;
  /**
   * Deletes the specified EC2 Fleets. After you delete an EC2 Fleet, it launches no new instances. You must also specify whether a deleted EC2 Fleet should terminate its instances. If you choose to terminate the instances, the EC2 Fleet enters the deleted_terminating state. Otherwise, the EC2 Fleet enters the deleted_running state, and the instances continue to run until they are interrupted or you terminate them manually. For instant fleets, EC2 Fleet must terminate the instances when the fleet is deleted. A deleted instant fleet with running instances is not supported.  Restrictions    You can delete up to 25 instant fleets in a single request. If you exceed this number, no instant fleets are deleted and an error is returned. There is no restriction on the number of fleets of type maintain or request that can be deleted in a single request.   Up to 1000 instances can be terminated in a single request to delete instant fleets.   For more information, see Delete an EC2 Fleet in the Amazon EC2 User Guide.
   */
  deleteFleets(callback?: (err: AWSError, data: EC2.Types.DeleteFleetsResult) => void): Request<EC2.Types.DeleteFleetsResult, AWSError>;
  /**
   * Deletes one or more flow logs.
   */
  deleteFlowLogs(params: EC2.Types.DeleteFlowLogsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteFlowLogsResult) => void): Request<EC2.Types.DeleteFlowLogsResult, AWSError>;
  /**
   * Deletes one or more flow logs.
   */
  deleteFlowLogs(callback?: (err: AWSError, data: EC2.Types.DeleteFlowLogsResult) => void): Request<EC2.Types.DeleteFlowLogsResult, AWSError>;
  /**
   * Deletes the specified Amazon FPGA Image (AFI).
   */
  deleteFpgaImage(params: EC2.Types.DeleteFpgaImageRequest, callback?: (err: AWSError, data: EC2.Types.DeleteFpgaImageResult) => void): Request<EC2.Types.DeleteFpgaImageResult, AWSError>;
  /**
   * Deletes the specified Amazon FPGA Image (AFI).
   */
  deleteFpgaImage(callback?: (err: AWSError, data: EC2.Types.DeleteFpgaImageResult) => void): Request<EC2.Types.DeleteFpgaImageResult, AWSError>;
  /**
   * Deletes the specified event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  deleteInstanceEventWindow(params: EC2.Types.DeleteInstanceEventWindowRequest, callback?: (err: AWSError, data: EC2.Types.DeleteInstanceEventWindowResult) => void): Request<EC2.Types.DeleteInstanceEventWindowResult, AWSError>;
  /**
   * Deletes the specified event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  deleteInstanceEventWindow(callback?: (err: AWSError, data: EC2.Types.DeleteInstanceEventWindowResult) => void): Request<EC2.Types.DeleteInstanceEventWindowResult, AWSError>;
  /**
   * Deletes the specified internet gateway. You must detach the internet gateway from the VPC before you can delete it.
   */
  deleteInternetGateway(params: EC2.Types.DeleteInternetGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified internet gateway. You must detach the internet gateway from the VPC before you can delete it.
   */
  deleteInternetGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Delete an IPAM. Deleting an IPAM removes all monitored data associated with the IPAM including the historical data for CIDRs. For more information, see Delete an IPAM in the Amazon VPC IPAM User Guide. 
   */
  deleteIpam(params: EC2.Types.DeleteIpamRequest, callback?: (err: AWSError, data: EC2.Types.DeleteIpamResult) => void): Request<EC2.Types.DeleteIpamResult, AWSError>;
  /**
   * Delete an IPAM. Deleting an IPAM removes all monitored data associated with the IPAM including the historical data for CIDRs. For more information, see Delete an IPAM in the Amazon VPC IPAM User Guide. 
   */
  deleteIpam(callback?: (err: AWSError, data: EC2.Types.DeleteIpamResult) => void): Request<EC2.Types.DeleteIpamResult, AWSError>;
  /**
   * Delete an IPAM pool.  You cannot delete an IPAM pool if there are allocations in it or CIDRs provisioned to it. To release allocations, see ReleaseIpamPoolAllocation. To deprovision pool CIDRs, see DeprovisionIpamPoolCidr.  For more information, see Delete a pool in the Amazon VPC IPAM User Guide. 
   */
  deleteIpamPool(params: EC2.Types.DeleteIpamPoolRequest, callback?: (err: AWSError, data: EC2.Types.DeleteIpamPoolResult) => void): Request<EC2.Types.DeleteIpamPoolResult, AWSError>;
  /**
   * Delete an IPAM pool.  You cannot delete an IPAM pool if there are allocations in it or CIDRs provisioned to it. To release allocations, see ReleaseIpamPoolAllocation. To deprovision pool CIDRs, see DeprovisionIpamPoolCidr.  For more information, see Delete a pool in the Amazon VPC IPAM User Guide. 
   */
  deleteIpamPool(callback?: (err: AWSError, data: EC2.Types.DeleteIpamPoolResult) => void): Request<EC2.Types.DeleteIpamPoolResult, AWSError>;
  /**
   * Deletes an IPAM resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  deleteIpamResourceDiscovery(params: EC2.Types.DeleteIpamResourceDiscoveryRequest, callback?: (err: AWSError, data: EC2.Types.DeleteIpamResourceDiscoveryResult) => void): Request<EC2.Types.DeleteIpamResourceDiscoveryResult, AWSError>;
  /**
   * Deletes an IPAM resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  deleteIpamResourceDiscovery(callback?: (err: AWSError, data: EC2.Types.DeleteIpamResourceDiscoveryResult) => void): Request<EC2.Types.DeleteIpamResourceDiscoveryResult, AWSError>;
  /**
   * Delete the scope for an IPAM. You cannot delete the default scopes. For more information, see Delete a scope in the Amazon VPC IPAM User Guide. 
   */
  deleteIpamScope(params: EC2.Types.DeleteIpamScopeRequest, callback?: (err: AWSError, data: EC2.Types.DeleteIpamScopeResult) => void): Request<EC2.Types.DeleteIpamScopeResult, AWSError>;
  /**
   * Delete the scope for an IPAM. You cannot delete the default scopes. For more information, see Delete a scope in the Amazon VPC IPAM User Guide. 
   */
  deleteIpamScope(callback?: (err: AWSError, data: EC2.Types.DeleteIpamScopeResult) => void): Request<EC2.Types.DeleteIpamScopeResult, AWSError>;
  /**
   * Deletes the specified key pair, by removing the public key from Amazon EC2.
   */
  deleteKeyPair(params: EC2.Types.DeleteKeyPairRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified key pair, by removing the public key from Amazon EC2.
   */
  deleteKeyPair(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes a launch template. Deleting a launch template deletes all of its versions.
   */
  deleteLaunchTemplate(params: EC2.Types.DeleteLaunchTemplateRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLaunchTemplateResult) => void): Request<EC2.Types.DeleteLaunchTemplateResult, AWSError>;
  /**
   * Deletes a launch template. Deleting a launch template deletes all of its versions.
   */
  deleteLaunchTemplate(callback?: (err: AWSError, data: EC2.Types.DeleteLaunchTemplateResult) => void): Request<EC2.Types.DeleteLaunchTemplateResult, AWSError>;
  /**
   * Deletes one or more versions of a launch template. You cannot delete the default version of a launch template; you must first assign a different version as the default. If the default version is the only version for the launch template, you must delete the entire launch template using DeleteLaunchTemplate.
   */
  deleteLaunchTemplateVersions(params: EC2.Types.DeleteLaunchTemplateVersionsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLaunchTemplateVersionsResult) => void): Request<EC2.Types.DeleteLaunchTemplateVersionsResult, AWSError>;
  /**
   * Deletes one or more versions of a launch template. You cannot delete the default version of a launch template; you must first assign a different version as the default. If the default version is the only version for the launch template, you must delete the entire launch template using DeleteLaunchTemplate.
   */
  deleteLaunchTemplateVersions(callback?: (err: AWSError, data: EC2.Types.DeleteLaunchTemplateVersionsResult) => void): Request<EC2.Types.DeleteLaunchTemplateVersionsResult, AWSError>;
  /**
   * Deletes the specified route from the specified local gateway route table.
   */
  deleteLocalGatewayRoute(params: EC2.Types.DeleteLocalGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteResult, AWSError>;
  /**
   * Deletes the specified route from the specified local gateway route table.
   */
  deleteLocalGatewayRoute(callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteResult, AWSError>;
  /**
   *  Deletes a local gateway route table. 
   */
  deleteLocalGatewayRouteTable(params: EC2.Types.DeleteLocalGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableResult, AWSError>;
  /**
   *  Deletes a local gateway route table. 
   */
  deleteLocalGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableResult, AWSError>;
  /**
   *  Deletes a local gateway route table virtual interface group association. 
   */
  deleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation(params: EC2.Types.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult, AWSError>;
  /**
   *  Deletes a local gateway route table virtual interface group association. 
   */
  deleteLocalGatewayRouteTableVirtualInterfaceGroupAssociation(callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult, AWSError>;
  /**
   * Deletes the specified association between a VPC and local gateway route table.
   */
  deleteLocalGatewayRouteTableVpcAssociation(params: EC2.Types.DeleteLocalGatewayRouteTableVpcAssociationRequest, callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableVpcAssociationResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableVpcAssociationResult, AWSError>;
  /**
   * Deletes the specified association between a VPC and local gateway route table.
   */
  deleteLocalGatewayRouteTableVpcAssociation(callback?: (err: AWSError, data: EC2.Types.DeleteLocalGatewayRouteTableVpcAssociationResult) => void): Request<EC2.Types.DeleteLocalGatewayRouteTableVpcAssociationResult, AWSError>;
  /**
   * Deletes the specified managed prefix list. You must first remove all references to the prefix list in your resources.
   */
  deleteManagedPrefixList(params: EC2.Types.DeleteManagedPrefixListRequest, callback?: (err: AWSError, data: EC2.Types.DeleteManagedPrefixListResult) => void): Request<EC2.Types.DeleteManagedPrefixListResult, AWSError>;
  /**
   * Deletes the specified managed prefix list. You must first remove all references to the prefix list in your resources.
   */
  deleteManagedPrefixList(callback?: (err: AWSError, data: EC2.Types.DeleteManagedPrefixListResult) => void): Request<EC2.Types.DeleteManagedPrefixListResult, AWSError>;
  /**
   * Deletes the specified NAT gateway. Deleting a public NAT gateway disassociates its Elastic IP address, but does not release the address from your account. Deleting a NAT gateway does not delete any NAT gateway routes in your route tables.
   */
  deleteNatGateway(params: EC2.Types.DeleteNatGatewayRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNatGatewayResult) => void): Request<EC2.Types.DeleteNatGatewayResult, AWSError>;
  /**
   * Deletes the specified NAT gateway. Deleting a public NAT gateway disassociates its Elastic IP address, but does not release the address from your account. Deleting a NAT gateway does not delete any NAT gateway routes in your route tables.
   */
  deleteNatGateway(callback?: (err: AWSError, data: EC2.Types.DeleteNatGatewayResult) => void): Request<EC2.Types.DeleteNatGatewayResult, AWSError>;
  /**
   * Deletes the specified network ACL. You can't delete the ACL if it's associated with any subnets. You can't delete the default network ACL.
   */
  deleteNetworkAcl(params: EC2.Types.DeleteNetworkAclRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified network ACL. You can't delete the ACL if it's associated with any subnets. You can't delete the default network ACL.
   */
  deleteNetworkAcl(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified ingress or egress entry (rule) from the specified network ACL.
   */
  deleteNetworkAclEntry(params: EC2.Types.DeleteNetworkAclEntryRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified ingress or egress entry (rule) from the specified network ACL.
   */
  deleteNetworkAclEntry(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified Network Access Scope.
   */
  deleteNetworkInsightsAccessScope(params: EC2.Types.DeleteNetworkInsightsAccessScopeRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAccessScopeResult) => void): Request<EC2.Types.DeleteNetworkInsightsAccessScopeResult, AWSError>;
  /**
   * Deletes the specified Network Access Scope.
   */
  deleteNetworkInsightsAccessScope(callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAccessScopeResult) => void): Request<EC2.Types.DeleteNetworkInsightsAccessScopeResult, AWSError>;
  /**
   * Deletes the specified Network Access Scope analysis.
   */
  deleteNetworkInsightsAccessScopeAnalysis(params: EC2.Types.DeleteNetworkInsightsAccessScopeAnalysisRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAccessScopeAnalysisResult) => void): Request<EC2.Types.DeleteNetworkInsightsAccessScopeAnalysisResult, AWSError>;
  /**
   * Deletes the specified Network Access Scope analysis.
   */
  deleteNetworkInsightsAccessScopeAnalysis(callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAccessScopeAnalysisResult) => void): Request<EC2.Types.DeleteNetworkInsightsAccessScopeAnalysisResult, AWSError>;
  /**
   * Deletes the specified network insights analysis.
   */
  deleteNetworkInsightsAnalysis(params: EC2.Types.DeleteNetworkInsightsAnalysisRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAnalysisResult) => void): Request<EC2.Types.DeleteNetworkInsightsAnalysisResult, AWSError>;
  /**
   * Deletes the specified network insights analysis.
   */
  deleteNetworkInsightsAnalysis(callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsAnalysisResult) => void): Request<EC2.Types.DeleteNetworkInsightsAnalysisResult, AWSError>;
  /**
   * Deletes the specified path.
   */
  deleteNetworkInsightsPath(params: EC2.Types.DeleteNetworkInsightsPathRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsPathResult) => void): Request<EC2.Types.DeleteNetworkInsightsPathResult, AWSError>;
  /**
   * Deletes the specified path.
   */
  deleteNetworkInsightsPath(callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInsightsPathResult) => void): Request<EC2.Types.DeleteNetworkInsightsPathResult, AWSError>;
  /**
   * Deletes the specified network interface. You must detach the network interface before you can delete it.
   */
  deleteNetworkInterface(params: EC2.Types.DeleteNetworkInterfaceRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified network interface. You must detach the network interface before you can delete it.
   */
  deleteNetworkInterface(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes a permission for a network interface. By default, you cannot delete the permission if the account for which you're removing the permission has attached the network interface to an instance. However, you can force delete the permission, regardless of any attachment.
   */
  deleteNetworkInterfacePermission(params: EC2.Types.DeleteNetworkInterfacePermissionRequest, callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInterfacePermissionResult) => void): Request<EC2.Types.DeleteNetworkInterfacePermissionResult, AWSError>;
  /**
   * Deletes a permission for a network interface. By default, you cannot delete the permission if the account for which you're removing the permission has attached the network interface to an instance. However, you can force delete the permission, regardless of any attachment.
   */
  deleteNetworkInterfacePermission(callback?: (err: AWSError, data: EC2.Types.DeleteNetworkInterfacePermissionResult) => void): Request<EC2.Types.DeleteNetworkInterfacePermissionResult, AWSError>;
  /**
   * Deletes the specified placement group. You must terminate all instances in the placement group before you can delete the placement group. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  deletePlacementGroup(params: EC2.Types.DeletePlacementGroupRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified placement group. You must terminate all instances in the placement group before you can delete the placement group. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  deletePlacementGroup(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Delete a public IPv4 pool. A public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs that you own and bring to Amazon Web Services to manage with IPAM. IPv6 addresses you bring to Amazon Web Services, however, use IPAM pools only.
   */
  deletePublicIpv4Pool(params: EC2.Types.DeletePublicIpv4PoolRequest, callback?: (err: AWSError, data: EC2.Types.DeletePublicIpv4PoolResult) => void): Request<EC2.Types.DeletePublicIpv4PoolResult, AWSError>;
  /**
   * Delete a public IPv4 pool. A public IPv4 pool is an EC2 IP address pool required for the public IPv4 CIDRs that you own and bring to Amazon Web Services to manage with IPAM. IPv6 addresses you bring to Amazon Web Services, however, use IPAM pools only.
   */
  deletePublicIpv4Pool(callback?: (err: AWSError, data: EC2.Types.DeletePublicIpv4PoolResult) => void): Request<EC2.Types.DeletePublicIpv4PoolResult, AWSError>;
  /**
   * Deletes the queued purchases for the specified Reserved Instances.
   */
  deleteQueuedReservedInstances(params: EC2.Types.DeleteQueuedReservedInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DeleteQueuedReservedInstancesResult) => void): Request<EC2.Types.DeleteQueuedReservedInstancesResult, AWSError>;
  /**
   * Deletes the queued purchases for the specified Reserved Instances.
   */
  deleteQueuedReservedInstances(callback?: (err: AWSError, data: EC2.Types.DeleteQueuedReservedInstancesResult) => void): Request<EC2.Types.DeleteQueuedReservedInstancesResult, AWSError>;
  /**
   * Deletes the specified route from the specified route table.
   */
  deleteRoute(params: EC2.Types.DeleteRouteRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified route from the specified route table.
   */
  deleteRoute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified route table. You must disassociate the route table from any subnets before you can delete it. You can't delete the main route table.
   */
  deleteRouteTable(params: EC2.Types.DeleteRouteTableRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified route table. You must disassociate the route table from any subnets before you can delete it. You can't delete the main route table.
   */
  deleteRouteTable(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes a security group. If you attempt to delete a security group that is associated with an instance, or is referenced by another security group, the operation fails with InvalidGroup.InUse in EC2-Classic or DependencyViolation in EC2-VPC.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  deleteSecurityGroup(params: EC2.Types.DeleteSecurityGroupRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes a security group. If you attempt to delete a security group that is associated with an instance, or is referenced by another security group, the operation fails with InvalidGroup.InUse in EC2-Classic or DependencyViolation in EC2-VPC.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  deleteSecurityGroup(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified snapshot. When you make periodic snapshots of a volume, the snapshots are incremental, and only the blocks on the device that have changed since your last snapshot are saved in the new snapshot. When you delete a snapshot, only the data not needed for any other snapshot is removed. So regardless of which prior snapshots have been deleted, all active snapshots will have access to all the information needed to restore the volume. You cannot delete a snapshot of the root device of an EBS volume used by a registered AMI. You must first de-register the AMI before you can delete the snapshot. For more information, see Delete an Amazon EBS snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteSnapshot(params: EC2.Types.DeleteSnapshotRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified snapshot. When you make periodic snapshots of a volume, the snapshots are incremental, and only the blocks on the device that have changed since your last snapshot are saved in the new snapshot. When you delete a snapshot, only the data not needed for any other snapshot is removed. So regardless of which prior snapshots have been deleted, all active snapshots will have access to all the information needed to restore the volume. You cannot delete a snapshot of the root device of an EBS volume used by a registered AMI. You must first de-register the AMI before you can delete the snapshot. For more information, see Delete an Amazon EBS snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteSnapshot(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the data feed for Spot Instances.
   */
  deleteSpotDatafeedSubscription(params: EC2.Types.DeleteSpotDatafeedSubscriptionRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the data feed for Spot Instances.
   */
  deleteSpotDatafeedSubscription(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified subnet. You must terminate all running instances in the subnet before you can delete the subnet.
   */
  deleteSubnet(params: EC2.Types.DeleteSubnetRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified subnet. You must terminate all running instances in the subnet before you can delete the subnet.
   */
  deleteSubnet(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes a subnet CIDR reservation.
   */
  deleteSubnetCidrReservation(params: EC2.Types.DeleteSubnetCidrReservationRequest, callback?: (err: AWSError, data: EC2.Types.DeleteSubnetCidrReservationResult) => void): Request<EC2.Types.DeleteSubnetCidrReservationResult, AWSError>;
  /**
   * Deletes a subnet CIDR reservation.
   */
  deleteSubnetCidrReservation(callback?: (err: AWSError, data: EC2.Types.DeleteSubnetCidrReservationResult) => void): Request<EC2.Types.DeleteSubnetCidrReservationResult, AWSError>;
  /**
   * Deletes the specified set of tags from the specified set of resources. To list the current tags, use DescribeTags. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteTags(params: EC2.Types.DeleteTagsRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified set of tags from the specified set of resources. To list the current tags, use DescribeTags. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteTags(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified Traffic Mirror filter. You cannot delete a Traffic Mirror filter that is in use by a Traffic Mirror session.
   */
  deleteTrafficMirrorFilter(params: EC2.Types.DeleteTrafficMirrorFilterRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorFilterResult) => void): Request<EC2.Types.DeleteTrafficMirrorFilterResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror filter. You cannot delete a Traffic Mirror filter that is in use by a Traffic Mirror session.
   */
  deleteTrafficMirrorFilter(callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorFilterResult) => void): Request<EC2.Types.DeleteTrafficMirrorFilterResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror rule.
   */
  deleteTrafficMirrorFilterRule(params: EC2.Types.DeleteTrafficMirrorFilterRuleRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.DeleteTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror rule.
   */
  deleteTrafficMirrorFilterRule(callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.DeleteTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror session.
   */
  deleteTrafficMirrorSession(params: EC2.Types.DeleteTrafficMirrorSessionRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorSessionResult) => void): Request<EC2.Types.DeleteTrafficMirrorSessionResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror session.
   */
  deleteTrafficMirrorSession(callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorSessionResult) => void): Request<EC2.Types.DeleteTrafficMirrorSessionResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror target. You cannot delete a Traffic Mirror target that is in use by a Traffic Mirror session.
   */
  deleteTrafficMirrorTarget(params: EC2.Types.DeleteTrafficMirrorTargetRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorTargetResult) => void): Request<EC2.Types.DeleteTrafficMirrorTargetResult, AWSError>;
  /**
   * Deletes the specified Traffic Mirror target. You cannot delete a Traffic Mirror target that is in use by a Traffic Mirror session.
   */
  deleteTrafficMirrorTarget(callback?: (err: AWSError, data: EC2.Types.DeleteTrafficMirrorTargetResult) => void): Request<EC2.Types.DeleteTrafficMirrorTargetResult, AWSError>;
  /**
   * Deletes the specified transit gateway.
   */
  deleteTransitGateway(params: EC2.Types.DeleteTransitGatewayRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayResult) => void): Request<EC2.Types.DeleteTransitGatewayResult, AWSError>;
  /**
   * Deletes the specified transit gateway.
   */
  deleteTransitGateway(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayResult) => void): Request<EC2.Types.DeleteTransitGatewayResult, AWSError>;
  /**
   * Deletes the specified Connect attachment. You must first delete any Connect peers for the attachment.
   */
  deleteTransitGatewayConnect(params: EC2.Types.DeleteTransitGatewayConnectRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayConnectResult) => void): Request<EC2.Types.DeleteTransitGatewayConnectResult, AWSError>;
  /**
   * Deletes the specified Connect attachment. You must first delete any Connect peers for the attachment.
   */
  deleteTransitGatewayConnect(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayConnectResult) => void): Request<EC2.Types.DeleteTransitGatewayConnectResult, AWSError>;
  /**
   * Deletes the specified Connect peer.
   */
  deleteTransitGatewayConnectPeer(params: EC2.Types.DeleteTransitGatewayConnectPeerRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayConnectPeerResult) => void): Request<EC2.Types.DeleteTransitGatewayConnectPeerResult, AWSError>;
  /**
   * Deletes the specified Connect peer.
   */
  deleteTransitGatewayConnectPeer(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayConnectPeerResult) => void): Request<EC2.Types.DeleteTransitGatewayConnectPeerResult, AWSError>;
  /**
   * Deletes the specified transit gateway multicast domain.
   */
  deleteTransitGatewayMulticastDomain(params: EC2.Types.DeleteTransitGatewayMulticastDomainRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.DeleteTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Deletes the specified transit gateway multicast domain.
   */
  deleteTransitGatewayMulticastDomain(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.DeleteTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Deletes a transit gateway peering attachment.
   */
  deleteTransitGatewayPeeringAttachment(params: EC2.Types.DeleteTransitGatewayPeeringAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.DeleteTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Deletes a transit gateway peering attachment.
   */
  deleteTransitGatewayPeeringAttachment(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.DeleteTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Deletes the specified transit gateway policy table.
   */
  deleteTransitGatewayPolicyTable(params: EC2.Types.DeleteTransitGatewayPolicyTableRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPolicyTableResult) => void): Request<EC2.Types.DeleteTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Deletes the specified transit gateway policy table.
   */
  deleteTransitGatewayPolicyTable(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPolicyTableResult) => void): Request<EC2.Types.DeleteTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Deletes a reference (route) to a prefix list in a specified transit gateway route table.
   */
  deleteTransitGatewayPrefixListReference(params: EC2.Types.DeleteTransitGatewayPrefixListReferenceRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.DeleteTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Deletes a reference (route) to a prefix list in a specified transit gateway route table.
   */
  deleteTransitGatewayPrefixListReference(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.DeleteTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Deletes the specified route from the specified transit gateway route table.
   */
  deleteTransitGatewayRoute(params: EC2.Types.DeleteTransitGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteResult, AWSError>;
  /**
   * Deletes the specified route from the specified transit gateway route table.
   */
  deleteTransitGatewayRoute(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteResult, AWSError>;
  /**
   * Deletes the specified transit gateway route table. You must disassociate the route table from any transit gateway route tables before you can delete it.
   */
  deleteTransitGatewayRouteTable(params: EC2.Types.DeleteTransitGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteTableResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteTableResult, AWSError>;
  /**
   * Deletes the specified transit gateway route table. You must disassociate the route table from any transit gateway route tables before you can delete it.
   */
  deleteTransitGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteTableResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteTableResult, AWSError>;
  /**
   * Advertises to the transit gateway that a transit gateway route table is deleted.
   */
  deleteTransitGatewayRouteTableAnnouncement(params: EC2.Types.DeleteTransitGatewayRouteTableAnnouncementRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteTableAnnouncementResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteTableAnnouncementResult, AWSError>;
  /**
   * Advertises to the transit gateway that a transit gateway route table is deleted.
   */
  deleteTransitGatewayRouteTableAnnouncement(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayRouteTableAnnouncementResult) => void): Request<EC2.Types.DeleteTransitGatewayRouteTableAnnouncementResult, AWSError>;
  /**
   * Deletes the specified VPC attachment.
   */
  deleteTransitGatewayVpcAttachment(params: EC2.Types.DeleteTransitGatewayVpcAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.DeleteTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Deletes the specified VPC attachment.
   */
  deleteTransitGatewayVpcAttachment(callback?: (err: AWSError, data: EC2.Types.DeleteTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.DeleteTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access endpoint.
   */
  deleteVerifiedAccessEndpoint(params: EC2.Types.DeleteVerifiedAccessEndpointRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessEndpointResult) => void): Request<EC2.Types.DeleteVerifiedAccessEndpointResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access endpoint.
   */
  deleteVerifiedAccessEndpoint(callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessEndpointResult) => void): Request<EC2.Types.DeleteVerifiedAccessEndpointResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access group.
   */
  deleteVerifiedAccessGroup(params: EC2.Types.DeleteVerifiedAccessGroupRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessGroupResult) => void): Request<EC2.Types.DeleteVerifiedAccessGroupResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access group.
   */
  deleteVerifiedAccessGroup(callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessGroupResult) => void): Request<EC2.Types.DeleteVerifiedAccessGroupResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access instance.
   */
  deleteVerifiedAccessInstance(params: EC2.Types.DeleteVerifiedAccessInstanceRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessInstanceResult) => void): Request<EC2.Types.DeleteVerifiedAccessInstanceResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access instance.
   */
  deleteVerifiedAccessInstance(callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessInstanceResult) => void): Request<EC2.Types.DeleteVerifiedAccessInstanceResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access trust provider.
   */
  deleteVerifiedAccessTrustProvider(params: EC2.Types.DeleteVerifiedAccessTrustProviderRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.DeleteVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Delete an Amazon Web Services Verified Access trust provider.
   */
  deleteVerifiedAccessTrustProvider(callback?: (err: AWSError, data: EC2.Types.DeleteVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.DeleteVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Deletes the specified EBS volume. The volume must be in the available state (not attached to an instance). The volume can remain in the deleting state for several minutes. For more information, see Delete an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteVolume(params: EC2.Types.DeleteVolumeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified EBS volume. The volume must be in the available state (not attached to an instance). The volume can remain in the deleting state for several minutes. For more information, see Delete an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  deleteVolume(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified VPC. You must detach or delete all gateways and resources that are associated with the VPC before you can delete it. For example, you must terminate all instances running in the VPC, delete all security groups associated with the VPC (except the default one), delete all route tables associated with the VPC (except the default one), and so on.
   */
  deleteVpc(params: EC2.Types.DeleteVpcRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified VPC. You must detach or delete all gateways and resources that are associated with the VPC before you can delete it. For example, you must terminate all instances running in the VPC, delete all security groups associated with the VPC (except the default one), delete all route tables associated with the VPC (except the default one), and so on.
   */
  deleteVpc(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified VPC endpoint connection notifications.
   */
  deleteVpcEndpointConnectionNotifications(params: EC2.Types.DeleteVpcEndpointConnectionNotificationsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointConnectionNotificationsResult) => void): Request<EC2.Types.DeleteVpcEndpointConnectionNotificationsResult, AWSError>;
  /**
   * Deletes the specified VPC endpoint connection notifications.
   */
  deleteVpcEndpointConnectionNotifications(callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointConnectionNotificationsResult) => void): Request<EC2.Types.DeleteVpcEndpointConnectionNotificationsResult, AWSError>;
  /**
   * Deletes the specified VPC endpoint service configurations. Before you can delete an endpoint service configuration, you must reject any Available or PendingAcceptance interface endpoint connections that are attached to the service.
   */
  deleteVpcEndpointServiceConfigurations(params: EC2.Types.DeleteVpcEndpointServiceConfigurationsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointServiceConfigurationsResult) => void): Request<EC2.Types.DeleteVpcEndpointServiceConfigurationsResult, AWSError>;
  /**
   * Deletes the specified VPC endpoint service configurations. Before you can delete an endpoint service configuration, you must reject any Available or PendingAcceptance interface endpoint connections that are attached to the service.
   */
  deleteVpcEndpointServiceConfigurations(callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointServiceConfigurationsResult) => void): Request<EC2.Types.DeleteVpcEndpointServiceConfigurationsResult, AWSError>;
  /**
   * Deletes the specified VPC endpoints. When you delete a gateway endpoint, we delete the endpoint routes in the route tables for the endpoint. When you delete a Gateway Load Balancer endpoint, we delete its endpoint network interfaces. You can only delete Gateway Load Balancer endpoints when the routes that are associated with the endpoint are deleted. When you delete an interface endpoint, we delete its endpoint network interfaces.
   */
  deleteVpcEndpoints(params: EC2.Types.DeleteVpcEndpointsRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointsResult) => void): Request<EC2.Types.DeleteVpcEndpointsResult, AWSError>;
  /**
   * Deletes the specified VPC endpoints. When you delete a gateway endpoint, we delete the endpoint routes in the route tables for the endpoint. When you delete a Gateway Load Balancer endpoint, we delete its endpoint network interfaces. You can only delete Gateway Load Balancer endpoints when the routes that are associated with the endpoint are deleted. When you delete an interface endpoint, we delete its endpoint network interfaces.
   */
  deleteVpcEndpoints(callback?: (err: AWSError, data: EC2.Types.DeleteVpcEndpointsResult) => void): Request<EC2.Types.DeleteVpcEndpointsResult, AWSError>;
  /**
   * Deletes a VPC peering connection. Either the owner of the requester VPC or the owner of the accepter VPC can delete the VPC peering connection if it's in the active state. The owner of the requester VPC can delete a VPC peering connection in the pending-acceptance state. You cannot delete a VPC peering connection that's in the failed state.
   */
  deleteVpcPeeringConnection(params: EC2.Types.DeleteVpcPeeringConnectionRequest, callback?: (err: AWSError, data: EC2.Types.DeleteVpcPeeringConnectionResult) => void): Request<EC2.Types.DeleteVpcPeeringConnectionResult, AWSError>;
  /**
   * Deletes a VPC peering connection. Either the owner of the requester VPC or the owner of the accepter VPC can delete the VPC peering connection if it's in the active state. The owner of the requester VPC can delete a VPC peering connection in the pending-acceptance state. You cannot delete a VPC peering connection that's in the failed state.
   */
  deleteVpcPeeringConnection(callback?: (err: AWSError, data: EC2.Types.DeleteVpcPeeringConnectionResult) => void): Request<EC2.Types.DeleteVpcPeeringConnectionResult, AWSError>;
  /**
   * Deletes the specified VPN connection. If you're deleting the VPC and its associated components, we recommend that you detach the virtual private gateway from the VPC and delete the VPC before deleting the VPN connection. If you believe that the tunnel credentials for your VPN connection have been compromised, you can delete the VPN connection and create a new one that has new keys, without needing to delete the VPC or virtual private gateway. If you create a new VPN connection, you must reconfigure the customer gateway device using the new configuration information returned with the new VPN connection ID. For certificate-based authentication, delete all Certificate Manager (ACM) private certificates used for the Amazon Web Services-side tunnel endpoints for the VPN connection before deleting the VPN connection.
   */
  deleteVpnConnection(params: EC2.Types.DeleteVpnConnectionRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified VPN connection. If you're deleting the VPC and its associated components, we recommend that you detach the virtual private gateway from the VPC and delete the VPC before deleting the VPN connection. If you believe that the tunnel credentials for your VPN connection have been compromised, you can delete the VPN connection and create a new one that has new keys, without needing to delete the VPC or virtual private gateway. If you create a new VPN connection, you must reconfigure the customer gateway device using the new configuration information returned with the new VPN connection ID. For certificate-based authentication, delete all Certificate Manager (ACM) private certificates used for the Amazon Web Services-side tunnel endpoints for the VPN connection before deleting the VPN connection.
   */
  deleteVpnConnection(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.
   */
  deleteVpnConnectionRoute(params: EC2.Types.DeleteVpnConnectionRouteRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified static route associated with a VPN connection between an existing virtual private gateway and a VPN customer gateway. The static route allows traffic to be routed from the virtual private gateway to the VPN customer gateway.
   */
  deleteVpnConnectionRoute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified virtual private gateway. You must first detach the virtual private gateway from the VPC. Note that you don't need to delete the virtual private gateway if you plan to delete and recreate the VPN connection between your VPC and your network.
   */
  deleteVpnGateway(params: EC2.Types.DeleteVpnGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deletes the specified virtual private gateway. You must first detach the virtual private gateway from the VPC. Note that you don't need to delete the virtual private gateway if you plan to delete and recreate the VPN connection between your VPC and your network.
   */
  deleteVpnGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Releases the specified address range that you provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool. Before you can release an address range, you must stop advertising it using WithdrawByoipCidr and you must not have any IP addresses allocated from its address range.
   */
  deprovisionByoipCidr(params: EC2.Types.DeprovisionByoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.DeprovisionByoipCidrResult) => void): Request<EC2.Types.DeprovisionByoipCidrResult, AWSError>;
  /**
   * Releases the specified address range that you provisioned for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and deletes the corresponding address pool. Before you can release an address range, you must stop advertising it using WithdrawByoipCidr and you must not have any IP addresses allocated from its address range.
   */
  deprovisionByoipCidr(callback?: (err: AWSError, data: EC2.Types.DeprovisionByoipCidrResult) => void): Request<EC2.Types.DeprovisionByoipCidrResult, AWSError>;
  /**
   * Deprovision a CIDR provisioned from an IPAM pool. If you deprovision a CIDR from a pool that has a source pool, the CIDR is recycled back into the source pool. For more information, see Deprovision pool CIDRs in the Amazon VPC IPAM User Guide.
   */
  deprovisionIpamPoolCidr(params: EC2.Types.DeprovisionIpamPoolCidrRequest, callback?: (err: AWSError, data: EC2.Types.DeprovisionIpamPoolCidrResult) => void): Request<EC2.Types.DeprovisionIpamPoolCidrResult, AWSError>;
  /**
   * Deprovision a CIDR provisioned from an IPAM pool. If you deprovision a CIDR from a pool that has a source pool, the CIDR is recycled back into the source pool. For more information, see Deprovision pool CIDRs in the Amazon VPC IPAM User Guide.
   */
  deprovisionIpamPoolCidr(callback?: (err: AWSError, data: EC2.Types.DeprovisionIpamPoolCidrResult) => void): Request<EC2.Types.DeprovisionIpamPoolCidrResult, AWSError>;
  /**
   * Deprovision a CIDR from a public IPv4 pool.
   */
  deprovisionPublicIpv4PoolCidr(params: EC2.Types.DeprovisionPublicIpv4PoolCidrRequest, callback?: (err: AWSError, data: EC2.Types.DeprovisionPublicIpv4PoolCidrResult) => void): Request<EC2.Types.DeprovisionPublicIpv4PoolCidrResult, AWSError>;
  /**
   * Deprovision a CIDR from a public IPv4 pool.
   */
  deprovisionPublicIpv4PoolCidr(callback?: (err: AWSError, data: EC2.Types.DeprovisionPublicIpv4PoolCidrResult) => void): Request<EC2.Types.DeprovisionPublicIpv4PoolCidrResult, AWSError>;
  /**
   * Deregisters the specified AMI. After you deregister an AMI, it can't be used to launch new instances. If you deregister an AMI that matches a Recycle Bin retention rule, the AMI is retained in the Recycle Bin for the specified retention period. For more information, see Recycle Bin in the Amazon EC2 User Guide. When you deregister an AMI, it doesn't affect any instances that you've already launched from the AMI. You'll continue to incur usage costs for those instances until you terminate them. When you deregister an Amazon EBS-backed AMI, it doesn't affect the snapshot that was created for the root volume of the instance during the AMI creation process. When you deregister an instance store-backed AMI, it doesn't affect the files that you uploaded to Amazon S3 when you created the AMI.
   */
  deregisterImage(params: EC2.Types.DeregisterImageRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deregisters the specified AMI. After you deregister an AMI, it can't be used to launch new instances. If you deregister an AMI that matches a Recycle Bin retention rule, the AMI is retained in the Recycle Bin for the specified retention period. For more information, see Recycle Bin in the Amazon EC2 User Guide. When you deregister an AMI, it doesn't affect any instances that you've already launched from the AMI. You'll continue to incur usage costs for those instances until you terminate them. When you deregister an Amazon EBS-backed AMI, it doesn't affect the snapshot that was created for the root volume of the instance during the AMI creation process. When you deregister an instance store-backed AMI, it doesn't affect the files that you uploaded to Amazon S3 when you created the AMI.
   */
  deregisterImage(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region.
   */
  deregisterInstanceEventNotificationAttributes(params: EC2.Types.DeregisterInstanceEventNotificationAttributesRequest, callback?: (err: AWSError, data: EC2.Types.DeregisterInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.DeregisterInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Deregisters tag keys to prevent tags that have the specified tag keys from being included in scheduled event notifications for resources in the Region.
   */
  deregisterInstanceEventNotificationAttributes(callback?: (err: AWSError, data: EC2.Types.DeregisterInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.DeregisterInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Deregisters the specified members (network interfaces) from the transit gateway multicast group.
   */
  deregisterTransitGatewayMulticastGroupMembers(params: EC2.Types.DeregisterTransitGatewayMulticastGroupMembersRequest, callback?: (err: AWSError, data: EC2.Types.DeregisterTransitGatewayMulticastGroupMembersResult) => void): Request<EC2.Types.DeregisterTransitGatewayMulticastGroupMembersResult, AWSError>;
  /**
   * Deregisters the specified members (network interfaces) from the transit gateway multicast group.
   */
  deregisterTransitGatewayMulticastGroupMembers(callback?: (err: AWSError, data: EC2.Types.DeregisterTransitGatewayMulticastGroupMembersResult) => void): Request<EC2.Types.DeregisterTransitGatewayMulticastGroupMembersResult, AWSError>;
  /**
   * Deregisters the specified sources (network interfaces) from the transit gateway multicast group.
   */
  deregisterTransitGatewayMulticastGroupSources(params: EC2.Types.DeregisterTransitGatewayMulticastGroupSourcesRequest, callback?: (err: AWSError, data: EC2.Types.DeregisterTransitGatewayMulticastGroupSourcesResult) => void): Request<EC2.Types.DeregisterTransitGatewayMulticastGroupSourcesResult, AWSError>;
  /**
   * Deregisters the specified sources (network interfaces) from the transit gateway multicast group.
   */
  deregisterTransitGatewayMulticastGroupSources(callback?: (err: AWSError, data: EC2.Types.DeregisterTransitGatewayMulticastGroupSourcesResult) => void): Request<EC2.Types.DeregisterTransitGatewayMulticastGroupSourcesResult, AWSError>;
  /**
   * Describes attributes of your Amazon Web Services account. The following are the supported account attributes:    supported-platforms: Indicates whether your account can launch instances into EC2-Classic and EC2-VPC, or only into EC2-VPC.    default-vpc: The ID of the default VPC for your account, or none.    max-instances: This attribute is no longer supported. The returned value does not reflect your actual vCPU limit for running On-Demand Instances. For more information, see On-Demand Instance Limits in the Amazon Elastic Compute Cloud User Guide.    vpc-max-security-groups-per-interface: The maximum number of security groups that you can assign to a network interface.    max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-Classic.     vpc-max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-VPC.    We are retiring EC2-Classic on August 15, 2022. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide. 
   */
  describeAccountAttributes(params: EC2.Types.DescribeAccountAttributesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAccountAttributesResult) => void): Request<EC2.Types.DescribeAccountAttributesResult, AWSError>;
  /**
   * Describes attributes of your Amazon Web Services account. The following are the supported account attributes:    supported-platforms: Indicates whether your account can launch instances into EC2-Classic and EC2-VPC, or only into EC2-VPC.    default-vpc: The ID of the default VPC for your account, or none.    max-instances: This attribute is no longer supported. The returned value does not reflect your actual vCPU limit for running On-Demand Instances. For more information, see On-Demand Instance Limits in the Amazon Elastic Compute Cloud User Guide.    vpc-max-security-groups-per-interface: The maximum number of security groups that you can assign to a network interface.    max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-Classic.     vpc-max-elastic-ips: The maximum number of Elastic IP addresses that you can allocate for use with EC2-VPC.    We are retiring EC2-Classic on August 15, 2022. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide. 
   */
  describeAccountAttributes(callback?: (err: AWSError, data: EC2.Types.DescribeAccountAttributesResult) => void): Request<EC2.Types.DescribeAccountAttributesResult, AWSError>;
  /**
   * Describes an Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  describeAddressTransfers(params: EC2.Types.DescribeAddressTransfersRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAddressTransfersResult) => void): Request<EC2.Types.DescribeAddressTransfersResult, AWSError>;
  /**
   * Describes an Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  describeAddressTransfers(callback?: (err: AWSError, data: EC2.Types.DescribeAddressTransfersResult) => void): Request<EC2.Types.DescribeAddressTransfersResult, AWSError>;
  /**
   * Describes the specified Elastic IP addresses or all of your Elastic IP addresses. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeAddresses(params: EC2.Types.DescribeAddressesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAddressesResult) => void): Request<EC2.Types.DescribeAddressesResult, AWSError>;
  /**
   * Describes the specified Elastic IP addresses or all of your Elastic IP addresses. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeAddresses(callback?: (err: AWSError, data: EC2.Types.DescribeAddressesResult) => void): Request<EC2.Types.DescribeAddressesResult, AWSError>;
  /**
   * Describes the attributes of the specified Elastic IP addresses. For requirements, see Using reverse DNS for email applications.
   */
  describeAddressesAttribute(params: EC2.Types.DescribeAddressesAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAddressesAttributeResult) => void): Request<EC2.Types.DescribeAddressesAttributeResult, AWSError>;
  /**
   * Describes the attributes of the specified Elastic IP addresses. For requirements, see Using reverse DNS for email applications.
   */
  describeAddressesAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeAddressesAttributeResult) => void): Request<EC2.Types.DescribeAddressesAttributeResult, AWSError>;
  /**
   * Describes the longer ID format settings for all resource types in a specific Region. This request is useful for performing a quick audit to determine whether a specific Region is fully opted in for longer IDs (17-character IDs). This request only returns information about resource types that support longer IDs. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.
   */
  describeAggregateIdFormat(params: EC2.Types.DescribeAggregateIdFormatRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAggregateIdFormatResult) => void): Request<EC2.Types.DescribeAggregateIdFormatResult, AWSError>;
  /**
   * Describes the longer ID format settings for all resource types in a specific Region. This request is useful for performing a quick audit to determine whether a specific Region is fully opted in for longer IDs (17-character IDs). This request only returns information about resource types that support longer IDs. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.
   */
  describeAggregateIdFormat(callback?: (err: AWSError, data: EC2.Types.DescribeAggregateIdFormatResult) => void): Request<EC2.Types.DescribeAggregateIdFormatResult, AWSError>;
  /**
   * Describes the Availability Zones, Local Zones, and Wavelength Zones that are available to you. If there is an event impacting a zone, you can use this request to view the state and any provided messages for that zone. For more information about Availability Zones, Local Zones, and Wavelength Zones, see Regions and zones in the Amazon Elastic Compute Cloud User Guide.
   */
  describeAvailabilityZones(params: EC2.Types.DescribeAvailabilityZonesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAvailabilityZonesResult) => void): Request<EC2.Types.DescribeAvailabilityZonesResult, AWSError>;
  /**
   * Describes the Availability Zones, Local Zones, and Wavelength Zones that are available to you. If there is an event impacting a zone, you can use this request to view the state and any provided messages for that zone. For more information about Availability Zones, Local Zones, and Wavelength Zones, see Regions and zones in the Amazon Elastic Compute Cloud User Guide.
   */
  describeAvailabilityZones(callback?: (err: AWSError, data: EC2.Types.DescribeAvailabilityZonesResult) => void): Request<EC2.Types.DescribeAvailabilityZonesResult, AWSError>;
  /**
   * Describes the current Infrastructure Performance metric subscriptions.
   */
  describeAwsNetworkPerformanceMetricSubscriptions(params: EC2.Types.DescribeAwsNetworkPerformanceMetricSubscriptionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeAwsNetworkPerformanceMetricSubscriptionsResult) => void): Request<EC2.Types.DescribeAwsNetworkPerformanceMetricSubscriptionsResult, AWSError>;
  /**
   * Describes the current Infrastructure Performance metric subscriptions.
   */
  describeAwsNetworkPerformanceMetricSubscriptions(callback?: (err: AWSError, data: EC2.Types.DescribeAwsNetworkPerformanceMetricSubscriptionsResult) => void): Request<EC2.Types.DescribeAwsNetworkPerformanceMetricSubscriptionsResult, AWSError>;
  /**
   * Describes the specified bundle tasks or all of your bundle tasks.  Completed bundle tasks are listed for only a limited time. If your bundle task is no longer in the list, you can still register an AMI from it. Just use RegisterImage with the Amazon S3 bucket name and image manifest name you provided to the bundle task. 
   */
  describeBundleTasks(params: EC2.Types.DescribeBundleTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeBundleTasksResult) => void): Request<EC2.Types.DescribeBundleTasksResult, AWSError>;
  /**
   * Describes the specified bundle tasks or all of your bundle tasks.  Completed bundle tasks are listed for only a limited time. If your bundle task is no longer in the list, you can still register an AMI from it. Just use RegisterImage with the Amazon S3 bucket name and image manifest name you provided to the bundle task. 
   */
  describeBundleTasks(callback?: (err: AWSError, data: EC2.Types.DescribeBundleTasksResult) => void): Request<EC2.Types.DescribeBundleTasksResult, AWSError>;
  /**
   * Describes the IP address ranges that were specified in calls to ProvisionByoipCidr. To describe the address pools that were created when you provisioned the address ranges, use DescribePublicIpv4Pools or DescribeIpv6Pools.
   */
  describeByoipCidrs(params: EC2.Types.DescribeByoipCidrsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeByoipCidrsResult) => void): Request<EC2.Types.DescribeByoipCidrsResult, AWSError>;
  /**
   * Describes the IP address ranges that were specified in calls to ProvisionByoipCidr. To describe the address pools that were created when you provisioned the address ranges, use DescribePublicIpv4Pools or DescribeIpv6Pools.
   */
  describeByoipCidrs(callback?: (err: AWSError, data: EC2.Types.DescribeByoipCidrsResult) => void): Request<EC2.Types.DescribeByoipCidrsResult, AWSError>;
  /**
   * Describes one or more Capacity Reservation Fleets.
   */
  describeCapacityReservationFleets(params: EC2.Types.DescribeCapacityReservationFleetsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeCapacityReservationFleetsResult) => void): Request<EC2.Types.DescribeCapacityReservationFleetsResult, AWSError>;
  /**
   * Describes one or more Capacity Reservation Fleets.
   */
  describeCapacityReservationFleets(callback?: (err: AWSError, data: EC2.Types.DescribeCapacityReservationFleetsResult) => void): Request<EC2.Types.DescribeCapacityReservationFleetsResult, AWSError>;
  /**
   * Describes one or more of your Capacity Reservations. The results describe only the Capacity Reservations in the Amazon Web Services Region that you're currently using.
   */
  describeCapacityReservations(params: EC2.Types.DescribeCapacityReservationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeCapacityReservationsResult) => void): Request<EC2.Types.DescribeCapacityReservationsResult, AWSError>;
  /**
   * Describes one or more of your Capacity Reservations. The results describe only the Capacity Reservations in the Amazon Web Services Region that you're currently using.
   */
  describeCapacityReservations(callback?: (err: AWSError, data: EC2.Types.DescribeCapacityReservationsResult) => void): Request<EC2.Types.DescribeCapacityReservationsResult, AWSError>;
  /**
   * Describes one or more of your carrier gateways.
   */
  describeCarrierGateways(params: EC2.Types.DescribeCarrierGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeCarrierGatewaysResult) => void): Request<EC2.Types.DescribeCarrierGatewaysResult, AWSError>;
  /**
   * Describes one or more of your carrier gateways.
   */
  describeCarrierGateways(callback?: (err: AWSError, data: EC2.Types.DescribeCarrierGatewaysResult) => void): Request<EC2.Types.DescribeCarrierGatewaysResult, AWSError>;
  /**
   * Describes one or more of your linked EC2-Classic instances. This request only returns information about EC2-Classic instances linked to a VPC through ClassicLink. You cannot use this request to return information about other instances.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeClassicLinkInstances(params: EC2.Types.DescribeClassicLinkInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClassicLinkInstancesResult) => void): Request<EC2.Types.DescribeClassicLinkInstancesResult, AWSError>;
  /**
   * Describes one or more of your linked EC2-Classic instances. This request only returns information about EC2-Classic instances linked to a VPC through ClassicLink. You cannot use this request to return information about other instances.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeClassicLinkInstances(callback?: (err: AWSError, data: EC2.Types.DescribeClassicLinkInstancesResult) => void): Request<EC2.Types.DescribeClassicLinkInstancesResult, AWSError>;
  /**
   * Describes the authorization rules for a specified Client VPN endpoint.
   */
  describeClientVpnAuthorizationRules(params: EC2.Types.DescribeClientVpnAuthorizationRulesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnAuthorizationRulesResult) => void): Request<EC2.Types.DescribeClientVpnAuthorizationRulesResult, AWSError>;
  /**
   * Describes the authorization rules for a specified Client VPN endpoint.
   */
  describeClientVpnAuthorizationRules(callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnAuthorizationRulesResult) => void): Request<EC2.Types.DescribeClientVpnAuthorizationRulesResult, AWSError>;
  /**
   * Describes active client connections and connections that have been terminated within the last 60 minutes for the specified Client VPN endpoint.
   */
  describeClientVpnConnections(params: EC2.Types.DescribeClientVpnConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnConnectionsResult) => void): Request<EC2.Types.DescribeClientVpnConnectionsResult, AWSError>;
  /**
   * Describes active client connections and connections that have been terminated within the last 60 minutes for the specified Client VPN endpoint.
   */
  describeClientVpnConnections(callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnConnectionsResult) => void): Request<EC2.Types.DescribeClientVpnConnectionsResult, AWSError>;
  /**
   * Describes one or more Client VPN endpoints in the account.
   */
  describeClientVpnEndpoints(params: EC2.Types.DescribeClientVpnEndpointsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnEndpointsResult) => void): Request<EC2.Types.DescribeClientVpnEndpointsResult, AWSError>;
  /**
   * Describes one or more Client VPN endpoints in the account.
   */
  describeClientVpnEndpoints(callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnEndpointsResult) => void): Request<EC2.Types.DescribeClientVpnEndpointsResult, AWSError>;
  /**
   * Describes the routes for the specified Client VPN endpoint.
   */
  describeClientVpnRoutes(params: EC2.Types.DescribeClientVpnRoutesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnRoutesResult) => void): Request<EC2.Types.DescribeClientVpnRoutesResult, AWSError>;
  /**
   * Describes the routes for the specified Client VPN endpoint.
   */
  describeClientVpnRoutes(callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnRoutesResult) => void): Request<EC2.Types.DescribeClientVpnRoutesResult, AWSError>;
  /**
   * Describes the target networks associated with the specified Client VPN endpoint.
   */
  describeClientVpnTargetNetworks(params: EC2.Types.DescribeClientVpnTargetNetworksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnTargetNetworksResult) => void): Request<EC2.Types.DescribeClientVpnTargetNetworksResult, AWSError>;
  /**
   * Describes the target networks associated with the specified Client VPN endpoint.
   */
  describeClientVpnTargetNetworks(callback?: (err: AWSError, data: EC2.Types.DescribeClientVpnTargetNetworksResult) => void): Request<EC2.Types.DescribeClientVpnTargetNetworksResult, AWSError>;
  /**
   * Describes the specified customer-owned address pools or all of your customer-owned address pools.
   */
  describeCoipPools(params: EC2.Types.DescribeCoipPoolsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeCoipPoolsResult) => void): Request<EC2.Types.DescribeCoipPoolsResult, AWSError>;
  /**
   * Describes the specified customer-owned address pools or all of your customer-owned address pools.
   */
  describeCoipPools(callback?: (err: AWSError, data: EC2.Types.DescribeCoipPoolsResult) => void): Request<EC2.Types.DescribeCoipPoolsResult, AWSError>;
  /**
   * Describes the specified conversion tasks or all your conversion tasks. For more information, see the VM Import/Export User Guide. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  describeConversionTasks(params: EC2.Types.DescribeConversionTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Describes the specified conversion tasks or all your conversion tasks. For more information, see the VM Import/Export User Guide. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  describeConversionTasks(callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Describes one or more of your VPN customer gateways. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeCustomerGateways(params: EC2.Types.DescribeCustomerGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeCustomerGatewaysResult) => void): Request<EC2.Types.DescribeCustomerGatewaysResult, AWSError>;
  /**
   * Describes one or more of your VPN customer gateways. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeCustomerGateways(callback?: (err: AWSError, data: EC2.Types.DescribeCustomerGatewaysResult) => void): Request<EC2.Types.DescribeCustomerGatewaysResult, AWSError>;
  /**
   * Describes one or more of your DHCP options sets. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  describeDhcpOptions(params: EC2.Types.DescribeDhcpOptionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeDhcpOptionsResult) => void): Request<EC2.Types.DescribeDhcpOptionsResult, AWSError>;
  /**
   * Describes one or more of your DHCP options sets. For more information, see DHCP options sets in the Amazon Virtual Private Cloud User Guide.
   */
  describeDhcpOptions(callback?: (err: AWSError, data: EC2.Types.DescribeDhcpOptionsResult) => void): Request<EC2.Types.DescribeDhcpOptionsResult, AWSError>;
  /**
   * Describes one or more of your egress-only internet gateways.
   */
  describeEgressOnlyInternetGateways(params: EC2.Types.DescribeEgressOnlyInternetGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeEgressOnlyInternetGatewaysResult) => void): Request<EC2.Types.DescribeEgressOnlyInternetGatewaysResult, AWSError>;
  /**
   * Describes one or more of your egress-only internet gateways.
   */
  describeEgressOnlyInternetGateways(callback?: (err: AWSError, data: EC2.Types.DescribeEgressOnlyInternetGatewaysResult) => void): Request<EC2.Types.DescribeEgressOnlyInternetGatewaysResult, AWSError>;
  /**
   * Describes the Elastic Graphics accelerator associated with your instances. For more information about Elastic Graphics, see Amazon Elastic Graphics.
   */
  describeElasticGpus(params: EC2.Types.DescribeElasticGpusRequest, callback?: (err: AWSError, data: EC2.Types.DescribeElasticGpusResult) => void): Request<EC2.Types.DescribeElasticGpusResult, AWSError>;
  /**
   * Describes the Elastic Graphics accelerator associated with your instances. For more information about Elastic Graphics, see Amazon Elastic Graphics.
   */
  describeElasticGpus(callback?: (err: AWSError, data: EC2.Types.DescribeElasticGpusResult) => void): Request<EC2.Types.DescribeElasticGpusResult, AWSError>;
  /**
   * Describes the specified export image tasks or all of your export image tasks.
   */
  describeExportImageTasks(params: EC2.Types.DescribeExportImageTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeExportImageTasksResult) => void): Request<EC2.Types.DescribeExportImageTasksResult, AWSError>;
  /**
   * Describes the specified export image tasks or all of your export image tasks.
   */
  describeExportImageTasks(callback?: (err: AWSError, data: EC2.Types.DescribeExportImageTasksResult) => void): Request<EC2.Types.DescribeExportImageTasksResult, AWSError>;
  /**
   * Describes the specified export instance tasks or all of your export instance tasks.
   */
  describeExportTasks(params: EC2.Types.DescribeExportTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Describes the specified export instance tasks or all of your export instance tasks.
   */
  describeExportTasks(callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Describe details for Windows AMIs that are configured for faster launching.
   */
  describeFastLaunchImages(params: EC2.Types.DescribeFastLaunchImagesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFastLaunchImagesResult) => void): Request<EC2.Types.DescribeFastLaunchImagesResult, AWSError>;
  /**
   * Describe details for Windows AMIs that are configured for faster launching.
   */
  describeFastLaunchImages(callback?: (err: AWSError, data: EC2.Types.DescribeFastLaunchImagesResult) => void): Request<EC2.Types.DescribeFastLaunchImagesResult, AWSError>;
  /**
   * Describes the state of fast snapshot restores for your snapshots.
   */
  describeFastSnapshotRestores(params: EC2.Types.DescribeFastSnapshotRestoresRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFastSnapshotRestoresResult) => void): Request<EC2.Types.DescribeFastSnapshotRestoresResult, AWSError>;
  /**
   * Describes the state of fast snapshot restores for your snapshots.
   */
  describeFastSnapshotRestores(callback?: (err: AWSError, data: EC2.Types.DescribeFastSnapshotRestoresResult) => void): Request<EC2.Types.DescribeFastSnapshotRestoresResult, AWSError>;
  /**
   * Describes the events for the specified EC2 Fleet during the specified time. EC2 Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. EC2 Fleet events are available for 48 hours. For more information, see Monitor fleet events using Amazon EventBridge in the Amazon EC2 User Guide.
   */
  describeFleetHistory(params: EC2.Types.DescribeFleetHistoryRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFleetHistoryResult) => void): Request<EC2.Types.DescribeFleetHistoryResult, AWSError>;
  /**
   * Describes the events for the specified EC2 Fleet during the specified time. EC2 Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. EC2 Fleet events are available for 48 hours. For more information, see Monitor fleet events using Amazon EventBridge in the Amazon EC2 User Guide.
   */
  describeFleetHistory(callback?: (err: AWSError, data: EC2.Types.DescribeFleetHistoryResult) => void): Request<EC2.Types.DescribeFleetHistoryResult, AWSError>;
  /**
   * Describes the running instances for the specified EC2 Fleet. For more information, see Monitor your EC2 Fleet in the Amazon EC2 User Guide.
   */
  describeFleetInstances(params: EC2.Types.DescribeFleetInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFleetInstancesResult) => void): Request<EC2.Types.DescribeFleetInstancesResult, AWSError>;
  /**
   * Describes the running instances for the specified EC2 Fleet. For more information, see Monitor your EC2 Fleet in the Amazon EC2 User Guide.
   */
  describeFleetInstances(callback?: (err: AWSError, data: EC2.Types.DescribeFleetInstancesResult) => void): Request<EC2.Types.DescribeFleetInstancesResult, AWSError>;
  /**
   * Describes the specified EC2 Fleets or all of your EC2 Fleets. For more information, see Monitor your EC2 Fleet in the Amazon EC2 User Guide.
   */
  describeFleets(params: EC2.Types.DescribeFleetsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFleetsResult) => void): Request<EC2.Types.DescribeFleetsResult, AWSError>;
  /**
   * Describes the specified EC2 Fleets or all of your EC2 Fleets. For more information, see Monitor your EC2 Fleet in the Amazon EC2 User Guide.
   */
  describeFleets(callback?: (err: AWSError, data: EC2.Types.DescribeFleetsResult) => void): Request<EC2.Types.DescribeFleetsResult, AWSError>;
  /**
   * Describes one or more flow logs. To view the published flow log records, you must view the log destination. For example, the CloudWatch Logs log group, the Amazon S3 bucket, or the Kinesis Data Firehose delivery stream.
   */
  describeFlowLogs(params: EC2.Types.DescribeFlowLogsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFlowLogsResult) => void): Request<EC2.Types.DescribeFlowLogsResult, AWSError>;
  /**
   * Describes one or more flow logs. To view the published flow log records, you must view the log destination. For example, the CloudWatch Logs log group, the Amazon S3 bucket, or the Kinesis Data Firehose delivery stream.
   */
  describeFlowLogs(callback?: (err: AWSError, data: EC2.Types.DescribeFlowLogsResult) => void): Request<EC2.Types.DescribeFlowLogsResult, AWSError>;
  /**
   * Describes the specified attribute of the specified Amazon FPGA Image (AFI).
   */
  describeFpgaImageAttribute(params: EC2.Types.DescribeFpgaImageAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFpgaImageAttributeResult) => void): Request<EC2.Types.DescribeFpgaImageAttributeResult, AWSError>;
  /**
   * Describes the specified attribute of the specified Amazon FPGA Image (AFI).
   */
  describeFpgaImageAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeFpgaImageAttributeResult) => void): Request<EC2.Types.DescribeFpgaImageAttributeResult, AWSError>;
  /**
   * Describes the Amazon FPGA Images (AFIs) available to you. These include public AFIs, private AFIs that you own, and AFIs owned by other Amazon Web Services accounts for which you have load permissions.
   */
  describeFpgaImages(params: EC2.Types.DescribeFpgaImagesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeFpgaImagesResult) => void): Request<EC2.Types.DescribeFpgaImagesResult, AWSError>;
  /**
   * Describes the Amazon FPGA Images (AFIs) available to you. These include public AFIs, private AFIs that you own, and AFIs owned by other Amazon Web Services accounts for which you have load permissions.
   */
  describeFpgaImages(callback?: (err: AWSError, data: EC2.Types.DescribeFpgaImagesResult) => void): Request<EC2.Types.DescribeFpgaImagesResult, AWSError>;
  /**
   * Describes the Dedicated Host reservations that are available to purchase. The results describe all of the Dedicated Host reservation offerings, including offerings that might not match the instance family and Region of your Dedicated Hosts. When purchasing an offering, ensure that the instance family and Region of the offering matches that of the Dedicated Hosts with which it is to be associated. For more information about supported instance types, see Dedicated Hosts in the Amazon EC2 User Guide. 
   */
  describeHostReservationOfferings(params: EC2.Types.DescribeHostReservationOfferingsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeHostReservationOfferingsResult) => void): Request<EC2.Types.DescribeHostReservationOfferingsResult, AWSError>;
  /**
   * Describes the Dedicated Host reservations that are available to purchase. The results describe all of the Dedicated Host reservation offerings, including offerings that might not match the instance family and Region of your Dedicated Hosts. When purchasing an offering, ensure that the instance family and Region of the offering matches that of the Dedicated Hosts with which it is to be associated. For more information about supported instance types, see Dedicated Hosts in the Amazon EC2 User Guide. 
   */
  describeHostReservationOfferings(callback?: (err: AWSError, data: EC2.Types.DescribeHostReservationOfferingsResult) => void): Request<EC2.Types.DescribeHostReservationOfferingsResult, AWSError>;
  /**
   * Describes reservations that are associated with Dedicated Hosts in your account.
   */
  describeHostReservations(params: EC2.Types.DescribeHostReservationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeHostReservationsResult) => void): Request<EC2.Types.DescribeHostReservationsResult, AWSError>;
  /**
   * Describes reservations that are associated with Dedicated Hosts in your account.
   */
  describeHostReservations(callback?: (err: AWSError, data: EC2.Types.DescribeHostReservationsResult) => void): Request<EC2.Types.DescribeHostReservationsResult, AWSError>;
  /**
   * Describes the specified Dedicated Hosts or all your Dedicated Hosts. The results describe only the Dedicated Hosts in the Region you're currently using. All listed instances consume capacity on your Dedicated Host. Dedicated Hosts that have recently been released are listed with the state released.
   */
  describeHosts(params: EC2.Types.DescribeHostsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeHostsResult) => void): Request<EC2.Types.DescribeHostsResult, AWSError>;
  /**
   * Describes the specified Dedicated Hosts or all your Dedicated Hosts. The results describe only the Dedicated Hosts in the Region you're currently using. All listed instances consume capacity on your Dedicated Host. Dedicated Hosts that have recently been released are listed with the state released.
   */
  describeHosts(callback?: (err: AWSError, data: EC2.Types.DescribeHostsResult) => void): Request<EC2.Types.DescribeHostsResult, AWSError>;
  /**
   * Describes your IAM instance profile associations.
   */
  describeIamInstanceProfileAssociations(params: EC2.Types.DescribeIamInstanceProfileAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIamInstanceProfileAssociationsResult) => void): Request<EC2.Types.DescribeIamInstanceProfileAssociationsResult, AWSError>;
  /**
   * Describes your IAM instance profile associations.
   */
  describeIamInstanceProfileAssociations(callback?: (err: AWSError, data: EC2.Types.DescribeIamInstanceProfileAssociationsResult) => void): Request<EC2.Types.DescribeIamInstanceProfileAssociationsResult, AWSError>;
  /**
   * Describes the ID format settings for your resources on a per-Region basis, for example, to view which resource types are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the IAM user who makes the request; they do not apply to the entire Amazon Web Services account. By default, an IAM user defaults to the same settings as the root user, unless they explicitly override the settings by running the ModifyIdFormat command. Resources created with longer IDs are visible to all IAM users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  describeIdFormat(params: EC2.Types.DescribeIdFormatRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIdFormatResult) => void): Request<EC2.Types.DescribeIdFormatResult, AWSError>;
  /**
   * Describes the ID format settings for your resources on a per-Region basis, for example, to view which resource types are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the IAM user who makes the request; they do not apply to the entire Amazon Web Services account. By default, an IAM user defaults to the same settings as the root user, unless they explicitly override the settings by running the ModifyIdFormat command. Resources created with longer IDs are visible to all IAM users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  describeIdFormat(callback?: (err: AWSError, data: EC2.Types.DescribeIdFormatResult) => void): Request<EC2.Types.DescribeIdFormatResult, AWSError>;
  /**
   * Describes the ID format settings for resources for the specified IAM user, IAM role, or root user. For example, you can view the resource types that are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the principal specified in the request. They do not apply to the principal that makes the request.
   */
  describeIdentityIdFormat(params: EC2.Types.DescribeIdentityIdFormatRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIdentityIdFormatResult) => void): Request<EC2.Types.DescribeIdentityIdFormatResult, AWSError>;
  /**
   * Describes the ID format settings for resources for the specified IAM user, IAM role, or root user. For example, you can view the resource types that are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the principal specified in the request. They do not apply to the principal that makes the request.
   */
  describeIdentityIdFormat(callback?: (err: AWSError, data: EC2.Types.DescribeIdentityIdFormatResult) => void): Request<EC2.Types.DescribeIdentityIdFormatResult, AWSError>;
  /**
   * Describes the specified attribute of the specified AMI. You can specify only one attribute at a time.
   */
  describeImageAttribute(params: EC2.Types.DescribeImageAttributeRequest, callback?: (err: AWSError, data: EC2.Types.ImageAttribute) => void): Request<EC2.Types.ImageAttribute, AWSError>;
  /**
   * Describes the specified attribute of the specified AMI. You can specify only one attribute at a time.
   */
  describeImageAttribute(callback?: (err: AWSError, data: EC2.Types.ImageAttribute) => void): Request<EC2.Types.ImageAttribute, AWSError>;
  /**
   * Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you. The images available to you include public images, private images that you own, and private images owned by other Amazon Web Services accounts for which you have explicit launch permissions. Recently deregistered images appear in the returned results for a short interval and then return empty results. After all instances that reference a deregistered AMI are terminated, specifying the ID of the image will eventually return an error indicating that the AMI ID cannot be found.
   */
  describeImages(params: EC2.Types.DescribeImagesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you. The images available to you include public images, private images that you own, and private images owned by other Amazon Web Services accounts for which you have explicit launch permissions. Recently deregistered images appear in the returned results for a short interval and then return empty results. After all instances that reference a deregistered AMI are terminated, specifying the ID of the image will eventually return an error indicating that the AMI ID cannot be found.
   */
  describeImages(callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Displays details about an import virtual machine or import snapshot tasks that are already created.
   */
  describeImportImageTasks(params: EC2.Types.DescribeImportImageTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeImportImageTasksResult) => void): Request<EC2.Types.DescribeImportImageTasksResult, AWSError>;
  /**
   * Displays details about an import virtual machine or import snapshot tasks that are already created.
   */
  describeImportImageTasks(callback?: (err: AWSError, data: EC2.Types.DescribeImportImageTasksResult) => void): Request<EC2.Types.DescribeImportImageTasksResult, AWSError>;
  /**
   * Describes your import snapshot tasks.
   */
  describeImportSnapshotTasks(params: EC2.Types.DescribeImportSnapshotTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeImportSnapshotTasksResult) => void): Request<EC2.Types.DescribeImportSnapshotTasksResult, AWSError>;
  /**
   * Describes your import snapshot tasks.
   */
  describeImportSnapshotTasks(callback?: (err: AWSError, data: EC2.Types.DescribeImportSnapshotTasksResult) => void): Request<EC2.Types.DescribeImportSnapshotTasksResult, AWSError>;
  /**
   * Describes the specified attribute of the specified instance. You can specify only one attribute at a time. Valid attribute values are: instanceType | kernel | ramdisk | userData | disableApiTermination | instanceInitiatedShutdownBehavior | rootDeviceName | blockDeviceMapping | productCodes | sourceDestCheck | groupSet | ebsOptimized | sriovNetSupport 
   */
  describeInstanceAttribute(params: EC2.Types.DescribeInstanceAttributeRequest, callback?: (err: AWSError, data: EC2.Types.InstanceAttribute) => void): Request<EC2.Types.InstanceAttribute, AWSError>;
  /**
   * Describes the specified attribute of the specified instance. You can specify only one attribute at a time. Valid attribute values are: instanceType | kernel | ramdisk | userData | disableApiTermination | instanceInitiatedShutdownBehavior | rootDeviceName | blockDeviceMapping | productCodes | sourceDestCheck | groupSet | ebsOptimized | sriovNetSupport 
   */
  describeInstanceAttribute(callback?: (err: AWSError, data: EC2.Types.InstanceAttribute) => void): Request<EC2.Types.InstanceAttribute, AWSError>;
  /**
   * Describes the credit option for CPU usage of the specified burstable performance instances. The credit options are standard and unlimited. If you do not specify an instance ID, Amazon EC2 returns burstable performance instances with the unlimited credit option, as well as instances that were previously configured as T2, T3, and T3a with the unlimited credit option. For example, if you resize a T2 instance, while it is configured as unlimited, to an M4 instance, Amazon EC2 returns the M4 instance. If you specify one or more instance IDs, Amazon EC2 returns the credit option (standard or unlimited) of those instances. If you specify an instance ID that is not valid, such as an instance that is not a burstable performance instance, an error is returned. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If an Availability Zone is experiencing a service disruption and you specify instance IDs in the affected zone, or do not specify any instance IDs at all, the call fails. If you specify only instance IDs in an unaffected zone, the call works normally. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  describeInstanceCreditSpecifications(params: EC2.Types.DescribeInstanceCreditSpecificationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceCreditSpecificationsResult) => void): Request<EC2.Types.DescribeInstanceCreditSpecificationsResult, AWSError>;
  /**
   * Describes the credit option for CPU usage of the specified burstable performance instances. The credit options are standard and unlimited. If you do not specify an instance ID, Amazon EC2 returns burstable performance instances with the unlimited credit option, as well as instances that were previously configured as T2, T3, and T3a with the unlimited credit option. For example, if you resize a T2 instance, while it is configured as unlimited, to an M4 instance, Amazon EC2 returns the M4 instance. If you specify one or more instance IDs, Amazon EC2 returns the credit option (standard or unlimited) of those instances. If you specify an instance ID that is not valid, such as an instance that is not a burstable performance instance, an error is returned. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If an Availability Zone is experiencing a service disruption and you specify instance IDs in the affected zone, or do not specify any instance IDs at all, the call fails. If you specify only instance IDs in an unaffected zone, the call works normally. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  describeInstanceCreditSpecifications(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceCreditSpecificationsResult) => void): Request<EC2.Types.DescribeInstanceCreditSpecificationsResult, AWSError>;
  /**
   * Describes the tag keys that are registered to appear in scheduled event notifications for resources in the current Region.
   */
  describeInstanceEventNotificationAttributes(params: EC2.Types.DescribeInstanceEventNotificationAttributesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.DescribeInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Describes the tag keys that are registered to appear in scheduled event notifications for resources in the current Region.
   */
  describeInstanceEventNotificationAttributes(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.DescribeInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Describes the specified event windows or all event windows. If you specify event window IDs, the output includes information for only the specified event windows. If you specify filters, the output includes information for only those event windows that meet the filter criteria. If you do not specify event windows IDs or filters, the output includes information for all event windows, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully.  For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  describeInstanceEventWindows(params: EC2.Types.DescribeInstanceEventWindowsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceEventWindowsResult) => void): Request<EC2.Types.DescribeInstanceEventWindowsResult, AWSError>;
  /**
   * Describes the specified event windows or all event windows. If you specify event window IDs, the output includes information for only the specified event windows. If you specify filters, the output includes information for only those event windows that meet the filter criteria. If you do not specify event windows IDs or filters, the output includes information for all event windows, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully.  For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  describeInstanceEventWindows(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceEventWindowsResult) => void): Request<EC2.Types.DescribeInstanceEventWindowsResult, AWSError>;
  /**
   * Describes the status of the specified instances or all of your instances. By default, only running instances are described, unless you specifically indicate to return the status of all instances. Instance status includes the following components:    Status checks - Amazon EC2 performs status checks on running EC2 instances to identify hardware and software issues. For more information, see Status checks for your instances and Troubleshoot instances with failed status checks in the Amazon EC2 User Guide.    Scheduled events - Amazon EC2 can schedule events (such as reboot, stop, or terminate) for your instances related to hardware issues, software updates, or system maintenance. For more information, see Scheduled events for your instances in the Amazon EC2 User Guide.    Instance state - You can manage your instances from the moment you launch them through their termination. For more information, see Instance lifecycle in the Amazon EC2 User Guide.  
   */
  describeInstanceStatus(params: EC2.Types.DescribeInstanceStatusRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Describes the status of the specified instances or all of your instances. By default, only running instances are described, unless you specifically indicate to return the status of all instances. Instance status includes the following components:    Status checks - Amazon EC2 performs status checks on running EC2 instances to identify hardware and software issues. For more information, see Status checks for your instances and Troubleshoot instances with failed status checks in the Amazon EC2 User Guide.    Scheduled events - Amazon EC2 can schedule events (such as reboot, stop, or terminate) for your instances related to hardware issues, software updates, or system maintenance. For more information, see Scheduled events for your instances in the Amazon EC2 User Guide.    Instance state - You can manage your instances from the moment you launch them through their termination. For more information, see Instance lifecycle in the Amazon EC2 User Guide.  
   */
  describeInstanceStatus(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Returns a list of all instance types offered. The results can be filtered by location (Region or Availability Zone). If no location is specified, the instance types offered in the current Region are returned.
   */
  describeInstanceTypeOfferings(params: EC2.Types.DescribeInstanceTypeOfferingsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceTypeOfferingsResult) => void): Request<EC2.Types.DescribeInstanceTypeOfferingsResult, AWSError>;
  /**
   * Returns a list of all instance types offered. The results can be filtered by location (Region or Availability Zone). If no location is specified, the instance types offered in the current Region are returned.
   */
  describeInstanceTypeOfferings(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceTypeOfferingsResult) => void): Request<EC2.Types.DescribeInstanceTypeOfferingsResult, AWSError>;
  /**
   * Describes the details of the instance types that are offered in a location. The results can be filtered by the attributes of the instance types.
   */
  describeInstanceTypes(params: EC2.Types.DescribeInstanceTypesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceTypesResult) => void): Request<EC2.Types.DescribeInstanceTypesResult, AWSError>;
  /**
   * Describes the details of the instance types that are offered in a location. The results can be filtered by the attributes of the instance types.
   */
  describeInstanceTypes(callback?: (err: AWSError, data: EC2.Types.DescribeInstanceTypesResult) => void): Request<EC2.Types.DescribeInstanceTypesResult, AWSError>;
  /**
   * Describes the specified instances or all instances. If you specify instance IDs, the output includes information for only the specified instances. If you specify filters, the output includes information for only those instances that meet the filter criteria. If you do not specify instance IDs or filters, the output includes information for all instances, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully. If you specify an instance ID that is not valid, an error is returned. If you specify an instance that you do not own, it is not included in the output. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If you describe instances in the rare case where an Availability Zone is experiencing a service disruption and you specify instance IDs that are in the affected zone, or do not specify any instance IDs at all, the call fails. If you describe instances and specify only instance IDs that are in an unaffected zone, the call works normally.
   */
  describeInstances(params: EC2.Types.DescribeInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Describes the specified instances or all instances. If you specify instance IDs, the output includes information for only the specified instances. If you specify filters, the output includes information for only those instances that meet the filter criteria. If you do not specify instance IDs or filters, the output includes information for all instances, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully. If you specify an instance ID that is not valid, an error is returned. If you specify an instance that you do not own, it is not included in the output. Recently terminated instances might appear in the returned results. This interval is usually less than one hour. If you describe instances in the rare case where an Availability Zone is experiencing a service disruption and you specify instance IDs that are in the affected zone, or do not specify any instance IDs at all, the call fails. If you describe instances and specify only instance IDs that are in an unaffected zone, the call works normally.
   */
  describeInstances(callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Describes one or more of your internet gateways.
   */
  describeInternetGateways(params: EC2.Types.DescribeInternetGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeInternetGatewaysResult) => void): Request<EC2.Types.DescribeInternetGatewaysResult, AWSError>;
  /**
   * Describes one or more of your internet gateways.
   */
  describeInternetGateways(callback?: (err: AWSError, data: EC2.Types.DescribeInternetGatewaysResult) => void): Request<EC2.Types.DescribeInternetGatewaysResult, AWSError>;
  /**
   * Get information about your IPAM pools.
   */
  describeIpamPools(params: EC2.Types.DescribeIpamPoolsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpamPoolsResult) => void): Request<EC2.Types.DescribeIpamPoolsResult, AWSError>;
  /**
   * Get information about your IPAM pools.
   */
  describeIpamPools(callback?: (err: AWSError, data: EC2.Types.DescribeIpamPoolsResult) => void): Request<EC2.Types.DescribeIpamPoolsResult, AWSError>;
  /**
   * Describes IPAM resource discoveries. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  describeIpamResourceDiscoveries(params: EC2.Types.DescribeIpamResourceDiscoveriesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpamResourceDiscoveriesResult) => void): Request<EC2.Types.DescribeIpamResourceDiscoveriesResult, AWSError>;
  /**
   * Describes IPAM resource discoveries. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  describeIpamResourceDiscoveries(callback?: (err: AWSError, data: EC2.Types.DescribeIpamResourceDiscoveriesResult) => void): Request<EC2.Types.DescribeIpamResourceDiscoveriesResult, AWSError>;
  /**
   * Describes resource discovery association with an Amazon VPC IPAM. An associated resource discovery is a resource discovery that has been associated with an IPAM..
   */
  describeIpamResourceDiscoveryAssociations(params: EC2.Types.DescribeIpamResourceDiscoveryAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpamResourceDiscoveryAssociationsResult) => void): Request<EC2.Types.DescribeIpamResourceDiscoveryAssociationsResult, AWSError>;
  /**
   * Describes resource discovery association with an Amazon VPC IPAM. An associated resource discovery is a resource discovery that has been associated with an IPAM..
   */
  describeIpamResourceDiscoveryAssociations(callback?: (err: AWSError, data: EC2.Types.DescribeIpamResourceDiscoveryAssociationsResult) => void): Request<EC2.Types.DescribeIpamResourceDiscoveryAssociationsResult, AWSError>;
  /**
   * Get information about your IPAM scopes.
   */
  describeIpamScopes(params: EC2.Types.DescribeIpamScopesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpamScopesResult) => void): Request<EC2.Types.DescribeIpamScopesResult, AWSError>;
  /**
   * Get information about your IPAM scopes.
   */
  describeIpamScopes(callback?: (err: AWSError, data: EC2.Types.DescribeIpamScopesResult) => void): Request<EC2.Types.DescribeIpamScopesResult, AWSError>;
  /**
   * Get information about your IPAM pools. For more information, see What is IPAM? in the Amazon VPC IPAM User Guide. 
   */
  describeIpams(params: EC2.Types.DescribeIpamsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpamsResult) => void): Request<EC2.Types.DescribeIpamsResult, AWSError>;
  /**
   * Get information about your IPAM pools. For more information, see What is IPAM? in the Amazon VPC IPAM User Guide. 
   */
  describeIpams(callback?: (err: AWSError, data: EC2.Types.DescribeIpamsResult) => void): Request<EC2.Types.DescribeIpamsResult, AWSError>;
  /**
   * Describes your IPv6 address pools.
   */
  describeIpv6Pools(params: EC2.Types.DescribeIpv6PoolsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeIpv6PoolsResult) => void): Request<EC2.Types.DescribeIpv6PoolsResult, AWSError>;
  /**
   * Describes your IPv6 address pools.
   */
  describeIpv6Pools(callback?: (err: AWSError, data: EC2.Types.DescribeIpv6PoolsResult) => void): Request<EC2.Types.DescribeIpv6PoolsResult, AWSError>;
  /**
   * Describes the specified key pairs or all of your key pairs. For more information about key pairs, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  describeKeyPairs(params: EC2.Types.DescribeKeyPairsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeKeyPairsResult) => void): Request<EC2.Types.DescribeKeyPairsResult, AWSError>;
  /**
   * Describes the specified key pairs or all of your key pairs. For more information about key pairs, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  describeKeyPairs(callback?: (err: AWSError, data: EC2.Types.DescribeKeyPairsResult) => void): Request<EC2.Types.DescribeKeyPairsResult, AWSError>;
  /**
   * Describes one or more versions of a specified launch template. You can describe all versions, individual versions, or a range of versions. You can also describe all the latest versions or all the default versions of all the launch templates in your account.
   */
  describeLaunchTemplateVersions(params: EC2.Types.DescribeLaunchTemplateVersionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLaunchTemplateVersionsResult) => void): Request<EC2.Types.DescribeLaunchTemplateVersionsResult, AWSError>;
  /**
   * Describes one or more versions of a specified launch template. You can describe all versions, individual versions, or a range of versions. You can also describe all the latest versions or all the default versions of all the launch templates in your account.
   */
  describeLaunchTemplateVersions(callback?: (err: AWSError, data: EC2.Types.DescribeLaunchTemplateVersionsResult) => void): Request<EC2.Types.DescribeLaunchTemplateVersionsResult, AWSError>;
  /**
   * Describes one or more launch templates.
   */
  describeLaunchTemplates(params: EC2.Types.DescribeLaunchTemplatesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLaunchTemplatesResult) => void): Request<EC2.Types.DescribeLaunchTemplatesResult, AWSError>;
  /**
   * Describes one or more launch templates.
   */
  describeLaunchTemplates(callback?: (err: AWSError, data: EC2.Types.DescribeLaunchTemplatesResult) => void): Request<EC2.Types.DescribeLaunchTemplatesResult, AWSError>;
  /**
   * Describes the associations between virtual interface groups and local gateway route tables.
   */
  describeLocalGatewayRouteTableVirtualInterfaceGroupAssociations(params: EC2.Types.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult, AWSError>;
  /**
   * Describes the associations between virtual interface groups and local gateway route tables.
   */
  describeLocalGatewayRouteTableVirtualInterfaceGroupAssociations(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult, AWSError>;
  /**
   * Describes the specified associations between VPCs and local gateway route tables.
   */
  describeLocalGatewayRouteTableVpcAssociations(params: EC2.Types.DescribeLocalGatewayRouteTableVpcAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTableVpcAssociationsResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTableVpcAssociationsResult, AWSError>;
  /**
   * Describes the specified associations between VPCs and local gateway route tables.
   */
  describeLocalGatewayRouteTableVpcAssociations(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTableVpcAssociationsResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTableVpcAssociationsResult, AWSError>;
  /**
   * Describes one or more local gateway route tables. By default, all local gateway route tables are described. Alternatively, you can filter the results.
   */
  describeLocalGatewayRouteTables(params: EC2.Types.DescribeLocalGatewayRouteTablesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTablesResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTablesResult, AWSError>;
  /**
   * Describes one or more local gateway route tables. By default, all local gateway route tables are described. Alternatively, you can filter the results.
   */
  describeLocalGatewayRouteTables(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayRouteTablesResult) => void): Request<EC2.Types.DescribeLocalGatewayRouteTablesResult, AWSError>;
  /**
   * Describes the specified local gateway virtual interface groups.
   */
  describeLocalGatewayVirtualInterfaceGroups(params: EC2.Types.DescribeLocalGatewayVirtualInterfaceGroupsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayVirtualInterfaceGroupsResult) => void): Request<EC2.Types.DescribeLocalGatewayVirtualInterfaceGroupsResult, AWSError>;
  /**
   * Describes the specified local gateway virtual interface groups.
   */
  describeLocalGatewayVirtualInterfaceGroups(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayVirtualInterfaceGroupsResult) => void): Request<EC2.Types.DescribeLocalGatewayVirtualInterfaceGroupsResult, AWSError>;
  /**
   * Describes the specified local gateway virtual interfaces.
   */
  describeLocalGatewayVirtualInterfaces(params: EC2.Types.DescribeLocalGatewayVirtualInterfacesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayVirtualInterfacesResult) => void): Request<EC2.Types.DescribeLocalGatewayVirtualInterfacesResult, AWSError>;
  /**
   * Describes the specified local gateway virtual interfaces.
   */
  describeLocalGatewayVirtualInterfaces(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewayVirtualInterfacesResult) => void): Request<EC2.Types.DescribeLocalGatewayVirtualInterfacesResult, AWSError>;
  /**
   * Describes one or more local gateways. By default, all local gateways are described. Alternatively, you can filter the results.
   */
  describeLocalGateways(params: EC2.Types.DescribeLocalGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewaysResult) => void): Request<EC2.Types.DescribeLocalGatewaysResult, AWSError>;
  /**
   * Describes one or more local gateways. By default, all local gateways are described. Alternatively, you can filter the results.
   */
  describeLocalGateways(callback?: (err: AWSError, data: EC2.Types.DescribeLocalGatewaysResult) => void): Request<EC2.Types.DescribeLocalGatewaysResult, AWSError>;
  /**
   * Describes your managed prefix lists and any Amazon Web Services-managed prefix lists. To view the entries for your prefix list, use GetManagedPrefixListEntries.
   */
  describeManagedPrefixLists(params: EC2.Types.DescribeManagedPrefixListsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeManagedPrefixListsResult) => void): Request<EC2.Types.DescribeManagedPrefixListsResult, AWSError>;
  /**
   * Describes your managed prefix lists and any Amazon Web Services-managed prefix lists. To view the entries for your prefix list, use GetManagedPrefixListEntries.
   */
  describeManagedPrefixLists(callback?: (err: AWSError, data: EC2.Types.DescribeManagedPrefixListsResult) => void): Request<EC2.Types.DescribeManagedPrefixListsResult, AWSError>;
  /**
   * Describes your Elastic IP addresses that are being moved to the EC2-VPC platform, or that are being restored to the EC2-Classic platform. This request does not return information about any other Elastic IP addresses in your account.
   */
  describeMovingAddresses(params: EC2.Types.DescribeMovingAddressesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeMovingAddressesResult) => void): Request<EC2.Types.DescribeMovingAddressesResult, AWSError>;
  /**
   * Describes your Elastic IP addresses that are being moved to the EC2-VPC platform, or that are being restored to the EC2-Classic platform. This request does not return information about any other Elastic IP addresses in your account.
   */
  describeMovingAddresses(callback?: (err: AWSError, data: EC2.Types.DescribeMovingAddressesResult) => void): Request<EC2.Types.DescribeMovingAddressesResult, AWSError>;
  /**
   * Describes one or more of your NAT gateways.
   */
  describeNatGateways(params: EC2.Types.DescribeNatGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Describes one or more of your NAT gateways.
   */
  describeNatGateways(callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Describes one or more of your network ACLs. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  describeNetworkAcls(params: EC2.Types.DescribeNetworkAclsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkAclsResult) => void): Request<EC2.Types.DescribeNetworkAclsResult, AWSError>;
  /**
   * Describes one or more of your network ACLs. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  describeNetworkAcls(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkAclsResult) => void): Request<EC2.Types.DescribeNetworkAclsResult, AWSError>;
  /**
   * Describes the specified Network Access Scope analyses.
   */
  describeNetworkInsightsAccessScopeAnalyses(params: EC2.Types.DescribeNetworkInsightsAccessScopeAnalysesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAccessScopeAnalysesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAccessScopeAnalysesResult, AWSError>;
  /**
   * Describes the specified Network Access Scope analyses.
   */
  describeNetworkInsightsAccessScopeAnalyses(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAccessScopeAnalysesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAccessScopeAnalysesResult, AWSError>;
  /**
   * Describes the specified Network Access Scopes.
   */
  describeNetworkInsightsAccessScopes(params: EC2.Types.DescribeNetworkInsightsAccessScopesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAccessScopesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAccessScopesResult, AWSError>;
  /**
   * Describes the specified Network Access Scopes.
   */
  describeNetworkInsightsAccessScopes(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAccessScopesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAccessScopesResult, AWSError>;
  /**
   * Describes one or more of your network insights analyses.
   */
  describeNetworkInsightsAnalyses(params: EC2.Types.DescribeNetworkInsightsAnalysesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAnalysesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAnalysesResult, AWSError>;
  /**
   * Describes one or more of your network insights analyses.
   */
  describeNetworkInsightsAnalyses(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsAnalysesResult) => void): Request<EC2.Types.DescribeNetworkInsightsAnalysesResult, AWSError>;
  /**
   * Describes one or more of your paths.
   */
  describeNetworkInsightsPaths(params: EC2.Types.DescribeNetworkInsightsPathsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsPathsResult) => void): Request<EC2.Types.DescribeNetworkInsightsPathsResult, AWSError>;
  /**
   * Describes one or more of your paths.
   */
  describeNetworkInsightsPaths(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInsightsPathsResult) => void): Request<EC2.Types.DescribeNetworkInsightsPathsResult, AWSError>;
  /**
   * Describes a network interface attribute. You can specify only one attribute at a time.
   */
  describeNetworkInterfaceAttribute(params: EC2.Types.DescribeNetworkInterfaceAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfaceAttributeResult) => void): Request<EC2.Types.DescribeNetworkInterfaceAttributeResult, AWSError>;
  /**
   * Describes a network interface attribute. You can specify only one attribute at a time.
   */
  describeNetworkInterfaceAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfaceAttributeResult) => void): Request<EC2.Types.DescribeNetworkInterfaceAttributeResult, AWSError>;
  /**
   * Describes the permissions for your network interfaces. 
   */
  describeNetworkInterfacePermissions(params: EC2.Types.DescribeNetworkInterfacePermissionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacePermissionsResult) => void): Request<EC2.Types.DescribeNetworkInterfacePermissionsResult, AWSError>;
  /**
   * Describes the permissions for your network interfaces. 
   */
  describeNetworkInterfacePermissions(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacePermissionsResult) => void): Request<EC2.Types.DescribeNetworkInterfacePermissionsResult, AWSError>;
  /**
   * Describes one or more of your network interfaces.
   */
  describeNetworkInterfaces(params: EC2.Types.DescribeNetworkInterfacesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacesResult) => void): Request<EC2.Types.DescribeNetworkInterfacesResult, AWSError>;
  /**
   * Describes one or more of your network interfaces.
   */
  describeNetworkInterfaces(callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacesResult) => void): Request<EC2.Types.DescribeNetworkInterfacesResult, AWSError>;
  /**
   * Describes the specified placement groups or all of your placement groups. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  describePlacementGroups(params: EC2.Types.DescribePlacementGroupsRequest, callback?: (err: AWSError, data: EC2.Types.DescribePlacementGroupsResult) => void): Request<EC2.Types.DescribePlacementGroupsResult, AWSError>;
  /**
   * Describes the specified placement groups or all of your placement groups. For more information, see Placement groups in the Amazon EC2 User Guide.
   */
  describePlacementGroups(callback?: (err: AWSError, data: EC2.Types.DescribePlacementGroupsResult) => void): Request<EC2.Types.DescribePlacementGroupsResult, AWSError>;
  /**
   * Describes available Amazon Web Services services in a prefix list format, which includes the prefix list name and prefix list ID of the service and the IP address range for the service. We recommend that you use DescribeManagedPrefixLists instead.
   */
  describePrefixLists(params: EC2.Types.DescribePrefixListsRequest, callback?: (err: AWSError, data: EC2.Types.DescribePrefixListsResult) => void): Request<EC2.Types.DescribePrefixListsResult, AWSError>;
  /**
   * Describes available Amazon Web Services services in a prefix list format, which includes the prefix list name and prefix list ID of the service and the IP address range for the service. We recommend that you use DescribeManagedPrefixLists instead.
   */
  describePrefixLists(callback?: (err: AWSError, data: EC2.Types.DescribePrefixListsResult) => void): Request<EC2.Types.DescribePrefixListsResult, AWSError>;
  /**
   * Describes the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference.  By default, all IAM roles and IAM users default to the same ID settings as the root user, unless they explicitly override the settings. This request is useful for identifying those IAM users and IAM roles that have overridden the default ID settings. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. 
   */
  describePrincipalIdFormat(params: EC2.Types.DescribePrincipalIdFormatRequest, callback?: (err: AWSError, data: EC2.Types.DescribePrincipalIdFormatResult) => void): Request<EC2.Types.DescribePrincipalIdFormatResult, AWSError>;
  /**
   * Describes the ID format settings for the root user and all IAM roles and IAM users that have explicitly specified a longer ID (17-character ID) preference.  By default, all IAM roles and IAM users default to the same ID settings as the root user, unless they explicitly override the settings. This request is useful for identifying those IAM users and IAM roles that have overridden the default ID settings. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. 
   */
  describePrincipalIdFormat(callback?: (err: AWSError, data: EC2.Types.DescribePrincipalIdFormatResult) => void): Request<EC2.Types.DescribePrincipalIdFormatResult, AWSError>;
  /**
   * Describes the specified IPv4 address pools.
   */
  describePublicIpv4Pools(params: EC2.Types.DescribePublicIpv4PoolsRequest, callback?: (err: AWSError, data: EC2.Types.DescribePublicIpv4PoolsResult) => void): Request<EC2.Types.DescribePublicIpv4PoolsResult, AWSError>;
  /**
   * Describes the specified IPv4 address pools.
   */
  describePublicIpv4Pools(callback?: (err: AWSError, data: EC2.Types.DescribePublicIpv4PoolsResult) => void): Request<EC2.Types.DescribePublicIpv4PoolsResult, AWSError>;
  /**
   * Describes the Regions that are enabled for your account, or all Regions. For a list of the Regions supported by Amazon EC2, see  Amazon Elastic Compute Cloud endpoints and quotas. For information about enabling and disabling Regions for your account, see Managing Amazon Web Services Regions in the Amazon Web Services General Reference.
   */
  describeRegions(params: EC2.Types.DescribeRegionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeRegionsResult) => void): Request<EC2.Types.DescribeRegionsResult, AWSError>;
  /**
   * Describes the Regions that are enabled for your account, or all Regions. For a list of the Regions supported by Amazon EC2, see  Amazon Elastic Compute Cloud endpoints and quotas. For information about enabling and disabling Regions for your account, see Managing Amazon Web Services Regions in the Amazon Web Services General Reference.
   */
  describeRegions(callback?: (err: AWSError, data: EC2.Types.DescribeRegionsResult) => void): Request<EC2.Types.DescribeRegionsResult, AWSError>;
  /**
   * Describes a root volume replacement task. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.
   */
  describeReplaceRootVolumeTasks(params: EC2.Types.DescribeReplaceRootVolumeTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeReplaceRootVolumeTasksResult) => void): Request<EC2.Types.DescribeReplaceRootVolumeTasksResult, AWSError>;
  /**
   * Describes a root volume replacement task. For more information, see Replace a root volume in the Amazon Elastic Compute Cloud User Guide.
   */
  describeReplaceRootVolumeTasks(callback?: (err: AWSError, data: EC2.Types.DescribeReplaceRootVolumeTasksResult) => void): Request<EC2.Types.DescribeReplaceRootVolumeTasksResult, AWSError>;
  /**
   * Describes one or more of the Reserved Instances that you purchased. For more information about Reserved Instances, see Reserved Instances in the Amazon EC2 User Guide.
   */
  describeReservedInstances(params: EC2.Types.DescribeReservedInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesResult) => void): Request<EC2.Types.DescribeReservedInstancesResult, AWSError>;
  /**
   * Describes one or more of the Reserved Instances that you purchased. For more information about Reserved Instances, see Reserved Instances in the Amazon EC2 User Guide.
   */
  describeReservedInstances(callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesResult) => void): Request<EC2.Types.DescribeReservedInstancesResult, AWSError>;
  /**
   * Describes your account's Reserved Instance listings in the Reserved Instance Marketplace. The Reserved Instance Marketplace matches sellers who want to resell Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. As a seller, you choose to list some or all of your Reserved Instances, and you specify the upfront price to receive for them. Your Reserved Instances are then listed in the Reserved Instance Marketplace and are available for purchase. As a buyer, you specify the configuration of the Reserved Instance to purchase, and the Marketplace matches what you're searching for with what's available. The Marketplace first sells the lowest priced Reserved Instances to you, and continues to sell available Reserved Instance listings to you until your demand is met. You are charged based on the total price of all of the listings that you purchase. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  describeReservedInstancesListings(params: EC2.Types.DescribeReservedInstancesListingsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesListingsResult) => void): Request<EC2.Types.DescribeReservedInstancesListingsResult, AWSError>;
  /**
   * Describes your account's Reserved Instance listings in the Reserved Instance Marketplace. The Reserved Instance Marketplace matches sellers who want to resell Reserved Instance capacity that they no longer need with buyers who want to purchase additional capacity. Reserved Instances bought and sold through the Reserved Instance Marketplace work like any other Reserved Instances. As a seller, you choose to list some or all of your Reserved Instances, and you specify the upfront price to receive for them. Your Reserved Instances are then listed in the Reserved Instance Marketplace and are available for purchase. As a buyer, you specify the configuration of the Reserved Instance to purchase, and the Marketplace matches what you're searching for with what's available. The Marketplace first sells the lowest priced Reserved Instances to you, and continues to sell available Reserved Instance listings to you until your demand is met. You are charged based on the total price of all of the listings that you purchase. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  describeReservedInstancesListings(callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesListingsResult) => void): Request<EC2.Types.DescribeReservedInstancesListingsResult, AWSError>;
  /**
   * Describes the modifications made to your Reserved Instances. If no parameter is specified, information about all your Reserved Instances modification requests is returned. If a modification ID is specified, only information about the specific modification is returned. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.
   */
  describeReservedInstancesModifications(params: EC2.Types.DescribeReservedInstancesModificationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesModificationsResult) => void): Request<EC2.Types.DescribeReservedInstancesModificationsResult, AWSError>;
  /**
   * Describes the modifications made to your Reserved Instances. If no parameter is specified, information about all your Reserved Instances modification requests is returned. If a modification ID is specified, only information about the specific modification is returned. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.
   */
  describeReservedInstancesModifications(callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesModificationsResult) => void): Request<EC2.Types.DescribeReservedInstancesModificationsResult, AWSError>;
  /**
   * Describes Reserved Instance offerings that are available for purchase. With Reserved Instances, you purchase the right to launch instances for a period of time. During that time period, you do not receive insufficient capacity errors, and you pay a lower usage rate than the rate charged for On-Demand instances for the actual time used. If you have listed your own Reserved Instances for sale in the Reserved Instance Marketplace, they will be excluded from these results. This is to ensure that you do not purchase your own Reserved Instances. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  describeReservedInstancesOfferings(params: EC2.Types.DescribeReservedInstancesOfferingsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesOfferingsResult) => void): Request<EC2.Types.DescribeReservedInstancesOfferingsResult, AWSError>;
  /**
   * Describes Reserved Instance offerings that are available for purchase. With Reserved Instances, you purchase the right to launch instances for a period of time. During that time period, you do not receive insufficient capacity errors, and you pay a lower usage rate than the rate charged for On-Demand instances for the actual time used. If you have listed your own Reserved Instances for sale in the Reserved Instance Marketplace, they will be excluded from these results. This is to ensure that you do not purchase your own Reserved Instances. For more information, see Reserved Instance Marketplace in the Amazon EC2 User Guide.
   */
  describeReservedInstancesOfferings(callback?: (err: AWSError, data: EC2.Types.DescribeReservedInstancesOfferingsResult) => void): Request<EC2.Types.DescribeReservedInstancesOfferingsResult, AWSError>;
  /**
   * Describes one or more of your route tables. Each subnet in your VPC must be associated with a route table. If a subnet is not explicitly associated with any route table, it is implicitly associated with the main route table. This command does not return the subnet ID for implicit associations. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  describeRouteTables(params: EC2.Types.DescribeRouteTablesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeRouteTablesResult) => void): Request<EC2.Types.DescribeRouteTablesResult, AWSError>;
  /**
   * Describes one or more of your route tables. Each subnet in your VPC must be associated with a route table. If a subnet is not explicitly associated with any route table, it is implicitly associated with the main route table. This command does not return the subnet ID for implicit associations. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  describeRouteTables(callback?: (err: AWSError, data: EC2.Types.DescribeRouteTablesResult) => void): Request<EC2.Types.DescribeRouteTablesResult, AWSError>;
  /**
   * Finds available schedules that meet the specified criteria. You can search for an available schedule no more than 3 months in advance. You must meet the minimum required duration of 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours. After you find a schedule that meets your needs, call PurchaseScheduledInstances to purchase Scheduled Instances with that schedule.
   */
  describeScheduledInstanceAvailability(params: EC2.Types.DescribeScheduledInstanceAvailabilityRequest, callback?: (err: AWSError, data: EC2.Types.DescribeScheduledInstanceAvailabilityResult) => void): Request<EC2.Types.DescribeScheduledInstanceAvailabilityResult, AWSError>;
  /**
   * Finds available schedules that meet the specified criteria. You can search for an available schedule no more than 3 months in advance. You must meet the minimum required duration of 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours. After you find a schedule that meets your needs, call PurchaseScheduledInstances to purchase Scheduled Instances with that schedule.
   */
  describeScheduledInstanceAvailability(callback?: (err: AWSError, data: EC2.Types.DescribeScheduledInstanceAvailabilityResult) => void): Request<EC2.Types.DescribeScheduledInstanceAvailabilityResult, AWSError>;
  /**
   * Describes the specified Scheduled Instances or all your Scheduled Instances.
   */
  describeScheduledInstances(params: EC2.Types.DescribeScheduledInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeScheduledInstancesResult) => void): Request<EC2.Types.DescribeScheduledInstancesResult, AWSError>;
  /**
   * Describes the specified Scheduled Instances or all your Scheduled Instances.
   */
  describeScheduledInstances(callback?: (err: AWSError, data: EC2.Types.DescribeScheduledInstancesResult) => void): Request<EC2.Types.DescribeScheduledInstancesResult, AWSError>;
  /**
   * [VPC only] Describes the VPCs on the other side of a VPC peering connection that are referencing the security groups you've specified in this request.
   */
  describeSecurityGroupReferences(params: EC2.Types.DescribeSecurityGroupReferencesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupReferencesResult) => void): Request<EC2.Types.DescribeSecurityGroupReferencesResult, AWSError>;
  /**
   * [VPC only] Describes the VPCs on the other side of a VPC peering connection that are referencing the security groups you've specified in this request.
   */
  describeSecurityGroupReferences(callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupReferencesResult) => void): Request<EC2.Types.DescribeSecurityGroupReferencesResult, AWSError>;
  /**
   * Describes one or more of your security group rules.
   */
  describeSecurityGroupRules(params: EC2.Types.DescribeSecurityGroupRulesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupRulesResult) => void): Request<EC2.Types.DescribeSecurityGroupRulesResult, AWSError>;
  /**
   * Describes one or more of your security group rules.
   */
  describeSecurityGroupRules(callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupRulesResult) => void): Request<EC2.Types.DescribeSecurityGroupRulesResult, AWSError>;
  /**
   * Describes the specified security groups or all of your security groups. A security group is for use with instances either in the EC2-Classic platform or in a specific VPC. For more information, see Amazon EC2 security groups in the Amazon Elastic Compute Cloud User Guide and Security groups for your VPC in the Amazon Virtual Private Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeSecurityGroups(params: EC2.Types.DescribeSecurityGroupsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupsResult) => void): Request<EC2.Types.DescribeSecurityGroupsResult, AWSError>;
  /**
   * Describes the specified security groups or all of your security groups. A security group is for use with instances either in the EC2-Classic platform or in a specific VPC. For more information, see Amazon EC2 security groups in the Amazon Elastic Compute Cloud User Guide and Security groups for your VPC in the Amazon Virtual Private Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeSecurityGroups(callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupsResult) => void): Request<EC2.Types.DescribeSecurityGroupsResult, AWSError>;
  /**
   * Describes the specified attribute of the specified snapshot. You can specify only one attribute at a time. For more information about EBS snapshots, see Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  describeSnapshotAttribute(params: EC2.Types.DescribeSnapshotAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotAttributeResult) => void): Request<EC2.Types.DescribeSnapshotAttributeResult, AWSError>;
  /**
   * Describes the specified attribute of the specified snapshot. You can specify only one attribute at a time. For more information about EBS snapshots, see Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  describeSnapshotAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotAttributeResult) => void): Request<EC2.Types.DescribeSnapshotAttributeResult, AWSError>;
  /**
   * Describes the storage tier status of one or more Amazon EBS snapshots.
   */
  describeSnapshotTierStatus(params: EC2.Types.DescribeSnapshotTierStatusRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotTierStatusResult) => void): Request<EC2.Types.DescribeSnapshotTierStatusResult, AWSError>;
  /**
   * Describes the storage tier status of one or more Amazon EBS snapshots.
   */
  describeSnapshotTierStatus(callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotTierStatusResult) => void): Request<EC2.Types.DescribeSnapshotTierStatusResult, AWSError>;
  /**
   * Describes the specified EBS snapshots available to you or all of the EBS snapshots available to you. The snapshots available to you include public snapshots, private snapshots that you own, and private snapshots owned by other Amazon Web Services accounts for which you have explicit create volume permissions. The create volume permissions fall into the following categories:    public: The owner of the snapshot granted create volume permissions for the snapshot to the all group. All Amazon Web Services accounts have create volume permissions for these snapshots.    explicit: The owner of the snapshot granted create volume permissions to a specific Amazon Web Services account.    implicit: An Amazon Web Services account has implicit create volume permissions for all snapshots it owns.   The list of snapshots returned can be filtered by specifying snapshot IDs, snapshot owners, or Amazon Web Services accounts with create volume permissions. If no options are specified, Amazon EC2 returns all snapshots for which you have create volume permissions. If you specify one or more snapshot IDs, only snapshots that have the specified IDs are returned. If you specify an invalid snapshot ID, an error is returned. If you specify a snapshot ID for which you do not have access, it is not included in the returned results. If you specify one or more snapshot owners using the OwnerIds option, only snapshots from the specified owners and for which you have access are returned. The results can include the Amazon Web Services account IDs of the specified owners, amazon for snapshots owned by Amazon, or self for snapshots that you own. If you specify a list of restorable users, only snapshots with create snapshot permissions for those users are returned. You can specify Amazon Web Services account IDs (if you own the snapshots), self for snapshots for which you own or have explicit permissions, or all for public snapshots. If you are describing a long list of snapshots, we recommend that you paginate the output to make the list more manageable. For more information, see Pagination. To get the state of fast snapshot restores for a snapshot, use DescribeFastSnapshotRestores. For more information about EBS snapshots, see Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  describeSnapshots(params: EC2.Types.DescribeSnapshotsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotsResult) => void): Request<EC2.Types.DescribeSnapshotsResult, AWSError>;
  /**
   * Describes the specified EBS snapshots available to you or all of the EBS snapshots available to you. The snapshots available to you include public snapshots, private snapshots that you own, and private snapshots owned by other Amazon Web Services accounts for which you have explicit create volume permissions. The create volume permissions fall into the following categories:    public: The owner of the snapshot granted create volume permissions for the snapshot to the all group. All Amazon Web Services accounts have create volume permissions for these snapshots.    explicit: The owner of the snapshot granted create volume permissions to a specific Amazon Web Services account.    implicit: An Amazon Web Services account has implicit create volume permissions for all snapshots it owns.   The list of snapshots returned can be filtered by specifying snapshot IDs, snapshot owners, or Amazon Web Services accounts with create volume permissions. If no options are specified, Amazon EC2 returns all snapshots for which you have create volume permissions. If you specify one or more snapshot IDs, only snapshots that have the specified IDs are returned. If you specify an invalid snapshot ID, an error is returned. If you specify a snapshot ID for which you do not have access, it is not included in the returned results. If you specify one or more snapshot owners using the OwnerIds option, only snapshots from the specified owners and for which you have access are returned. The results can include the Amazon Web Services account IDs of the specified owners, amazon for snapshots owned by Amazon, or self for snapshots that you own. If you specify a list of restorable users, only snapshots with create snapshot permissions for those users are returned. You can specify Amazon Web Services account IDs (if you own the snapshots), self for snapshots for which you own or have explicit permissions, or all for public snapshots. If you are describing a long list of snapshots, we recommend that you paginate the output to make the list more manageable. For more information, see Pagination. To get the state of fast snapshot restores for a snapshot, use DescribeFastSnapshotRestores. For more information about EBS snapshots, see Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  describeSnapshots(callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotsResult) => void): Request<EC2.Types.DescribeSnapshotsResult, AWSError>;
  /**
   * Describes the data feed for Spot Instances. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.
   */
  describeSpotDatafeedSubscription(params: EC2.Types.DescribeSpotDatafeedSubscriptionRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotDatafeedSubscriptionResult) => void): Request<EC2.Types.DescribeSpotDatafeedSubscriptionResult, AWSError>;
  /**
   * Describes the data feed for Spot Instances. For more information, see Spot Instance data feed in the Amazon EC2 User Guide for Linux Instances.
   */
  describeSpotDatafeedSubscription(callback?: (err: AWSError, data: EC2.Types.DescribeSpotDatafeedSubscriptionResult) => void): Request<EC2.Types.DescribeSpotDatafeedSubscriptionResult, AWSError>;
  /**
   * Describes the running instances for the specified Spot Fleet.
   */
  describeSpotFleetInstances(params: EC2.Types.DescribeSpotFleetInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetInstancesResponse) => void): Request<EC2.Types.DescribeSpotFleetInstancesResponse, AWSError>;
  /**
   * Describes the running instances for the specified Spot Fleet.
   */
  describeSpotFleetInstances(callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetInstancesResponse) => void): Request<EC2.Types.DescribeSpotFleetInstancesResponse, AWSError>;
  /**
   * Describes the events for the specified Spot Fleet request during the specified time. Spot Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. Spot Fleet events are available for 48 hours. For more information, see Monitor fleet events using Amazon EventBridge in the Amazon EC2 User Guide.
   */
  describeSpotFleetRequestHistory(params: EC2.Types.DescribeSpotFleetRequestHistoryRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetRequestHistoryResponse) => void): Request<EC2.Types.DescribeSpotFleetRequestHistoryResponse, AWSError>;
  /**
   * Describes the events for the specified Spot Fleet request during the specified time. Spot Fleet events are delayed by up to 30 seconds before they can be described. This ensures that you can query by the last evaluated time and not miss a recorded event. Spot Fleet events are available for 48 hours. For more information, see Monitor fleet events using Amazon EventBridge in the Amazon EC2 User Guide.
   */
  describeSpotFleetRequestHistory(callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetRequestHistoryResponse) => void): Request<EC2.Types.DescribeSpotFleetRequestHistoryResponse, AWSError>;
  /**
   * Describes your Spot Fleet requests. Spot Fleet requests are deleted 48 hours after they are canceled and their instances are terminated.
   */
  describeSpotFleetRequests(params: EC2.Types.DescribeSpotFleetRequestsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetRequestsResponse) => void): Request<EC2.Types.DescribeSpotFleetRequestsResponse, AWSError>;
  /**
   * Describes your Spot Fleet requests. Spot Fleet requests are deleted 48 hours after they are canceled and their instances are terminated.
   */
  describeSpotFleetRequests(callback?: (err: AWSError, data: EC2.Types.DescribeSpotFleetRequestsResponse) => void): Request<EC2.Types.DescribeSpotFleetRequestsResponse, AWSError>;
  /**
   * Describes the specified Spot Instance requests. You can use DescribeSpotInstanceRequests to find a running Spot Instance by examining the response. If the status of the Spot Instance is fulfilled, the instance ID appears in the response and contains the identifier of the instance. Alternatively, you can use DescribeInstances with a filter to look for instances where the instance lifecycle is spot. We recommend that you set MaxResults to a value between 5 and 1000 to limit the number of items returned. This paginates the output, which makes the list more manageable and returns the items faster. If the list of items exceeds your MaxResults value, then that number of items is returned along with a NextToken value that can be passed to a subsequent DescribeSpotInstanceRequests request to retrieve the remaining items. Spot Instance requests are deleted four hours after they are canceled and their instances are terminated.
   */
  describeSpotInstanceRequests(params: EC2.Types.DescribeSpotInstanceRequestsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotInstanceRequestsResult) => void): Request<EC2.Types.DescribeSpotInstanceRequestsResult, AWSError>;
  /**
   * Describes the specified Spot Instance requests. You can use DescribeSpotInstanceRequests to find a running Spot Instance by examining the response. If the status of the Spot Instance is fulfilled, the instance ID appears in the response and contains the identifier of the instance. Alternatively, you can use DescribeInstances with a filter to look for instances where the instance lifecycle is spot. We recommend that you set MaxResults to a value between 5 and 1000 to limit the number of items returned. This paginates the output, which makes the list more manageable and returns the items faster. If the list of items exceeds your MaxResults value, then that number of items is returned along with a NextToken value that can be passed to a subsequent DescribeSpotInstanceRequests request to retrieve the remaining items. Spot Instance requests are deleted four hours after they are canceled and their instances are terminated.
   */
  describeSpotInstanceRequests(callback?: (err: AWSError, data: EC2.Types.DescribeSpotInstanceRequestsResult) => void): Request<EC2.Types.DescribeSpotInstanceRequestsResult, AWSError>;
  /**
   * Describes the Spot price history. For more information, see Spot Instance pricing history in the Amazon EC2 User Guide for Linux Instances. When you specify a start and end time, the operation returns the prices of the instance types within that time range. It also returns the last price change before the start time, which is the effective price as of the start time.
   */
  describeSpotPriceHistory(params: EC2.Types.DescribeSpotPriceHistoryRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSpotPriceHistoryResult) => void): Request<EC2.Types.DescribeSpotPriceHistoryResult, AWSError>;
  /**
   * Describes the Spot price history. For more information, see Spot Instance pricing history in the Amazon EC2 User Guide for Linux Instances. When you specify a start and end time, the operation returns the prices of the instance types within that time range. It also returns the last price change before the start time, which is the effective price as of the start time.
   */
  describeSpotPriceHistory(callback?: (err: AWSError, data: EC2.Types.DescribeSpotPriceHistoryResult) => void): Request<EC2.Types.DescribeSpotPriceHistoryResult, AWSError>;
  /**
   * [VPC only] Describes the stale security group rules for security groups in a specified VPC. Rules are stale when they reference a deleted security group in the same VPC or in a peer VPC, or if they reference a security group in a peer VPC for which the VPC peering connection has been deleted.
   */
  describeStaleSecurityGroups(params: EC2.Types.DescribeStaleSecurityGroupsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeStaleSecurityGroupsResult) => void): Request<EC2.Types.DescribeStaleSecurityGroupsResult, AWSError>;
  /**
   * [VPC only] Describes the stale security group rules for security groups in a specified VPC. Rules are stale when they reference a deleted security group in the same VPC or in a peer VPC, or if they reference a security group in a peer VPC for which the VPC peering connection has been deleted.
   */
  describeStaleSecurityGroups(callback?: (err: AWSError, data: EC2.Types.DescribeStaleSecurityGroupsResult) => void): Request<EC2.Types.DescribeStaleSecurityGroupsResult, AWSError>;
  /**
   * Describes the progress of the AMI store tasks. You can describe the store tasks for specified AMIs. If you don't specify the AMIs, you get a paginated list of store tasks from the last 31 days. For each AMI task, the response indicates if the task is InProgress, Completed, or Failed. For tasks InProgress, the response shows the estimated progress as a percentage. Tasks are listed in reverse chronological order. Currently, only tasks from the past 31 days can be viewed. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  describeStoreImageTasks(params: EC2.Types.DescribeStoreImageTasksRequest, callback?: (err: AWSError, data: EC2.Types.DescribeStoreImageTasksResult) => void): Request<EC2.Types.DescribeStoreImageTasksResult, AWSError>;
  /**
   * Describes the progress of the AMI store tasks. You can describe the store tasks for specified AMIs. If you don't specify the AMIs, you get a paginated list of store tasks from the last 31 days. For each AMI task, the response indicates if the task is InProgress, Completed, or Failed. For tasks InProgress, the response shows the estimated progress as a percentage. Tasks are listed in reverse chronological order. Currently, only tasks from the past 31 days can be viewed. To use this API, you must have the required permissions. For more information, see Permissions for storing and restoring AMIs using Amazon S3 in the Amazon EC2 User Guide. For more information, see Store and restore an AMI using Amazon S3 in the Amazon EC2 User Guide.
   */
  describeStoreImageTasks(callback?: (err: AWSError, data: EC2.Types.DescribeStoreImageTasksResult) => void): Request<EC2.Types.DescribeStoreImageTasksResult, AWSError>;
  /**
   * Describes one or more of your subnets. For more information, see Your VPC and subnets in the Amazon Virtual Private Cloud User Guide.
   */
  describeSubnets(params: EC2.Types.DescribeSubnetsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeSubnetsResult) => void): Request<EC2.Types.DescribeSubnetsResult, AWSError>;
  /**
   * Describes one or more of your subnets. For more information, see Your VPC and subnets in the Amazon Virtual Private Cloud User Guide.
   */
  describeSubnets(callback?: (err: AWSError, data: EC2.Types.DescribeSubnetsResult) => void): Request<EC2.Types.DescribeSubnetsResult, AWSError>;
  /**
   * Describes the specified tags for your EC2 resources. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide.
   */
  describeTags(params: EC2.Types.DescribeTagsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTagsResult) => void): Request<EC2.Types.DescribeTagsResult, AWSError>;
  /**
   * Describes the specified tags for your EC2 resources. For more information about tags, see Tag your Amazon EC2 resources in the Amazon Elastic Compute Cloud User Guide.
   */
  describeTags(callback?: (err: AWSError, data: EC2.Types.DescribeTagsResult) => void): Request<EC2.Types.DescribeTagsResult, AWSError>;
  /**
   * Describes one or more Traffic Mirror filters.
   */
  describeTrafficMirrorFilters(params: EC2.Types.DescribeTrafficMirrorFiltersRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorFiltersResult) => void): Request<EC2.Types.DescribeTrafficMirrorFiltersResult, AWSError>;
  /**
   * Describes one or more Traffic Mirror filters.
   */
  describeTrafficMirrorFilters(callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorFiltersResult) => void): Request<EC2.Types.DescribeTrafficMirrorFiltersResult, AWSError>;
  /**
   * Describes one or more Traffic Mirror sessions. By default, all Traffic Mirror sessions are described. Alternatively, you can filter the results.
   */
  describeTrafficMirrorSessions(params: EC2.Types.DescribeTrafficMirrorSessionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorSessionsResult) => void): Request<EC2.Types.DescribeTrafficMirrorSessionsResult, AWSError>;
  /**
   * Describes one or more Traffic Mirror sessions. By default, all Traffic Mirror sessions are described. Alternatively, you can filter the results.
   */
  describeTrafficMirrorSessions(callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorSessionsResult) => void): Request<EC2.Types.DescribeTrafficMirrorSessionsResult, AWSError>;
  /**
   * Information about one or more Traffic Mirror targets.
   */
  describeTrafficMirrorTargets(params: EC2.Types.DescribeTrafficMirrorTargetsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorTargetsResult) => void): Request<EC2.Types.DescribeTrafficMirrorTargetsResult, AWSError>;
  /**
   * Information about one or more Traffic Mirror targets.
   */
  describeTrafficMirrorTargets(callback?: (err: AWSError, data: EC2.Types.DescribeTrafficMirrorTargetsResult) => void): Request<EC2.Types.DescribeTrafficMirrorTargetsResult, AWSError>;
  /**
   * Describes one or more attachments between resources and transit gateways. By default, all attachments are described. Alternatively, you can filter the results by attachment ID, attachment state, resource ID, or resource owner.
   */
  describeTransitGatewayAttachments(params: EC2.Types.DescribeTransitGatewayAttachmentsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayAttachmentsResult, AWSError>;
  /**
   * Describes one or more attachments between resources and transit gateways. By default, all attachments are described. Alternatively, you can filter the results by attachment ID, attachment state, resource ID, or resource owner.
   */
  describeTransitGatewayAttachments(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayAttachmentsResult, AWSError>;
  /**
   * Describes one or more Connect peers.
   */
  describeTransitGatewayConnectPeers(params: EC2.Types.DescribeTransitGatewayConnectPeersRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayConnectPeersResult) => void): Request<EC2.Types.DescribeTransitGatewayConnectPeersResult, AWSError>;
  /**
   * Describes one or more Connect peers.
   */
  describeTransitGatewayConnectPeers(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayConnectPeersResult) => void): Request<EC2.Types.DescribeTransitGatewayConnectPeersResult, AWSError>;
  /**
   * Describes one or more Connect attachments.
   */
  describeTransitGatewayConnects(params: EC2.Types.DescribeTransitGatewayConnectsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayConnectsResult) => void): Request<EC2.Types.DescribeTransitGatewayConnectsResult, AWSError>;
  /**
   * Describes one or more Connect attachments.
   */
  describeTransitGatewayConnects(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayConnectsResult) => void): Request<EC2.Types.DescribeTransitGatewayConnectsResult, AWSError>;
  /**
   * Describes one or more transit gateway multicast domains.
   */
  describeTransitGatewayMulticastDomains(params: EC2.Types.DescribeTransitGatewayMulticastDomainsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayMulticastDomainsResult) => void): Request<EC2.Types.DescribeTransitGatewayMulticastDomainsResult, AWSError>;
  /**
   * Describes one or more transit gateway multicast domains.
   */
  describeTransitGatewayMulticastDomains(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayMulticastDomainsResult) => void): Request<EC2.Types.DescribeTransitGatewayMulticastDomainsResult, AWSError>;
  /**
   * Describes your transit gateway peering attachments.
   */
  describeTransitGatewayPeeringAttachments(params: EC2.Types.DescribeTransitGatewayPeeringAttachmentsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayPeeringAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayPeeringAttachmentsResult, AWSError>;
  /**
   * Describes your transit gateway peering attachments.
   */
  describeTransitGatewayPeeringAttachments(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayPeeringAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayPeeringAttachmentsResult, AWSError>;
  /**
   * Describes one or more transit gateway route policy tables. 
   */
  describeTransitGatewayPolicyTables(params: EC2.Types.DescribeTransitGatewayPolicyTablesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayPolicyTablesResult) => void): Request<EC2.Types.DescribeTransitGatewayPolicyTablesResult, AWSError>;
  /**
   * Describes one or more transit gateway route policy tables. 
   */
  describeTransitGatewayPolicyTables(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayPolicyTablesResult) => void): Request<EC2.Types.DescribeTransitGatewayPolicyTablesResult, AWSError>;
  /**
   * Describes one or more transit gateway route table advertisements.
   */
  describeTransitGatewayRouteTableAnnouncements(params: EC2.Types.DescribeTransitGatewayRouteTableAnnouncementsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayRouteTableAnnouncementsResult) => void): Request<EC2.Types.DescribeTransitGatewayRouteTableAnnouncementsResult, AWSError>;
  /**
   * Describes one or more transit gateway route table advertisements.
   */
  describeTransitGatewayRouteTableAnnouncements(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayRouteTableAnnouncementsResult) => void): Request<EC2.Types.DescribeTransitGatewayRouteTableAnnouncementsResult, AWSError>;
  /**
   * Describes one or more transit gateway route tables. By default, all transit gateway route tables are described. Alternatively, you can filter the results.
   */
  describeTransitGatewayRouteTables(params: EC2.Types.DescribeTransitGatewayRouteTablesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayRouteTablesResult) => void): Request<EC2.Types.DescribeTransitGatewayRouteTablesResult, AWSError>;
  /**
   * Describes one or more transit gateway route tables. By default, all transit gateway route tables are described. Alternatively, you can filter the results.
   */
  describeTransitGatewayRouteTables(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayRouteTablesResult) => void): Request<EC2.Types.DescribeTransitGatewayRouteTablesResult, AWSError>;
  /**
   * Describes one or more VPC attachments. By default, all VPC attachments are described. Alternatively, you can filter the results.
   */
  describeTransitGatewayVpcAttachments(params: EC2.Types.DescribeTransitGatewayVpcAttachmentsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayVpcAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayVpcAttachmentsResult, AWSError>;
  /**
   * Describes one or more VPC attachments. By default, all VPC attachments are described. Alternatively, you can filter the results.
   */
  describeTransitGatewayVpcAttachments(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewayVpcAttachmentsResult) => void): Request<EC2.Types.DescribeTransitGatewayVpcAttachmentsResult, AWSError>;
  /**
   * Describes one or more transit gateways. By default, all transit gateways are described. Alternatively, you can filter the results.
   */
  describeTransitGateways(params: EC2.Types.DescribeTransitGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewaysResult) => void): Request<EC2.Types.DescribeTransitGatewaysResult, AWSError>;
  /**
   * Describes one or more transit gateways. By default, all transit gateways are described. Alternatively, you can filter the results.
   */
  describeTransitGateways(callback?: (err: AWSError, data: EC2.Types.DescribeTransitGatewaysResult) => void): Request<EC2.Types.DescribeTransitGatewaysResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Describes one or more network interface trunk associations.
   */
  describeTrunkInterfaceAssociations(params: EC2.Types.DescribeTrunkInterfaceAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeTrunkInterfaceAssociationsResult) => void): Request<EC2.Types.DescribeTrunkInterfaceAssociationsResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Describes one or more network interface trunk associations.
   */
  describeTrunkInterfaceAssociations(callback?: (err: AWSError, data: EC2.Types.DescribeTrunkInterfaceAssociationsResult) => void): Request<EC2.Types.DescribeTrunkInterfaceAssociationsResult, AWSError>;
  /**
   * Describe Amazon Web Services Verified Access endpoints.
   */
  describeVerifiedAccessEndpoints(params: EC2.Types.DescribeVerifiedAccessEndpointsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessEndpointsResult) => void): Request<EC2.Types.DescribeVerifiedAccessEndpointsResult, AWSError>;
  /**
   * Describe Amazon Web Services Verified Access endpoints.
   */
  describeVerifiedAccessEndpoints(callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessEndpointsResult) => void): Request<EC2.Types.DescribeVerifiedAccessEndpointsResult, AWSError>;
  /**
   * Describe details of existing Verified Access groups.
   */
  describeVerifiedAccessGroups(params: EC2.Types.DescribeVerifiedAccessGroupsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessGroupsResult) => void): Request<EC2.Types.DescribeVerifiedAccessGroupsResult, AWSError>;
  /**
   * Describe details of existing Verified Access groups.
   */
  describeVerifiedAccessGroups(callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessGroupsResult) => void): Request<EC2.Types.DescribeVerifiedAccessGroupsResult, AWSError>;
  /**
   * Describes the current logging configuration for the Amazon Web Services Verified Access instances.
   */
  describeVerifiedAccessInstanceLoggingConfigurations(params: EC2.Types.DescribeVerifiedAccessInstanceLoggingConfigurationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessInstanceLoggingConfigurationsResult) => void): Request<EC2.Types.DescribeVerifiedAccessInstanceLoggingConfigurationsResult, AWSError>;
  /**
   * Describes the current logging configuration for the Amazon Web Services Verified Access instances.
   */
  describeVerifiedAccessInstanceLoggingConfigurations(callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessInstanceLoggingConfigurationsResult) => void): Request<EC2.Types.DescribeVerifiedAccessInstanceLoggingConfigurationsResult, AWSError>;
  /**
   * Describe Verified Access instances.
   */
  describeVerifiedAccessInstances(params: EC2.Types.DescribeVerifiedAccessInstancesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessInstancesResult) => void): Request<EC2.Types.DescribeVerifiedAccessInstancesResult, AWSError>;
  /**
   * Describe Verified Access instances.
   */
  describeVerifiedAccessInstances(callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessInstancesResult) => void): Request<EC2.Types.DescribeVerifiedAccessInstancesResult, AWSError>;
  /**
   * Describe details of existing Verified Access trust providers.
   */
  describeVerifiedAccessTrustProviders(params: EC2.Types.DescribeVerifiedAccessTrustProvidersRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessTrustProvidersResult) => void): Request<EC2.Types.DescribeVerifiedAccessTrustProvidersResult, AWSError>;
  /**
   * Describe details of existing Verified Access trust providers.
   */
  describeVerifiedAccessTrustProviders(callback?: (err: AWSError, data: EC2.Types.DescribeVerifiedAccessTrustProvidersResult) => void): Request<EC2.Types.DescribeVerifiedAccessTrustProvidersResult, AWSError>;
  /**
   * Describes the specified attribute of the specified volume. You can specify only one attribute at a time. For more information about EBS volumes, see Amazon EBS volumes in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumeAttribute(params: EC2.Types.DescribeVolumeAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVolumeAttributeResult) => void): Request<EC2.Types.DescribeVolumeAttributeResult, AWSError>;
  /**
   * Describes the specified attribute of the specified volume. You can specify only one attribute at a time. For more information about EBS volumes, see Amazon EBS volumes in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumeAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeVolumeAttributeResult) => void): Request<EC2.Types.DescribeVolumeAttributeResult, AWSError>;
  /**
   * Describes the status of the specified volumes. Volume status provides the result of the checks performed on your volumes to determine events that can impair the performance of your volumes. The performance of a volume can be affected if an issue occurs on the volume's underlying host. If the volume's underlying host experiences a power outage or system issue, after the system is restored, there could be data inconsistencies on the volume. Volume events notify you if this occurs. Volume actions notify you if any action needs to be taken in response to the event. The DescribeVolumeStatus operation provides the following information about the specified volumes:  Status: Reflects the current status of the volume. The possible values are ok, impaired , warning, or insufficient-data. If all checks pass, the overall status of the volume is ok. If the check fails, the overall status is impaired. If the status is insufficient-data, then the checks might still be taking place on your volume at the time. We recommend that you retry the request. For more information about volume status, see Monitor the status of your volumes in the Amazon Elastic Compute Cloud User Guide.  Events: Reflect the cause of a volume status and might require you to take action. For example, if your volume returns an impaired status, then the volume event might be potential-data-inconsistency. This means that your volume has been affected by an issue with the underlying host, has all I/O operations disabled, and might have inconsistent data.  Actions: Reflect the actions you might have to take in response to an event. For example, if the status of the volume is impaired and the volume event shows potential-data-inconsistency, then the action shows enable-volume-io. This means that you may want to enable the I/O operations for the volume by calling the EnableVolumeIO action and then check the volume for data consistency. Volume status is based on the volume status checks, and does not reflect the volume state. Therefore, volume status does not indicate volumes in the error state (for example, when a volume is incapable of accepting I/O.)
   */
  describeVolumeStatus(params: EC2.Types.DescribeVolumeStatusRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVolumeStatusResult) => void): Request<EC2.Types.DescribeVolumeStatusResult, AWSError>;
  /**
   * Describes the status of the specified volumes. Volume status provides the result of the checks performed on your volumes to determine events that can impair the performance of your volumes. The performance of a volume can be affected if an issue occurs on the volume's underlying host. If the volume's underlying host experiences a power outage or system issue, after the system is restored, there could be data inconsistencies on the volume. Volume events notify you if this occurs. Volume actions notify you if any action needs to be taken in response to the event. The DescribeVolumeStatus operation provides the following information about the specified volumes:  Status: Reflects the current status of the volume. The possible values are ok, impaired , warning, or insufficient-data. If all checks pass, the overall status of the volume is ok. If the check fails, the overall status is impaired. If the status is insufficient-data, then the checks might still be taking place on your volume at the time. We recommend that you retry the request. For more information about volume status, see Monitor the status of your volumes in the Amazon Elastic Compute Cloud User Guide.  Events: Reflect the cause of a volume status and might require you to take action. For example, if your volume returns an impaired status, then the volume event might be potential-data-inconsistency. This means that your volume has been affected by an issue with the underlying host, has all I/O operations disabled, and might have inconsistent data.  Actions: Reflect the actions you might have to take in response to an event. For example, if the status of the volume is impaired and the volume event shows potential-data-inconsistency, then the action shows enable-volume-io. This means that you may want to enable the I/O operations for the volume by calling the EnableVolumeIO action and then check the volume for data consistency. Volume status is based on the volume status checks, and does not reflect the volume state. Therefore, volume status does not indicate volumes in the error state (for example, when a volume is incapable of accepting I/O.)
   */
  describeVolumeStatus(callback?: (err: AWSError, data: EC2.Types.DescribeVolumeStatusResult) => void): Request<EC2.Types.DescribeVolumeStatusResult, AWSError>;
  /**
   * Describes the specified EBS volumes or all of your EBS volumes. If you are describing a long list of volumes, we recommend that you paginate the output to make the list more manageable. For more information, see Pagination. For more information about EBS volumes, see Amazon EBS volumes in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumes(params: EC2.Types.DescribeVolumesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Describes the specified EBS volumes or all of your EBS volumes. If you are describing a long list of volumes, we recommend that you paginate the output to make the list more manageable. For more information, see Pagination. For more information about EBS volumes, see Amazon EBS volumes in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumes(callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Describes the most recent volume modification request for the specified EBS volumes. If a volume has never been modified, some information in the output will be null. If a volume has been modified more than once, the output includes only the most recent modification request. You can also use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the Amazon CloudWatch Events User Guide. For more information, see Monitor the progress of volume modifications in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumesModifications(params: EC2.Types.DescribeVolumesModificationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVolumesModificationsResult) => void): Request<EC2.Types.DescribeVolumesModificationsResult, AWSError>;
  /**
   * Describes the most recent volume modification request for the specified EBS volumes. If a volume has never been modified, some information in the output will be null. If a volume has been modified more than once, the output includes only the most recent modification request. You can also use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the Amazon CloudWatch Events User Guide. For more information, see Monitor the progress of volume modifications in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVolumesModifications(callback?: (err: AWSError, data: EC2.Types.DescribeVolumesModificationsResult) => void): Request<EC2.Types.DescribeVolumesModificationsResult, AWSError>;
  /**
   * Describes the specified attribute of the specified VPC. You can specify only one attribute at a time.
   */
  describeVpcAttribute(params: EC2.Types.DescribeVpcAttributeRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcAttributeResult) => void): Request<EC2.Types.DescribeVpcAttributeResult, AWSError>;
  /**
   * Describes the specified attribute of the specified VPC. You can specify only one attribute at a time.
   */
  describeVpcAttribute(callback?: (err: AWSError, data: EC2.Types.DescribeVpcAttributeResult) => void): Request<EC2.Types.DescribeVpcAttributeResult, AWSError>;
  /**
   * Describes the ClassicLink status of one or more VPCs.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeVpcClassicLink(params: EC2.Types.DescribeVpcClassicLinkRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcClassicLinkResult) => void): Request<EC2.Types.DescribeVpcClassicLinkResult, AWSError>;
  /**
   * Describes the ClassicLink status of one or more VPCs.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  describeVpcClassicLink(callback?: (err: AWSError, data: EC2.Types.DescribeVpcClassicLinkResult) => void): Request<EC2.Types.DescribeVpcClassicLinkResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Describes the ClassicLink DNS support status of one or more VPCs. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVpcClassicLinkDnsSupport(params: EC2.Types.DescribeVpcClassicLinkDnsSupportRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.DescribeVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Describes the ClassicLink DNS support status of one or more VPCs. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.
   */
  describeVpcClassicLinkDnsSupport(callback?: (err: AWSError, data: EC2.Types.DescribeVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.DescribeVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   * Describes the connection notifications for VPC endpoints and VPC endpoint services.
   */
  describeVpcEndpointConnectionNotifications(params: EC2.Types.DescribeVpcEndpointConnectionNotificationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointConnectionNotificationsResult) => void): Request<EC2.Types.DescribeVpcEndpointConnectionNotificationsResult, AWSError>;
  /**
   * Describes the connection notifications for VPC endpoints and VPC endpoint services.
   */
  describeVpcEndpointConnectionNotifications(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointConnectionNotificationsResult) => void): Request<EC2.Types.DescribeVpcEndpointConnectionNotificationsResult, AWSError>;
  /**
   * Describes the VPC endpoint connections to your VPC endpoint services, including any endpoints that are pending your acceptance.
   */
  describeVpcEndpointConnections(params: EC2.Types.DescribeVpcEndpointConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointConnectionsResult) => void): Request<EC2.Types.DescribeVpcEndpointConnectionsResult, AWSError>;
  /**
   * Describes the VPC endpoint connections to your VPC endpoint services, including any endpoints that are pending your acceptance.
   */
  describeVpcEndpointConnections(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointConnectionsResult) => void): Request<EC2.Types.DescribeVpcEndpointConnectionsResult, AWSError>;
  /**
   * Describes the VPC endpoint service configurations in your account (your services).
   */
  describeVpcEndpointServiceConfigurations(params: EC2.Types.DescribeVpcEndpointServiceConfigurationsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServiceConfigurationsResult) => void): Request<EC2.Types.DescribeVpcEndpointServiceConfigurationsResult, AWSError>;
  /**
   * Describes the VPC endpoint service configurations in your account (your services).
   */
  describeVpcEndpointServiceConfigurations(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServiceConfigurationsResult) => void): Request<EC2.Types.DescribeVpcEndpointServiceConfigurationsResult, AWSError>;
  /**
   * Describes the principals (service consumers) that are permitted to discover your VPC endpoint service.
   */
  describeVpcEndpointServicePermissions(params: EC2.Types.DescribeVpcEndpointServicePermissionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServicePermissionsResult) => void): Request<EC2.Types.DescribeVpcEndpointServicePermissionsResult, AWSError>;
  /**
   * Describes the principals (service consumers) that are permitted to discover your VPC endpoint service.
   */
  describeVpcEndpointServicePermissions(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServicePermissionsResult) => void): Request<EC2.Types.DescribeVpcEndpointServicePermissionsResult, AWSError>;
  /**
   * Describes available services to which you can create a VPC endpoint. When the service provider and the consumer have different accounts in multiple Availability Zones, and the consumer views the VPC endpoint service information, the response only includes the common Availability Zones. For example, when the service provider account uses us-east-1a and us-east-1c and the consumer uses us-east-1a and us-east-1b, the response includes the VPC endpoint services in the common Availability Zone, us-east-1a.
   */
  describeVpcEndpointServices(params: EC2.Types.DescribeVpcEndpointServicesRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServicesResult) => void): Request<EC2.Types.DescribeVpcEndpointServicesResult, AWSError>;
  /**
   * Describes available services to which you can create a VPC endpoint. When the service provider and the consumer have different accounts in multiple Availability Zones, and the consumer views the VPC endpoint service information, the response only includes the common Availability Zones. For example, when the service provider account uses us-east-1a and us-east-1c and the consumer uses us-east-1a and us-east-1b, the response includes the VPC endpoint services in the common Availability Zone, us-east-1a.
   */
  describeVpcEndpointServices(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointServicesResult) => void): Request<EC2.Types.DescribeVpcEndpointServicesResult, AWSError>;
  /**
   * Describes your VPC endpoints.
   */
  describeVpcEndpoints(params: EC2.Types.DescribeVpcEndpointsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointsResult) => void): Request<EC2.Types.DescribeVpcEndpointsResult, AWSError>;
  /**
   * Describes your VPC endpoints.
   */
  describeVpcEndpoints(callback?: (err: AWSError, data: EC2.Types.DescribeVpcEndpointsResult) => void): Request<EC2.Types.DescribeVpcEndpointsResult, AWSError>;
  /**
   * Describes one or more of your VPC peering connections.
   */
  describeVpcPeeringConnections(params: EC2.Types.DescribeVpcPeeringConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
  /**
   * Describes one or more of your VPC peering connections.
   */
  describeVpcPeeringConnections(callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
  /**
   * Describes one or more of your VPCs.
   */
  describeVpcs(params: EC2.Types.DescribeVpcsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Describes one or more of your VPCs.
   */
  describeVpcs(callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Describes one or more of your VPN connections. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeVpnConnections(params: EC2.Types.DescribeVpnConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Describes one or more of your VPN connections. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeVpnConnections(callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Describes one or more of your virtual private gateways. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeVpnGateways(params: EC2.Types.DescribeVpnGatewaysRequest, callback?: (err: AWSError, data: EC2.Types.DescribeVpnGatewaysResult) => void): Request<EC2.Types.DescribeVpnGatewaysResult, AWSError>;
  /**
   * Describes one or more of your virtual private gateways. For more information, see Amazon Web Services Site-to-Site VPN in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  describeVpnGateways(callback?: (err: AWSError, data: EC2.Types.DescribeVpnGatewaysResult) => void): Request<EC2.Types.DescribeVpnGatewaysResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Unlinks (detaches) a linked EC2-Classic instance from a VPC. After the instance has been unlinked, the VPC security groups are no longer associated with it. An instance is automatically unlinked from a VPC when it's stopped.
   */
  detachClassicLinkVpc(params: EC2.Types.DetachClassicLinkVpcRequest, callback?: (err: AWSError, data: EC2.Types.DetachClassicLinkVpcResult) => void): Request<EC2.Types.DetachClassicLinkVpcResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Unlinks (detaches) a linked EC2-Classic instance from a VPC. After the instance has been unlinked, the VPC security groups are no longer associated with it. An instance is automatically unlinked from a VPC when it's stopped.
   */
  detachClassicLinkVpc(callback?: (err: AWSError, data: EC2.Types.DetachClassicLinkVpcResult) => void): Request<EC2.Types.DetachClassicLinkVpcResult, AWSError>;
  /**
   * Detaches an internet gateway from a VPC, disabling connectivity between the internet and the VPC. The VPC must not contain any running instances with Elastic IP addresses or public IPv4 addresses.
   */
  detachInternetGateway(params: EC2.Types.DetachInternetGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Detaches an internet gateway from a VPC, disabling connectivity between the internet and the VPC. The VPC must not contain any running instances with Elastic IP addresses or public IPv4 addresses.
   */
  detachInternetGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Detaches a network interface from an instance.
   */
  detachNetworkInterface(params: EC2.Types.DetachNetworkInterfaceRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Detaches a network interface from an instance.
   */
  detachNetworkInterface(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Detach a trust provider from an Amazon Web Services Verified Access instance.
   */
  detachVerifiedAccessTrustProvider(params: EC2.Types.DetachVerifiedAccessTrustProviderRequest, callback?: (err: AWSError, data: EC2.Types.DetachVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.DetachVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Detach a trust provider from an Amazon Web Services Verified Access instance.
   */
  detachVerifiedAccessTrustProvider(callback?: (err: AWSError, data: EC2.Types.DetachVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.DetachVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Detaches an EBS volume from an instance. Make sure to unmount any file systems on the device within your operating system before detaching the volume. Failure to do so can result in the volume becoming stuck in the busy state while detaching. If this happens, detachment can be delayed indefinitely until you unmount the volume, force detachment, reboot the instance, or all three. If an EBS volume is the root device of an instance, it can't be detached while the instance is running. To detach the root volume, stop the instance first. When a volume with an Amazon Web Services Marketplace product code is detached from an instance, the product code is no longer associated with the instance. For more information, see Detach an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  detachVolume(params: EC2.Types.DetachVolumeRequest, callback?: (err: AWSError, data: EC2.Types.VolumeAttachment) => void): Request<EC2.Types.VolumeAttachment, AWSError>;
  /**
   * Detaches an EBS volume from an instance. Make sure to unmount any file systems on the device within your operating system before detaching the volume. Failure to do so can result in the volume becoming stuck in the busy state while detaching. If this happens, detachment can be delayed indefinitely until you unmount the volume, force detachment, reboot the instance, or all three. If an EBS volume is the root device of an instance, it can't be detached while the instance is running. To detach the root volume, stop the instance first. When a volume with an Amazon Web Services Marketplace product code is detached from an instance, the product code is no longer associated with the instance. For more information, see Detach an Amazon EBS volume in the Amazon Elastic Compute Cloud User Guide.
   */
  detachVolume(callback?: (err: AWSError, data: EC2.Types.VolumeAttachment) => void): Request<EC2.Types.VolumeAttachment, AWSError>;
  /**
   * Detaches a virtual private gateway from a VPC. You do this if you're planning to turn off the VPC and not use it anymore. You can confirm a virtual private gateway has been completely detached from a VPC by describing the virtual private gateway (any attachments to the virtual private gateway are also described). You must wait for the attachment's state to switch to detached before you can delete the VPC or attach a different VPC to the virtual private gateway.
   */
  detachVpnGateway(params: EC2.Types.DetachVpnGatewayRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Detaches a virtual private gateway from a VPC. You do this if you're planning to turn off the VPC and not use it anymore. You can confirm a virtual private gateway has been completely detached from a VPC by describing the virtual private gateway (any attachments to the virtual private gateway are also described). You must wait for the attachment's state to switch to detached before you can delete the VPC or attach a different VPC to the virtual private gateway.
   */
  detachVpnGateway(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disables Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  disableAddressTransfer(params: EC2.Types.DisableAddressTransferRequest, callback?: (err: AWSError, data: EC2.Types.DisableAddressTransferResult) => void): Request<EC2.Types.DisableAddressTransferResult, AWSError>;
  /**
   * Disables Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  disableAddressTransfer(callback?: (err: AWSError, data: EC2.Types.DisableAddressTransferResult) => void): Request<EC2.Types.DisableAddressTransferResult, AWSError>;
  /**
   * Disables Infrastructure Performance metric subscriptions.
   */
  disableAwsNetworkPerformanceMetricSubscription(params: EC2.Types.DisableAwsNetworkPerformanceMetricSubscriptionRequest, callback?: (err: AWSError, data: EC2.Types.DisableAwsNetworkPerformanceMetricSubscriptionResult) => void): Request<EC2.Types.DisableAwsNetworkPerformanceMetricSubscriptionResult, AWSError>;
  /**
   * Disables Infrastructure Performance metric subscriptions.
   */
  disableAwsNetworkPerformanceMetricSubscription(callback?: (err: AWSError, data: EC2.Types.DisableAwsNetworkPerformanceMetricSubscriptionResult) => void): Request<EC2.Types.DisableAwsNetworkPerformanceMetricSubscriptionResult, AWSError>;
  /**
   * Disables EBS encryption by default for your account in the current Region. After you disable encryption by default, you can still create encrypted volumes by enabling encryption when you create each volume. Disabling encryption by default does not change the encryption status of your existing volumes. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  disableEbsEncryptionByDefault(params: EC2.Types.DisableEbsEncryptionByDefaultRequest, callback?: (err: AWSError, data: EC2.Types.DisableEbsEncryptionByDefaultResult) => void): Request<EC2.Types.DisableEbsEncryptionByDefaultResult, AWSError>;
  /**
   * Disables EBS encryption by default for your account in the current Region. After you disable encryption by default, you can still create encrypted volumes by enabling encryption when you create each volume. Disabling encryption by default does not change the encryption status of your existing volumes. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  disableEbsEncryptionByDefault(callback?: (err: AWSError, data: EC2.Types.DisableEbsEncryptionByDefaultResult) => void): Request<EC2.Types.DisableEbsEncryptionByDefaultResult, AWSError>;
  /**
   * Discontinue faster launching for a Windows AMI, and clean up existing pre-provisioned snapshots. When you disable faster launching, the AMI uses the standard launch process for each instance. All pre-provisioned snapshots must be removed before you can enable faster launching again.  To change these settings, you must own the AMI. 
   */
  disableFastLaunch(params: EC2.Types.DisableFastLaunchRequest, callback?: (err: AWSError, data: EC2.Types.DisableFastLaunchResult) => void): Request<EC2.Types.DisableFastLaunchResult, AWSError>;
  /**
   * Discontinue faster launching for a Windows AMI, and clean up existing pre-provisioned snapshots. When you disable faster launching, the AMI uses the standard launch process for each instance. All pre-provisioned snapshots must be removed before you can enable faster launching again.  To change these settings, you must own the AMI. 
   */
  disableFastLaunch(callback?: (err: AWSError, data: EC2.Types.DisableFastLaunchResult) => void): Request<EC2.Types.DisableFastLaunchResult, AWSError>;
  /**
   * Disables fast snapshot restores for the specified snapshots in the specified Availability Zones.
   */
  disableFastSnapshotRestores(params: EC2.Types.DisableFastSnapshotRestoresRequest, callback?: (err: AWSError, data: EC2.Types.DisableFastSnapshotRestoresResult) => void): Request<EC2.Types.DisableFastSnapshotRestoresResult, AWSError>;
  /**
   * Disables fast snapshot restores for the specified snapshots in the specified Availability Zones.
   */
  disableFastSnapshotRestores(callback?: (err: AWSError, data: EC2.Types.DisableFastSnapshotRestoresResult) => void): Request<EC2.Types.DisableFastSnapshotRestoresResult, AWSError>;
  /**
   * Cancels the deprecation of the specified AMI. For more information, see Deprecate an AMI in the Amazon EC2 User Guide.
   */
  disableImageDeprecation(params: EC2.Types.DisableImageDeprecationRequest, callback?: (err: AWSError, data: EC2.Types.DisableImageDeprecationResult) => void): Request<EC2.Types.DisableImageDeprecationResult, AWSError>;
  /**
   * Cancels the deprecation of the specified AMI. For more information, see Deprecate an AMI in the Amazon EC2 User Guide.
   */
  disableImageDeprecation(callback?: (err: AWSError, data: EC2.Types.DisableImageDeprecationResult) => void): Request<EC2.Types.DisableImageDeprecationResult, AWSError>;
  /**
   * Disable the IPAM account. For more information, see Enable integration with Organizations in the Amazon VPC IPAM User Guide. 
   */
  disableIpamOrganizationAdminAccount(params: EC2.Types.DisableIpamOrganizationAdminAccountRequest, callback?: (err: AWSError, data: EC2.Types.DisableIpamOrganizationAdminAccountResult) => void): Request<EC2.Types.DisableIpamOrganizationAdminAccountResult, AWSError>;
  /**
   * Disable the IPAM account. For more information, see Enable integration with Organizations in the Amazon VPC IPAM User Guide. 
   */
  disableIpamOrganizationAdminAccount(callback?: (err: AWSError, data: EC2.Types.DisableIpamOrganizationAdminAccountResult) => void): Request<EC2.Types.DisableIpamOrganizationAdminAccountResult, AWSError>;
  /**
   * Disables access to the EC2 serial console of all instances for your account. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  disableSerialConsoleAccess(params: EC2.Types.DisableSerialConsoleAccessRequest, callback?: (err: AWSError, data: EC2.Types.DisableSerialConsoleAccessResult) => void): Request<EC2.Types.DisableSerialConsoleAccessResult, AWSError>;
  /**
   * Disables access to the EC2 serial console of all instances for your account. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  disableSerialConsoleAccess(callback?: (err: AWSError, data: EC2.Types.DisableSerialConsoleAccessResult) => void): Request<EC2.Types.DisableSerialConsoleAccessResult, AWSError>;
  /**
   * Disables the specified resource attachment from propagating routes to the specified propagation route table.
   */
  disableTransitGatewayRouteTablePropagation(params: EC2.Types.DisableTransitGatewayRouteTablePropagationRequest, callback?: (err: AWSError, data: EC2.Types.DisableTransitGatewayRouteTablePropagationResult) => void): Request<EC2.Types.DisableTransitGatewayRouteTablePropagationResult, AWSError>;
  /**
   * Disables the specified resource attachment from propagating routes to the specified propagation route table.
   */
  disableTransitGatewayRouteTablePropagation(callback?: (err: AWSError, data: EC2.Types.DisableTransitGatewayRouteTablePropagationResult) => void): Request<EC2.Types.DisableTransitGatewayRouteTablePropagationResult, AWSError>;
  /**
   * Disables a virtual private gateway (VGW) from propagating routes to a specified route table of a VPC.
   */
  disableVgwRoutePropagation(params: EC2.Types.DisableVgwRoutePropagationRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disables a virtual private gateway (VGW) from propagating routes to a specified route table of a VPC.
   */
  disableVgwRoutePropagation(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disables ClassicLink for a VPC. You cannot disable ClassicLink for a VPC that has EC2-Classic instances linked to it.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  disableVpcClassicLink(params: EC2.Types.DisableVpcClassicLinkRequest, callback?: (err: AWSError, data: EC2.Types.DisableVpcClassicLinkResult) => void): Request<EC2.Types.DisableVpcClassicLinkResult, AWSError>;
  /**
   * Disables ClassicLink for a VPC. You cannot disable ClassicLink for a VPC that has EC2-Classic instances linked to it.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  disableVpcClassicLink(callback?: (err: AWSError, data: EC2.Types.DisableVpcClassicLinkResult) => void): Request<EC2.Types.DisableVpcClassicLinkResult, AWSError>;
  /**
   * Disables ClassicLink DNS support for a VPC. If disabled, DNS hostnames resolve to public IP addresses when addressed between a linked EC2-Classic instance and instances in the VPC to which it's linked. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  disableVpcClassicLinkDnsSupport(params: EC2.Types.DisableVpcClassicLinkDnsSupportRequest, callback?: (err: AWSError, data: EC2.Types.DisableVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.DisableVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   * Disables ClassicLink DNS support for a VPC. If disabled, DNS hostnames resolve to public IP addresses when addressed between a linked EC2-Classic instance and instances in the VPC to which it's linked. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  disableVpcClassicLinkDnsSupport(callback?: (err: AWSError, data: EC2.Types.DisableVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.DisableVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   * Disassociates an Elastic IP address from the instance or network interface it's associated with. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error.
   */
  disassociateAddress(params: EC2.Types.DisassociateAddressRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disassociates an Elastic IP address from the instance or network interface it's associated with. An Elastic IP address is for use in either the EC2-Classic platform or in a VPC. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  This is an idempotent operation. If you perform the operation more than once, Amazon EC2 doesn't return an error.
   */
  disassociateAddress(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disassociates a target network from the specified Client VPN endpoint. When you disassociate the last target network from a Client VPN, the following happens:   The route that was automatically added for the VPC is deleted   All active client connections are terminated   New client connections are disallowed   The Client VPN endpoint's status changes to pending-associate   
   */
  disassociateClientVpnTargetNetwork(params: EC2.Types.DisassociateClientVpnTargetNetworkRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateClientVpnTargetNetworkResult) => void): Request<EC2.Types.DisassociateClientVpnTargetNetworkResult, AWSError>;
  /**
   * Disassociates a target network from the specified Client VPN endpoint. When you disassociate the last target network from a Client VPN, the following happens:   The route that was automatically added for the VPC is deleted   All active client connections are terminated   New client connections are disallowed   The Client VPN endpoint's status changes to pending-associate   
   */
  disassociateClientVpnTargetNetwork(callback?: (err: AWSError, data: EC2.Types.DisassociateClientVpnTargetNetworkResult) => void): Request<EC2.Types.DisassociateClientVpnTargetNetworkResult, AWSError>;
  /**
   * Disassociates an IAM role from an Certificate Manager (ACM) certificate. Disassociating an IAM role from an ACM certificate removes the Amazon S3 object that contains the certificate, certificate chain, and encrypted private key from the Amazon S3 bucket. It also revokes the IAM role's permission to use the KMS key used to encrypt the private key. This effectively revokes the role's permission to use the certificate.
   */
  disassociateEnclaveCertificateIamRole(params: EC2.Types.DisassociateEnclaveCertificateIamRoleRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateEnclaveCertificateIamRoleResult) => void): Request<EC2.Types.DisassociateEnclaveCertificateIamRoleResult, AWSError>;
  /**
   * Disassociates an IAM role from an Certificate Manager (ACM) certificate. Disassociating an IAM role from an ACM certificate removes the Amazon S3 object that contains the certificate, certificate chain, and encrypted private key from the Amazon S3 bucket. It also revokes the IAM role's permission to use the KMS key used to encrypt the private key. This effectively revokes the role's permission to use the certificate.
   */
  disassociateEnclaveCertificateIamRole(callback?: (err: AWSError, data: EC2.Types.DisassociateEnclaveCertificateIamRoleResult) => void): Request<EC2.Types.DisassociateEnclaveCertificateIamRoleResult, AWSError>;
  /**
   * Disassociates an IAM instance profile from a running or stopped instance. Use DescribeIamInstanceProfileAssociations to get the association ID.
   */
  disassociateIamInstanceProfile(params: EC2.Types.DisassociateIamInstanceProfileRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateIamInstanceProfileResult) => void): Request<EC2.Types.DisassociateIamInstanceProfileResult, AWSError>;
  /**
   * Disassociates an IAM instance profile from a running or stopped instance. Use DescribeIamInstanceProfileAssociations to get the association ID.
   */
  disassociateIamInstanceProfile(callback?: (err: AWSError, data: EC2.Types.DisassociateIamInstanceProfileResult) => void): Request<EC2.Types.DisassociateIamInstanceProfileResult, AWSError>;
  /**
   * Disassociates one or more targets from an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  disassociateInstanceEventWindow(params: EC2.Types.DisassociateInstanceEventWindowRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateInstanceEventWindowResult) => void): Request<EC2.Types.DisassociateInstanceEventWindowResult, AWSError>;
  /**
   * Disassociates one or more targets from an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  disassociateInstanceEventWindow(callback?: (err: AWSError, data: EC2.Types.DisassociateInstanceEventWindowResult) => void): Request<EC2.Types.DisassociateInstanceEventWindowResult, AWSError>;
  /**
   * Disassociates a resource discovery from an Amazon VPC IPAM. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  disassociateIpamResourceDiscovery(params: EC2.Types.DisassociateIpamResourceDiscoveryRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateIpamResourceDiscoveryResult) => void): Request<EC2.Types.DisassociateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Disassociates a resource discovery from an Amazon VPC IPAM. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  disassociateIpamResourceDiscovery(callback?: (err: AWSError, data: EC2.Types.DisassociateIpamResourceDiscoveryResult) => void): Request<EC2.Types.DisassociateIpamResourceDiscoveryResult, AWSError>;
  /**
   * Disassociates secondary Elastic IP addresses (EIPs) from a public NAT gateway. You cannot disassociate your primary EIP. For more information, see Edit secondary IP address associations in the Amazon Virtual Private Cloud User Guide. While disassociating is in progress, you cannot associate/disassociate additional EIPs while the connections are being drained. You are, however, allowed to delete the NAT gateway. An EIP will only be released at the end of MaxDrainDurationSeconds. The EIPs stay associated and support the existing connections but do not support any new connections (new connections are distributed across the remaining associated EIPs). As the existing connections drain out, the EIPs (and the corresponding private IPs mapped to them) get released.
   */
  disassociateNatGatewayAddress(params: EC2.Types.DisassociateNatGatewayAddressRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateNatGatewayAddressResult) => void): Request<EC2.Types.DisassociateNatGatewayAddressResult, AWSError>;
  /**
   * Disassociates secondary Elastic IP addresses (EIPs) from a public NAT gateway. You cannot disassociate your primary EIP. For more information, see Edit secondary IP address associations in the Amazon Virtual Private Cloud User Guide. While disassociating is in progress, you cannot associate/disassociate additional EIPs while the connections are being drained. You are, however, allowed to delete the NAT gateway. An EIP will only be released at the end of MaxDrainDurationSeconds. The EIPs stay associated and support the existing connections but do not support any new connections (new connections are distributed across the remaining associated EIPs). As the existing connections drain out, the EIPs (and the corresponding private IPs mapped to them) get released.
   */
  disassociateNatGatewayAddress(callback?: (err: AWSError, data: EC2.Types.DisassociateNatGatewayAddressResult) => void): Request<EC2.Types.DisassociateNatGatewayAddressResult, AWSError>;
  /**
   * Disassociates a subnet or gateway from a route table. After you perform this action, the subnet no longer uses the routes in the route table. Instead, it uses the routes in the VPC's main route table. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  disassociateRouteTable(params: EC2.Types.DisassociateRouteTableRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disassociates a subnet or gateway from a route table. After you perform this action, the subnet no longer uses the routes in the route table. Instead, it uses the routes in the VPC's main route table. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  disassociateRouteTable(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Disassociates a CIDR block from a subnet. Currently, you can disassociate an IPv6 CIDR block only. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it. 
   */
  disassociateSubnetCidrBlock(params: EC2.Types.DisassociateSubnetCidrBlockRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateSubnetCidrBlockResult) => void): Request<EC2.Types.DisassociateSubnetCidrBlockResult, AWSError>;
  /**
   * Disassociates a CIDR block from a subnet. Currently, you can disassociate an IPv6 CIDR block only. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it. 
   */
  disassociateSubnetCidrBlock(callback?: (err: AWSError, data: EC2.Types.DisassociateSubnetCidrBlockResult) => void): Request<EC2.Types.DisassociateSubnetCidrBlockResult, AWSError>;
  /**
   * Disassociates the specified subnets from the transit gateway multicast domain. 
   */
  disassociateTransitGatewayMulticastDomain(params: EC2.Types.DisassociateTransitGatewayMulticastDomainRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.DisassociateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Disassociates the specified subnets from the transit gateway multicast domain. 
   */
  disassociateTransitGatewayMulticastDomain(callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayMulticastDomainResult) => void): Request<EC2.Types.DisassociateTransitGatewayMulticastDomainResult, AWSError>;
  /**
   * Removes the association between an an attachment and a policy table.
   */
  disassociateTransitGatewayPolicyTable(params: EC2.Types.DisassociateTransitGatewayPolicyTableRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.DisassociateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Removes the association between an an attachment and a policy table.
   */
  disassociateTransitGatewayPolicyTable(callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayPolicyTableResult) => void): Request<EC2.Types.DisassociateTransitGatewayPolicyTableResult, AWSError>;
  /**
   * Disassociates a resource attachment from a transit gateway route table.
   */
  disassociateTransitGatewayRouteTable(params: EC2.Types.DisassociateTransitGatewayRouteTableRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayRouteTableResult) => void): Request<EC2.Types.DisassociateTransitGatewayRouteTableResult, AWSError>;
  /**
   * Disassociates a resource attachment from a transit gateway route table.
   */
  disassociateTransitGatewayRouteTable(callback?: (err: AWSError, data: EC2.Types.DisassociateTransitGatewayRouteTableResult) => void): Request<EC2.Types.DisassociateTransitGatewayRouteTableResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Removes an association between a branch network interface with a trunk network interface.
   */
  disassociateTrunkInterface(params: EC2.Types.DisassociateTrunkInterfaceRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateTrunkInterfaceResult) => void): Request<EC2.Types.DisassociateTrunkInterfaceResult, AWSError>;
  /**
   *  This API action is currently in limited preview only. If you are interested in using this feature, contact your account manager.  Removes an association between a branch network interface with a trunk network interface.
   */
  disassociateTrunkInterface(callback?: (err: AWSError, data: EC2.Types.DisassociateTrunkInterfaceResult) => void): Request<EC2.Types.DisassociateTrunkInterfaceResult, AWSError>;
  /**
   * Disassociates a CIDR block from a VPC. To disassociate the CIDR block, you must specify its association ID. You can get the association ID by using DescribeVpcs. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it.  You cannot disassociate the CIDR block with which you originally created the VPC (the primary CIDR block).
   */
  disassociateVpcCidrBlock(params: EC2.Types.DisassociateVpcCidrBlockRequest, callback?: (err: AWSError, data: EC2.Types.DisassociateVpcCidrBlockResult) => void): Request<EC2.Types.DisassociateVpcCidrBlockResult, AWSError>;
  /**
   * Disassociates a CIDR block from a VPC. To disassociate the CIDR block, you must specify its association ID. You can get the association ID by using DescribeVpcs. You must detach or delete all gateways and resources that are associated with the CIDR block before you can disassociate it.  You cannot disassociate the CIDR block with which you originally created the VPC (the primary CIDR block).
   */
  disassociateVpcCidrBlock(callback?: (err: AWSError, data: EC2.Types.DisassociateVpcCidrBlockResult) => void): Request<EC2.Types.DisassociateVpcCidrBlockResult, AWSError>;
  /**
   * Enables Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  enableAddressTransfer(params: EC2.Types.EnableAddressTransferRequest, callback?: (err: AWSError, data: EC2.Types.EnableAddressTransferResult) => void): Request<EC2.Types.EnableAddressTransferResult, AWSError>;
  /**
   * Enables Elastic IP address transfer. For more information, see Transfer Elastic IP addresses in the Amazon Virtual Private Cloud User Guide.
   */
  enableAddressTransfer(callback?: (err: AWSError, data: EC2.Types.EnableAddressTransferResult) => void): Request<EC2.Types.EnableAddressTransferResult, AWSError>;
  /**
   * Enables Infrastructure Performance subscriptions.
   */
  enableAwsNetworkPerformanceMetricSubscription(params: EC2.Types.EnableAwsNetworkPerformanceMetricSubscriptionRequest, callback?: (err: AWSError, data: EC2.Types.EnableAwsNetworkPerformanceMetricSubscriptionResult) => void): Request<EC2.Types.EnableAwsNetworkPerformanceMetricSubscriptionResult, AWSError>;
  /**
   * Enables Infrastructure Performance subscriptions.
   */
  enableAwsNetworkPerformanceMetricSubscription(callback?: (err: AWSError, data: EC2.Types.EnableAwsNetworkPerformanceMetricSubscriptionResult) => void): Request<EC2.Types.EnableAwsNetworkPerformanceMetricSubscriptionResult, AWSError>;
  /**
   * Enables EBS encryption by default for your account in the current Region. After you enable encryption by default, the EBS volumes that you create are always encrypted, either using the default KMS key or the KMS key that you specified when you created each volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. You can specify the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. Enabling encryption by default has no effect on the encryption status of your existing volumes. After you enable encryption by default, you can no longer launch instances using instance types that do not support encryption. For more information, see Supported instance types.
   */
  enableEbsEncryptionByDefault(params: EC2.Types.EnableEbsEncryptionByDefaultRequest, callback?: (err: AWSError, data: EC2.Types.EnableEbsEncryptionByDefaultResult) => void): Request<EC2.Types.EnableEbsEncryptionByDefaultResult, AWSError>;
  /**
   * Enables EBS encryption by default for your account in the current Region. After you enable encryption by default, the EBS volumes that you create are always encrypted, either using the default KMS key or the KMS key that you specified when you created each volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. You can specify the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. Enabling encryption by default has no effect on the encryption status of your existing volumes. After you enable encryption by default, you can no longer launch instances using instance types that do not support encryption. For more information, see Supported instance types.
   */
  enableEbsEncryptionByDefault(callback?: (err: AWSError, data: EC2.Types.EnableEbsEncryptionByDefaultResult) => void): Request<EC2.Types.EnableEbsEncryptionByDefaultResult, AWSError>;
  /**
   * When you enable faster launching for a Windows AMI, images are pre-provisioned, using snapshots to launch instances up to 65% faster. To create the optimized Windows image, Amazon EC2 launches an instance and runs through Sysprep steps, rebooting as required. Then it creates a set of reserved snapshots that are used for subsequent launches. The reserved snapshots are automatically replenished as they are used, depending on your settings for launch frequency.  To change these settings, you must own the AMI. 
   */
  enableFastLaunch(params: EC2.Types.EnableFastLaunchRequest, callback?: (err: AWSError, data: EC2.Types.EnableFastLaunchResult) => void): Request<EC2.Types.EnableFastLaunchResult, AWSError>;
  /**
   * When you enable faster launching for a Windows AMI, images are pre-provisioned, using snapshots to launch instances up to 65% faster. To create the optimized Windows image, Amazon EC2 launches an instance and runs through Sysprep steps, rebooting as required. Then it creates a set of reserved snapshots that are used for subsequent launches. The reserved snapshots are automatically replenished as they are used, depending on your settings for launch frequency.  To change these settings, you must own the AMI. 
   */
  enableFastLaunch(callback?: (err: AWSError, data: EC2.Types.EnableFastLaunchResult) => void): Request<EC2.Types.EnableFastLaunchResult, AWSError>;
  /**
   * Enables fast snapshot restores for the specified snapshots in the specified Availability Zones. You get the full benefit of fast snapshot restores after they enter the enabled state. To get the current state of fast snapshot restores, use DescribeFastSnapshotRestores. To disable fast snapshot restores, use DisableFastSnapshotRestores. For more information, see Amazon EBS fast snapshot restore in the Amazon Elastic Compute Cloud User Guide.
   */
  enableFastSnapshotRestores(params: EC2.Types.EnableFastSnapshotRestoresRequest, callback?: (err: AWSError, data: EC2.Types.EnableFastSnapshotRestoresResult) => void): Request<EC2.Types.EnableFastSnapshotRestoresResult, AWSError>;
  /**
   * Enables fast snapshot restores for the specified snapshots in the specified Availability Zones. You get the full benefit of fast snapshot restores after they enter the enabled state. To get the current state of fast snapshot restores, use DescribeFastSnapshotRestores. To disable fast snapshot restores, use DisableFastSnapshotRestores. For more information, see Amazon EBS fast snapshot restore in the Amazon Elastic Compute Cloud User Guide.
   */
  enableFastSnapshotRestores(callback?: (err: AWSError, data: EC2.Types.EnableFastSnapshotRestoresResult) => void): Request<EC2.Types.EnableFastSnapshotRestoresResult, AWSError>;
  /**
   * Enables deprecation of the specified AMI at the specified date and time. For more information, see Deprecate an AMI in the Amazon EC2 User Guide.
   */
  enableImageDeprecation(params: EC2.Types.EnableImageDeprecationRequest, callback?: (err: AWSError, data: EC2.Types.EnableImageDeprecationResult) => void): Request<EC2.Types.EnableImageDeprecationResult, AWSError>;
  /**
   * Enables deprecation of the specified AMI at the specified date and time. For more information, see Deprecate an AMI in the Amazon EC2 User Guide.
   */
  enableImageDeprecation(callback?: (err: AWSError, data: EC2.Types.EnableImageDeprecationResult) => void): Request<EC2.Types.EnableImageDeprecationResult, AWSError>;
  /**
   * Enable an Organizations member account as the IPAM admin account. You cannot select the Organizations management account as the IPAM admin account. For more information, see Enable integration with Organizations in the Amazon VPC IPAM User Guide. 
   */
  enableIpamOrganizationAdminAccount(params: EC2.Types.EnableIpamOrganizationAdminAccountRequest, callback?: (err: AWSError, data: EC2.Types.EnableIpamOrganizationAdminAccountResult) => void): Request<EC2.Types.EnableIpamOrganizationAdminAccountResult, AWSError>;
  /**
   * Enable an Organizations member account as the IPAM admin account. You cannot select the Organizations management account as the IPAM admin account. For more information, see Enable integration with Organizations in the Amazon VPC IPAM User Guide. 
   */
  enableIpamOrganizationAdminAccount(callback?: (err: AWSError, data: EC2.Types.EnableIpamOrganizationAdminAccountResult) => void): Request<EC2.Types.EnableIpamOrganizationAdminAccountResult, AWSError>;
  /**
   * Establishes a trust relationship between Reachability Analyzer and Organizations. This operation must be performed by the management account for the organization. After you establish a trust relationship, a user in the management account or a delegated administrator account can run a cross-account analysis using resources from the member accounts.
   */
  enableReachabilityAnalyzerOrganizationSharing(params: EC2.Types.EnableReachabilityAnalyzerOrganizationSharingRequest, callback?: (err: AWSError, data: EC2.Types.EnableReachabilityAnalyzerOrganizationSharingResult) => void): Request<EC2.Types.EnableReachabilityAnalyzerOrganizationSharingResult, AWSError>;
  /**
   * Establishes a trust relationship between Reachability Analyzer and Organizations. This operation must be performed by the management account for the organization. After you establish a trust relationship, a user in the management account or a delegated administrator account can run a cross-account analysis using resources from the member accounts.
   */
  enableReachabilityAnalyzerOrganizationSharing(callback?: (err: AWSError, data: EC2.Types.EnableReachabilityAnalyzerOrganizationSharingResult) => void): Request<EC2.Types.EnableReachabilityAnalyzerOrganizationSharingResult, AWSError>;
  /**
   * Enables access to the EC2 serial console of all instances for your account. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  enableSerialConsoleAccess(params: EC2.Types.EnableSerialConsoleAccessRequest, callback?: (err: AWSError, data: EC2.Types.EnableSerialConsoleAccessResult) => void): Request<EC2.Types.EnableSerialConsoleAccessResult, AWSError>;
  /**
   * Enables access to the EC2 serial console of all instances for your account. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  enableSerialConsoleAccess(callback?: (err: AWSError, data: EC2.Types.EnableSerialConsoleAccessResult) => void): Request<EC2.Types.EnableSerialConsoleAccessResult, AWSError>;
  /**
   * Enables the specified attachment to propagate routes to the specified propagation route table.
   */
  enableTransitGatewayRouteTablePropagation(params: EC2.Types.EnableTransitGatewayRouteTablePropagationRequest, callback?: (err: AWSError, data: EC2.Types.EnableTransitGatewayRouteTablePropagationResult) => void): Request<EC2.Types.EnableTransitGatewayRouteTablePropagationResult, AWSError>;
  /**
   * Enables the specified attachment to propagate routes to the specified propagation route table.
   */
  enableTransitGatewayRouteTablePropagation(callback?: (err: AWSError, data: EC2.Types.EnableTransitGatewayRouteTablePropagationResult) => void): Request<EC2.Types.EnableTransitGatewayRouteTablePropagationResult, AWSError>;
  /**
   * Enables a virtual private gateway (VGW) to propagate routes to the specified route table of a VPC.
   */
  enableVgwRoutePropagation(params: EC2.Types.EnableVgwRoutePropagationRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Enables a virtual private gateway (VGW) to propagate routes to the specified route table of a VPC.
   */
  enableVgwRoutePropagation(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Enables I/O operations for a volume that had I/O operations disabled because the data on the volume was potentially inconsistent.
   */
  enableVolumeIO(params: EC2.Types.EnableVolumeIORequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Enables I/O operations for a volume that had I/O operations disabled because the data on the volume was potentially inconsistent.
   */
  enableVolumeIO(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Enables a VPC for ClassicLink. You can then link EC2-Classic instances to your ClassicLink-enabled VPC to allow communication over private IP addresses. You cannot enable your VPC for ClassicLink if any of your VPC route tables have existing routes for address ranges within the 10.0.0.0/8 IP address range, excluding local routes for VPCs in the 10.0.0.0/16 and 10.1.0.0/16 IP address ranges. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.
   */
  enableVpcClassicLink(params: EC2.Types.EnableVpcClassicLinkRequest, callback?: (err: AWSError, data: EC2.Types.EnableVpcClassicLinkResult) => void): Request<EC2.Types.EnableVpcClassicLinkResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Enables a VPC for ClassicLink. You can then link EC2-Classic instances to your ClassicLink-enabled VPC to allow communication over private IP addresses. You cannot enable your VPC for ClassicLink if any of your VPC route tables have existing routes for address ranges within the 10.0.0.0/8 IP address range, excluding local routes for VPCs in the 10.0.0.0/16 and 10.1.0.0/16 IP address ranges. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide.
   */
  enableVpcClassicLink(callback?: (err: AWSError, data: EC2.Types.EnableVpcClassicLinkResult) => void): Request<EC2.Types.EnableVpcClassicLinkResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Enables a VPC to support DNS hostname resolution for ClassicLink. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.
   */
  enableVpcClassicLinkDnsSupport(params: EC2.Types.EnableVpcClassicLinkDnsSupportRequest, callback?: (err: AWSError, data: EC2.Types.EnableVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.EnableVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Enables a VPC to support DNS hostname resolution for ClassicLink. If enabled, the DNS hostname of a linked EC2-Classic instance resolves to its private IP address when addressed from an instance in the VPC to which it's linked. Similarly, the DNS hostname of an instance in a VPC resolves to its private IP address when addressed from a linked EC2-Classic instance. For more information, see ClassicLink in the Amazon Elastic Compute Cloud User Guide. You must specify a VPC ID in the request.
   */
  enableVpcClassicLinkDnsSupport(callback?: (err: AWSError, data: EC2.Types.EnableVpcClassicLinkDnsSupportResult) => void): Request<EC2.Types.EnableVpcClassicLinkDnsSupportResult, AWSError>;
  /**
   * Downloads the client certificate revocation list for the specified Client VPN endpoint.
   */
  exportClientVpnClientCertificateRevocationList(params: EC2.Types.ExportClientVpnClientCertificateRevocationListRequest, callback?: (err: AWSError, data: EC2.Types.ExportClientVpnClientCertificateRevocationListResult) => void): Request<EC2.Types.ExportClientVpnClientCertificateRevocationListResult, AWSError>;
  /**
   * Downloads the client certificate revocation list for the specified Client VPN endpoint.
   */
  exportClientVpnClientCertificateRevocationList(callback?: (err: AWSError, data: EC2.Types.ExportClientVpnClientCertificateRevocationListResult) => void): Request<EC2.Types.ExportClientVpnClientCertificateRevocationListResult, AWSError>;
  /**
   * Downloads the contents of the Client VPN endpoint configuration file for the specified Client VPN endpoint. The Client VPN endpoint configuration file includes the Client VPN endpoint and certificate information clients need to establish a connection with the Client VPN endpoint.
   */
  exportClientVpnClientConfiguration(params: EC2.Types.ExportClientVpnClientConfigurationRequest, callback?: (err: AWSError, data: EC2.Types.ExportClientVpnClientConfigurationResult) => void): Request<EC2.Types.ExportClientVpnClientConfigurationResult, AWSError>;
  /**
   * Downloads the contents of the Client VPN endpoint configuration file for the specified Client VPN endpoint. The Client VPN endpoint configuration file includes the Client VPN endpoint and certificate information clients need to establish a connection with the Client VPN endpoint.
   */
  exportClientVpnClientConfiguration(callback?: (err: AWSError, data: EC2.Types.ExportClientVpnClientConfigurationResult) => void): Request<EC2.Types.ExportClientVpnClientConfigurationResult, AWSError>;
  /**
   * Exports an Amazon Machine Image (AMI) to a VM file. For more information, see Exporting a VM directly from an Amazon Machine Image (AMI) in the VM Import/Export User Guide.
   */
  exportImage(params: EC2.Types.ExportImageRequest, callback?: (err: AWSError, data: EC2.Types.ExportImageResult) => void): Request<EC2.Types.ExportImageResult, AWSError>;
  /**
   * Exports an Amazon Machine Image (AMI) to a VM file. For more information, see Exporting a VM directly from an Amazon Machine Image (AMI) in the VM Import/Export User Guide.
   */
  exportImage(callback?: (err: AWSError, data: EC2.Types.ExportImageResult) => void): Request<EC2.Types.ExportImageResult, AWSError>;
  /**
   * Exports routes from the specified transit gateway route table to the specified S3 bucket. By default, all routes are exported. Alternatively, you can filter by CIDR range. The routes are saved to the specified bucket in a JSON file. For more information, see Export Route Tables to Amazon S3 in Transit Gateways.
   */
  exportTransitGatewayRoutes(params: EC2.Types.ExportTransitGatewayRoutesRequest, callback?: (err: AWSError, data: EC2.Types.ExportTransitGatewayRoutesResult) => void): Request<EC2.Types.ExportTransitGatewayRoutesResult, AWSError>;
  /**
   * Exports routes from the specified transit gateway route table to the specified S3 bucket. By default, all routes are exported. Alternatively, you can filter by CIDR range. The routes are saved to the specified bucket in a JSON file. For more information, see Export Route Tables to Amazon S3 in Transit Gateways.
   */
  exportTransitGatewayRoutes(callback?: (err: AWSError, data: EC2.Types.ExportTransitGatewayRoutesResult) => void): Request<EC2.Types.ExportTransitGatewayRoutesResult, AWSError>;
  /**
   * Returns the IAM roles that are associated with the specified ACM (ACM) certificate. It also returns the name of the Amazon S3 bucket and the Amazon S3 object key where the certificate, certificate chain, and encrypted private key bundle are stored, and the ARN of the KMS key that's used to encrypt the private key.
   */
  getAssociatedEnclaveCertificateIamRoles(params: EC2.Types.GetAssociatedEnclaveCertificateIamRolesRequest, callback?: (err: AWSError, data: EC2.Types.GetAssociatedEnclaveCertificateIamRolesResult) => void): Request<EC2.Types.GetAssociatedEnclaveCertificateIamRolesResult, AWSError>;
  /**
   * Returns the IAM roles that are associated with the specified ACM (ACM) certificate. It also returns the name of the Amazon S3 bucket and the Amazon S3 object key where the certificate, certificate chain, and encrypted private key bundle are stored, and the ARN of the KMS key that's used to encrypt the private key.
   */
  getAssociatedEnclaveCertificateIamRoles(callback?: (err: AWSError, data: EC2.Types.GetAssociatedEnclaveCertificateIamRolesResult) => void): Request<EC2.Types.GetAssociatedEnclaveCertificateIamRolesResult, AWSError>;
  /**
   * Gets information about the IPv6 CIDR block associations for a specified IPv6 address pool.
   */
  getAssociatedIpv6PoolCidrs(params: EC2.Types.GetAssociatedIpv6PoolCidrsRequest, callback?: (err: AWSError, data: EC2.Types.GetAssociatedIpv6PoolCidrsResult) => void): Request<EC2.Types.GetAssociatedIpv6PoolCidrsResult, AWSError>;
  /**
   * Gets information about the IPv6 CIDR block associations for a specified IPv6 address pool.
   */
  getAssociatedIpv6PoolCidrs(callback?: (err: AWSError, data: EC2.Types.GetAssociatedIpv6PoolCidrsResult) => void): Request<EC2.Types.GetAssociatedIpv6PoolCidrsResult, AWSError>;
  /**
   * Gets network performance data.
   */
  getAwsNetworkPerformanceData(params: EC2.Types.GetAwsNetworkPerformanceDataRequest, callback?: (err: AWSError, data: EC2.Types.GetAwsNetworkPerformanceDataResult) => void): Request<EC2.Types.GetAwsNetworkPerformanceDataResult, AWSError>;
  /**
   * Gets network performance data.
   */
  getAwsNetworkPerformanceData(callback?: (err: AWSError, data: EC2.Types.GetAwsNetworkPerformanceDataResult) => void): Request<EC2.Types.GetAwsNetworkPerformanceDataResult, AWSError>;
  /**
   * Gets usage information about a Capacity Reservation. If the Capacity Reservation is shared, it shows usage information for the Capacity Reservation owner and each Amazon Web Services account that is currently using the shared capacity. If the Capacity Reservation is not shared, it shows only the Capacity Reservation owner's usage.
   */
  getCapacityReservationUsage(params: EC2.Types.GetCapacityReservationUsageRequest, callback?: (err: AWSError, data: EC2.Types.GetCapacityReservationUsageResult) => void): Request<EC2.Types.GetCapacityReservationUsageResult, AWSError>;
  /**
   * Gets usage information about a Capacity Reservation. If the Capacity Reservation is shared, it shows usage information for the Capacity Reservation owner and each Amazon Web Services account that is currently using the shared capacity. If the Capacity Reservation is not shared, it shows only the Capacity Reservation owner's usage.
   */
  getCapacityReservationUsage(callback?: (err: AWSError, data: EC2.Types.GetCapacityReservationUsageResult) => void): Request<EC2.Types.GetCapacityReservationUsageResult, AWSError>;
  /**
   * Describes the allocations from the specified customer-owned address pool.
   */
  getCoipPoolUsage(params: EC2.Types.GetCoipPoolUsageRequest, callback?: (err: AWSError, data: EC2.Types.GetCoipPoolUsageResult) => void): Request<EC2.Types.GetCoipPoolUsageResult, AWSError>;
  /**
   * Describes the allocations from the specified customer-owned address pool.
   */
  getCoipPoolUsage(callback?: (err: AWSError, data: EC2.Types.GetCoipPoolUsageResult) => void): Request<EC2.Types.GetCoipPoolUsageResult, AWSError>;
  /**
   * Gets the console output for the specified instance. For Linux instances, the instance console output displays the exact console output that would normally be displayed on a physical monitor attached to a computer. For Windows instances, the instance console output includes the last three system event log errors. By default, the console output returns buffered information that was posted shortly after an instance transition state (start, stop, reboot, or terminate). This information is available for at least one hour after the most recent post. Only the most recent 64 KB of console output is available. You can optionally retrieve the latest serial console output at any time during the instance lifecycle. This option is supported on instance types that use the Nitro hypervisor. For more information, see Instance console output in the Amazon EC2 User Guide.
   */
  getConsoleOutput(params: EC2.Types.GetConsoleOutputRequest, callback?: (err: AWSError, data: EC2.Types.GetConsoleOutputResult) => void): Request<EC2.Types.GetConsoleOutputResult, AWSError>;
  /**
   * Gets the console output for the specified instance. For Linux instances, the instance console output displays the exact console output that would normally be displayed on a physical monitor attached to a computer. For Windows instances, the instance console output includes the last three system event log errors. By default, the console output returns buffered information that was posted shortly after an instance transition state (start, stop, reboot, or terminate). This information is available for at least one hour after the most recent post. Only the most recent 64 KB of console output is available. You can optionally retrieve the latest serial console output at any time during the instance lifecycle. This option is supported on instance types that use the Nitro hypervisor. For more information, see Instance console output in the Amazon EC2 User Guide.
   */
  getConsoleOutput(callback?: (err: AWSError, data: EC2.Types.GetConsoleOutputResult) => void): Request<EC2.Types.GetConsoleOutputResult, AWSError>;
  /**
   * Retrieve a JPG-format screenshot of a running instance to help with troubleshooting. The returned content is Base64-encoded.
   */
  getConsoleScreenshot(params: EC2.Types.GetConsoleScreenshotRequest, callback?: (err: AWSError, data: EC2.Types.GetConsoleScreenshotResult) => void): Request<EC2.Types.GetConsoleScreenshotResult, AWSError>;
  /**
   * Retrieve a JPG-format screenshot of a running instance to help with troubleshooting. The returned content is Base64-encoded.
   */
  getConsoleScreenshot(callback?: (err: AWSError, data: EC2.Types.GetConsoleScreenshotResult) => void): Request<EC2.Types.GetConsoleScreenshotResult, AWSError>;
  /**
   * Describes the default credit option for CPU usage of a burstable performance instance family. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  getDefaultCreditSpecification(params: EC2.Types.GetDefaultCreditSpecificationRequest, callback?: (err: AWSError, data: EC2.Types.GetDefaultCreditSpecificationResult) => void): Request<EC2.Types.GetDefaultCreditSpecificationResult, AWSError>;
  /**
   * Describes the default credit option for CPU usage of a burstable performance instance family. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  getDefaultCreditSpecification(callback?: (err: AWSError, data: EC2.Types.GetDefaultCreditSpecificationResult) => void): Request<EC2.Types.GetDefaultCreditSpecificationResult, AWSError>;
  /**
   * Describes the default KMS key for EBS encryption by default for your account in this Region. You can change the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  getEbsDefaultKmsKeyId(params: EC2.Types.GetEbsDefaultKmsKeyIdRequest, callback?: (err: AWSError, data: EC2.Types.GetEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.GetEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Describes the default KMS key for EBS encryption by default for your account in this Region. You can change the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  getEbsDefaultKmsKeyId(callback?: (err: AWSError, data: EC2.Types.GetEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.GetEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Describes whether EBS encryption by default is enabled for your account in the current Region. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  getEbsEncryptionByDefault(params: EC2.Types.GetEbsEncryptionByDefaultRequest, callback?: (err: AWSError, data: EC2.Types.GetEbsEncryptionByDefaultResult) => void): Request<EC2.Types.GetEbsEncryptionByDefaultResult, AWSError>;
  /**
   * Describes whether EBS encryption by default is enabled for your account in the current Region. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  getEbsEncryptionByDefault(callback?: (err: AWSError, data: EC2.Types.GetEbsEncryptionByDefaultResult) => void): Request<EC2.Types.GetEbsEncryptionByDefaultResult, AWSError>;
  /**
   * Generates a CloudFormation template that streamlines and automates the integration of VPC flow logs with Amazon Athena. This make it easier for you to query and gain insights from VPC flow logs data. Based on the information that you provide, we configure resources in the template to do the following:   Create a table in Athena that maps fields to a custom log format   Create a Lambda function that updates the table with new partitions on a daily, weekly, or monthly basis   Create a table partitioned between two timestamps in the past   Create a set of named queries in Athena that you can use to get started quickly  
   */
  getFlowLogsIntegrationTemplate(params: EC2.Types.GetFlowLogsIntegrationTemplateRequest, callback?: (err: AWSError, data: EC2.Types.GetFlowLogsIntegrationTemplateResult) => void): Request<EC2.Types.GetFlowLogsIntegrationTemplateResult, AWSError>;
  /**
   * Generates a CloudFormation template that streamlines and automates the integration of VPC flow logs with Amazon Athena. This make it easier for you to query and gain insights from VPC flow logs data. Based on the information that you provide, we configure resources in the template to do the following:   Create a table in Athena that maps fields to a custom log format   Create a Lambda function that updates the table with new partitions on a daily, weekly, or monthly basis   Create a table partitioned between two timestamps in the past   Create a set of named queries in Athena that you can use to get started quickly  
   */
  getFlowLogsIntegrationTemplate(callback?: (err: AWSError, data: EC2.Types.GetFlowLogsIntegrationTemplateResult) => void): Request<EC2.Types.GetFlowLogsIntegrationTemplateResult, AWSError>;
  /**
   * Lists the resource groups to which a Capacity Reservation has been added.
   */
  getGroupsForCapacityReservation(params: EC2.Types.GetGroupsForCapacityReservationRequest, callback?: (err: AWSError, data: EC2.Types.GetGroupsForCapacityReservationResult) => void): Request<EC2.Types.GetGroupsForCapacityReservationResult, AWSError>;
  /**
   * Lists the resource groups to which a Capacity Reservation has been added.
   */
  getGroupsForCapacityReservation(callback?: (err: AWSError, data: EC2.Types.GetGroupsForCapacityReservationResult) => void): Request<EC2.Types.GetGroupsForCapacityReservationResult, AWSError>;
  /**
   * Preview a reservation purchase with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This is a preview of the PurchaseHostReservation action and does not result in the offering being purchased.
   */
  getHostReservationPurchasePreview(params: EC2.Types.GetHostReservationPurchasePreviewRequest, callback?: (err: AWSError, data: EC2.Types.GetHostReservationPurchasePreviewResult) => void): Request<EC2.Types.GetHostReservationPurchasePreviewResult, AWSError>;
  /**
   * Preview a reservation purchase with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This is a preview of the PurchaseHostReservation action and does not result in the offering being purchased.
   */
  getHostReservationPurchasePreview(callback?: (err: AWSError, data: EC2.Types.GetHostReservationPurchasePreviewResult) => void): Request<EC2.Types.GetHostReservationPurchasePreviewResult, AWSError>;
  /**
   * Returns a list of instance types with the specified instance attributes. You can use the response to preview the instance types without launching instances. Note that the response does not consider capacity. When you specify multiple parameters, you get instance types that satisfy all of the specified parameters. If you specify multiple values for a parameter, you get instance types that satisfy any of the specified values. For more information, see Preview instance types with specified attributes, Attribute-based instance type selection for EC2 Fleet, Attribute-based instance type selection for Spot Fleet, and Spot placement score in the Amazon EC2 User Guide, and Creating an Auto Scaling group using attribute-based instance type selection in the Amazon EC2 Auto Scaling User Guide.
   */
  getInstanceTypesFromInstanceRequirements(params: EC2.Types.GetInstanceTypesFromInstanceRequirementsRequest, callback?: (err: AWSError, data: EC2.Types.GetInstanceTypesFromInstanceRequirementsResult) => void): Request<EC2.Types.GetInstanceTypesFromInstanceRequirementsResult, AWSError>;
  /**
   * Returns a list of instance types with the specified instance attributes. You can use the response to preview the instance types without launching instances. Note that the response does not consider capacity. When you specify multiple parameters, you get instance types that satisfy all of the specified parameters. If you specify multiple values for a parameter, you get instance types that satisfy any of the specified values. For more information, see Preview instance types with specified attributes, Attribute-based instance type selection for EC2 Fleet, Attribute-based instance type selection for Spot Fleet, and Spot placement score in the Amazon EC2 User Guide, and Creating an Auto Scaling group using attribute-based instance type selection in the Amazon EC2 Auto Scaling User Guide.
   */
  getInstanceTypesFromInstanceRequirements(callback?: (err: AWSError, data: EC2.Types.GetInstanceTypesFromInstanceRequirementsResult) => void): Request<EC2.Types.GetInstanceTypesFromInstanceRequirementsResult, AWSError>;
  /**
   * A binary representation of the UEFI variable store. Only non-volatile variables are stored. This is a base64 encoded and zlib compressed binary value that must be properly encoded. When you use register-image to create an AMI, you can create an exact copy of your variable store by passing the UEFI data in the UefiData parameter. You can modify the UEFI data by using the python-uefivars tool on GitHub. You can use the tool to convert the UEFI data into a human-readable format (JSON), which you can inspect and modify, and then convert back into the binary format to use with register-image. For more information, see UEFI Secure Boot in the Amazon EC2 User Guide.
   */
  getInstanceUefiData(params: EC2.Types.GetInstanceUefiDataRequest, callback?: (err: AWSError, data: EC2.Types.GetInstanceUefiDataResult) => void): Request<EC2.Types.GetInstanceUefiDataResult, AWSError>;
  /**
   * A binary representation of the UEFI variable store. Only non-volatile variables are stored. This is a base64 encoded and zlib compressed binary value that must be properly encoded. When you use register-image to create an AMI, you can create an exact copy of your variable store by passing the UEFI data in the UefiData parameter. You can modify the UEFI data by using the python-uefivars tool on GitHub. You can use the tool to convert the UEFI data into a human-readable format (JSON), which you can inspect and modify, and then convert back into the binary format to use with register-image. For more information, see UEFI Secure Boot in the Amazon EC2 User Guide.
   */
  getInstanceUefiData(callback?: (err: AWSError, data: EC2.Types.GetInstanceUefiDataResult) => void): Request<EC2.Types.GetInstanceUefiDataResult, AWSError>;
  /**
   * Retrieve historical information about a CIDR within an IPAM scope. For more information, see View the history of IP addresses in the Amazon VPC IPAM User Guide.
   */
  getIpamAddressHistory(params: EC2.Types.GetIpamAddressHistoryRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamAddressHistoryResult) => void): Request<EC2.Types.GetIpamAddressHistoryResult, AWSError>;
  /**
   * Retrieve historical information about a CIDR within an IPAM scope. For more information, see View the history of IP addresses in the Amazon VPC IPAM User Guide.
   */
  getIpamAddressHistory(callback?: (err: AWSError, data: EC2.Types.GetIpamAddressHistoryResult) => void): Request<EC2.Types.GetIpamAddressHistoryResult, AWSError>;
  /**
   * Gets IPAM discovered accounts. A discovered account is an Amazon Web Services account that is monitored under a resource discovery. If you have integrated IPAM with Amazon Web Services Organizations, all accounts in the organization are discovered accounts. Only the IPAM account can get all discovered accounts in the organization.
   */
  getIpamDiscoveredAccounts(params: EC2.Types.GetIpamDiscoveredAccountsRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamDiscoveredAccountsResult) => void): Request<EC2.Types.GetIpamDiscoveredAccountsResult, AWSError>;
  /**
   * Gets IPAM discovered accounts. A discovered account is an Amazon Web Services account that is monitored under a resource discovery. If you have integrated IPAM with Amazon Web Services Organizations, all accounts in the organization are discovered accounts. Only the IPAM account can get all discovered accounts in the organization.
   */
  getIpamDiscoveredAccounts(callback?: (err: AWSError, data: EC2.Types.GetIpamDiscoveredAccountsResult) => void): Request<EC2.Types.GetIpamDiscoveredAccountsResult, AWSError>;
  /**
   * Returns the resource CIDRs that are monitored as part of a resource discovery. A discovered resource is a resource CIDR monitored under a resource discovery. The following resources can be discovered: VPCs, Public IPv4 pools, VPC subnets, and Elastic IP addresses. 
   */
  getIpamDiscoveredResourceCidrs(params: EC2.Types.GetIpamDiscoveredResourceCidrsRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamDiscoveredResourceCidrsResult) => void): Request<EC2.Types.GetIpamDiscoveredResourceCidrsResult, AWSError>;
  /**
   * Returns the resource CIDRs that are monitored as part of a resource discovery. A discovered resource is a resource CIDR monitored under a resource discovery. The following resources can be discovered: VPCs, Public IPv4 pools, VPC subnets, and Elastic IP addresses. 
   */
  getIpamDiscoveredResourceCidrs(callback?: (err: AWSError, data: EC2.Types.GetIpamDiscoveredResourceCidrsResult) => void): Request<EC2.Types.GetIpamDiscoveredResourceCidrsResult, AWSError>;
  /**
   * Get a list of all the CIDR allocations in an IPAM pool.  If you use this action after AllocateIpamPoolCidr or ReleaseIpamPoolAllocation, note that all EC2 API actions follow an eventual consistency model. 
   */
  getIpamPoolAllocations(params: EC2.Types.GetIpamPoolAllocationsRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamPoolAllocationsResult) => void): Request<EC2.Types.GetIpamPoolAllocationsResult, AWSError>;
  /**
   * Get a list of all the CIDR allocations in an IPAM pool.  If you use this action after AllocateIpamPoolCidr or ReleaseIpamPoolAllocation, note that all EC2 API actions follow an eventual consistency model. 
   */
  getIpamPoolAllocations(callback?: (err: AWSError, data: EC2.Types.GetIpamPoolAllocationsResult) => void): Request<EC2.Types.GetIpamPoolAllocationsResult, AWSError>;
  /**
   * Get the CIDRs provisioned to an IPAM pool.
   */
  getIpamPoolCidrs(params: EC2.Types.GetIpamPoolCidrsRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamPoolCidrsResult) => void): Request<EC2.Types.GetIpamPoolCidrsResult, AWSError>;
  /**
   * Get the CIDRs provisioned to an IPAM pool.
   */
  getIpamPoolCidrs(callback?: (err: AWSError, data: EC2.Types.GetIpamPoolCidrsResult) => void): Request<EC2.Types.GetIpamPoolCidrsResult, AWSError>;
  /**
   * Returns resource CIDRs managed by IPAM in a given scope. If an IPAM is associated with more than one resource discovery, the resource CIDRs across all of the resource discoveries is returned. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  getIpamResourceCidrs(params: EC2.Types.GetIpamResourceCidrsRequest, callback?: (err: AWSError, data: EC2.Types.GetIpamResourceCidrsResult) => void): Request<EC2.Types.GetIpamResourceCidrsResult, AWSError>;
  /**
   * Returns resource CIDRs managed by IPAM in a given scope. If an IPAM is associated with more than one resource discovery, the resource CIDRs across all of the resource discoveries is returned. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  getIpamResourceCidrs(callback?: (err: AWSError, data: EC2.Types.GetIpamResourceCidrsResult) => void): Request<EC2.Types.GetIpamResourceCidrsResult, AWSError>;
  /**
   * Retrieves the configuration data of the specified instance. You can use this data to create a launch template.  This action calls on other describe actions to get instance information. Depending on your instance configuration, you may need to allow the following actions in your IAM policy: DescribeSpotInstanceRequests, DescribeInstanceCreditSpecifications, DescribeVolumes, DescribeInstanceAttribute, and DescribeElasticGpus. Or, you can allow describe* depending on your instance requirements.
   */
  getLaunchTemplateData(params: EC2.Types.GetLaunchTemplateDataRequest, callback?: (err: AWSError, data: EC2.Types.GetLaunchTemplateDataResult) => void): Request<EC2.Types.GetLaunchTemplateDataResult, AWSError>;
  /**
   * Retrieves the configuration data of the specified instance. You can use this data to create a launch template.  This action calls on other describe actions to get instance information. Depending on your instance configuration, you may need to allow the following actions in your IAM policy: DescribeSpotInstanceRequests, DescribeInstanceCreditSpecifications, DescribeVolumes, DescribeInstanceAttribute, and DescribeElasticGpus. Or, you can allow describe* depending on your instance requirements.
   */
  getLaunchTemplateData(callback?: (err: AWSError, data: EC2.Types.GetLaunchTemplateDataResult) => void): Request<EC2.Types.GetLaunchTemplateDataResult, AWSError>;
  /**
   * Gets information about the resources that are associated with the specified managed prefix list.
   */
  getManagedPrefixListAssociations(params: EC2.Types.GetManagedPrefixListAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.GetManagedPrefixListAssociationsResult) => void): Request<EC2.Types.GetManagedPrefixListAssociationsResult, AWSError>;
  /**
   * Gets information about the resources that are associated with the specified managed prefix list.
   */
  getManagedPrefixListAssociations(callback?: (err: AWSError, data: EC2.Types.GetManagedPrefixListAssociationsResult) => void): Request<EC2.Types.GetManagedPrefixListAssociationsResult, AWSError>;
  /**
   * Gets information about the entries for a specified managed prefix list.
   */
  getManagedPrefixListEntries(params: EC2.Types.GetManagedPrefixListEntriesRequest, callback?: (err: AWSError, data: EC2.Types.GetManagedPrefixListEntriesResult) => void): Request<EC2.Types.GetManagedPrefixListEntriesResult, AWSError>;
  /**
   * Gets information about the entries for a specified managed prefix list.
   */
  getManagedPrefixListEntries(callback?: (err: AWSError, data: EC2.Types.GetManagedPrefixListEntriesResult) => void): Request<EC2.Types.GetManagedPrefixListEntriesResult, AWSError>;
  /**
   * Gets the findings for the specified Network Access Scope analysis.
   */
  getNetworkInsightsAccessScopeAnalysisFindings(params: EC2.Types.GetNetworkInsightsAccessScopeAnalysisFindingsRequest, callback?: (err: AWSError, data: EC2.Types.GetNetworkInsightsAccessScopeAnalysisFindingsResult) => void): Request<EC2.Types.GetNetworkInsightsAccessScopeAnalysisFindingsResult, AWSError>;
  /**
   * Gets the findings for the specified Network Access Scope analysis.
   */
  getNetworkInsightsAccessScopeAnalysisFindings(callback?: (err: AWSError, data: EC2.Types.GetNetworkInsightsAccessScopeAnalysisFindingsResult) => void): Request<EC2.Types.GetNetworkInsightsAccessScopeAnalysisFindingsResult, AWSError>;
  /**
   * Gets the content for the specified Network Access Scope.
   */
  getNetworkInsightsAccessScopeContent(params: EC2.Types.GetNetworkInsightsAccessScopeContentRequest, callback?: (err: AWSError, data: EC2.Types.GetNetworkInsightsAccessScopeContentResult) => void): Request<EC2.Types.GetNetworkInsightsAccessScopeContentResult, AWSError>;
  /**
   * Gets the content for the specified Network Access Scope.
   */
  getNetworkInsightsAccessScopeContent(callback?: (err: AWSError, data: EC2.Types.GetNetworkInsightsAccessScopeContentResult) => void): Request<EC2.Types.GetNetworkInsightsAccessScopeContentResult, AWSError>;
  /**
   * Retrieves the encrypted administrator password for a running Windows instance. The Windows password is generated at boot by the EC2Config service or EC2Launch scripts (Windows Server 2016 and later). This usually only happens the first time an instance is launched. For more information, see EC2Config and EC2Launch in the Amazon EC2 User Guide. For the EC2Config service, the password is not generated for rebundled AMIs unless Ec2SetPassword is enabled before bundling. The password is encrypted using the key pair that you specified when you launched the instance. You must provide the corresponding key pair file. When you launch an instance, password generation and encryption may take a few minutes. If you try to retrieve the password before it's available, the output returns an empty string. We recommend that you wait up to 15 minutes after launching an instance before trying to retrieve the generated password.
   */
  getPasswordData(params: EC2.Types.GetPasswordDataRequest, callback?: (err: AWSError, data: EC2.Types.GetPasswordDataResult) => void): Request<EC2.Types.GetPasswordDataResult, AWSError>;
  /**
   * Retrieves the encrypted administrator password for a running Windows instance. The Windows password is generated at boot by the EC2Config service or EC2Launch scripts (Windows Server 2016 and later). This usually only happens the first time an instance is launched. For more information, see EC2Config and EC2Launch in the Amazon EC2 User Guide. For the EC2Config service, the password is not generated for rebundled AMIs unless Ec2SetPassword is enabled before bundling. The password is encrypted using the key pair that you specified when you launched the instance. You must provide the corresponding key pair file. When you launch an instance, password generation and encryption may take a few minutes. If you try to retrieve the password before it's available, the output returns an empty string. We recommend that you wait up to 15 minutes after launching an instance before trying to retrieve the generated password.
   */
  getPasswordData(callback?: (err: AWSError, data: EC2.Types.GetPasswordDataResult) => void): Request<EC2.Types.GetPasswordDataResult, AWSError>;
  /**
   * Returns a quote and exchange information for exchanging one or more specified Convertible Reserved Instances for a new Convertible Reserved Instance. If the exchange cannot be performed, the reason is returned in the response. Use AcceptReservedInstancesExchangeQuote to perform the exchange.
   */
  getReservedInstancesExchangeQuote(params: EC2.Types.GetReservedInstancesExchangeQuoteRequest, callback?: (err: AWSError, data: EC2.Types.GetReservedInstancesExchangeQuoteResult) => void): Request<EC2.Types.GetReservedInstancesExchangeQuoteResult, AWSError>;
  /**
   * Returns a quote and exchange information for exchanging one or more specified Convertible Reserved Instances for a new Convertible Reserved Instance. If the exchange cannot be performed, the reason is returned in the response. Use AcceptReservedInstancesExchangeQuote to perform the exchange.
   */
  getReservedInstancesExchangeQuote(callback?: (err: AWSError, data: EC2.Types.GetReservedInstancesExchangeQuoteResult) => void): Request<EC2.Types.GetReservedInstancesExchangeQuoteResult, AWSError>;
  /**
   * Retrieves the access status of your account to the EC2 serial console of all instances. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  getSerialConsoleAccessStatus(params: EC2.Types.GetSerialConsoleAccessStatusRequest, callback?: (err: AWSError, data: EC2.Types.GetSerialConsoleAccessStatusResult) => void): Request<EC2.Types.GetSerialConsoleAccessStatusResult, AWSError>;
  /**
   * Retrieves the access status of your account to the EC2 serial console of all instances. By default, access to the EC2 serial console is disabled for your account. For more information, see Manage account access to the EC2 serial console in the Amazon EC2 User Guide.
   */
  getSerialConsoleAccessStatus(callback?: (err: AWSError, data: EC2.Types.GetSerialConsoleAccessStatusResult) => void): Request<EC2.Types.GetSerialConsoleAccessStatusResult, AWSError>;
  /**
   * Calculates the Spot placement score for a Region or Availability Zone based on the specified target capacity and compute requirements. You can specify your compute requirements either by using InstanceRequirementsWithMetadata and letting Amazon EC2 choose the optimal instance types to fulfill your Spot request, or you can specify the instance types by using InstanceTypes. For more information, see Spot placement score in the Amazon EC2 User Guide.
   */
  getSpotPlacementScores(params: EC2.Types.GetSpotPlacementScoresRequest, callback?: (err: AWSError, data: EC2.Types.GetSpotPlacementScoresResult) => void): Request<EC2.Types.GetSpotPlacementScoresResult, AWSError>;
  /**
   * Calculates the Spot placement score for a Region or Availability Zone based on the specified target capacity and compute requirements. You can specify your compute requirements either by using InstanceRequirementsWithMetadata and letting Amazon EC2 choose the optimal instance types to fulfill your Spot request, or you can specify the instance types by using InstanceTypes. For more information, see Spot placement score in the Amazon EC2 User Guide.
   */
  getSpotPlacementScores(callback?: (err: AWSError, data: EC2.Types.GetSpotPlacementScoresResult) => void): Request<EC2.Types.GetSpotPlacementScoresResult, AWSError>;
  /**
   * Gets information about the subnet CIDR reservations.
   */
  getSubnetCidrReservations(params: EC2.Types.GetSubnetCidrReservationsRequest, callback?: (err: AWSError, data: EC2.Types.GetSubnetCidrReservationsResult) => void): Request<EC2.Types.GetSubnetCidrReservationsResult, AWSError>;
  /**
   * Gets information about the subnet CIDR reservations.
   */
  getSubnetCidrReservations(callback?: (err: AWSError, data: EC2.Types.GetSubnetCidrReservationsResult) => void): Request<EC2.Types.GetSubnetCidrReservationsResult, AWSError>;
  /**
   * Lists the route tables to which the specified resource attachment propagates routes.
   */
  getTransitGatewayAttachmentPropagations(params: EC2.Types.GetTransitGatewayAttachmentPropagationsRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayAttachmentPropagationsResult) => void): Request<EC2.Types.GetTransitGatewayAttachmentPropagationsResult, AWSError>;
  /**
   * Lists the route tables to which the specified resource attachment propagates routes.
   */
  getTransitGatewayAttachmentPropagations(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayAttachmentPropagationsResult) => void): Request<EC2.Types.GetTransitGatewayAttachmentPropagationsResult, AWSError>;
  /**
   * Gets information about the associations for the transit gateway multicast domain.
   */
  getTransitGatewayMulticastDomainAssociations(params: EC2.Types.GetTransitGatewayMulticastDomainAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Gets information about the associations for the transit gateway multicast domain.
   */
  getTransitGatewayMulticastDomainAssociations(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Gets a list of the transit gateway policy table associations.
   */
  getTransitGatewayPolicyTableAssociations(params: EC2.Types.GetTransitGatewayPolicyTableAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPolicyTableAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayPolicyTableAssociationsResult, AWSError>;
  /**
   * Gets a list of the transit gateway policy table associations.
   */
  getTransitGatewayPolicyTableAssociations(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPolicyTableAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayPolicyTableAssociationsResult, AWSError>;
  /**
   * Returns a list of transit gateway policy table entries.
   */
  getTransitGatewayPolicyTableEntries(params: EC2.Types.GetTransitGatewayPolicyTableEntriesRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPolicyTableEntriesResult) => void): Request<EC2.Types.GetTransitGatewayPolicyTableEntriesResult, AWSError>;
  /**
   * Returns a list of transit gateway policy table entries.
   */
  getTransitGatewayPolicyTableEntries(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPolicyTableEntriesResult) => void): Request<EC2.Types.GetTransitGatewayPolicyTableEntriesResult, AWSError>;
  /**
   * Gets information about the prefix list references in a specified transit gateway route table.
   */
  getTransitGatewayPrefixListReferences(params: EC2.Types.GetTransitGatewayPrefixListReferencesRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPrefixListReferencesResult) => void): Request<EC2.Types.GetTransitGatewayPrefixListReferencesResult, AWSError>;
  /**
   * Gets information about the prefix list references in a specified transit gateway route table.
   */
  getTransitGatewayPrefixListReferences(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayPrefixListReferencesResult) => void): Request<EC2.Types.GetTransitGatewayPrefixListReferencesResult, AWSError>;
  /**
   * Gets information about the associations for the specified transit gateway route table.
   */
  getTransitGatewayRouteTableAssociations(params: EC2.Types.GetTransitGatewayRouteTableAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayRouteTableAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayRouteTableAssociationsResult, AWSError>;
  /**
   * Gets information about the associations for the specified transit gateway route table.
   */
  getTransitGatewayRouteTableAssociations(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayRouteTableAssociationsResult) => void): Request<EC2.Types.GetTransitGatewayRouteTableAssociationsResult, AWSError>;
  /**
   * Gets information about the route table propagations for the specified transit gateway route table.
   */
  getTransitGatewayRouteTablePropagations(params: EC2.Types.GetTransitGatewayRouteTablePropagationsRequest, callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayRouteTablePropagationsResult) => void): Request<EC2.Types.GetTransitGatewayRouteTablePropagationsResult, AWSError>;
  /**
   * Gets information about the route table propagations for the specified transit gateway route table.
   */
  getTransitGatewayRouteTablePropagations(callback?: (err: AWSError, data: EC2.Types.GetTransitGatewayRouteTablePropagationsResult) => void): Request<EC2.Types.GetTransitGatewayRouteTablePropagationsResult, AWSError>;
  /**
   * Get the Verified Access policy associated with the endpoint.
   */
  getVerifiedAccessEndpointPolicy(params: EC2.Types.GetVerifiedAccessEndpointPolicyRequest, callback?: (err: AWSError, data: EC2.Types.GetVerifiedAccessEndpointPolicyResult) => void): Request<EC2.Types.GetVerifiedAccessEndpointPolicyResult, AWSError>;
  /**
   * Get the Verified Access policy associated with the endpoint.
   */
  getVerifiedAccessEndpointPolicy(callback?: (err: AWSError, data: EC2.Types.GetVerifiedAccessEndpointPolicyResult) => void): Request<EC2.Types.GetVerifiedAccessEndpointPolicyResult, AWSError>;
  /**
   * Shows the contents of the Verified Access policy associated with the group.
   */
  getVerifiedAccessGroupPolicy(params: EC2.Types.GetVerifiedAccessGroupPolicyRequest, callback?: (err: AWSError, data: EC2.Types.GetVerifiedAccessGroupPolicyResult) => void): Request<EC2.Types.GetVerifiedAccessGroupPolicyResult, AWSError>;
  /**
   * Shows the contents of the Verified Access policy associated with the group.
   */
  getVerifiedAccessGroupPolicy(callback?: (err: AWSError, data: EC2.Types.GetVerifiedAccessGroupPolicyResult) => void): Request<EC2.Types.GetVerifiedAccessGroupPolicyResult, AWSError>;
  /**
   * Download an Amazon Web Services-provided sample configuration file to be used with the customer gateway device specified for your Site-to-Site VPN connection.
   */
  getVpnConnectionDeviceSampleConfiguration(params: EC2.Types.GetVpnConnectionDeviceSampleConfigurationRequest, callback?: (err: AWSError, data: EC2.Types.GetVpnConnectionDeviceSampleConfigurationResult) => void): Request<EC2.Types.GetVpnConnectionDeviceSampleConfigurationResult, AWSError>;
  /**
   * Download an Amazon Web Services-provided sample configuration file to be used with the customer gateway device specified for your Site-to-Site VPN connection.
   */
  getVpnConnectionDeviceSampleConfiguration(callback?: (err: AWSError, data: EC2.Types.GetVpnConnectionDeviceSampleConfigurationResult) => void): Request<EC2.Types.GetVpnConnectionDeviceSampleConfigurationResult, AWSError>;
  /**
   * Obtain a list of customer gateway devices for which sample configuration files can be provided. The request has no additional parameters. You can also see the list of device types with sample configuration files available under Your customer gateway device in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  getVpnConnectionDeviceTypes(params: EC2.Types.GetVpnConnectionDeviceTypesRequest, callback?: (err: AWSError, data: EC2.Types.GetVpnConnectionDeviceTypesResult) => void): Request<EC2.Types.GetVpnConnectionDeviceTypesResult, AWSError>;
  /**
   * Obtain a list of customer gateway devices for which sample configuration files can be provided. The request has no additional parameters. You can also see the list of device types with sample configuration files available under Your customer gateway device in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  getVpnConnectionDeviceTypes(callback?: (err: AWSError, data: EC2.Types.GetVpnConnectionDeviceTypesResult) => void): Request<EC2.Types.GetVpnConnectionDeviceTypesResult, AWSError>;
  /**
   * Get details of available tunnel endpoint maintenance.
   */
  getVpnTunnelReplacementStatus(params: EC2.Types.GetVpnTunnelReplacementStatusRequest, callback?: (err: AWSError, data: EC2.Types.GetVpnTunnelReplacementStatusResult) => void): Request<EC2.Types.GetVpnTunnelReplacementStatusResult, AWSError>;
  /**
   * Get details of available tunnel endpoint maintenance.
   */
  getVpnTunnelReplacementStatus(callback?: (err: AWSError, data: EC2.Types.GetVpnTunnelReplacementStatusResult) => void): Request<EC2.Types.GetVpnTunnelReplacementStatusResult, AWSError>;
  /**
   * Uploads a client certificate revocation list to the specified Client VPN endpoint. Uploading a client certificate revocation list overwrites the existing client certificate revocation list. Uploading a client certificate revocation list resets existing client connections.
   */
  importClientVpnClientCertificateRevocationList(params: EC2.Types.ImportClientVpnClientCertificateRevocationListRequest, callback?: (err: AWSError, data: EC2.Types.ImportClientVpnClientCertificateRevocationListResult) => void): Request<EC2.Types.ImportClientVpnClientCertificateRevocationListResult, AWSError>;
  /**
   * Uploads a client certificate revocation list to the specified Client VPN endpoint. Uploading a client certificate revocation list overwrites the existing client certificate revocation list. Uploading a client certificate revocation list resets existing client connections.
   */
  importClientVpnClientCertificateRevocationList(callback?: (err: AWSError, data: EC2.Types.ImportClientVpnClientCertificateRevocationListResult) => void): Request<EC2.Types.ImportClientVpnClientCertificateRevocationListResult, AWSError>;
  /**
   *  To import your virtual machines (VMs) with a console-based experience, you can use the Import virtual machine images to Amazon Web Services template in the Migration Hub Orchestrator console. For more information, see the  Migration Hub Orchestrator User Guide .  Import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI).  Amazon Web Services VM Import/Export strongly recommends specifying a value for either the --license-type or --usage-operation parameter when you create a new VM Import task. This ensures your operating system is licensed appropriately and your billing is optimized.  For more information, see Importing a VM as an image using VM Import/Export in the VM Import/Export User Guide.
   */
  importImage(params: EC2.Types.ImportImageRequest, callback?: (err: AWSError, data: EC2.Types.ImportImageResult) => void): Request<EC2.Types.ImportImageResult, AWSError>;
  /**
   *  To import your virtual machines (VMs) with a console-based experience, you can use the Import virtual machine images to Amazon Web Services template in the Migration Hub Orchestrator console. For more information, see the  Migration Hub Orchestrator User Guide .  Import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI).  Amazon Web Services VM Import/Export strongly recommends specifying a value for either the --license-type or --usage-operation parameter when you create a new VM Import task. This ensures your operating system is licensed appropriately and your billing is optimized.  For more information, see Importing a VM as an image using VM Import/Export in the VM Import/Export User Guide.
   */
  importImage(callback?: (err: AWSError, data: EC2.Types.ImportImageResult) => void): Request<EC2.Types.ImportImageResult, AWSError>;
  /**
   * Creates an import instance task using metadata from the specified disk image. This API action supports only single-volume VMs. To import multi-volume VMs, use ImportImage instead. This API action is not supported by the Command Line Interface (CLI). For information about using the Amazon EC2 CLI, which is deprecated, see Importing a VM to Amazon EC2 in the Amazon EC2 CLI Reference PDF file. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  importInstance(params: EC2.Types.ImportInstanceRequest, callback?: (err: AWSError, data: EC2.Types.ImportInstanceResult) => void): Request<EC2.Types.ImportInstanceResult, AWSError>;
  /**
   * Creates an import instance task using metadata from the specified disk image. This API action supports only single-volume VMs. To import multi-volume VMs, use ImportImage instead. This API action is not supported by the Command Line Interface (CLI). For information about using the Amazon EC2 CLI, which is deprecated, see Importing a VM to Amazon EC2 in the Amazon EC2 CLI Reference PDF file. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  importInstance(callback?: (err: AWSError, data: EC2.Types.ImportInstanceResult) => void): Request<EC2.Types.ImportInstanceResult, AWSError>;
  /**
   * Imports the public key from an RSA or ED25519 key pair that you created with a third-party tool. Compare this with CreateKeyPair, in which Amazon Web Services creates the key pair and gives the keys to you (Amazon Web Services keeps a copy of the public key). With ImportKeyPair, you create the key pair and give Amazon Web Services just the public key. The private key is never transferred between you and Amazon Web Services. For more information about key pairs, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  importKeyPair(params: EC2.Types.ImportKeyPairRequest, callback?: (err: AWSError, data: EC2.Types.ImportKeyPairResult) => void): Request<EC2.Types.ImportKeyPairResult, AWSError>;
  /**
   * Imports the public key from an RSA or ED25519 key pair that you created with a third-party tool. Compare this with CreateKeyPair, in which Amazon Web Services creates the key pair and gives the keys to you (Amazon Web Services keeps a copy of the public key). With ImportKeyPair, you create the key pair and give Amazon Web Services just the public key. The private key is never transferred between you and Amazon Web Services. For more information about key pairs, see Amazon EC2 key pairs in the Amazon Elastic Compute Cloud User Guide.
   */
  importKeyPair(callback?: (err: AWSError, data: EC2.Types.ImportKeyPairResult) => void): Request<EC2.Types.ImportKeyPairResult, AWSError>;
  /**
   * Imports a disk into an EBS snapshot. For more information, see Importing a disk as a snapshot using VM Import/Export in the VM Import/Export User Guide.
   */
  importSnapshot(params: EC2.Types.ImportSnapshotRequest, callback?: (err: AWSError, data: EC2.Types.ImportSnapshotResult) => void): Request<EC2.Types.ImportSnapshotResult, AWSError>;
  /**
   * Imports a disk into an EBS snapshot. For more information, see Importing a disk as a snapshot using VM Import/Export in the VM Import/Export User Guide.
   */
  importSnapshot(callback?: (err: AWSError, data: EC2.Types.ImportSnapshotResult) => void): Request<EC2.Types.ImportSnapshotResult, AWSError>;
  /**
   * Creates an import volume task using metadata from the specified disk image. This API action supports only single-volume VMs. To import multi-volume VMs, use ImportImage instead. To import a disk to a snapshot, use ImportSnapshot instead. This API action is not supported by the Command Line Interface (CLI). For information about using the Amazon EC2 CLI, which is deprecated, see Importing Disks to Amazon EBS in the Amazon EC2 CLI Reference PDF file. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  importVolume(params: EC2.Types.ImportVolumeRequest, callback?: (err: AWSError, data: EC2.Types.ImportVolumeResult) => void): Request<EC2.Types.ImportVolumeResult, AWSError>;
  /**
   * Creates an import volume task using metadata from the specified disk image. This API action supports only single-volume VMs. To import multi-volume VMs, use ImportImage instead. To import a disk to a snapshot, use ImportSnapshot instead. This API action is not supported by the Command Line Interface (CLI). For information about using the Amazon EC2 CLI, which is deprecated, see Importing Disks to Amazon EBS in the Amazon EC2 CLI Reference PDF file. For information about the import manifest referenced by this API action, see VM Import Manifest.
   */
  importVolume(callback?: (err: AWSError, data: EC2.Types.ImportVolumeResult) => void): Request<EC2.Types.ImportVolumeResult, AWSError>;
  /**
   * Lists one or more AMIs that are currently in the Recycle Bin. For more information, see Recycle Bin in the Amazon EC2 User Guide.
   */
  listImagesInRecycleBin(params: EC2.Types.ListImagesInRecycleBinRequest, callback?: (err: AWSError, data: EC2.Types.ListImagesInRecycleBinResult) => void): Request<EC2.Types.ListImagesInRecycleBinResult, AWSError>;
  /**
   * Lists one or more AMIs that are currently in the Recycle Bin. For more information, see Recycle Bin in the Amazon EC2 User Guide.
   */
  listImagesInRecycleBin(callback?: (err: AWSError, data: EC2.Types.ListImagesInRecycleBinResult) => void): Request<EC2.Types.ListImagesInRecycleBinResult, AWSError>;
  /**
   * Lists one or more snapshots that are currently in the Recycle Bin.
   */
  listSnapshotsInRecycleBin(params: EC2.Types.ListSnapshotsInRecycleBinRequest, callback?: (err: AWSError, data: EC2.Types.ListSnapshotsInRecycleBinResult) => void): Request<EC2.Types.ListSnapshotsInRecycleBinResult, AWSError>;
  /**
   * Lists one or more snapshots that are currently in the Recycle Bin.
   */
  listSnapshotsInRecycleBin(callback?: (err: AWSError, data: EC2.Types.ListSnapshotsInRecycleBinResult) => void): Request<EC2.Types.ListSnapshotsInRecycleBinResult, AWSError>;
  /**
   * Modifies an attribute of the specified Elastic IP address. For requirements, see Using reverse DNS for email applications.
   */
  modifyAddressAttribute(params: EC2.Types.ModifyAddressAttributeRequest, callback?: (err: AWSError, data: EC2.Types.ModifyAddressAttributeResult) => void): Request<EC2.Types.ModifyAddressAttributeResult, AWSError>;
  /**
   * Modifies an attribute of the specified Elastic IP address. For requirements, see Using reverse DNS for email applications.
   */
  modifyAddressAttribute(callback?: (err: AWSError, data: EC2.Types.ModifyAddressAttributeResult) => void): Request<EC2.Types.ModifyAddressAttributeResult, AWSError>;
  /**
   * Changes the opt-in status of the Local Zone and Wavelength Zone group for your account. Use  DescribeAvailabilityZones to view the value for GroupName.
   */
  modifyAvailabilityZoneGroup(params: EC2.Types.ModifyAvailabilityZoneGroupRequest, callback?: (err: AWSError, data: EC2.Types.ModifyAvailabilityZoneGroupResult) => void): Request<EC2.Types.ModifyAvailabilityZoneGroupResult, AWSError>;
  /**
   * Changes the opt-in status of the Local Zone and Wavelength Zone group for your account. Use  DescribeAvailabilityZones to view the value for GroupName.
   */
  modifyAvailabilityZoneGroup(callback?: (err: AWSError, data: EC2.Types.ModifyAvailabilityZoneGroupResult) => void): Request<EC2.Types.ModifyAvailabilityZoneGroupResult, AWSError>;
  /**
   * Modifies a Capacity Reservation's capacity and the conditions under which it is to be released. You cannot change a Capacity Reservation's instance type, EBS optimization, instance store settings, platform, Availability Zone, or instance eligibility. If you need to modify any of these attributes, we recommend that you cancel the Capacity Reservation, and then create a new one with the required attributes.
   */
  modifyCapacityReservation(params: EC2.Types.ModifyCapacityReservationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyCapacityReservationResult) => void): Request<EC2.Types.ModifyCapacityReservationResult, AWSError>;
  /**
   * Modifies a Capacity Reservation's capacity and the conditions under which it is to be released. You cannot change a Capacity Reservation's instance type, EBS optimization, instance store settings, platform, Availability Zone, or instance eligibility. If you need to modify any of these attributes, we recommend that you cancel the Capacity Reservation, and then create a new one with the required attributes.
   */
  modifyCapacityReservation(callback?: (err: AWSError, data: EC2.Types.ModifyCapacityReservationResult) => void): Request<EC2.Types.ModifyCapacityReservationResult, AWSError>;
  /**
   * Modifies a Capacity Reservation Fleet. When you modify the total target capacity of a Capacity Reservation Fleet, the Fleet automatically creates new Capacity Reservations, or modifies or cancels existing Capacity Reservations in the Fleet to meet the new total target capacity. When you modify the end date for the Fleet, the end dates for all of the individual Capacity Reservations in the Fleet are updated accordingly.
   */
  modifyCapacityReservationFleet(params: EC2.Types.ModifyCapacityReservationFleetRequest, callback?: (err: AWSError, data: EC2.Types.ModifyCapacityReservationFleetResult) => void): Request<EC2.Types.ModifyCapacityReservationFleetResult, AWSError>;
  /**
   * Modifies a Capacity Reservation Fleet. When you modify the total target capacity of a Capacity Reservation Fleet, the Fleet automatically creates new Capacity Reservations, or modifies or cancels existing Capacity Reservations in the Fleet to meet the new total target capacity. When you modify the end date for the Fleet, the end dates for all of the individual Capacity Reservations in the Fleet are updated accordingly.
   */
  modifyCapacityReservationFleet(callback?: (err: AWSError, data: EC2.Types.ModifyCapacityReservationFleetResult) => void): Request<EC2.Types.ModifyCapacityReservationFleetResult, AWSError>;
  /**
   * Modifies the specified Client VPN endpoint. Modifying the DNS server resets existing client connections.
   */
  modifyClientVpnEndpoint(params: EC2.Types.ModifyClientVpnEndpointRequest, callback?: (err: AWSError, data: EC2.Types.ModifyClientVpnEndpointResult) => void): Request<EC2.Types.ModifyClientVpnEndpointResult, AWSError>;
  /**
   * Modifies the specified Client VPN endpoint. Modifying the DNS server resets existing client connections.
   */
  modifyClientVpnEndpoint(callback?: (err: AWSError, data: EC2.Types.ModifyClientVpnEndpointResult) => void): Request<EC2.Types.ModifyClientVpnEndpointResult, AWSError>;
  /**
   * Modifies the default credit option for CPU usage of burstable performance instances. The default credit option is set at the account level per Amazon Web Services Region, and is specified per instance family. All new burstable performance instances in the account launch using the default credit option.  ModifyDefaultCreditSpecification is an asynchronous operation, which works at an Amazon Web Services Region level and modifies the credit option for each Availability Zone. All zones in a Region are updated within five minutes. But if instances are launched during this operation, they might not get the new credit option until the zone is updated. To verify whether the update has occurred, you can call GetDefaultCreditSpecification and check DefaultCreditSpecification for updates. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  modifyDefaultCreditSpecification(params: EC2.Types.ModifyDefaultCreditSpecificationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyDefaultCreditSpecificationResult) => void): Request<EC2.Types.ModifyDefaultCreditSpecificationResult, AWSError>;
  /**
   * Modifies the default credit option for CPU usage of burstable performance instances. The default credit option is set at the account level per Amazon Web Services Region, and is specified per instance family. All new burstable performance instances in the account launch using the default credit option.  ModifyDefaultCreditSpecification is an asynchronous operation, which works at an Amazon Web Services Region level and modifies the credit option for each Availability Zone. All zones in a Region are updated within five minutes. But if instances are launched during this operation, they might not get the new credit option until the zone is updated. To verify whether the update has occurred, you can call GetDefaultCreditSpecification and check DefaultCreditSpecification for updates. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  modifyDefaultCreditSpecification(callback?: (err: AWSError, data: EC2.Types.ModifyDefaultCreditSpecificationResult) => void): Request<EC2.Types.ModifyDefaultCreditSpecificationResult, AWSError>;
  /**
   * Changes the default KMS key for EBS encryption by default for your account in this Region. Amazon Web Services creates a unique Amazon Web Services managed KMS key in each Region for use with encryption by default. If you change the default KMS key to a symmetric customer managed KMS key, it is used instead of the Amazon Web Services managed KMS key. To reset the default KMS key to the Amazon Web Services managed KMS key for EBS, use ResetEbsDefaultKmsKeyId. Amazon EBS does not support asymmetric KMS keys. If you delete or disable the customer managed KMS key that you specified for use with encryption by default, your instances will fail to launch. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  modifyEbsDefaultKmsKeyId(params: EC2.Types.ModifyEbsDefaultKmsKeyIdRequest, callback?: (err: AWSError, data: EC2.Types.ModifyEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.ModifyEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Changes the default KMS key for EBS encryption by default for your account in this Region. Amazon Web Services creates a unique Amazon Web Services managed KMS key in each Region for use with encryption by default. If you change the default KMS key to a symmetric customer managed KMS key, it is used instead of the Amazon Web Services managed KMS key. To reset the default KMS key to the Amazon Web Services managed KMS key for EBS, use ResetEbsDefaultKmsKeyId. Amazon EBS does not support asymmetric KMS keys. If you delete or disable the customer managed KMS key that you specified for use with encryption by default, your instances will fail to launch. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  modifyEbsDefaultKmsKeyId(callback?: (err: AWSError, data: EC2.Types.ModifyEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.ModifyEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Modifies the specified EC2 Fleet. You can only modify an EC2 Fleet request of type maintain. While the EC2 Fleet is being modified, it is in the modifying state. To scale up your EC2 Fleet, increase its target capacity. The EC2 Fleet launches the additional Spot Instances according to the allocation strategy for the EC2 Fleet request. If the allocation strategy is lowest-price, the EC2 Fleet launches instances using the Spot Instance pool with the lowest price. If the allocation strategy is diversified, the EC2 Fleet distributes the instances across the Spot Instance pools. If the allocation strategy is capacity-optimized, EC2 Fleet launches instances from Spot Instance pools with optimal capacity for the number of instances that are launching. To scale down your EC2 Fleet, decrease its target capacity. First, the EC2 Fleet cancels any open requests that exceed the new target capacity. You can request that the EC2 Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is lowest-price, the EC2 Fleet terminates the instances with the highest price per unit. If the allocation strategy is capacity-optimized, the EC2 Fleet terminates the instances in the Spot Instance pools that have the least available Spot Instance capacity. If the allocation strategy is diversified, the EC2 Fleet terminates instances across the Spot Instance pools. Alternatively, you can request that the EC2 Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually. If you are finished with your EC2 Fleet for now, but will use it again later, you can set the target capacity to 0.
   */
  modifyFleet(params: EC2.Types.ModifyFleetRequest, callback?: (err: AWSError, data: EC2.Types.ModifyFleetResult) => void): Request<EC2.Types.ModifyFleetResult, AWSError>;
  /**
   * Modifies the specified EC2 Fleet. You can only modify an EC2 Fleet request of type maintain. While the EC2 Fleet is being modified, it is in the modifying state. To scale up your EC2 Fleet, increase its target capacity. The EC2 Fleet launches the additional Spot Instances according to the allocation strategy for the EC2 Fleet request. If the allocation strategy is lowest-price, the EC2 Fleet launches instances using the Spot Instance pool with the lowest price. If the allocation strategy is diversified, the EC2 Fleet distributes the instances across the Spot Instance pools. If the allocation strategy is capacity-optimized, EC2 Fleet launches instances from Spot Instance pools with optimal capacity for the number of instances that are launching. To scale down your EC2 Fleet, decrease its target capacity. First, the EC2 Fleet cancels any open requests that exceed the new target capacity. You can request that the EC2 Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is lowest-price, the EC2 Fleet terminates the instances with the highest price per unit. If the allocation strategy is capacity-optimized, the EC2 Fleet terminates the instances in the Spot Instance pools that have the least available Spot Instance capacity. If the allocation strategy is diversified, the EC2 Fleet terminates instances across the Spot Instance pools. Alternatively, you can request that the EC2 Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually. If you are finished with your EC2 Fleet for now, but will use it again later, you can set the target capacity to 0.
   */
  modifyFleet(callback?: (err: AWSError, data: EC2.Types.ModifyFleetResult) => void): Request<EC2.Types.ModifyFleetResult, AWSError>;
  /**
   * Modifies the specified attribute of the specified Amazon FPGA Image (AFI).
   */
  modifyFpgaImageAttribute(params: EC2.Types.ModifyFpgaImageAttributeRequest, callback?: (err: AWSError, data: EC2.Types.ModifyFpgaImageAttributeResult) => void): Request<EC2.Types.ModifyFpgaImageAttributeResult, AWSError>;
  /**
   * Modifies the specified attribute of the specified Amazon FPGA Image (AFI).
   */
  modifyFpgaImageAttribute(callback?: (err: AWSError, data: EC2.Types.ModifyFpgaImageAttributeResult) => void): Request<EC2.Types.ModifyFpgaImageAttributeResult, AWSError>;
  /**
   * Modify the auto-placement setting of a Dedicated Host. When auto-placement is enabled, any instances that you launch with a tenancy of host but without a specific host ID are placed onto any available Dedicated Host in your account that has auto-placement enabled. When auto-placement is disabled, you need to provide a host ID to have the instance launch onto a specific host. If no host ID is provided, the instance is launched onto a suitable host with auto-placement enabled. You can also use this API action to modify a Dedicated Host to support either multiple instance types in an instance family, or to support a specific instance type only.
   */
  modifyHosts(params: EC2.Types.ModifyHostsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyHostsResult) => void): Request<EC2.Types.ModifyHostsResult, AWSError>;
  /**
   * Modify the auto-placement setting of a Dedicated Host. When auto-placement is enabled, any instances that you launch with a tenancy of host but without a specific host ID are placed onto any available Dedicated Host in your account that has auto-placement enabled. When auto-placement is disabled, you need to provide a host ID to have the instance launch onto a specific host. If no host ID is provided, the instance is launched onto a suitable host with auto-placement enabled. You can also use this API action to modify a Dedicated Host to support either multiple instance types in an instance family, or to support a specific instance type only.
   */
  modifyHosts(callback?: (err: AWSError, data: EC2.Types.ModifyHostsResult) => void): Request<EC2.Types.ModifyHostsResult, AWSError>;
  /**
   * Modifies the ID format for the specified resource on a per-Region basis. You can specify that resources should receive longer IDs (17-character IDs) when they are created. This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. This setting applies to the IAM user who makes the request; it does not apply to the entire Amazon Web Services account. By default, an IAM user defaults to the same settings as the root user. If you're using this action as the root user, then these settings apply to the entire account, unless an IAM user explicitly overrides these settings for themselves. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide. Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  modifyIdFormat(params: EC2.Types.ModifyIdFormatRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the ID format for the specified resource on a per-Region basis. You can specify that resources should receive longer IDs (17-character IDs) when they are created. This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. This setting applies to the IAM user who makes the request; it does not apply to the entire Amazon Web Services account. By default, an IAM user defaults to the same settings as the root user. If you're using this action as the root user, then these settings apply to the entire account, unless an IAM user explicitly overrides these settings for themselves. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide. Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  modifyIdFormat(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the ID format of a resource for a specified IAM user, IAM role, or the root user for an account; or all IAM users, IAM roles, and the root user for an account. You can specify that resources should receive longer IDs (17-character IDs) when they are created.  This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  This setting applies to the principal specified in the request; it does not apply to the principal that makes the request.  Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  modifyIdentityIdFormat(params: EC2.Types.ModifyIdentityIdFormatRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the ID format of a resource for a specified IAM user, IAM role, or the root user for an account; or all IAM users, IAM roles, and the root user for an account. You can specify that resources should receive longer IDs (17-character IDs) when they are created.  This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide.  This setting applies to the principal specified in the request; it does not apply to the principal that makes the request.  Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.
   */
  modifyIdentityIdFormat(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified AMI. You can specify only one attribute at a time. To specify the attribute, you can use the Attribute parameter, or one of the following parameters: Description, ImdsSupport, or LaunchPermission. Images with an Amazon Web Services Marketplace product code cannot be made public. To enable the SriovNetSupport enhanced networking attribute of an image, enable SriovNetSupport on an instance and create an AMI from the instance.
   */
  modifyImageAttribute(params: EC2.Types.ModifyImageAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified AMI. You can specify only one attribute at a time. To specify the attribute, you can use the Attribute parameter, or one of the following parameters: Description, ImdsSupport, or LaunchPermission. Images with an Amazon Web Services Marketplace product code cannot be made public. To enable the SriovNetSupport enhanced networking attribute of an image, enable SriovNetSupport on an instance and create an AMI from the instance.
   */
  modifyImageAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified instance. You can specify only one attribute at a time.  Note: Using this action to change the security groups associated with an elastic network interface (ENI) attached to an instance in a VPC can result in an error if the instance has more than one ENI. To change the security groups associated with an ENI attached to an instance that has multiple ENIs, we recommend that you use the ModifyNetworkInterfaceAttribute action. To modify some attributes, the instance must be stopped. For more information, see Modify a stopped instance in the Amazon EC2 User Guide.
   */
  modifyInstanceAttribute(params: EC2.Types.ModifyInstanceAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified instance. You can specify only one attribute at a time.  Note: Using this action to change the security groups associated with an elastic network interface (ENI) attached to an instance in a VPC can result in an error if the instance has more than one ENI. To change the security groups associated with an ENI attached to an instance that has multiple ENIs, we recommend that you use the ModifyNetworkInterfaceAttribute action. To modify some attributes, the instance must be stopped. For more information, see Modify a stopped instance in the Amazon EC2 User Guide.
   */
  modifyInstanceAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the Capacity Reservation settings for a stopped instance. Use this action to configure an instance to target a specific Capacity Reservation, run in any open Capacity Reservation with matching attributes, or run On-Demand Instance capacity.
   */
  modifyInstanceCapacityReservationAttributes(params: EC2.Types.ModifyInstanceCapacityReservationAttributesRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceCapacityReservationAttributesResult) => void): Request<EC2.Types.ModifyInstanceCapacityReservationAttributesResult, AWSError>;
  /**
   * Modifies the Capacity Reservation settings for a stopped instance. Use this action to configure an instance to target a specific Capacity Reservation, run in any open Capacity Reservation with matching attributes, or run On-Demand Instance capacity.
   */
  modifyInstanceCapacityReservationAttributes(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceCapacityReservationAttributesResult) => void): Request<EC2.Types.ModifyInstanceCapacityReservationAttributesResult, AWSError>;
  /**
   * Modifies the credit option for CPU usage on a running or stopped burstable performance instance. The credit options are standard and unlimited. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  modifyInstanceCreditSpecification(params: EC2.Types.ModifyInstanceCreditSpecificationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceCreditSpecificationResult) => void): Request<EC2.Types.ModifyInstanceCreditSpecificationResult, AWSError>;
  /**
   * Modifies the credit option for CPU usage on a running or stopped burstable performance instance. The credit options are standard and unlimited. For more information, see Burstable performance instances in the Amazon EC2 User Guide.
   */
  modifyInstanceCreditSpecification(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceCreditSpecificationResult) => void): Request<EC2.Types.ModifyInstanceCreditSpecificationResult, AWSError>;
  /**
   * Modifies the start time for a scheduled Amazon EC2 instance event.
   */
  modifyInstanceEventStartTime(params: EC2.Types.ModifyInstanceEventStartTimeRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceEventStartTimeResult) => void): Request<EC2.Types.ModifyInstanceEventStartTimeResult, AWSError>;
  /**
   * Modifies the start time for a scheduled Amazon EC2 instance event.
   */
  modifyInstanceEventStartTime(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceEventStartTimeResult) => void): Request<EC2.Types.ModifyInstanceEventStartTimeResult, AWSError>;
  /**
   * Modifies the specified event window. You can define either a set of time ranges or a cron expression when modifying the event window, but not both. To modify the targets associated with the event window, use the AssociateInstanceEventWindow and DisassociateInstanceEventWindow API. If Amazon Web Services has already scheduled an event, modifying an event window won't change the time of the scheduled event. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  modifyInstanceEventWindow(params: EC2.Types.ModifyInstanceEventWindowRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceEventWindowResult) => void): Request<EC2.Types.ModifyInstanceEventWindowResult, AWSError>;
  /**
   * Modifies the specified event window. You can define either a set of time ranges or a cron expression when modifying the event window, but not both. To modify the targets associated with the event window, use the AssociateInstanceEventWindow and DisassociateInstanceEventWindow API. If Amazon Web Services has already scheduled an event, modifying an event window won't change the time of the scheduled event. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.
   */
  modifyInstanceEventWindow(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceEventWindowResult) => void): Request<EC2.Types.ModifyInstanceEventWindowResult, AWSError>;
  /**
   * Modifies the recovery behavior of your instance to disable simplified automatic recovery or set the recovery behavior to default. The default configuration will not enable simplified automatic recovery for an unsupported instance type. For more information, see Simplified automatic recovery.
   */
  modifyInstanceMaintenanceOptions(params: EC2.Types.ModifyInstanceMaintenanceOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceMaintenanceOptionsResult) => void): Request<EC2.Types.ModifyInstanceMaintenanceOptionsResult, AWSError>;
  /**
   * Modifies the recovery behavior of your instance to disable simplified automatic recovery or set the recovery behavior to default. The default configuration will not enable simplified automatic recovery for an unsupported instance type. For more information, see Simplified automatic recovery.
   */
  modifyInstanceMaintenanceOptions(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceMaintenanceOptionsResult) => void): Request<EC2.Types.ModifyInstanceMaintenanceOptionsResult, AWSError>;
  /**
   * Modify the instance metadata parameters on a running or stopped instance. When you modify the parameters on a stopped instance, they are applied when the instance is started. When you modify the parameters on a running instance, the API responds with a state of “pending”. After the parameter modifications are successfully applied to the instance, the state of the modifications changes from “pending” to “applied” in subsequent describe-instances API calls. For more information, see Instance metadata and user data in the Amazon EC2 User Guide.
   */
  modifyInstanceMetadataOptions(params: EC2.Types.ModifyInstanceMetadataOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstanceMetadataOptionsResult) => void): Request<EC2.Types.ModifyInstanceMetadataOptionsResult, AWSError>;
  /**
   * Modify the instance metadata parameters on a running or stopped instance. When you modify the parameters on a stopped instance, they are applied when the instance is started. When you modify the parameters on a running instance, the API responds with a state of “pending”. After the parameter modifications are successfully applied to the instance, the state of the modifications changes from “pending” to “applied” in subsequent describe-instances API calls. For more information, see Instance metadata and user data in the Amazon EC2 User Guide.
   */
  modifyInstanceMetadataOptions(callback?: (err: AWSError, data: EC2.Types.ModifyInstanceMetadataOptionsResult) => void): Request<EC2.Types.ModifyInstanceMetadataOptionsResult, AWSError>;
  /**
   * Modifies the placement attributes for a specified instance. You can do the following:   Modify the affinity between an instance and a Dedicated Host. When affinity is set to host and the instance is not associated with a specific Dedicated Host, the next time the instance is launched, it is automatically associated with the host on which it lands. If the instance is restarted or rebooted, this relationship persists.   Change the Dedicated Host with which an instance is associated.   Change the instance tenancy of an instance.   Move an instance to or from a placement group.   At least one attribute for affinity, host ID, tenancy, or placement group name must be specified in the request. Affinity and tenancy can be modified in the same request. To modify the host ID, tenancy, placement group, or partition for an instance, the instance must be in the stopped state.
   */
  modifyInstancePlacement(params: EC2.Types.ModifyInstancePlacementRequest, callback?: (err: AWSError, data: EC2.Types.ModifyInstancePlacementResult) => void): Request<EC2.Types.ModifyInstancePlacementResult, AWSError>;
  /**
   * Modifies the placement attributes for a specified instance. You can do the following:   Modify the affinity between an instance and a Dedicated Host. When affinity is set to host and the instance is not associated with a specific Dedicated Host, the next time the instance is launched, it is automatically associated with the host on which it lands. If the instance is restarted or rebooted, this relationship persists.   Change the Dedicated Host with which an instance is associated.   Change the instance tenancy of an instance.   Move an instance to or from a placement group.   At least one attribute for affinity, host ID, tenancy, or placement group name must be specified in the request. Affinity and tenancy can be modified in the same request. To modify the host ID, tenancy, placement group, or partition for an instance, the instance must be in the stopped state.
   */
  modifyInstancePlacement(callback?: (err: AWSError, data: EC2.Types.ModifyInstancePlacementResult) => void): Request<EC2.Types.ModifyInstancePlacementResult, AWSError>;
  /**
   * Modify the configurations of an IPAM. 
   */
  modifyIpam(params: EC2.Types.ModifyIpamRequest, callback?: (err: AWSError, data: EC2.Types.ModifyIpamResult) => void): Request<EC2.Types.ModifyIpamResult, AWSError>;
  /**
   * Modify the configurations of an IPAM. 
   */
  modifyIpam(callback?: (err: AWSError, data: EC2.Types.ModifyIpamResult) => void): Request<EC2.Types.ModifyIpamResult, AWSError>;
  /**
   * Modify the configurations of an IPAM pool. For more information, see Modify a pool in the Amazon VPC IPAM User Guide. 
   */
  modifyIpamPool(params: EC2.Types.ModifyIpamPoolRequest, callback?: (err: AWSError, data: EC2.Types.ModifyIpamPoolResult) => void): Request<EC2.Types.ModifyIpamPoolResult, AWSError>;
  /**
   * Modify the configurations of an IPAM pool. For more information, see Modify a pool in the Amazon VPC IPAM User Guide. 
   */
  modifyIpamPool(callback?: (err: AWSError, data: EC2.Types.ModifyIpamPoolResult) => void): Request<EC2.Types.ModifyIpamPoolResult, AWSError>;
  /**
   * Modify a resource CIDR. You can use this action to transfer resource CIDRs between scopes and ignore resource CIDRs that you do not want to manage. If set to false, the resource will not be tracked for overlap, it cannot be auto-imported into a pool, and it will be removed from any pool it has an allocation in. For more information, see Move resource CIDRs between scopes and Change the monitoring state of resource CIDRs in the Amazon VPC IPAM User Guide.
   */
  modifyIpamResourceCidr(params: EC2.Types.ModifyIpamResourceCidrRequest, callback?: (err: AWSError, data: EC2.Types.ModifyIpamResourceCidrResult) => void): Request<EC2.Types.ModifyIpamResourceCidrResult, AWSError>;
  /**
   * Modify a resource CIDR. You can use this action to transfer resource CIDRs between scopes and ignore resource CIDRs that you do not want to manage. If set to false, the resource will not be tracked for overlap, it cannot be auto-imported into a pool, and it will be removed from any pool it has an allocation in. For more information, see Move resource CIDRs between scopes and Change the monitoring state of resource CIDRs in the Amazon VPC IPAM User Guide.
   */
  modifyIpamResourceCidr(callback?: (err: AWSError, data: EC2.Types.ModifyIpamResourceCidrResult) => void): Request<EC2.Types.ModifyIpamResourceCidrResult, AWSError>;
  /**
   * Modifies a resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  modifyIpamResourceDiscovery(params: EC2.Types.ModifyIpamResourceDiscoveryRequest, callback?: (err: AWSError, data: EC2.Types.ModifyIpamResourceDiscoveryResult) => void): Request<EC2.Types.ModifyIpamResourceDiscoveryResult, AWSError>;
  /**
   * Modifies a resource discovery. A resource discovery is an IPAM component that enables IPAM to manage and monitor resources that belong to the owning account.
   */
  modifyIpamResourceDiscovery(callback?: (err: AWSError, data: EC2.Types.ModifyIpamResourceDiscoveryResult) => void): Request<EC2.Types.ModifyIpamResourceDiscoveryResult, AWSError>;
  /**
   * Modify an IPAM scope.
   */
  modifyIpamScope(params: EC2.Types.ModifyIpamScopeRequest, callback?: (err: AWSError, data: EC2.Types.ModifyIpamScopeResult) => void): Request<EC2.Types.ModifyIpamScopeResult, AWSError>;
  /**
   * Modify an IPAM scope.
   */
  modifyIpamScope(callback?: (err: AWSError, data: EC2.Types.ModifyIpamScopeResult) => void): Request<EC2.Types.ModifyIpamScopeResult, AWSError>;
  /**
   * Modifies a launch template. You can specify which version of the launch template to set as the default version. When launching an instance, the default version applies when a launch template version is not specified.
   */
  modifyLaunchTemplate(params: EC2.Types.ModifyLaunchTemplateRequest, callback?: (err: AWSError, data: EC2.Types.ModifyLaunchTemplateResult) => void): Request<EC2.Types.ModifyLaunchTemplateResult, AWSError>;
  /**
   * Modifies a launch template. You can specify which version of the launch template to set as the default version. When launching an instance, the default version applies when a launch template version is not specified.
   */
  modifyLaunchTemplate(callback?: (err: AWSError, data: EC2.Types.ModifyLaunchTemplateResult) => void): Request<EC2.Types.ModifyLaunchTemplateResult, AWSError>;
  /**
   * Modifies the specified local gateway route.
   */
  modifyLocalGatewayRoute(params: EC2.Types.ModifyLocalGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.ModifyLocalGatewayRouteResult) => void): Request<EC2.Types.ModifyLocalGatewayRouteResult, AWSError>;
  /**
   * Modifies the specified local gateway route.
   */
  modifyLocalGatewayRoute(callback?: (err: AWSError, data: EC2.Types.ModifyLocalGatewayRouteResult) => void): Request<EC2.Types.ModifyLocalGatewayRouteResult, AWSError>;
  /**
   * Modifies the specified managed prefix list. Adding or removing entries in a prefix list creates a new version of the prefix list. Changing the name of the prefix list does not affect the version. If you specify a current version number that does not match the true current version number, the request fails.
   */
  modifyManagedPrefixList(params: EC2.Types.ModifyManagedPrefixListRequest, callback?: (err: AWSError, data: EC2.Types.ModifyManagedPrefixListResult) => void): Request<EC2.Types.ModifyManagedPrefixListResult, AWSError>;
  /**
   * Modifies the specified managed prefix list. Adding or removing entries in a prefix list creates a new version of the prefix list. Changing the name of the prefix list does not affect the version. If you specify a current version number that does not match the true current version number, the request fails.
   */
  modifyManagedPrefixList(callback?: (err: AWSError, data: EC2.Types.ModifyManagedPrefixListResult) => void): Request<EC2.Types.ModifyManagedPrefixListResult, AWSError>;
  /**
   * Modifies the specified network interface attribute. You can specify only one attribute at a time. You can use this action to attach and detach security groups from an existing EC2 instance.
   */
  modifyNetworkInterfaceAttribute(params: EC2.Types.ModifyNetworkInterfaceAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified network interface attribute. You can specify only one attribute at a time. You can use this action to attach and detach security groups from an existing EC2 instance.
   */
  modifyNetworkInterfaceAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the options for instance hostnames for the specified instance.
   */
  modifyPrivateDnsNameOptions(params: EC2.Types.ModifyPrivateDnsNameOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyPrivateDnsNameOptionsResult) => void): Request<EC2.Types.ModifyPrivateDnsNameOptionsResult, AWSError>;
  /**
   * Modifies the options for instance hostnames for the specified instance.
   */
  modifyPrivateDnsNameOptions(callback?: (err: AWSError, data: EC2.Types.ModifyPrivateDnsNameOptionsResult) => void): Request<EC2.Types.ModifyPrivateDnsNameOptionsResult, AWSError>;
  /**
   * Modifies the configuration of your Reserved Instances, such as the Availability Zone, instance count, or instance type. The Reserved Instances to be modified must be identical, except for Availability Zone, network platform, and instance type. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  modifyReservedInstances(params: EC2.Types.ModifyReservedInstancesRequest, callback?: (err: AWSError, data: EC2.Types.ModifyReservedInstancesResult) => void): Request<EC2.Types.ModifyReservedInstancesResult, AWSError>;
  /**
   * Modifies the configuration of your Reserved Instances, such as the Availability Zone, instance count, or instance type. The Reserved Instances to be modified must be identical, except for Availability Zone, network platform, and instance type. For more information, see Modifying Reserved Instances in the Amazon EC2 User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  modifyReservedInstances(callback?: (err: AWSError, data: EC2.Types.ModifyReservedInstancesResult) => void): Request<EC2.Types.ModifyReservedInstancesResult, AWSError>;
  /**
   * Modifies the rules of a security group.
   */
  modifySecurityGroupRules(params: EC2.Types.ModifySecurityGroupRulesRequest, callback?: (err: AWSError, data: EC2.Types.ModifySecurityGroupRulesResult) => void): Request<EC2.Types.ModifySecurityGroupRulesResult, AWSError>;
  /**
   * Modifies the rules of a security group.
   */
  modifySecurityGroupRules(callback?: (err: AWSError, data: EC2.Types.ModifySecurityGroupRulesResult) => void): Request<EC2.Types.ModifySecurityGroupRulesResult, AWSError>;
  /**
   * Adds or removes permission settings for the specified snapshot. You may add or remove specified Amazon Web Services account IDs from a snapshot's list of create volume permissions, but you cannot do both in a single operation. If you need to both add and remove account IDs for a snapshot, you must use multiple operations. You can make up to 500 modifications to a snapshot in a single operation. Encrypted snapshots and snapshots with Amazon Web Services Marketplace product codes cannot be made public. Snapshots encrypted with your default KMS key cannot be shared with other accounts. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  modifySnapshotAttribute(params: EC2.Types.ModifySnapshotAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Adds or removes permission settings for the specified snapshot. You may add or remove specified Amazon Web Services account IDs from a snapshot's list of create volume permissions, but you cannot do both in a single operation. If you need to both add and remove account IDs for a snapshot, you must use multiple operations. You can make up to 500 modifications to a snapshot in a single operation. Encrypted snapshots and snapshots with Amazon Web Services Marketplace product codes cannot be made public. Snapshots encrypted with your default KMS key cannot be shared with other accounts. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  modifySnapshotAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Archives an Amazon EBS snapshot. When you archive a snapshot, it is converted to a full snapshot that includes all of the blocks of data that were written to the volume at the time the snapshot was created, and moved from the standard tier to the archive tier. For more information, see Archive Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  modifySnapshotTier(params: EC2.Types.ModifySnapshotTierRequest, callback?: (err: AWSError, data: EC2.Types.ModifySnapshotTierResult) => void): Request<EC2.Types.ModifySnapshotTierResult, AWSError>;
  /**
   * Archives an Amazon EBS snapshot. When you archive a snapshot, it is converted to a full snapshot that includes all of the blocks of data that were written to the volume at the time the snapshot was created, and moved from the standard tier to the archive tier. For more information, see Archive Amazon EBS snapshots in the Amazon Elastic Compute Cloud User Guide.
   */
  modifySnapshotTier(callback?: (err: AWSError, data: EC2.Types.ModifySnapshotTierResult) => void): Request<EC2.Types.ModifySnapshotTierResult, AWSError>;
  /**
   * Modifies the specified Spot Fleet request. You can only modify a Spot Fleet request of type maintain. While the Spot Fleet request is being modified, it is in the modifying state. To scale up your Spot Fleet, increase its target capacity. The Spot Fleet launches the additional Spot Instances according to the allocation strategy for the Spot Fleet request. If the allocation strategy is lowestPrice, the Spot Fleet launches instances using the Spot Instance pool with the lowest price. If the allocation strategy is diversified, the Spot Fleet distributes the instances across the Spot Instance pools. If the allocation strategy is capacityOptimized, Spot Fleet launches instances from Spot Instance pools with optimal capacity for the number of instances that are launching. To scale down your Spot Fleet, decrease its target capacity. First, the Spot Fleet cancels any open requests that exceed the new target capacity. You can request that the Spot Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is lowestPrice, the Spot Fleet terminates the instances with the highest price per unit. If the allocation strategy is capacityOptimized, the Spot Fleet terminates the instances in the Spot Instance pools that have the least available Spot Instance capacity. If the allocation strategy is diversified, the Spot Fleet terminates instances across the Spot Instance pools. Alternatively, you can request that the Spot Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually. If you are finished with your Spot Fleet for now, but will use it again later, you can set the target capacity to 0.
   */
  modifySpotFleetRequest(params: EC2.Types.ModifySpotFleetRequestRequest, callback?: (err: AWSError, data: EC2.Types.ModifySpotFleetRequestResponse) => void): Request<EC2.Types.ModifySpotFleetRequestResponse, AWSError>;
  /**
   * Modifies the specified Spot Fleet request. You can only modify a Spot Fleet request of type maintain. While the Spot Fleet request is being modified, it is in the modifying state. To scale up your Spot Fleet, increase its target capacity. The Spot Fleet launches the additional Spot Instances according to the allocation strategy for the Spot Fleet request. If the allocation strategy is lowestPrice, the Spot Fleet launches instances using the Spot Instance pool with the lowest price. If the allocation strategy is diversified, the Spot Fleet distributes the instances across the Spot Instance pools. If the allocation strategy is capacityOptimized, Spot Fleet launches instances from Spot Instance pools with optimal capacity for the number of instances that are launching. To scale down your Spot Fleet, decrease its target capacity. First, the Spot Fleet cancels any open requests that exceed the new target capacity. You can request that the Spot Fleet terminate Spot Instances until the size of the fleet no longer exceeds the new target capacity. If the allocation strategy is lowestPrice, the Spot Fleet terminates the instances with the highest price per unit. If the allocation strategy is capacityOptimized, the Spot Fleet terminates the instances in the Spot Instance pools that have the least available Spot Instance capacity. If the allocation strategy is diversified, the Spot Fleet terminates instances across the Spot Instance pools. Alternatively, you can request that the Spot Fleet keep the fleet at its current size, but not replace any Spot Instances that are interrupted or that you terminate manually. If you are finished with your Spot Fleet for now, but will use it again later, you can set the target capacity to 0.
   */
  modifySpotFleetRequest(callback?: (err: AWSError, data: EC2.Types.ModifySpotFleetRequestResponse) => void): Request<EC2.Types.ModifySpotFleetRequestResponse, AWSError>;
  /**
   * Modifies a subnet attribute. You can only modify one attribute at a time. Use this action to modify subnets on Amazon Web Services Outposts.   To modify a subnet on an Outpost rack, set both MapCustomerOwnedIpOnLaunch and CustomerOwnedIpv4Pool. These two parameters act as a single attribute.   To modify a subnet on an Outpost server, set either EnableLniAtDeviceIndex or DisableLniAtDeviceIndex.   For more information about Amazon Web Services Outposts, see the following:    Outpost servers     Outpost racks   
   */
  modifySubnetAttribute(params: EC2.Types.ModifySubnetAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies a subnet attribute. You can only modify one attribute at a time. Use this action to modify subnets on Amazon Web Services Outposts.   To modify a subnet on an Outpost rack, set both MapCustomerOwnedIpOnLaunch and CustomerOwnedIpv4Pool. These two parameters act as a single attribute.   To modify a subnet on an Outpost server, set either EnableLniAtDeviceIndex or DisableLniAtDeviceIndex.   For more information about Amazon Web Services Outposts, see the following:    Outpost servers     Outpost racks   
   */
  modifySubnetAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Allows or restricts mirroring network services.  By default, Amazon DNS network services are not eligible for Traffic Mirror. Use AddNetworkServices to add network services to a Traffic Mirror filter. When a network service is added to the Traffic Mirror filter, all traffic related to that network service will be mirrored. When you no longer want to mirror network services, use RemoveNetworkServices to remove the network services from the Traffic Mirror filter. 
   */
  modifyTrafficMirrorFilterNetworkServices(params: EC2.Types.ModifyTrafficMirrorFilterNetworkServicesRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorFilterNetworkServicesResult) => void): Request<EC2.Types.ModifyTrafficMirrorFilterNetworkServicesResult, AWSError>;
  /**
   * Allows or restricts mirroring network services.  By default, Amazon DNS network services are not eligible for Traffic Mirror. Use AddNetworkServices to add network services to a Traffic Mirror filter. When a network service is added to the Traffic Mirror filter, all traffic related to that network service will be mirrored. When you no longer want to mirror network services, use RemoveNetworkServices to remove the network services from the Traffic Mirror filter. 
   */
  modifyTrafficMirrorFilterNetworkServices(callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorFilterNetworkServicesResult) => void): Request<EC2.Types.ModifyTrafficMirrorFilterNetworkServicesResult, AWSError>;
  /**
   * Modifies the specified Traffic Mirror rule.  DestinationCidrBlock and SourceCidrBlock must both be an IPv4 range or an IPv6 range.
   */
  modifyTrafficMirrorFilterRule(params: EC2.Types.ModifyTrafficMirrorFilterRuleRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.ModifyTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Modifies the specified Traffic Mirror rule.  DestinationCidrBlock and SourceCidrBlock must both be an IPv4 range or an IPv6 range.
   */
  modifyTrafficMirrorFilterRule(callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorFilterRuleResult) => void): Request<EC2.Types.ModifyTrafficMirrorFilterRuleResult, AWSError>;
  /**
   * Modifies a Traffic Mirror session.
   */
  modifyTrafficMirrorSession(params: EC2.Types.ModifyTrafficMirrorSessionRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorSessionResult) => void): Request<EC2.Types.ModifyTrafficMirrorSessionResult, AWSError>;
  /**
   * Modifies a Traffic Mirror session.
   */
  modifyTrafficMirrorSession(callback?: (err: AWSError, data: EC2.Types.ModifyTrafficMirrorSessionResult) => void): Request<EC2.Types.ModifyTrafficMirrorSessionResult, AWSError>;
  /**
   * Modifies the specified transit gateway. When you modify a transit gateway, the modified options are applied to new transit gateway attachments only. Your existing transit gateway attachments are not modified.
   */
  modifyTransitGateway(params: EC2.Types.ModifyTransitGatewayRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayResult) => void): Request<EC2.Types.ModifyTransitGatewayResult, AWSError>;
  /**
   * Modifies the specified transit gateway. When you modify a transit gateway, the modified options are applied to new transit gateway attachments only. Your existing transit gateway attachments are not modified.
   */
  modifyTransitGateway(callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayResult) => void): Request<EC2.Types.ModifyTransitGatewayResult, AWSError>;
  /**
   * Modifies a reference (route) to a prefix list in a specified transit gateway route table.
   */
  modifyTransitGatewayPrefixListReference(params: EC2.Types.ModifyTransitGatewayPrefixListReferenceRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.ModifyTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Modifies a reference (route) to a prefix list in a specified transit gateway route table.
   */
  modifyTransitGatewayPrefixListReference(callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayPrefixListReferenceResult) => void): Request<EC2.Types.ModifyTransitGatewayPrefixListReferenceResult, AWSError>;
  /**
   * Modifies the specified VPC attachment.
   */
  modifyTransitGatewayVpcAttachment(params: EC2.Types.ModifyTransitGatewayVpcAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.ModifyTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Modifies the specified VPC attachment.
   */
  modifyTransitGatewayVpcAttachment(callback?: (err: AWSError, data: EC2.Types.ModifyTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.ModifyTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Modifies the configuration of an Amazon Web Services Verified Access endpoint.
   */
  modifyVerifiedAccessEndpoint(params: EC2.Types.ModifyVerifiedAccessEndpointRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessEndpointResult) => void): Request<EC2.Types.ModifyVerifiedAccessEndpointResult, AWSError>;
  /**
   * Modifies the configuration of an Amazon Web Services Verified Access endpoint.
   */
  modifyVerifiedAccessEndpoint(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessEndpointResult) => void): Request<EC2.Types.ModifyVerifiedAccessEndpointResult, AWSError>;
  /**
   * Modifies the specified Verified Access endpoint policy.
   */
  modifyVerifiedAccessEndpointPolicy(params: EC2.Types.ModifyVerifiedAccessEndpointPolicyRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessEndpointPolicyResult) => void): Request<EC2.Types.ModifyVerifiedAccessEndpointPolicyResult, AWSError>;
  /**
   * Modifies the specified Verified Access endpoint policy.
   */
  modifyVerifiedAccessEndpointPolicy(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessEndpointPolicyResult) => void): Request<EC2.Types.ModifyVerifiedAccessEndpointPolicyResult, AWSError>;
  /**
   * Modifies the specified Verified Access group configuration.
   */
  modifyVerifiedAccessGroup(params: EC2.Types.ModifyVerifiedAccessGroupRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessGroupResult) => void): Request<EC2.Types.ModifyVerifiedAccessGroupResult, AWSError>;
  /**
   * Modifies the specified Verified Access group configuration.
   */
  modifyVerifiedAccessGroup(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessGroupResult) => void): Request<EC2.Types.ModifyVerifiedAccessGroupResult, AWSError>;
  /**
   * Modifies the specified Verified Access group policy.
   */
  modifyVerifiedAccessGroupPolicy(params: EC2.Types.ModifyVerifiedAccessGroupPolicyRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessGroupPolicyResult) => void): Request<EC2.Types.ModifyVerifiedAccessGroupPolicyResult, AWSError>;
  /**
   * Modifies the specified Verified Access group policy.
   */
  modifyVerifiedAccessGroupPolicy(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessGroupPolicyResult) => void): Request<EC2.Types.ModifyVerifiedAccessGroupPolicyResult, AWSError>;
  /**
   * Modifies the configuration of the specified Verified Access instance.
   */
  modifyVerifiedAccessInstance(params: EC2.Types.ModifyVerifiedAccessInstanceRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessInstanceResult) => void): Request<EC2.Types.ModifyVerifiedAccessInstanceResult, AWSError>;
  /**
   * Modifies the configuration of the specified Verified Access instance.
   */
  modifyVerifiedAccessInstance(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessInstanceResult) => void): Request<EC2.Types.ModifyVerifiedAccessInstanceResult, AWSError>;
  /**
   * Modifies the logging configuration for the specified Amazon Web Services Verified Access instance.
   */
  modifyVerifiedAccessInstanceLoggingConfiguration(params: EC2.Types.ModifyVerifiedAccessInstanceLoggingConfigurationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessInstanceLoggingConfigurationResult) => void): Request<EC2.Types.ModifyVerifiedAccessInstanceLoggingConfigurationResult, AWSError>;
  /**
   * Modifies the logging configuration for the specified Amazon Web Services Verified Access instance.
   */
  modifyVerifiedAccessInstanceLoggingConfiguration(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessInstanceLoggingConfigurationResult) => void): Request<EC2.Types.ModifyVerifiedAccessInstanceLoggingConfigurationResult, AWSError>;
  /**
   * Modifies the configuration of the specified Amazon Web Services Verified Access trust provider.
   */
  modifyVerifiedAccessTrustProvider(params: EC2.Types.ModifyVerifiedAccessTrustProviderRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.ModifyVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * Modifies the configuration of the specified Amazon Web Services Verified Access trust provider.
   */
  modifyVerifiedAccessTrustProvider(callback?: (err: AWSError, data: EC2.Types.ModifyVerifiedAccessTrustProviderResult) => void): Request<EC2.Types.ModifyVerifiedAccessTrustProviderResult, AWSError>;
  /**
   * You can modify several parameters of an existing EBS volume, including volume size, volume type, and IOPS capacity. If your EBS volume is attached to a current-generation EC2 instance type, you might be able to apply these changes without stopping the instance or detaching the volume from it. For more information about modifying EBS volumes, see Amazon EBS Elastic Volumes (Linux instances) or Amazon EBS Elastic Volumes (Windows instances). When you complete a resize operation on your volume, you need to extend the volume's file-system size to take advantage of the new storage capacity. For more information, see Extend a Linux file system or Extend a Windows file system.  You can use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the Amazon CloudWatch Events User Guide. You can also track the status of a modification using DescribeVolumesModifications. For information about tracking status changes using either method, see Monitor the progress of volume modifications. With previous-generation instance types, resizing an EBS volume might require detaching and reattaching the volume or stopping and restarting the instance. After modifying a volume, you must wait at least six hours and ensure that the volume is in the in-use or available state before you can modify the same volume. This is sometimes referred to as a cooldown period.
   */
  modifyVolume(params: EC2.Types.ModifyVolumeRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVolumeResult) => void): Request<EC2.Types.ModifyVolumeResult, AWSError>;
  /**
   * You can modify several parameters of an existing EBS volume, including volume size, volume type, and IOPS capacity. If your EBS volume is attached to a current-generation EC2 instance type, you might be able to apply these changes without stopping the instance or detaching the volume from it. For more information about modifying EBS volumes, see Amazon EBS Elastic Volumes (Linux instances) or Amazon EBS Elastic Volumes (Windows instances). When you complete a resize operation on your volume, you need to extend the volume's file-system size to take advantage of the new storage capacity. For more information, see Extend a Linux file system or Extend a Windows file system.  You can use CloudWatch Events to check the status of a modification to an EBS volume. For information about CloudWatch Events, see the Amazon CloudWatch Events User Guide. You can also track the status of a modification using DescribeVolumesModifications. For information about tracking status changes using either method, see Monitor the progress of volume modifications. With previous-generation instance types, resizing an EBS volume might require detaching and reattaching the volume or stopping and restarting the instance. After modifying a volume, you must wait at least six hours and ensure that the volume is in the in-use or available state before you can modify the same volume. This is sometimes referred to as a cooldown period.
   */
  modifyVolume(callback?: (err: AWSError, data: EC2.Types.ModifyVolumeResult) => void): Request<EC2.Types.ModifyVolumeResult, AWSError>;
  /**
   * Modifies a volume attribute. By default, all I/O operations for the volume are suspended when the data on the volume is determined to be potentially inconsistent, to prevent undetectable, latent data corruption. The I/O access to the volume can be resumed by first enabling I/O access and then checking the data consistency on your volume. You can change the default behavior to resume I/O operations. We recommend that you change this only for boot volumes or for volumes that are stateless or disposable.
   */
  modifyVolumeAttribute(params: EC2.Types.ModifyVolumeAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies a volume attribute. By default, all I/O operations for the volume are suspended when the data on the volume is determined to be potentially inconsistent, to prevent undetectable, latent data corruption. The I/O access to the volume can be resumed by first enabling I/O access and then checking the data consistency on your volume. You can change the default behavior to resume I/O operations. We recommend that you change this only for boot volumes or for volumes that are stateless or disposable.
   */
  modifyVolumeAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified VPC.
   */
  modifyVpcAttribute(params: EC2.Types.ModifyVpcAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies the specified attribute of the specified VPC.
   */
  modifyVpcAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Modifies attributes of a specified VPC endpoint. The attributes that you can modify depend on the type of VPC endpoint (interface, gateway, or Gateway Load Balancer). For more information, see the Amazon Web Services PrivateLink Guide.
   */
  modifyVpcEndpoint(params: EC2.Types.ModifyVpcEndpointRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointResult) => void): Request<EC2.Types.ModifyVpcEndpointResult, AWSError>;
  /**
   * Modifies attributes of a specified VPC endpoint. The attributes that you can modify depend on the type of VPC endpoint (interface, gateway, or Gateway Load Balancer). For more information, see the Amazon Web Services PrivateLink Guide.
   */
  modifyVpcEndpoint(callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointResult) => void): Request<EC2.Types.ModifyVpcEndpointResult, AWSError>;
  /**
   * Modifies a connection notification for VPC endpoint or VPC endpoint service. You can change the SNS topic for the notification, or the events for which to be notified. 
   */
  modifyVpcEndpointConnectionNotification(params: EC2.Types.ModifyVpcEndpointConnectionNotificationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointConnectionNotificationResult) => void): Request<EC2.Types.ModifyVpcEndpointConnectionNotificationResult, AWSError>;
  /**
   * Modifies a connection notification for VPC endpoint or VPC endpoint service. You can change the SNS topic for the notification, or the events for which to be notified. 
   */
  modifyVpcEndpointConnectionNotification(callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointConnectionNotificationResult) => void): Request<EC2.Types.ModifyVpcEndpointConnectionNotificationResult, AWSError>;
  /**
   * Modifies the attributes of your VPC endpoint service configuration. You can change the Network Load Balancers or Gateway Load Balancers for your service, and you can specify whether acceptance is required for requests to connect to your endpoint service through an interface VPC endpoint. If you set or modify the private DNS name, you must prove that you own the private DNS domain name.
   */
  modifyVpcEndpointServiceConfiguration(params: EC2.Types.ModifyVpcEndpointServiceConfigurationRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServiceConfigurationResult) => void): Request<EC2.Types.ModifyVpcEndpointServiceConfigurationResult, AWSError>;
  /**
   * Modifies the attributes of your VPC endpoint service configuration. You can change the Network Load Balancers or Gateway Load Balancers for your service, and you can specify whether acceptance is required for requests to connect to your endpoint service through an interface VPC endpoint. If you set or modify the private DNS name, you must prove that you own the private DNS domain name.
   */
  modifyVpcEndpointServiceConfiguration(callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServiceConfigurationResult) => void): Request<EC2.Types.ModifyVpcEndpointServiceConfigurationResult, AWSError>;
  /**
   * Modifies the payer responsibility for your VPC endpoint service.
   */
  modifyVpcEndpointServicePayerResponsibility(params: EC2.Types.ModifyVpcEndpointServicePayerResponsibilityRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServicePayerResponsibilityResult) => void): Request<EC2.Types.ModifyVpcEndpointServicePayerResponsibilityResult, AWSError>;
  /**
   * Modifies the payer responsibility for your VPC endpoint service.
   */
  modifyVpcEndpointServicePayerResponsibility(callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServicePayerResponsibilityResult) => void): Request<EC2.Types.ModifyVpcEndpointServicePayerResponsibilityResult, AWSError>;
  /**
   * Modifies the permissions for your VPC endpoint service. You can add or remove permissions for service consumers (Amazon Web Services accounts, users, and IAM roles) to connect to your endpoint service. If you grant permissions to all principals, the service is public. Any users who know the name of a public service can send a request to attach an endpoint. If the service does not require manual approval, attachments are automatically approved.
   */
  modifyVpcEndpointServicePermissions(params: EC2.Types.ModifyVpcEndpointServicePermissionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServicePermissionsResult) => void): Request<EC2.Types.ModifyVpcEndpointServicePermissionsResult, AWSError>;
  /**
   * Modifies the permissions for your VPC endpoint service. You can add or remove permissions for service consumers (Amazon Web Services accounts, users, and IAM roles) to connect to your endpoint service. If you grant permissions to all principals, the service is public. Any users who know the name of a public service can send a request to attach an endpoint. If the service does not require manual approval, attachments are automatically approved.
   */
  modifyVpcEndpointServicePermissions(callback?: (err: AWSError, data: EC2.Types.ModifyVpcEndpointServicePermissionsResult) => void): Request<EC2.Types.ModifyVpcEndpointServicePermissionsResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Modifies the VPC peering connection options on one side of a VPC peering connection. You can do the following:   Enable/disable communication over the peering connection between an EC2-Classic instance that's linked to your VPC (using ClassicLink) and instances in the peer VPC.   Enable/disable communication over the peering connection between instances in your VPC and an EC2-Classic instance that's linked to the peer VPC.   Enable/disable the ability to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.   If the peered VPCs are in the same Amazon Web Services account, you can enable DNS resolution for queries from the local VPC. This ensures that queries from the local VPC resolve to private IP addresses in the peer VPC. This option is not available if the peered VPCs are in different Amazon Web Services accounts or different Regions. For peered VPCs in different Amazon Web Services accounts, each Amazon Web Services account owner must initiate a separate request to modify the peering connection options. For inter-region peering connections, you must use the Region for the requester VPC to modify the requester VPC peering options and the Region for the accepter VPC to modify the accepter VPC peering options. To verify which VPCs are the accepter and the requester for a VPC peering connection, use the DescribeVpcPeeringConnections command.
   */
  modifyVpcPeeringConnectionOptions(params: EC2.Types.ModifyVpcPeeringConnectionOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcPeeringConnectionOptionsResult) => void): Request<EC2.Types.ModifyVpcPeeringConnectionOptionsResult, AWSError>;
  /**
   *  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  Modifies the VPC peering connection options on one side of a VPC peering connection. You can do the following:   Enable/disable communication over the peering connection between an EC2-Classic instance that's linked to your VPC (using ClassicLink) and instances in the peer VPC.   Enable/disable communication over the peering connection between instances in your VPC and an EC2-Classic instance that's linked to the peer VPC.   Enable/disable the ability to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.   If the peered VPCs are in the same Amazon Web Services account, you can enable DNS resolution for queries from the local VPC. This ensures that queries from the local VPC resolve to private IP addresses in the peer VPC. This option is not available if the peered VPCs are in different Amazon Web Services accounts or different Regions. For peered VPCs in different Amazon Web Services accounts, each Amazon Web Services account owner must initiate a separate request to modify the peering connection options. For inter-region peering connections, you must use the Region for the requester VPC to modify the requester VPC peering options and the Region for the accepter VPC to modify the accepter VPC peering options. To verify which VPCs are the accepter and the requester for a VPC peering connection, use the DescribeVpcPeeringConnections command.
   */
  modifyVpcPeeringConnectionOptions(callback?: (err: AWSError, data: EC2.Types.ModifyVpcPeeringConnectionOptionsResult) => void): Request<EC2.Types.ModifyVpcPeeringConnectionOptionsResult, AWSError>;
  /**
   * Modifies the instance tenancy attribute of the specified VPC. You can change the instance tenancy attribute of a VPC to default only. You cannot change the instance tenancy attribute to dedicated. After you modify the tenancy of the VPC, any new instances that you launch into the VPC have a tenancy of default, unless you specify otherwise during launch. The tenancy of any existing instances in the VPC is not affected. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.
   */
  modifyVpcTenancy(params: EC2.Types.ModifyVpcTenancyRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpcTenancyResult) => void): Request<EC2.Types.ModifyVpcTenancyResult, AWSError>;
  /**
   * Modifies the instance tenancy attribute of the specified VPC. You can change the instance tenancy attribute of a VPC to default only. You cannot change the instance tenancy attribute to dedicated. After you modify the tenancy of the VPC, any new instances that you launch into the VPC have a tenancy of default, unless you specify otherwise during launch. The tenancy of any existing instances in the VPC is not affected. For more information, see Dedicated Instances in the Amazon Elastic Compute Cloud User Guide.
   */
  modifyVpcTenancy(callback?: (err: AWSError, data: EC2.Types.ModifyVpcTenancyResult) => void): Request<EC2.Types.ModifyVpcTenancyResult, AWSError>;
  /**
   * Modifies the customer gateway or the target gateway of an Amazon Web Services Site-to-Site VPN connection. To modify the target gateway, the following migration options are available:   An existing virtual private gateway to a new virtual private gateway   An existing virtual private gateway to a transit gateway   An existing transit gateway to a new transit gateway   An existing transit gateway to a virtual private gateway   Before you perform the migration to the new gateway, you must configure the new gateway. Use CreateVpnGateway to create a virtual private gateway, or CreateTransitGateway to create a transit gateway. This step is required when you migrate from a virtual private gateway with static routes to a transit gateway.  You must delete the static routes before you migrate to the new gateway. Keep a copy of the static route before you delete it. You will need to add back these routes to the transit gateway after the VPN connection migration is complete. After you migrate to the new gateway, you might need to modify your VPC route table. Use CreateRoute and DeleteRoute to make the changes described in Update VPC route tables in the Amazon Web Services Site-to-Site VPN User Guide. When the new gateway is a transit gateway, modify the transit gateway route table to allow traffic between the VPC and the Amazon Web Services Site-to-Site VPN connection. Use CreateTransitGatewayRoute to add the routes.  If you deleted VPN static routes, you must add the static routes to the transit gateway route table. After you perform this operation, the VPN endpoint's IP addresses on the Amazon Web Services side and the tunnel options remain intact. Your Amazon Web Services Site-to-Site VPN connection will be temporarily unavailable for a brief period while we provision the new endpoints.
   */
  modifyVpnConnection(params: EC2.Types.ModifyVpnConnectionRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpnConnectionResult) => void): Request<EC2.Types.ModifyVpnConnectionResult, AWSError>;
  /**
   * Modifies the customer gateway or the target gateway of an Amazon Web Services Site-to-Site VPN connection. To modify the target gateway, the following migration options are available:   An existing virtual private gateway to a new virtual private gateway   An existing virtual private gateway to a transit gateway   An existing transit gateway to a new transit gateway   An existing transit gateway to a virtual private gateway   Before you perform the migration to the new gateway, you must configure the new gateway. Use CreateVpnGateway to create a virtual private gateway, or CreateTransitGateway to create a transit gateway. This step is required when you migrate from a virtual private gateway with static routes to a transit gateway.  You must delete the static routes before you migrate to the new gateway. Keep a copy of the static route before you delete it. You will need to add back these routes to the transit gateway after the VPN connection migration is complete. After you migrate to the new gateway, you might need to modify your VPC route table. Use CreateRoute and DeleteRoute to make the changes described in Update VPC route tables in the Amazon Web Services Site-to-Site VPN User Guide. When the new gateway is a transit gateway, modify the transit gateway route table to allow traffic between the VPC and the Amazon Web Services Site-to-Site VPN connection. Use CreateTransitGatewayRoute to add the routes.  If you deleted VPN static routes, you must add the static routes to the transit gateway route table. After you perform this operation, the VPN endpoint's IP addresses on the Amazon Web Services side and the tunnel options remain intact. Your Amazon Web Services Site-to-Site VPN connection will be temporarily unavailable for a brief period while we provision the new endpoints.
   */
  modifyVpnConnection(callback?: (err: AWSError, data: EC2.Types.ModifyVpnConnectionResult) => void): Request<EC2.Types.ModifyVpnConnectionResult, AWSError>;
  /**
   * Modifies the connection options for your Site-to-Site VPN connection. When you modify the VPN connection options, the VPN endpoint IP addresses on the Amazon Web Services side do not change, and the tunnel options do not change. Your VPN connection will be temporarily unavailable for a brief period while the VPN connection is updated.
   */
  modifyVpnConnectionOptions(params: EC2.Types.ModifyVpnConnectionOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpnConnectionOptionsResult) => void): Request<EC2.Types.ModifyVpnConnectionOptionsResult, AWSError>;
  /**
   * Modifies the connection options for your Site-to-Site VPN connection. When you modify the VPN connection options, the VPN endpoint IP addresses on the Amazon Web Services side do not change, and the tunnel options do not change. Your VPN connection will be temporarily unavailable for a brief period while the VPN connection is updated.
   */
  modifyVpnConnectionOptions(callback?: (err: AWSError, data: EC2.Types.ModifyVpnConnectionOptionsResult) => void): Request<EC2.Types.ModifyVpnConnectionOptionsResult, AWSError>;
  /**
   * Modifies the VPN tunnel endpoint certificate.
   */
  modifyVpnTunnelCertificate(params: EC2.Types.ModifyVpnTunnelCertificateRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpnTunnelCertificateResult) => void): Request<EC2.Types.ModifyVpnTunnelCertificateResult, AWSError>;
  /**
   * Modifies the VPN tunnel endpoint certificate.
   */
  modifyVpnTunnelCertificate(callback?: (err: AWSError, data: EC2.Types.ModifyVpnTunnelCertificateResult) => void): Request<EC2.Types.ModifyVpnTunnelCertificateResult, AWSError>;
  /**
   * Modifies the options for a VPN tunnel in an Amazon Web Services Site-to-Site VPN connection. You can modify multiple options for a tunnel in a single request, but you can only modify one tunnel at a time. For more information, see Site-to-Site VPN tunnel options for your Site-to-Site VPN connection in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  modifyVpnTunnelOptions(params: EC2.Types.ModifyVpnTunnelOptionsRequest, callback?: (err: AWSError, data: EC2.Types.ModifyVpnTunnelOptionsResult) => void): Request<EC2.Types.ModifyVpnTunnelOptionsResult, AWSError>;
  /**
   * Modifies the options for a VPN tunnel in an Amazon Web Services Site-to-Site VPN connection. You can modify multiple options for a tunnel in a single request, but you can only modify one tunnel at a time. For more information, see Site-to-Site VPN tunnel options for your Site-to-Site VPN connection in the Amazon Web Services Site-to-Site VPN User Guide.
   */
  modifyVpnTunnelOptions(callback?: (err: AWSError, data: EC2.Types.ModifyVpnTunnelOptionsResult) => void): Request<EC2.Types.ModifyVpnTunnelOptionsResult, AWSError>;
  /**
   * Enables detailed monitoring for a running instance. Otherwise, basic monitoring is enabled. For more information, see Monitor your instances using CloudWatch in the Amazon EC2 User Guide. To disable detailed monitoring, see UnmonitorInstances.
   */
  monitorInstances(params: EC2.Types.MonitorInstancesRequest, callback?: (err: AWSError, data: EC2.Types.MonitorInstancesResult) => void): Request<EC2.Types.MonitorInstancesResult, AWSError>;
  /**
   * Enables detailed monitoring for a running instance. Otherwise, basic monitoring is enabled. For more information, see Monitor your instances using CloudWatch in the Amazon EC2 User Guide. To disable detailed monitoring, see UnmonitorInstances.
   */
  monitorInstances(callback?: (err: AWSError, data: EC2.Types.MonitorInstancesResult) => void): Request<EC2.Types.MonitorInstancesResult, AWSError>;
  /**
   * Moves an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform. The Elastic IP address must be allocated to your account for more than 24 hours, and it must not be associated with an instance. After the Elastic IP address is moved, it is no longer available for use in the EC2-Classic platform, unless you move it back using the RestoreAddressToClassic request. You cannot move an Elastic IP address that was originally allocated for use in the EC2-VPC platform to the EC2-Classic platform.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  moveAddressToVpc(params: EC2.Types.MoveAddressToVpcRequest, callback?: (err: AWSError, data: EC2.Types.MoveAddressToVpcResult) => void): Request<EC2.Types.MoveAddressToVpcResult, AWSError>;
  /**
   * Moves an Elastic IP address from the EC2-Classic platform to the EC2-VPC platform. The Elastic IP address must be allocated to your account for more than 24 hours, and it must not be associated with an instance. After the Elastic IP address is moved, it is no longer available for use in the EC2-Classic platform, unless you move it back using the RestoreAddressToClassic request. You cannot move an Elastic IP address that was originally allocated for use in the EC2-VPC platform to the EC2-Classic platform.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  moveAddressToVpc(callback?: (err: AWSError, data: EC2.Types.MoveAddressToVpcResult) => void): Request<EC2.Types.MoveAddressToVpcResult, AWSError>;
  /**
   * Move a BYOIPv4 CIDR to IPAM from a public IPv4 pool. If you already have a BYOIPv4 CIDR with Amazon Web Services, you can move the CIDR to IPAM from a public IPv4 pool. You cannot move an IPv6 CIDR to IPAM. If you are bringing a new IP address to Amazon Web Services for the first time, complete the steps in Tutorial: BYOIP address CIDRs to IPAM.
   */
  moveByoipCidrToIpam(params: EC2.Types.MoveByoipCidrToIpamRequest, callback?: (err: AWSError, data: EC2.Types.MoveByoipCidrToIpamResult) => void): Request<EC2.Types.MoveByoipCidrToIpamResult, AWSError>;
  /**
   * Move a BYOIPv4 CIDR to IPAM from a public IPv4 pool. If you already have a BYOIPv4 CIDR with Amazon Web Services, you can move the CIDR to IPAM from a public IPv4 pool. You cannot move an IPv6 CIDR to IPAM. If you are bringing a new IP address to Amazon Web Services for the first time, complete the steps in Tutorial: BYOIP address CIDRs to IPAM.
   */
  moveByoipCidrToIpam(callback?: (err: AWSError, data: EC2.Types.MoveByoipCidrToIpamResult) => void): Request<EC2.Types.MoveByoipCidrToIpamResult, AWSError>;
  /**
   * Provisions an IPv4 or IPv6 address range for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool. After the address range is provisioned, it is ready to be advertised using AdvertiseByoipCidr. Amazon Web Services verifies that you own the address range and are authorized to advertise it. You must ensure that the address range is registered to you and that you created an RPKI ROA to authorize Amazon ASNs 16509 and 14618 to advertise the address range. For more information, see Bring your own IP addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. Provisioning an address range is an asynchronous operation, so the call returns immediately, but the address range is not ready to use until its status changes from pending-provision to provisioned. To monitor the status of an address range, use DescribeByoipCidrs. To allocate an Elastic IP address from your IPv4 address pool, use AllocateAddress with either the specific address from the address pool or the ID of the address pool.
   */
  provisionByoipCidr(params: EC2.Types.ProvisionByoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.ProvisionByoipCidrResult) => void): Request<EC2.Types.ProvisionByoipCidrResult, AWSError>;
  /**
   * Provisions an IPv4 or IPv6 address range for use with your Amazon Web Services resources through bring your own IP addresses (BYOIP) and creates a corresponding address pool. After the address range is provisioned, it is ready to be advertised using AdvertiseByoipCidr. Amazon Web Services verifies that you own the address range and are authorized to advertise it. You must ensure that the address range is registered to you and that you created an RPKI ROA to authorize Amazon ASNs 16509 and 14618 to advertise the address range. For more information, see Bring your own IP addresses (BYOIP) in the Amazon Elastic Compute Cloud User Guide. Provisioning an address range is an asynchronous operation, so the call returns immediately, but the address range is not ready to use until its status changes from pending-provision to provisioned. To monitor the status of an address range, use DescribeByoipCidrs. To allocate an Elastic IP address from your IPv4 address pool, use AllocateAddress with either the specific address from the address pool or the ID of the address pool.
   */
  provisionByoipCidr(callback?: (err: AWSError, data: EC2.Types.ProvisionByoipCidrResult) => void): Request<EC2.Types.ProvisionByoipCidrResult, AWSError>;
  /**
   * Provision a CIDR to an IPAM pool. You can use this action to provision new CIDRs to a top-level pool or to transfer a CIDR from a top-level pool to a pool within it. For more information, see Provision CIDRs to pools in the Amazon VPC IPAM User Guide. 
   */
  provisionIpamPoolCidr(params: EC2.Types.ProvisionIpamPoolCidrRequest, callback?: (err: AWSError, data: EC2.Types.ProvisionIpamPoolCidrResult) => void): Request<EC2.Types.ProvisionIpamPoolCidrResult, AWSError>;
  /**
   * Provision a CIDR to an IPAM pool. You can use this action to provision new CIDRs to a top-level pool or to transfer a CIDR from a top-level pool to a pool within it. For more information, see Provision CIDRs to pools in the Amazon VPC IPAM User Guide. 
   */
  provisionIpamPoolCidr(callback?: (err: AWSError, data: EC2.Types.ProvisionIpamPoolCidrResult) => void): Request<EC2.Types.ProvisionIpamPoolCidrResult, AWSError>;
  /**
   * Provision a CIDR to a public IPv4 pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide.
   */
  provisionPublicIpv4PoolCidr(params: EC2.Types.ProvisionPublicIpv4PoolCidrRequest, callback?: (err: AWSError, data: EC2.Types.ProvisionPublicIpv4PoolCidrResult) => void): Request<EC2.Types.ProvisionPublicIpv4PoolCidrResult, AWSError>;
  /**
   * Provision a CIDR to a public IPv4 pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide.
   */
  provisionPublicIpv4PoolCidr(callback?: (err: AWSError, data: EC2.Types.ProvisionPublicIpv4PoolCidrResult) => void): Request<EC2.Types.ProvisionPublicIpv4PoolCidrResult, AWSError>;
  /**
   * Purchase a reservation with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This action results in the specified reservation being purchased and charged to your account.
   */
  purchaseHostReservation(params: EC2.Types.PurchaseHostReservationRequest, callback?: (err: AWSError, data: EC2.Types.PurchaseHostReservationResult) => void): Request<EC2.Types.PurchaseHostReservationResult, AWSError>;
  /**
   * Purchase a reservation with configurations that match those of your Dedicated Host. You must have active Dedicated Hosts in your account before you purchase a reservation. This action results in the specified reservation being purchased and charged to your account.
   */
  purchaseHostReservation(callback?: (err: AWSError, data: EC2.Types.PurchaseHostReservationResult) => void): Request<EC2.Types.PurchaseHostReservationResult, AWSError>;
  /**
   * Purchases a Reserved Instance for use with your account. With Reserved Instances, you pay a lower hourly rate compared to On-Demand instance pricing. Use DescribeReservedInstancesOfferings to get a list of Reserved Instance offerings that match your specifications. After you've purchased a Reserved Instance, you can check for your new Reserved Instance with DescribeReservedInstances. To queue a purchase for a future date and time, specify a purchase time. If you do not specify a purchase time, the default is the current time. For more information, see Reserved Instances and Reserved Instance Marketplace in the Amazon EC2 User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  purchaseReservedInstancesOffering(params: EC2.Types.PurchaseReservedInstancesOfferingRequest, callback?: (err: AWSError, data: EC2.Types.PurchaseReservedInstancesOfferingResult) => void): Request<EC2.Types.PurchaseReservedInstancesOfferingResult, AWSError>;
  /**
   * Purchases a Reserved Instance for use with your account. With Reserved Instances, you pay a lower hourly rate compared to On-Demand instance pricing. Use DescribeReservedInstancesOfferings to get a list of Reserved Instance offerings that match your specifications. After you've purchased a Reserved Instance, you can check for your new Reserved Instance with DescribeReservedInstances. To queue a purchase for a future date and time, specify a purchase time. If you do not specify a purchase time, the default is the current time. For more information, see Reserved Instances and Reserved Instance Marketplace in the Amazon EC2 User Guide.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  purchaseReservedInstancesOffering(callback?: (err: AWSError, data: EC2.Types.PurchaseReservedInstancesOfferingResult) => void): Request<EC2.Types.PurchaseReservedInstancesOfferingResult, AWSError>;
  /**
   *  You can no longer purchase Scheduled Instances.  Purchases the Scheduled Instances with the specified schedule. Scheduled Instances enable you to purchase Amazon EC2 compute capacity by the hour for a one-year term. Before you can purchase a Scheduled Instance, you must call DescribeScheduledInstanceAvailability to check for available schedules and obtain a purchase token. After you purchase a Scheduled Instance, you must call RunScheduledInstances during each scheduled time period. After you purchase a Scheduled Instance, you can't cancel, modify, or resell your purchase.
   */
  purchaseScheduledInstances(params: EC2.Types.PurchaseScheduledInstancesRequest, callback?: (err: AWSError, data: EC2.Types.PurchaseScheduledInstancesResult) => void): Request<EC2.Types.PurchaseScheduledInstancesResult, AWSError>;
  /**
   *  You can no longer purchase Scheduled Instances.  Purchases the Scheduled Instances with the specified schedule. Scheduled Instances enable you to purchase Amazon EC2 compute capacity by the hour for a one-year term. Before you can purchase a Scheduled Instance, you must call DescribeScheduledInstanceAvailability to check for available schedules and obtain a purchase token. After you purchase a Scheduled Instance, you must call RunScheduledInstances during each scheduled time period. After you purchase a Scheduled Instance, you can't cancel, modify, or resell your purchase.
   */
  purchaseScheduledInstances(callback?: (err: AWSError, data: EC2.Types.PurchaseScheduledInstancesResult) => void): Request<EC2.Types.PurchaseScheduledInstancesResult, AWSError>;
  /**
   * Requests a reboot of the specified instances. This operation is asynchronous; it only queues a request to reboot the specified instances. The operation succeeds if the instances are valid and belong to you. Requests to reboot terminated instances are ignored. If an instance does not cleanly shut down within a few minutes, Amazon EC2 performs a hard reboot. For more information about troubleshooting, see Troubleshoot an unreachable instance in the Amazon EC2 User Guide.
   */
  rebootInstances(params: EC2.Types.RebootInstancesRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Requests a reboot of the specified instances. This operation is asynchronous; it only queues a request to reboot the specified instances. The operation succeeds if the instances are valid and belong to you. Requests to reboot terminated instances are ignored. If an instance does not cleanly shut down within a few minutes, Amazon EC2 performs a hard reboot. For more information about troubleshooting, see Troubleshoot an unreachable instance in the Amazon EC2 User Guide.
   */
  rebootInstances(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Registers an AMI. When you're creating an AMI, this is the final step you must complete before you can launch an instance from the AMI. For more information about creating AMIs, see Create your own AMI in the Amazon Elastic Compute Cloud User Guide.  For Amazon EBS-backed instances, CreateImage creates and registers the AMI in a single request, so you don't have to register the AMI yourself. We recommend that you always use CreateImage unless you have a specific reason to use RegisterImage.  If needed, you can deregister an AMI at any time. Any modifications you make to an AMI backed by an instance store volume invalidates its registration. If you make changes to an image, deregister the previous image and register the new image.  Register a snapshot of a root device volume  You can use RegisterImage to create an Amazon EBS-backed Linux AMI from a snapshot of a root device volume. You specify the snapshot using a block device mapping. You can't set the encryption state of the volume using the block device mapping. If the snapshot is encrypted, or encryption by default is enabled, the root volume of an instance launched from the AMI is encrypted. For more information, see Create a Linux AMI from a snapshot and Use encryption with Amazon EBS-backed AMIs in the Amazon Elastic Compute Cloud User Guide.  Amazon Web Services Marketplace product codes  If any snapshots have Amazon Web Services Marketplace product codes, they are copied to the new AMI. Windows and some Linux distributions, such as Red Hat Enterprise Linux (RHEL) and SUSE Linux Enterprise Server (SLES), use the Amazon EC2 billing product code associated with an AMI to verify the subscription status for package updates. To create a new AMI for operating systems that require a billing product code, instead of registering the AMI, do the following to preserve the billing product code association:   Launch an instance from an existing AMI with that billing product code.   Customize the instance.   Create an AMI from the instance using CreateImage.   If you purchase a Reserved Instance to apply to an On-Demand Instance that was launched from an AMI with a billing product code, make sure that the Reserved Instance has the matching billing product code. If you purchase a Reserved Instance without the matching billing product code, the Reserved Instance will not be applied to the On-Demand Instance. For information about how to obtain the platform details and billing information of an AMI, see Understand AMI billing information in the Amazon EC2 User Guide.
   */
  registerImage(params: EC2.Types.RegisterImageRequest, callback?: (err: AWSError, data: EC2.Types.RegisterImageResult) => void): Request<EC2.Types.RegisterImageResult, AWSError>;
  /**
   * Registers an AMI. When you're creating an AMI, this is the final step you must complete before you can launch an instance from the AMI. For more information about creating AMIs, see Create your own AMI in the Amazon Elastic Compute Cloud User Guide.  For Amazon EBS-backed instances, CreateImage creates and registers the AMI in a single request, so you don't have to register the AMI yourself. We recommend that you always use CreateImage unless you have a specific reason to use RegisterImage.  If needed, you can deregister an AMI at any time. Any modifications you make to an AMI backed by an instance store volume invalidates its registration. If you make changes to an image, deregister the previous image and register the new image.  Register a snapshot of a root device volume  You can use RegisterImage to create an Amazon EBS-backed Linux AMI from a snapshot of a root device volume. You specify the snapshot using a block device mapping. You can't set the encryption state of the volume using the block device mapping. If the snapshot is encrypted, or encryption by default is enabled, the root volume of an instance launched from the AMI is encrypted. For more information, see Create a Linux AMI from a snapshot and Use encryption with Amazon EBS-backed AMIs in the Amazon Elastic Compute Cloud User Guide.  Amazon Web Services Marketplace product codes  If any snapshots have Amazon Web Services Marketplace product codes, they are copied to the new AMI. Windows and some Linux distributions, such as Red Hat Enterprise Linux (RHEL) and SUSE Linux Enterprise Server (SLES), use the Amazon EC2 billing product code associated with an AMI to verify the subscription status for package updates. To create a new AMI for operating systems that require a billing product code, instead of registering the AMI, do the following to preserve the billing product code association:   Launch an instance from an existing AMI with that billing product code.   Customize the instance.   Create an AMI from the instance using CreateImage.   If you purchase a Reserved Instance to apply to an On-Demand Instance that was launched from an AMI with a billing product code, make sure that the Reserved Instance has the matching billing product code. If you purchase a Reserved Instance without the matching billing product code, the Reserved Instance will not be applied to the On-Demand Instance. For information about how to obtain the platform details and billing information of an AMI, see Understand AMI billing information in the Amazon EC2 User Guide.
   */
  registerImage(callback?: (err: AWSError, data: EC2.Types.RegisterImageResult) => void): Request<EC2.Types.RegisterImageResult, AWSError>;
  /**
   * Registers a set of tag keys to include in scheduled event notifications for your resources.  To remove tags, use DeregisterInstanceEventNotificationAttributes.
   */
  registerInstanceEventNotificationAttributes(params: EC2.Types.RegisterInstanceEventNotificationAttributesRequest, callback?: (err: AWSError, data: EC2.Types.RegisterInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.RegisterInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Registers a set of tag keys to include in scheduled event notifications for your resources.  To remove tags, use DeregisterInstanceEventNotificationAttributes.
   */
  registerInstanceEventNotificationAttributes(callback?: (err: AWSError, data: EC2.Types.RegisterInstanceEventNotificationAttributesResult) => void): Request<EC2.Types.RegisterInstanceEventNotificationAttributesResult, AWSError>;
  /**
   * Registers members (network interfaces) with the transit gateway multicast group. A member is a network interface associated with a supported EC2 instance that receives multicast traffic. For information about supported instances, see Multicast Consideration in Amazon VPC Transit Gateways. After you add the members, use SearchTransitGatewayMulticastGroups to verify that the members were added to the transit gateway multicast group.
   */
  registerTransitGatewayMulticastGroupMembers(params: EC2.Types.RegisterTransitGatewayMulticastGroupMembersRequest, callback?: (err: AWSError, data: EC2.Types.RegisterTransitGatewayMulticastGroupMembersResult) => void): Request<EC2.Types.RegisterTransitGatewayMulticastGroupMembersResult, AWSError>;
  /**
   * Registers members (network interfaces) with the transit gateway multicast group. A member is a network interface associated with a supported EC2 instance that receives multicast traffic. For information about supported instances, see Multicast Consideration in Amazon VPC Transit Gateways. After you add the members, use SearchTransitGatewayMulticastGroups to verify that the members were added to the transit gateway multicast group.
   */
  registerTransitGatewayMulticastGroupMembers(callback?: (err: AWSError, data: EC2.Types.RegisterTransitGatewayMulticastGroupMembersResult) => void): Request<EC2.Types.RegisterTransitGatewayMulticastGroupMembersResult, AWSError>;
  /**
   * Registers sources (network interfaces) with the specified transit gateway multicast group. A multicast source is a network interface attached to a supported instance that sends multicast traffic. For information about supported instances, see Multicast Considerations in Amazon VPC Transit Gateways. After you add the source, use SearchTransitGatewayMulticastGroups to verify that the source was added to the multicast group.
   */
  registerTransitGatewayMulticastGroupSources(params: EC2.Types.RegisterTransitGatewayMulticastGroupSourcesRequest, callback?: (err: AWSError, data: EC2.Types.RegisterTransitGatewayMulticastGroupSourcesResult) => void): Request<EC2.Types.RegisterTransitGatewayMulticastGroupSourcesResult, AWSError>;
  /**
   * Registers sources (network interfaces) with the specified transit gateway multicast group. A multicast source is a network interface attached to a supported instance that sends multicast traffic. For information about supported instances, see Multicast Considerations in Amazon VPC Transit Gateways. After you add the source, use SearchTransitGatewayMulticastGroups to verify that the source was added to the multicast group.
   */
  registerTransitGatewayMulticastGroupSources(callback?: (err: AWSError, data: EC2.Types.RegisterTransitGatewayMulticastGroupSourcesResult) => void): Request<EC2.Types.RegisterTransitGatewayMulticastGroupSourcesResult, AWSError>;
  /**
   * Rejects a request to associate cross-account subnets with a transit gateway multicast domain.
   */
  rejectTransitGatewayMulticastDomainAssociations(params: EC2.Types.RejectTransitGatewayMulticastDomainAssociationsRequest, callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.RejectTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Rejects a request to associate cross-account subnets with a transit gateway multicast domain.
   */
  rejectTransitGatewayMulticastDomainAssociations(callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayMulticastDomainAssociationsResult) => void): Request<EC2.Types.RejectTransitGatewayMulticastDomainAssociationsResult, AWSError>;
  /**
   * Rejects a transit gateway peering attachment request.
   */
  rejectTransitGatewayPeeringAttachment(params: EC2.Types.RejectTransitGatewayPeeringAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.RejectTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Rejects a transit gateway peering attachment request.
   */
  rejectTransitGatewayPeeringAttachment(callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayPeeringAttachmentResult) => void): Request<EC2.Types.RejectTransitGatewayPeeringAttachmentResult, AWSError>;
  /**
   * Rejects a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use AcceptTransitGatewayVpcAttachment to accept a VPC attachment request.
   */
  rejectTransitGatewayVpcAttachment(params: EC2.Types.RejectTransitGatewayVpcAttachmentRequest, callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.RejectTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Rejects a request to attach a VPC to a transit gateway. The VPC attachment must be in the pendingAcceptance state. Use DescribeTransitGatewayVpcAttachments to view your pending VPC attachment requests. Use AcceptTransitGatewayVpcAttachment to accept a VPC attachment request.
   */
  rejectTransitGatewayVpcAttachment(callback?: (err: AWSError, data: EC2.Types.RejectTransitGatewayVpcAttachmentResult) => void): Request<EC2.Types.RejectTransitGatewayVpcAttachmentResult, AWSError>;
  /**
   * Rejects VPC endpoint connection requests to your VPC endpoint service.
   */
  rejectVpcEndpointConnections(params: EC2.Types.RejectVpcEndpointConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.RejectVpcEndpointConnectionsResult) => void): Request<EC2.Types.RejectVpcEndpointConnectionsResult, AWSError>;
  /**
   * Rejects VPC endpoint connection requests to your VPC endpoint service.
   */
  rejectVpcEndpointConnections(callback?: (err: AWSError, data: EC2.Types.RejectVpcEndpointConnectionsResult) => void): Request<EC2.Types.RejectVpcEndpointConnectionsResult, AWSError>;
  /**
   * Rejects a VPC peering connection request. The VPC peering connection must be in the pending-acceptance state. Use the DescribeVpcPeeringConnections request to view your outstanding VPC peering connection requests. To delete an active VPC peering connection, or to delete a VPC peering connection request that you initiated, use DeleteVpcPeeringConnection.
   */
  rejectVpcPeeringConnection(params: EC2.Types.RejectVpcPeeringConnectionRequest, callback?: (err: AWSError, data: EC2.Types.RejectVpcPeeringConnectionResult) => void): Request<EC2.Types.RejectVpcPeeringConnectionResult, AWSError>;
  /**
   * Rejects a VPC peering connection request. The VPC peering connection must be in the pending-acceptance state. Use the DescribeVpcPeeringConnections request to view your outstanding VPC peering connection requests. To delete an active VPC peering connection, or to delete a VPC peering connection request that you initiated, use DeleteVpcPeeringConnection.
   */
  rejectVpcPeeringConnection(callback?: (err: AWSError, data: EC2.Types.RejectVpcPeeringConnectionResult) => void): Request<EC2.Types.RejectVpcPeeringConnectionResult, AWSError>;
  /**
   * Releases the specified Elastic IP address. [EC2-Classic, default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that it's associated with. To disassociate an Elastic IP address without releasing it, use DisassociateAddress.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  [Nondefault VPC] You must use DisassociateAddress to disassociate the Elastic IP address before you can release it. Otherwise, Amazon EC2 returns an error (InvalidIPAddress.InUse). After releasing an Elastic IP address, it is released to the IP address pool. Be sure to update your DNS records and any servers or devices that communicate with the address. If you attempt to release an Elastic IP address that you already released, you'll get an AuthFailure error if the address is already allocated to another Amazon Web Services account. [EC2-VPC] After you release an Elastic IP address for use in a VPC, you might be able to recover it. For more information, see AllocateAddress. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.
   */
  releaseAddress(params: EC2.Types.ReleaseAddressRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Releases the specified Elastic IP address. [EC2-Classic, default VPC] Releasing an Elastic IP address automatically disassociates it from any instance that it's associated with. To disassociate an Elastic IP address without releasing it, use DisassociateAddress.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide.  [Nondefault VPC] You must use DisassociateAddress to disassociate the Elastic IP address before you can release it. Otherwise, Amazon EC2 returns an error (InvalidIPAddress.InUse). After releasing an Elastic IP address, it is released to the IP address pool. Be sure to update your DNS records and any servers or devices that communicate with the address. If you attempt to release an Elastic IP address that you already released, you'll get an AuthFailure error if the address is already allocated to another Amazon Web Services account. [EC2-VPC] After you release an Elastic IP address for use in a VPC, you might be able to recover it. For more information, see AllocateAddress. For more information, see Elastic IP Addresses in the Amazon Elastic Compute Cloud User Guide.
   */
  releaseAddress(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * When you no longer want to use an On-Demand Dedicated Host it can be released. On-Demand billing is stopped and the host goes into released state. The host ID of Dedicated Hosts that have been released can no longer be specified in another request, for example, to modify the host. You must stop or terminate all instances on a host before it can be released. When Dedicated Hosts are released, it may take some time for them to stop counting toward your limit and you may receive capacity errors when trying to allocate new Dedicated Hosts. Wait a few minutes and then try again. Released hosts still appear in a DescribeHosts response.
   */
  releaseHosts(params: EC2.Types.ReleaseHostsRequest, callback?: (err: AWSError, data: EC2.Types.ReleaseHostsResult) => void): Request<EC2.Types.ReleaseHostsResult, AWSError>;
  /**
   * When you no longer want to use an On-Demand Dedicated Host it can be released. On-Demand billing is stopped and the host goes into released state. The host ID of Dedicated Hosts that have been released can no longer be specified in another request, for example, to modify the host. You must stop or terminate all instances on a host before it can be released. When Dedicated Hosts are released, it may take some time for them to stop counting toward your limit and you may receive capacity errors when trying to allocate new Dedicated Hosts. Wait a few minutes and then try again. Released hosts still appear in a DescribeHosts response.
   */
  releaseHosts(callback?: (err: AWSError, data: EC2.Types.ReleaseHostsResult) => void): Request<EC2.Types.ReleaseHostsResult, AWSError>;
  /**
   * Release an allocation within an IPAM pool. You can only use this action to release manual allocations. To remove an allocation for a resource without deleting the resource, set its monitored state to false using ModifyIpamResourceCidr. For more information, see Release an allocation in the Amazon VPC IPAM User Guide.   All EC2 API actions follow an eventual consistency model. 
   */
  releaseIpamPoolAllocation(params: EC2.Types.ReleaseIpamPoolAllocationRequest, callback?: (err: AWSError, data: EC2.Types.ReleaseIpamPoolAllocationResult) => void): Request<EC2.Types.ReleaseIpamPoolAllocationResult, AWSError>;
  /**
   * Release an allocation within an IPAM pool. You can only use this action to release manual allocations. To remove an allocation for a resource without deleting the resource, set its monitored state to false using ModifyIpamResourceCidr. For more information, see Release an allocation in the Amazon VPC IPAM User Guide.   All EC2 API actions follow an eventual consistency model. 
   */
  releaseIpamPoolAllocation(callback?: (err: AWSError, data: EC2.Types.ReleaseIpamPoolAllocationResult) => void): Request<EC2.Types.ReleaseIpamPoolAllocationResult, AWSError>;
  /**
   * Replaces an IAM instance profile for the specified running instance. You can use this action to change the IAM instance profile that's associated with an instance without having to disassociate the existing IAM instance profile first. Use DescribeIamInstanceProfileAssociations to get the association ID.
   */
  replaceIamInstanceProfileAssociation(params: EC2.Types.ReplaceIamInstanceProfileAssociationRequest, callback?: (err: AWSError, data: EC2.Types.ReplaceIamInstanceProfileAssociationResult) => void): Request<EC2.Types.ReplaceIamInstanceProfileAssociationResult, AWSError>;
  /**
   * Replaces an IAM instance profile for the specified running instance. You can use this action to change the IAM instance profile that's associated with an instance without having to disassociate the existing IAM instance profile first. Use DescribeIamInstanceProfileAssociations to get the association ID.
   */
  replaceIamInstanceProfileAssociation(callback?: (err: AWSError, data: EC2.Types.ReplaceIamInstanceProfileAssociationResult) => void): Request<EC2.Types.ReplaceIamInstanceProfileAssociationResult, AWSError>;
  /**
   * Changes which network ACL a subnet is associated with. By default when you create a subnet, it's automatically associated with the default network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide. This is an idempotent operation.
   */
  replaceNetworkAclAssociation(params: EC2.Types.ReplaceNetworkAclAssociationRequest, callback?: (err: AWSError, data: EC2.Types.ReplaceNetworkAclAssociationResult) => void): Request<EC2.Types.ReplaceNetworkAclAssociationResult, AWSError>;
  /**
   * Changes which network ACL a subnet is associated with. By default when you create a subnet, it's automatically associated with the default network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide. This is an idempotent operation.
   */
  replaceNetworkAclAssociation(callback?: (err: AWSError, data: EC2.Types.ReplaceNetworkAclAssociationResult) => void): Request<EC2.Types.ReplaceNetworkAclAssociationResult, AWSError>;
  /**
   * Replaces an entry (rule) in a network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  replaceNetworkAclEntry(params: EC2.Types.ReplaceNetworkAclEntryRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Replaces an entry (rule) in a network ACL. For more information, see Network ACLs in the Amazon Virtual Private Cloud User Guide.
   */
  replaceNetworkAclEntry(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Replaces an existing route within a route table in a VPC. You must specify either a destination CIDR block or a prefix list ID. You must also specify exactly one of the resources from the parameter list, or reset the local route to its default target. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  replaceRoute(params: EC2.Types.ReplaceRouteRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Replaces an existing route within a route table in a VPC. You must specify either a destination CIDR block or a prefix list ID. You must also specify exactly one of the resources from the parameter list, or reset the local route to its default target. For more information, see Route tables in the Amazon Virtual Private Cloud User Guide.
   */
  replaceRoute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Changes the route table associated with a given subnet, internet gateway, or virtual private gateway in a VPC. After the operation completes, the subnet or gateway uses the routes in the new route table. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide. You can also use this operation to change which table is the main route table in the VPC. Specify the main route table's association ID and the route table ID of the new main route table.
   */
  replaceRouteTableAssociation(params: EC2.Types.ReplaceRouteTableAssociationRequest, callback?: (err: AWSError, data: EC2.Types.ReplaceRouteTableAssociationResult) => void): Request<EC2.Types.ReplaceRouteTableAssociationResult, AWSError>;
  /**
   * Changes the route table associated with a given subnet, internet gateway, or virtual private gateway in a VPC. After the operation completes, the subnet or gateway uses the routes in the new route table. For more information about route tables, see Route tables in the Amazon Virtual Private Cloud User Guide. You can also use this operation to change which table is the main route table in the VPC. Specify the main route table's association ID and the route table ID of the new main route table.
   */
  replaceRouteTableAssociation(callback?: (err: AWSError, data: EC2.Types.ReplaceRouteTableAssociationResult) => void): Request<EC2.Types.ReplaceRouteTableAssociationResult, AWSError>;
  /**
   * Replaces the specified route in the specified transit gateway route table.
   */
  replaceTransitGatewayRoute(params: EC2.Types.ReplaceTransitGatewayRouteRequest, callback?: (err: AWSError, data: EC2.Types.ReplaceTransitGatewayRouteResult) => void): Request<EC2.Types.ReplaceTransitGatewayRouteResult, AWSError>;
  /**
   * Replaces the specified route in the specified transit gateway route table.
   */
  replaceTransitGatewayRoute(callback?: (err: AWSError, data: EC2.Types.ReplaceTransitGatewayRouteResult) => void): Request<EC2.Types.ReplaceTransitGatewayRouteResult, AWSError>;
  /**
   * Trigger replacement of specified VPN tunnel.
   */
  replaceVpnTunnel(params: EC2.Types.ReplaceVpnTunnelRequest, callback?: (err: AWSError, data: EC2.Types.ReplaceVpnTunnelResult) => void): Request<EC2.Types.ReplaceVpnTunnelResult, AWSError>;
  /**
   * Trigger replacement of specified VPN tunnel.
   */
  replaceVpnTunnel(callback?: (err: AWSError, data: EC2.Types.ReplaceVpnTunnelResult) => void): Request<EC2.Types.ReplaceVpnTunnelResult, AWSError>;
  /**
   * Submits feedback about the status of an instance. The instance must be in the running state. If your experience with the instance differs from the instance status returned by DescribeInstanceStatus, use ReportInstanceStatus to report your experience with the instance. Amazon EC2 collects this information to improve the accuracy of status checks. Use of this action does not change the value returned by DescribeInstanceStatus.
   */
  reportInstanceStatus(params: EC2.Types.ReportInstanceStatusRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Submits feedback about the status of an instance. The instance must be in the running state. If your experience with the instance differs from the instance status returned by DescribeInstanceStatus, use ReportInstanceStatus to report your experience with the instance. Amazon EC2 collects this information to improve the accuracy of status checks. Use of this action does not change the value returned by DescribeInstanceStatus.
   */
  reportInstanceStatus(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Creates a Spot Fleet request. The Spot Fleet request specifies the total target capacity and the On-Demand target capacity. Amazon EC2 calculates the difference between the total capacity and On-Demand capacity, and launches the difference as Spot capacity. You can submit a single request that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. By default, the Spot Fleet requests Spot Instances in the Spot Instance pool where the price per unit is the lowest. Each launch specification can include its own instance weighting that reflects the value of the instance type to your application workload. Alternatively, you can specify that the Spot Fleet distribute the target capacity across the Spot pools included in its launch specifications. By ensuring that the Spot Instances in your Spot Fleet are in different Spot pools, you can improve the availability of your fleet. You can specify tags for the Spot Fleet request and instances launched by the fleet. You cannot tag other resource types in a Spot Fleet request because only the spot-fleet-request and instance resource types are supported. For more information, see Spot Fleet requests in the Amazon EC2 User Guide.  We strongly discourage using the RequestSpotFleet API because it is a legacy API with no planned investment. For options for requesting Spot Instances, see Which is the best Spot request method to use? in the Amazon EC2 User Guide. 
   */
  requestSpotFleet(params: EC2.Types.RequestSpotFleetRequest, callback?: (err: AWSError, data: EC2.Types.RequestSpotFleetResponse) => void): Request<EC2.Types.RequestSpotFleetResponse, AWSError>;
  /**
   * Creates a Spot Fleet request. The Spot Fleet request specifies the total target capacity and the On-Demand target capacity. Amazon EC2 calculates the difference between the total capacity and On-Demand capacity, and launches the difference as Spot capacity. You can submit a single request that includes multiple launch specifications that vary by instance type, AMI, Availability Zone, or subnet. By default, the Spot Fleet requests Spot Instances in the Spot Instance pool where the price per unit is the lowest. Each launch specification can include its own instance weighting that reflects the value of the instance type to your application workload. Alternatively, you can specify that the Spot Fleet distribute the target capacity across the Spot pools included in its launch specifications. By ensuring that the Spot Instances in your Spot Fleet are in different Spot pools, you can improve the availability of your fleet. You can specify tags for the Spot Fleet request and instances launched by the fleet. You cannot tag other resource types in a Spot Fleet request because only the spot-fleet-request and instance resource types are supported. For more information, see Spot Fleet requests in the Amazon EC2 User Guide.  We strongly discourage using the RequestSpotFleet API because it is a legacy API with no planned investment. For options for requesting Spot Instances, see Which is the best Spot request method to use? in the Amazon EC2 User Guide. 
   */
  requestSpotFleet(callback?: (err: AWSError, data: EC2.Types.RequestSpotFleetResponse) => void): Request<EC2.Types.RequestSpotFleetResponse, AWSError>;
  /**
   * Creates a Spot Instance request. For more information, see Spot Instance requests in the Amazon EC2 User Guide for Linux Instances.  We strongly discourage using the RequestSpotInstances API because it is a legacy API with no planned investment. For options for requesting Spot Instances, see Which is the best Spot request method to use? in the Amazon EC2 User Guide for Linux Instances.   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide for Linux Instances. 
   */
  requestSpotInstances(params: EC2.Types.RequestSpotInstancesRequest, callback?: (err: AWSError, data: EC2.Types.RequestSpotInstancesResult) => void): Request<EC2.Types.RequestSpotInstancesResult, AWSError>;
  /**
   * Creates a Spot Instance request. For more information, see Spot Instance requests in the Amazon EC2 User Guide for Linux Instances.  We strongly discourage using the RequestSpotInstances API because it is a legacy API with no planned investment. For options for requesting Spot Instances, see Which is the best Spot request method to use? in the Amazon EC2 User Guide for Linux Instances.   We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide for Linux Instances. 
   */
  requestSpotInstances(callback?: (err: AWSError, data: EC2.Types.RequestSpotInstancesResult) => void): Request<EC2.Types.RequestSpotInstancesResult, AWSError>;
  /**
   * Resets the attribute of the specified IP address. For requirements, see Using reverse DNS for email applications.
   */
  resetAddressAttribute(params: EC2.Types.ResetAddressAttributeRequest, callback?: (err: AWSError, data: EC2.Types.ResetAddressAttributeResult) => void): Request<EC2.Types.ResetAddressAttributeResult, AWSError>;
  /**
   * Resets the attribute of the specified IP address. For requirements, see Using reverse DNS for email applications.
   */
  resetAddressAttribute(callback?: (err: AWSError, data: EC2.Types.ResetAddressAttributeResult) => void): Request<EC2.Types.ResetAddressAttributeResult, AWSError>;
  /**
   * Resets the default KMS key for EBS encryption for your account in this Region to the Amazon Web Services managed KMS key for EBS. After resetting the default KMS key to the Amazon Web Services managed KMS key, you can continue to encrypt by a customer managed KMS key by specifying it when you create the volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  resetEbsDefaultKmsKeyId(params: EC2.Types.ResetEbsDefaultKmsKeyIdRequest, callback?: (err: AWSError, data: EC2.Types.ResetEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.ResetEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Resets the default KMS key for EBS encryption for your account in this Region to the Amazon Web Services managed KMS key for EBS. After resetting the default KMS key to the Amazon Web Services managed KMS key, you can continue to encrypt by a customer managed KMS key by specifying it when you create the volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
   */
  resetEbsDefaultKmsKeyId(callback?: (err: AWSError, data: EC2.Types.ResetEbsDefaultKmsKeyIdResult) => void): Request<EC2.Types.ResetEbsDefaultKmsKeyIdResult, AWSError>;
  /**
   * Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its default value. You can only reset the load permission attribute.
   */
  resetFpgaImageAttribute(params: EC2.Types.ResetFpgaImageAttributeRequest, callback?: (err: AWSError, data: EC2.Types.ResetFpgaImageAttributeResult) => void): Request<EC2.Types.ResetFpgaImageAttributeResult, AWSError>;
  /**
   * Resets the specified attribute of the specified Amazon FPGA Image (AFI) to its default value. You can only reset the load permission attribute.
   */
  resetFpgaImageAttribute(callback?: (err: AWSError, data: EC2.Types.ResetFpgaImageAttributeResult) => void): Request<EC2.Types.ResetFpgaImageAttributeResult, AWSError>;
  /**
   * Resets an attribute of an AMI to its default value.
   */
  resetImageAttribute(params: EC2.Types.ResetImageAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets an attribute of an AMI to its default value.
   */
  resetImageAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets an attribute of an instance to its default value. To reset the kernel or ramdisk, the instance must be in a stopped state. To reset the sourceDestCheck, the instance can be either running or stopped. The sourceDestCheck attribute controls whether source/destination checking is enabled. The default value is true, which means checking is enabled. This value must be false for a NAT instance to perform NAT. For more information, see NAT Instances in the Amazon VPC User Guide.
   */
  resetInstanceAttribute(params: EC2.Types.ResetInstanceAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets an attribute of an instance to its default value. To reset the kernel or ramdisk, the instance must be in a stopped state. To reset the sourceDestCheck, the instance can be either running or stopped. The sourceDestCheck attribute controls whether source/destination checking is enabled. The default value is true, which means checking is enabled. This value must be false for a NAT instance to perform NAT. For more information, see NAT Instances in the Amazon VPC User Guide.
   */
  resetInstanceAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets a network interface attribute. You can specify only one attribute at a time.
   */
  resetNetworkInterfaceAttribute(params: EC2.Types.ResetNetworkInterfaceAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets a network interface attribute. You can specify only one attribute at a time.
   */
  resetNetworkInterfaceAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets permission settings for the specified snapshot. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  resetSnapshotAttribute(params: EC2.Types.ResetSnapshotAttributeRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Resets permission settings for the specified snapshot. For more information about modifying snapshot permissions, see Share a snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  resetSnapshotAttribute(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Restores an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform. You cannot move an Elastic IP address that was originally allocated for use in EC2-VPC. The Elastic IP address must not be associated with an instance or network interface.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  restoreAddressToClassic(params: EC2.Types.RestoreAddressToClassicRequest, callback?: (err: AWSError, data: EC2.Types.RestoreAddressToClassicResult) => void): Request<EC2.Types.RestoreAddressToClassicResult, AWSError>;
  /**
   * Restores an Elastic IP address that was previously moved to the EC2-VPC platform back to the EC2-Classic platform. You cannot move an Elastic IP address that was originally allocated for use in EC2-VPC. The Elastic IP address must not be associated with an instance or network interface.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  restoreAddressToClassic(callback?: (err: AWSError, data: EC2.Types.RestoreAddressToClassicResult) => void): Request<EC2.Types.RestoreAddressToClassicResult, AWSError>;
  /**
   * Restores an AMI from the Recycle Bin. For more information, see Recycle Bin in the Amazon EC2 User Guide.
   */
  restoreImageFromRecycleBin(params: EC2.Types.RestoreImageFromRecycleBinRequest, callback?: (err: AWSError, data: EC2.Types.RestoreImageFromRecycleBinResult) => void): Request<EC2.Types.RestoreImageFromRecycleBinResult, AWSError>;
  /**
   * Restores an AMI from the Recycle Bin. For more information, see Recycle Bin in the Amazon EC2 User Guide.
   */
  restoreImageFromRecycleBin(callback?: (err: AWSError, data: EC2.Types.RestoreImageFromRecycleBinResult) => void): Request<EC2.Types.RestoreImageFromRecycleBinResult, AWSError>;
  /**
   * Restores the entries from a previous version of a managed prefix list to a new version of the prefix list.
   */
  restoreManagedPrefixListVersion(params: EC2.Types.RestoreManagedPrefixListVersionRequest, callback?: (err: AWSError, data: EC2.Types.RestoreManagedPrefixListVersionResult) => void): Request<EC2.Types.RestoreManagedPrefixListVersionResult, AWSError>;
  /**
   * Restores the entries from a previous version of a managed prefix list to a new version of the prefix list.
   */
  restoreManagedPrefixListVersion(callback?: (err: AWSError, data: EC2.Types.RestoreManagedPrefixListVersionResult) => void): Request<EC2.Types.RestoreManagedPrefixListVersionResult, AWSError>;
  /**
   * Restores a snapshot from the Recycle Bin. For more information, see Restore snapshots from the Recycle Bin in the Amazon Elastic Compute Cloud User Guide.
   */
  restoreSnapshotFromRecycleBin(params: EC2.Types.RestoreSnapshotFromRecycleBinRequest, callback?: (err: AWSError, data: EC2.Types.RestoreSnapshotFromRecycleBinResult) => void): Request<EC2.Types.RestoreSnapshotFromRecycleBinResult, AWSError>;
  /**
   * Restores a snapshot from the Recycle Bin. For more information, see Restore snapshots from the Recycle Bin in the Amazon Elastic Compute Cloud User Guide.
   */
  restoreSnapshotFromRecycleBin(callback?: (err: AWSError, data: EC2.Types.RestoreSnapshotFromRecycleBinResult) => void): Request<EC2.Types.RestoreSnapshotFromRecycleBinResult, AWSError>;
  /**
   * Restores an archived Amazon EBS snapshot for use temporarily or permanently, or modifies the restore period or restore type for a snapshot that was previously temporarily restored. For more information see  Restore an archived snapshot and  modify the restore period or restore type for a temporarily restored snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  restoreSnapshotTier(params: EC2.Types.RestoreSnapshotTierRequest, callback?: (err: AWSError, data: EC2.Types.RestoreSnapshotTierResult) => void): Request<EC2.Types.RestoreSnapshotTierResult, AWSError>;
  /**
   * Restores an archived Amazon EBS snapshot for use temporarily or permanently, or modifies the restore period or restore type for a snapshot that was previously temporarily restored. For more information see  Restore an archived snapshot and  modify the restore period or restore type for a temporarily restored snapshot in the Amazon Elastic Compute Cloud User Guide.
   */
  restoreSnapshotTier(callback?: (err: AWSError, data: EC2.Types.RestoreSnapshotTierResult) => void): Request<EC2.Types.RestoreSnapshotTierResult, AWSError>;
  /**
   * Removes an ingress authorization rule from a Client VPN endpoint. 
   */
  revokeClientVpnIngress(params: EC2.Types.RevokeClientVpnIngressRequest, callback?: (err: AWSError, data: EC2.Types.RevokeClientVpnIngressResult) => void): Request<EC2.Types.RevokeClientVpnIngressResult, AWSError>;
  /**
   * Removes an ingress authorization rule from a Client VPN endpoint. 
   */
  revokeClientVpnIngress(callback?: (err: AWSError, data: EC2.Types.RevokeClientVpnIngressResult) => void): Request<EC2.Types.RevokeClientVpnIngressResult, AWSError>;
  /**
   * [VPC only] Removes the specified outbound (egress) rules from a security group for EC2-VPC. This action does not apply to security groups for use in EC2-Classic. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and destination (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [Default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.
   */
  revokeSecurityGroupEgress(params: EC2.Types.RevokeSecurityGroupEgressRequest, callback?: (err: AWSError, data: EC2.Types.RevokeSecurityGroupEgressResult) => void): Request<EC2.Types.RevokeSecurityGroupEgressResult, AWSError>;
  /**
   * [VPC only] Removes the specified outbound (egress) rules from a security group for EC2-VPC. This action does not apply to security groups for use in EC2-Classic. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and destination (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [Default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.
   */
  revokeSecurityGroupEgress(callback?: (err: AWSError, data: EC2.Types.RevokeSecurityGroupEgressResult) => void): Request<EC2.Types.RevokeSecurityGroupEgressResult, AWSError>;
  /**
   * Removes the specified inbound (ingress) rules from a security group. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and source (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [EC2-Classic, default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  revokeSecurityGroupIngress(params: EC2.Types.RevokeSecurityGroupIngressRequest, callback?: (err: AWSError, data: EC2.Types.RevokeSecurityGroupIngressResult) => void): Request<EC2.Types.RevokeSecurityGroupIngressResult, AWSError>;
  /**
   * Removes the specified inbound (ingress) rules from a security group. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and source (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [EC2-Classic, default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon Elastic Compute Cloud User Guide. 
   */
  revokeSecurityGroupIngress(callback?: (err: AWSError, data: EC2.Types.RevokeSecurityGroupIngressResult) => void): Request<EC2.Types.RevokeSecurityGroupIngressResult, AWSError>;
  /**
   * Launches the specified number of instances using an AMI for which you have permissions. You can specify a number of options, or leave the default options. The following rules apply:   [EC2-VPC] If you don't specify a subnet ID, we choose a default subnet from your default VPC for you. If you don't have a default VPC, you must specify a subnet ID in the request.   [EC2-Classic] If don't specify an Availability Zone, we choose one for you.   Some instance types must be launched into a VPC. If you do not have a default VPC, or if you do not specify a subnet ID, the request fails. For more information, see Instance types available only in a VPC.   [EC2-VPC] All instances have a network interface with a primary private IPv4 address. If you don't specify this address, we choose one from the IPv4 range of your subnet.   Not all instance types support IPv6 addresses. For more information, see Instance types.   If you don't specify a security group ID, we use the default security group. For more information, see Security groups.   If any of the AMIs have a product code attached for which the user has not subscribed, the request fails.   You can create a launch template, which is a resource that contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify the launch template instead of specifying the launch parameters. To ensure faster instance launches, break up large requests into smaller batches. For example, create five separate launch requests for 100 instances each instead of one launch request for 500 instances. An instance is ready for you to use when it's in the running state. You can check the state of your instance using DescribeInstances. You can tag instances and EBS volumes during launch, after launch, or both. For more information, see CreateTags and Tagging your Amazon EC2 resources. Linux instances have access to the public key of the key pair at boot. You can use this key to provide secure access to the instance. Amazon EC2 public images use this feature to provide secure access without passwords. For more information, see Key pairs. For troubleshooting, see What to do if an instance immediately terminates, and Troubleshooting connecting to your instance.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide. 
   */
  runInstances(params: EC2.Types.RunInstancesRequest, callback?: (err: AWSError, data: EC2.Types.Reservation) => void): Request<EC2.Types.Reservation, AWSError>;
  /**
   * Launches the specified number of instances using an AMI for which you have permissions. You can specify a number of options, or leave the default options. The following rules apply:   [EC2-VPC] If you don't specify a subnet ID, we choose a default subnet from your default VPC for you. If you don't have a default VPC, you must specify a subnet ID in the request.   [EC2-Classic] If don't specify an Availability Zone, we choose one for you.   Some instance types must be launched into a VPC. If you do not have a default VPC, or if you do not specify a subnet ID, the request fails. For more information, see Instance types available only in a VPC.   [EC2-VPC] All instances have a network interface with a primary private IPv4 address. If you don't specify this address, we choose one from the IPv4 range of your subnet.   Not all instance types support IPv6 addresses. For more information, see Instance types.   If you don't specify a security group ID, we use the default security group. For more information, see Security groups.   If any of the AMIs have a product code attached for which the user has not subscribed, the request fails.   You can create a launch template, which is a resource that contains the parameters to launch an instance. When you launch an instance using RunInstances, you can specify the launch template instead of specifying the launch parameters. To ensure faster instance launches, break up large requests into smaller batches. For example, create five separate launch requests for 100 instances each instead of one launch request for 500 instances. An instance is ready for you to use when it's in the running state. You can check the state of your instance using DescribeInstances. You can tag instances and EBS volumes during launch, after launch, or both. For more information, see CreateTags and Tagging your Amazon EC2 resources. Linux instances have access to the public key of the key pair at boot. You can use this key to provide secure access to the instance. Amazon EC2 public images use this feature to provide secure access without passwords. For more information, see Key pairs. For troubleshooting, see What to do if an instance immediately terminates, and Troubleshooting connecting to your instance.  We are retiring EC2-Classic. We recommend that you migrate from EC2-Classic to a VPC. For more information, see Migrate from EC2-Classic to a VPC in the Amazon EC2 User Guide. 
   */
  runInstances(callback?: (err: AWSError, data: EC2.Types.Reservation) => void): Request<EC2.Types.Reservation, AWSError>;
  /**
   * Launches the specified Scheduled Instances. Before you can launch a Scheduled Instance, you must purchase it and obtain an identifier using PurchaseScheduledInstances. You must launch a Scheduled Instance during its scheduled time period. You can't stop or reboot a Scheduled Instance, but you can terminate it as needed. If you terminate a Scheduled Instance before the current scheduled time period ends, you can launch it again after a few minutes. For more information, see Scheduled Instances in the Amazon EC2 User Guide.
   */
  runScheduledInstances(params: EC2.Types.RunScheduledInstancesRequest, callback?: (err: AWSError, data: EC2.Types.RunScheduledInstancesResult) => void): Request<EC2.Types.RunScheduledInstancesResult, AWSError>;
  /**
   * Launches the specified Scheduled Instances. Before you can launch a Scheduled Instance, you must purchase it and obtain an identifier using PurchaseScheduledInstances. You must launch a Scheduled Instance during its scheduled time period. You can't stop or reboot a Scheduled Instance, but you can terminate it as needed. If you terminate a Scheduled Instance before the current scheduled time period ends, you can launch it again after a few minutes. For more information, see Scheduled Instances in the Amazon EC2 User Guide.
   */
  runScheduledInstances(callback?: (err: AWSError, data: EC2.Types.RunScheduledInstancesResult) => void): Request<EC2.Types.RunScheduledInstancesResult, AWSError>;
  /**
   * Searches for routes in the specified local gateway route table.
   */
  searchLocalGatewayRoutes(params: EC2.Types.SearchLocalGatewayRoutesRequest, callback?: (err: AWSError, data: EC2.Types.SearchLocalGatewayRoutesResult) => void): Request<EC2.Types.SearchLocalGatewayRoutesResult, AWSError>;
  /**
   * Searches for routes in the specified local gateway route table.
   */
  searchLocalGatewayRoutes(callback?: (err: AWSError, data: EC2.Types.SearchLocalGatewayRoutesResult) => void): Request<EC2.Types.SearchLocalGatewayRoutesResult, AWSError>;
  /**
   * Searches one or more transit gateway multicast groups and returns the group membership information.
   */
  searchTransitGatewayMulticastGroups(params: EC2.Types.SearchTransitGatewayMulticastGroupsRequest, callback?: (err: AWSError, data: EC2.Types.SearchTransitGatewayMulticastGroupsResult) => void): Request<EC2.Types.SearchTransitGatewayMulticastGroupsResult, AWSError>;
  /**
   * Searches one or more transit gateway multicast groups and returns the group membership information.
   */
  searchTransitGatewayMulticastGroups(callback?: (err: AWSError, data: EC2.Types.SearchTransitGatewayMulticastGroupsResult) => void): Request<EC2.Types.SearchTransitGatewayMulticastGroupsResult, AWSError>;
  /**
   * Searches for routes in the specified transit gateway route table.
   */
  searchTransitGatewayRoutes(params: EC2.Types.SearchTransitGatewayRoutesRequest, callback?: (err: AWSError, data: EC2.Types.SearchTransitGatewayRoutesResult) => void): Request<EC2.Types.SearchTransitGatewayRoutesResult, AWSError>;
  /**
   * Searches for routes in the specified transit gateway route table.
   */
  searchTransitGatewayRoutes(callback?: (err: AWSError, data: EC2.Types.SearchTransitGatewayRoutesResult) => void): Request<EC2.Types.SearchTransitGatewayRoutesResult, AWSError>;
  /**
   * Sends a diagnostic interrupt to the specified Amazon EC2 instance to trigger a kernel panic (on Linux instances), or a blue screen/stop error (on Windows instances). For instances based on Intel and AMD processors, the interrupt is received as a non-maskable interrupt (NMI). In general, the operating system crashes and reboots when a kernel panic or stop error is triggered. The operating system can also be configured to perform diagnostic tasks, such as generating a memory dump file, loading a secondary kernel, or obtaining a call trace. Before sending a diagnostic interrupt to your instance, ensure that its operating system is configured to perform the required diagnostic tasks. For more information about configuring your operating system to generate a crash dump when a kernel panic or stop error occurs, see Send a diagnostic interrupt (for advanced users) (Linux instances) or Send a diagnostic interrupt (for advanced users) (Windows instances).
   */
  sendDiagnosticInterrupt(params: EC2.Types.SendDiagnosticInterruptRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Sends a diagnostic interrupt to the specified Amazon EC2 instance to trigger a kernel panic (on Linux instances), or a blue screen/stop error (on Windows instances). For instances based on Intel and AMD processors, the interrupt is received as a non-maskable interrupt (NMI). In general, the operating system crashes and reboots when a kernel panic or stop error is triggered. The operating system can also be configured to perform diagnostic tasks, such as generating a memory dump file, loading a secondary kernel, or obtaining a call trace. Before sending a diagnostic interrupt to your instance, ensure that its operating system is configured to perform the required diagnostic tasks. For more information about configuring your operating system to generate a crash dump when a kernel panic or stop error occurs, see Send a diagnostic interrupt (for advanced users) (Linux instances) or Send a diagnostic interrupt (for advanced users) (Windows instances).
   */
  sendDiagnosticInterrupt(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Starts an Amazon EBS-backed instance that you've previously stopped. Instances that use Amazon EBS volumes as their root devices can be quickly stopped and started. When an instance is stopped, the compute resources are released and you are not billed for instance usage. However, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. You can restart your instance at any time. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. Before stopping an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM. Performing this operation on an instance that uses an instance store as its root device returns an error. If you attempt to start a T3 instance with host tenancy and the unlimted CPU credit option, the request fails. The unlimited CPU credit option is not supported on Dedicated Hosts. Before you start the instance, either change its CPU credit option to standard, or change its tenancy to default or dedicated. For more information, see Stop and start your instance in the Amazon EC2 User Guide.
   */
  startInstances(params: EC2.Types.StartInstancesRequest, callback?: (err: AWSError, data: EC2.Types.StartInstancesResult) => void): Request<EC2.Types.StartInstancesResult, AWSError>;
  /**
   * Starts an Amazon EBS-backed instance that you've previously stopped. Instances that use Amazon EBS volumes as their root devices can be quickly stopped and started. When an instance is stopped, the compute resources are released and you are not billed for instance usage. However, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. You can restart your instance at any time. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. Before stopping an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM. Performing this operation on an instance that uses an instance store as its root device returns an error. If you attempt to start a T3 instance with host tenancy and the unlimted CPU credit option, the request fails. The unlimited CPU credit option is not supported on Dedicated Hosts. Before you start the instance, either change its CPU credit option to standard, or change its tenancy to default or dedicated. For more information, see Stop and start your instance in the Amazon EC2 User Guide.
   */
  startInstances(callback?: (err: AWSError, data: EC2.Types.StartInstancesResult) => void): Request<EC2.Types.StartInstancesResult, AWSError>;
  /**
   * Starts analyzing the specified Network Access Scope.
   */
  startNetworkInsightsAccessScopeAnalysis(params: EC2.Types.StartNetworkInsightsAccessScopeAnalysisRequest, callback?: (err: AWSError, data: EC2.Types.StartNetworkInsightsAccessScopeAnalysisResult) => void): Request<EC2.Types.StartNetworkInsightsAccessScopeAnalysisResult, AWSError>;
  /**
   * Starts analyzing the specified Network Access Scope.
   */
  startNetworkInsightsAccessScopeAnalysis(callback?: (err: AWSError, data: EC2.Types.StartNetworkInsightsAccessScopeAnalysisResult) => void): Request<EC2.Types.StartNetworkInsightsAccessScopeAnalysisResult, AWSError>;
  /**
   * Starts analyzing the specified path. If the path is reachable, the operation returns the shortest feasible path.
   */
  startNetworkInsightsAnalysis(params: EC2.Types.StartNetworkInsightsAnalysisRequest, callback?: (err: AWSError, data: EC2.Types.StartNetworkInsightsAnalysisResult) => void): Request<EC2.Types.StartNetworkInsightsAnalysisResult, AWSError>;
  /**
   * Starts analyzing the specified path. If the path is reachable, the operation returns the shortest feasible path.
   */
  startNetworkInsightsAnalysis(callback?: (err: AWSError, data: EC2.Types.StartNetworkInsightsAnalysisResult) => void): Request<EC2.Types.StartNetworkInsightsAnalysisResult, AWSError>;
  /**
   * Initiates the verification process to prove that the service provider owns the private DNS name domain for the endpoint service. The service provider must successfully perform the verification before the consumer can use the name to access the service. Before the service provider runs this command, they must add a record to the DNS server.
   */
  startVpcEndpointServicePrivateDnsVerification(params: EC2.Types.StartVpcEndpointServicePrivateDnsVerificationRequest, callback?: (err: AWSError, data: EC2.Types.StartVpcEndpointServicePrivateDnsVerificationResult) => void): Request<EC2.Types.StartVpcEndpointServicePrivateDnsVerificationResult, AWSError>;
  /**
   * Initiates the verification process to prove that the service provider owns the private DNS name domain for the endpoint service. The service provider must successfully perform the verification before the consumer can use the name to access the service. Before the service provider runs this command, they must add a record to the DNS server.
   */
  startVpcEndpointServicePrivateDnsVerification(callback?: (err: AWSError, data: EC2.Types.StartVpcEndpointServicePrivateDnsVerificationResult) => void): Request<EC2.Types.StartVpcEndpointServicePrivateDnsVerificationResult, AWSError>;
  /**
   * Stops an Amazon EBS-backed instance. For more information, see Stop and start your instance in the Amazon EC2 User Guide. You can use the Stop action to hibernate an instance if the instance is enabled for hibernation and it meets the hibernation prerequisites. For more information, see Hibernate your instance in the Amazon EC2 User Guide. We don't charge usage for a stopped instance, or data transfer fees; however, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. You can't stop or hibernate instance store-backed instances. You can't use the Stop action to hibernate Spot Instances, but you can specify that Amazon EC2 should hibernate Spot Instances when they are interrupted. For more information, see Hibernating interrupted Spot Instances in the Amazon EC2 User Guide. When you stop or hibernate an instance, we shut it down. You can restart your instance at any time. Before stopping or hibernating an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM, but hibernating an instance does preserve data stored in RAM. If an instance cannot hibernate successfully, a normal shutdown occurs. Stopping and hibernating an instance is different to rebooting or terminating it. For example, when you stop or hibernate an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, the root device and any other devices attached during the instance launch are automatically deleted. For more information about the differences between rebooting, stopping, hibernating, and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. When you stop an instance, we attempt to shut it down forcibly after a short while. If your instance appears stuck in the stopping state after a period of time, there may be an issue with the underlying host computer. For more information, see Troubleshoot stopping your instance in the Amazon EC2 User Guide.
   */
  stopInstances(params: EC2.Types.StopInstancesRequest, callback?: (err: AWSError, data: EC2.Types.StopInstancesResult) => void): Request<EC2.Types.StopInstancesResult, AWSError>;
  /**
   * Stops an Amazon EBS-backed instance. For more information, see Stop and start your instance in the Amazon EC2 User Guide. You can use the Stop action to hibernate an instance if the instance is enabled for hibernation and it meets the hibernation prerequisites. For more information, see Hibernate your instance in the Amazon EC2 User Guide. We don't charge usage for a stopped instance, or data transfer fees; however, your root partition Amazon EBS volume remains and continues to persist your data, and you are charged for Amazon EBS volume usage. Every time you start your instance, Amazon EC2 charges a one-minute minimum for instance usage, and thereafter charges per second for instance usage. You can't stop or hibernate instance store-backed instances. You can't use the Stop action to hibernate Spot Instances, but you can specify that Amazon EC2 should hibernate Spot Instances when they are interrupted. For more information, see Hibernating interrupted Spot Instances in the Amazon EC2 User Guide. When you stop or hibernate an instance, we shut it down. You can restart your instance at any time. Before stopping or hibernating an instance, make sure it is in a state from which it can be restarted. Stopping an instance does not preserve data stored in RAM, but hibernating an instance does preserve data stored in RAM. If an instance cannot hibernate successfully, a normal shutdown occurs. Stopping and hibernating an instance is different to rebooting or terminating it. For example, when you stop or hibernate an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, the root device and any other devices attached during the instance launch are automatically deleted. For more information about the differences between rebooting, stopping, hibernating, and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. When you stop an instance, we attempt to shut it down forcibly after a short while. If your instance appears stuck in the stopping state after a period of time, there may be an issue with the underlying host computer. For more information, see Troubleshoot stopping your instance in the Amazon EC2 User Guide.
   */
  stopInstances(callback?: (err: AWSError, data: EC2.Types.StopInstancesResult) => void): Request<EC2.Types.StopInstancesResult, AWSError>;
  /**
   * Terminates active Client VPN endpoint connections. This action can be used to terminate a specific client connection, or up to five connections established by a specific user.
   */
  terminateClientVpnConnections(params: EC2.Types.TerminateClientVpnConnectionsRequest, callback?: (err: AWSError, data: EC2.Types.TerminateClientVpnConnectionsResult) => void): Request<EC2.Types.TerminateClientVpnConnectionsResult, AWSError>;
  /**
   * Terminates active Client VPN endpoint connections. This action can be used to terminate a specific client connection, or up to five connections established by a specific user.
   */
  terminateClientVpnConnections(callback?: (err: AWSError, data: EC2.Types.TerminateClientVpnConnectionsResult) => void): Request<EC2.Types.TerminateClientVpnConnectionsResult, AWSError>;
  /**
   * Shuts down the specified instances. This operation is idempotent; if you terminate an instance more than once, each call succeeds.  If you specify multiple instances and the request fails (for example, because of a single incorrect instance ID), none of the instances are terminated. If you terminate multiple instances across multiple Availability Zones, and one or more of the specified instances are enabled for termination protection, the request fails with the following results:   The specified instances that are in the same Availability Zone as the protected instance are not terminated.   The specified instances that are in different Availability Zones, where no other specified instances are protected, are successfully terminated.   For example, say you have the following instances:   Instance A: us-east-1a; Not protected   Instance B: us-east-1a; Not protected   Instance C: us-east-1b; Protected   Instance D: us-east-1b; not protected   If you attempt to terminate all of these instances in the same request, the request reports failure with the following results:   Instance A and Instance B are successfully terminated because none of the specified instances in us-east-1a are enabled for termination protection.   Instance C and Instance D fail to terminate because at least one of the specified instances in us-east-1b (Instance C) is enabled for termination protection.   Terminated instances remain visible after termination (for approximately one hour). By default, Amazon EC2 deletes all EBS volumes that were attached when the instance launched. Volumes attached after instance launch continue running. You can stop, start, and terminate EBS-backed instances. You can only terminate instance store-backed instances. What happens to an instance differs if you stop it or terminate it. For example, when you stop an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, any attached EBS volumes with the DeleteOnTermination block device mapping parameter set to true are automatically deleted. For more information about the differences between stopping and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. For more information about troubleshooting, see Troubleshooting terminating your instance in the Amazon EC2 User Guide.
   */
  terminateInstances(params: EC2.Types.TerminateInstancesRequest, callback?: (err: AWSError, data: EC2.Types.TerminateInstancesResult) => void): Request<EC2.Types.TerminateInstancesResult, AWSError>;
  /**
   * Shuts down the specified instances. This operation is idempotent; if you terminate an instance more than once, each call succeeds.  If you specify multiple instances and the request fails (for example, because of a single incorrect instance ID), none of the instances are terminated. If you terminate multiple instances across multiple Availability Zones, and one or more of the specified instances are enabled for termination protection, the request fails with the following results:   The specified instances that are in the same Availability Zone as the protected instance are not terminated.   The specified instances that are in different Availability Zones, where no other specified instances are protected, are successfully terminated.   For example, say you have the following instances:   Instance A: us-east-1a; Not protected   Instance B: us-east-1a; Not protected   Instance C: us-east-1b; Protected   Instance D: us-east-1b; not protected   If you attempt to terminate all of these instances in the same request, the request reports failure with the following results:   Instance A and Instance B are successfully terminated because none of the specified instances in us-east-1a are enabled for termination protection.   Instance C and Instance D fail to terminate because at least one of the specified instances in us-east-1b (Instance C) is enabled for termination protection.   Terminated instances remain visible after termination (for approximately one hour). By default, Amazon EC2 deletes all EBS volumes that were attached when the instance launched. Volumes attached after instance launch continue running. You can stop, start, and terminate EBS-backed instances. You can only terminate instance store-backed instances. What happens to an instance differs if you stop it or terminate it. For example, when you stop an instance, the root device and any other devices attached to the instance persist. When you terminate an instance, any attached EBS volumes with the DeleteOnTermination block device mapping parameter set to true are automatically deleted. For more information about the differences between stopping and terminating instances, see Instance lifecycle in the Amazon EC2 User Guide. For more information about troubleshooting, see Troubleshooting terminating your instance in the Amazon EC2 User Guide.
   */
  terminateInstances(callback?: (err: AWSError, data: EC2.Types.TerminateInstancesResult) => void): Request<EC2.Types.TerminateInstancesResult, AWSError>;
  /**
   * Unassigns one or more IPv6 addresses IPv4 Prefix Delegation prefixes from a network interface.
   */
  unassignIpv6Addresses(params: EC2.Types.UnassignIpv6AddressesRequest, callback?: (err: AWSError, data: EC2.Types.UnassignIpv6AddressesResult) => void): Request<EC2.Types.UnassignIpv6AddressesResult, AWSError>;
  /**
   * Unassigns one or more IPv6 addresses IPv4 Prefix Delegation prefixes from a network interface.
   */
  unassignIpv6Addresses(callback?: (err: AWSError, data: EC2.Types.UnassignIpv6AddressesResult) => void): Request<EC2.Types.UnassignIpv6AddressesResult, AWSError>;
  /**
   * Unassigns one or more secondary private IP addresses, or IPv4 Prefix Delegation prefixes from a network interface.
   */
  unassignPrivateIpAddresses(params: EC2.Types.UnassignPrivateIpAddressesRequest, callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Unassigns one or more secondary private IP addresses, or IPv4 Prefix Delegation prefixes from a network interface.
   */
  unassignPrivateIpAddresses(callback?: (err: AWSError, data: {}) => void): Request<{}, AWSError>;
  /**
   * Unassigns secondary private IPv4 addresses from a private NAT gateway. You cannot unassign your primary private IP. For more information, see Edit secondary IP address associations in the Amazon Virtual Private Cloud User Guide. While unassigning is in progress, you cannot assign/unassign additional IP addresses while the connections are being drained. You are, however, allowed to delete the NAT gateway. A private IP address will only be released at the end of MaxDrainDurationSeconds. The private IP addresses stay associated and support the existing connections but do not support any new connections (new connections are distributed across the remaining assigned private IP address). After the existing connections drain out, the private IP addresses get released.   
   */
  unassignPrivateNatGatewayAddress(params: EC2.Types.UnassignPrivateNatGatewayAddressRequest, callback?: (err: AWSError, data: EC2.Types.UnassignPrivateNatGatewayAddressResult) => void): Request<EC2.Types.UnassignPrivateNatGatewayAddressResult, AWSError>;
  /**
   * Unassigns secondary private IPv4 addresses from a private NAT gateway. You cannot unassign your primary private IP. For more information, see Edit secondary IP address associations in the Amazon Virtual Private Cloud User Guide. While unassigning is in progress, you cannot assign/unassign additional IP addresses while the connections are being drained. You are, however, allowed to delete the NAT gateway. A private IP address will only be released at the end of MaxDrainDurationSeconds. The private IP addresses stay associated and support the existing connections but do not support any new connections (new connections are distributed across the remaining assigned private IP address). After the existing connections drain out, the private IP addresses get released.   
   */
  unassignPrivateNatGatewayAddress(callback?: (err: AWSError, data: EC2.Types.UnassignPrivateNatGatewayAddressResult) => void): Request<EC2.Types.UnassignPrivateNatGatewayAddressResult, AWSError>;
  /**
   * Disables detailed monitoring for a running instance. For more information, see Monitoring your instances and volumes in the Amazon EC2 User Guide.
   */
  unmonitorInstances(params: EC2.Types.UnmonitorInstancesRequest, callback?: (err: AWSError, data: EC2.Types.UnmonitorInstancesResult) => void): Request<EC2.Types.UnmonitorInstancesResult, AWSError>;
  /**
   * Disables detailed monitoring for a running instance. For more information, see Monitoring your instances and volumes in the Amazon EC2 User Guide.
   */
  unmonitorInstances(callback?: (err: AWSError, data: EC2.Types.UnmonitorInstancesResult) => void): Request<EC2.Types.UnmonitorInstancesResult, AWSError>;
  /**
   * [VPC only] Updates the description of an egress (outbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously. You can remove a description for a security group rule by omitting the description parameter in the request.
   */
  updateSecurityGroupRuleDescriptionsEgress(params: EC2.Types.UpdateSecurityGroupRuleDescriptionsEgressRequest, callback?: (err: AWSError, data: EC2.Types.UpdateSecurityGroupRuleDescriptionsEgressResult) => void): Request<EC2.Types.UpdateSecurityGroupRuleDescriptionsEgressResult, AWSError>;
  /**
   * [VPC only] Updates the description of an egress (outbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously. You can remove a description for a security group rule by omitting the description parameter in the request.
   */
  updateSecurityGroupRuleDescriptionsEgress(callback?: (err: AWSError, data: EC2.Types.UpdateSecurityGroupRuleDescriptionsEgressResult) => void): Request<EC2.Types.UpdateSecurityGroupRuleDescriptionsEgressResult, AWSError>;
  /**
   * Updates the description of an ingress (inbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously. You can remove a description for a security group rule by omitting the description parameter in the request.
   */
  updateSecurityGroupRuleDescriptionsIngress(params: EC2.Types.UpdateSecurityGroupRuleDescriptionsIngressRequest, callback?: (err: AWSError, data: EC2.Types.UpdateSecurityGroupRuleDescriptionsIngressResult) => void): Request<EC2.Types.UpdateSecurityGroupRuleDescriptionsIngressResult, AWSError>;
  /**
   * Updates the description of an ingress (inbound) security group rule. You can replace an existing description, or add a description to a rule that did not have one previously. You can remove a description for a security group rule by omitting the description parameter in the request.
   */
  updateSecurityGroupRuleDescriptionsIngress(callback?: (err: AWSError, data: EC2.Types.UpdateSecurityGroupRuleDescriptionsIngressResult) => void): Request<EC2.Types.UpdateSecurityGroupRuleDescriptionsIngressResult, AWSError>;
  /**
   * Stops advertising an address range that is provisioned as an address pool. You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. It can take a few minutes before traffic to the specified addresses stops routing to Amazon Web Services because of BGP propagation delays.
   */
  withdrawByoipCidr(params: EC2.Types.WithdrawByoipCidrRequest, callback?: (err: AWSError, data: EC2.Types.WithdrawByoipCidrResult) => void): Request<EC2.Types.WithdrawByoipCidrResult, AWSError>;
  /**
   * Stops advertising an address range that is provisioned as an address pool. You can perform this operation at most once every 10 seconds, even if you specify different address ranges each time. It can take a few minutes before traffic to the specified addresses stops routing to Amazon Web Services because of BGP propagation delays.
   */
  withdrawByoipCidr(callback?: (err: AWSError, data: EC2.Types.WithdrawByoipCidrResult) => void): Request<EC2.Types.WithdrawByoipCidrResult, AWSError>;
  /**
   * Waits for the instanceExists state by periodically calling the underlying EC2.describeInstancesoperation every 5 seconds (at most 40 times).
   */
  waitFor(state: "instanceExists", params: EC2.Types.DescribeInstancesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceExists state by periodically calling the underlying EC2.describeInstancesoperation every 5 seconds (at most 40 times).
   */
  waitFor(state: "instanceExists", callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the bundleTaskComplete state by periodically calling the underlying EC2.describeBundleTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "bundleTaskComplete", params: EC2.Types.DescribeBundleTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeBundleTasksResult) => void): Request<EC2.Types.DescribeBundleTasksResult, AWSError>;
  /**
   * Waits for the bundleTaskComplete state by periodically calling the underlying EC2.describeBundleTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "bundleTaskComplete", callback?: (err: AWSError, data: EC2.Types.DescribeBundleTasksResult) => void): Request<EC2.Types.DescribeBundleTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskCancelled state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskCancelled", params: EC2.Types.DescribeConversionTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskCancelled state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskCancelled", callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskCompleted state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskCompleted", params: EC2.Types.DescribeConversionTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskCompleted state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskCompleted", callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskDeleted state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskDeleted", params: EC2.Types.DescribeConversionTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the conversionTaskDeleted state by periodically calling the underlying EC2.describeConversionTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "conversionTaskDeleted", callback?: (err: AWSError, data: EC2.Types.DescribeConversionTasksResult) => void): Request<EC2.Types.DescribeConversionTasksResult, AWSError>;
  /**
   * Waits for the customerGatewayAvailable state by periodically calling the underlying EC2.describeCustomerGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "customerGatewayAvailable", params: EC2.Types.DescribeCustomerGatewaysRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeCustomerGatewaysResult) => void): Request<EC2.Types.DescribeCustomerGatewaysResult, AWSError>;
  /**
   * Waits for the customerGatewayAvailable state by periodically calling the underlying EC2.describeCustomerGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "customerGatewayAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeCustomerGatewaysResult) => void): Request<EC2.Types.DescribeCustomerGatewaysResult, AWSError>;
  /**
   * Waits for the exportTaskCancelled state by periodically calling the underlying EC2.describeExportTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "exportTaskCancelled", params: EC2.Types.DescribeExportTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Waits for the exportTaskCancelled state by periodically calling the underlying EC2.describeExportTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "exportTaskCancelled", callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Waits for the exportTaskCompleted state by periodically calling the underlying EC2.describeExportTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "exportTaskCompleted", params: EC2.Types.DescribeExportTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Waits for the exportTaskCompleted state by periodically calling the underlying EC2.describeExportTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "exportTaskCompleted", callback?: (err: AWSError, data: EC2.Types.DescribeExportTasksResult) => void): Request<EC2.Types.DescribeExportTasksResult, AWSError>;
  /**
   * Waits for the imageExists state by periodically calling the underlying EC2.describeImagesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "imageExists", params: EC2.Types.DescribeImagesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Waits for the imageExists state by periodically calling the underlying EC2.describeImagesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "imageExists", callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Waits for the imageAvailable state by periodically calling the underlying EC2.describeImagesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "imageAvailable", params: EC2.Types.DescribeImagesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Waits for the imageAvailable state by periodically calling the underlying EC2.describeImagesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "imageAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeImagesResult) => void): Request<EC2.Types.DescribeImagesResult, AWSError>;
  /**
   * Waits for the instanceRunning state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceRunning", params: EC2.Types.DescribeInstancesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceRunning state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceRunning", callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceStatusOk state by periodically calling the underlying EC2.describeInstanceStatusoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceStatusOk", params: EC2.Types.DescribeInstanceStatusRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Waits for the instanceStatusOk state by periodically calling the underlying EC2.describeInstanceStatusoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceStatusOk", callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Waits for the instanceStopped state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceStopped", params: EC2.Types.DescribeInstancesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceStopped state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceStopped", callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceTerminated state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceTerminated", params: EC2.Types.DescribeInstancesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the instanceTerminated state by periodically calling the underlying EC2.describeInstancesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "instanceTerminated", callback?: (err: AWSError, data: EC2.Types.DescribeInstancesResult) => void): Request<EC2.Types.DescribeInstancesResult, AWSError>;
  /**
   * Waits for the internetGatewayExists state by periodically calling the underlying EC2.describeInternetGatewaysoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "internetGatewayExists", params: EC2.Types.DescribeInternetGatewaysRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInternetGatewaysResult) => void): Request<EC2.Types.DescribeInternetGatewaysResult, AWSError>;
  /**
   * Waits for the internetGatewayExists state by periodically calling the underlying EC2.describeInternetGatewaysoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "internetGatewayExists", callback?: (err: AWSError, data: EC2.Types.DescribeInternetGatewaysResult) => void): Request<EC2.Types.DescribeInternetGatewaysResult, AWSError>;
  /**
   * Waits for the keyPairExists state by periodically calling the underlying EC2.describeKeyPairsoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "keyPairExists", params: EC2.Types.DescribeKeyPairsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeKeyPairsResult) => void): Request<EC2.Types.DescribeKeyPairsResult, AWSError>;
  /**
   * Waits for the keyPairExists state by periodically calling the underlying EC2.describeKeyPairsoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "keyPairExists", callback?: (err: AWSError, data: EC2.Types.DescribeKeyPairsResult) => void): Request<EC2.Types.DescribeKeyPairsResult, AWSError>;
  /**
   * Waits for the natGatewayAvailable state by periodically calling the underlying EC2.describeNatGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "natGatewayAvailable", params: EC2.Types.DescribeNatGatewaysRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Waits for the natGatewayAvailable state by periodically calling the underlying EC2.describeNatGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "natGatewayAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Waits for the natGatewayDeleted state by periodically calling the underlying EC2.describeNatGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "natGatewayDeleted", params: EC2.Types.DescribeNatGatewaysRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Waits for the natGatewayDeleted state by periodically calling the underlying EC2.describeNatGatewaysoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "natGatewayDeleted", callback?: (err: AWSError, data: EC2.Types.DescribeNatGatewaysResult) => void): Request<EC2.Types.DescribeNatGatewaysResult, AWSError>;
  /**
   * Waits for the networkInterfaceAvailable state by periodically calling the underlying EC2.describeNetworkInterfacesoperation every 20 seconds (at most 10 times).
   */
  waitFor(state: "networkInterfaceAvailable", params: EC2.Types.DescribeNetworkInterfacesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacesResult) => void): Request<EC2.Types.DescribeNetworkInterfacesResult, AWSError>;
  /**
   * Waits for the networkInterfaceAvailable state by periodically calling the underlying EC2.describeNetworkInterfacesoperation every 20 seconds (at most 10 times).
   */
  waitFor(state: "networkInterfaceAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeNetworkInterfacesResult) => void): Request<EC2.Types.DescribeNetworkInterfacesResult, AWSError>;
  /**
   * Waits for the passwordDataAvailable state by periodically calling the underlying EC2.getPasswordDataoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "passwordDataAvailable", params: EC2.Types.GetPasswordDataRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.GetPasswordDataResult) => void): Request<EC2.Types.GetPasswordDataResult, AWSError>;
  /**
   * Waits for the passwordDataAvailable state by periodically calling the underlying EC2.getPasswordDataoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "passwordDataAvailable", callback?: (err: AWSError, data: EC2.Types.GetPasswordDataResult) => void): Request<EC2.Types.GetPasswordDataResult, AWSError>;
  /**
   * Waits for the snapshotCompleted state by periodically calling the underlying EC2.describeSnapshotsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "snapshotCompleted", params: EC2.Types.DescribeSnapshotsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotsResult) => void): Request<EC2.Types.DescribeSnapshotsResult, AWSError>;
  /**
   * Waits for the snapshotCompleted state by periodically calling the underlying EC2.describeSnapshotsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "snapshotCompleted", callback?: (err: AWSError, data: EC2.Types.DescribeSnapshotsResult) => void): Request<EC2.Types.DescribeSnapshotsResult, AWSError>;
  /**
   * Waits for the snapshotImported state by periodically calling the underlying EC2.describeImportSnapshotTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "snapshotImported", params: EC2.Types.DescribeImportSnapshotTasksRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeImportSnapshotTasksResult) => void): Request<EC2.Types.DescribeImportSnapshotTasksResult, AWSError>;
  /**
   * Waits for the snapshotImported state by periodically calling the underlying EC2.describeImportSnapshotTasksoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "snapshotImported", callback?: (err: AWSError, data: EC2.Types.DescribeImportSnapshotTasksResult) => void): Request<EC2.Types.DescribeImportSnapshotTasksResult, AWSError>;
  /**
   * Waits for the securityGroupExists state by periodically calling the underlying EC2.describeSecurityGroupsoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "securityGroupExists", params: EC2.Types.DescribeSecurityGroupsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupsResult) => void): Request<EC2.Types.DescribeSecurityGroupsResult, AWSError>;
  /**
   * Waits for the securityGroupExists state by periodically calling the underlying EC2.describeSecurityGroupsoperation every 5 seconds (at most 6 times).
   */
  waitFor(state: "securityGroupExists", callback?: (err: AWSError, data: EC2.Types.DescribeSecurityGroupsResult) => void): Request<EC2.Types.DescribeSecurityGroupsResult, AWSError>;
  /**
   * Waits for the spotInstanceRequestFulfilled state by periodically calling the underlying EC2.describeSpotInstanceRequestsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "spotInstanceRequestFulfilled", params: EC2.Types.DescribeSpotInstanceRequestsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeSpotInstanceRequestsResult) => void): Request<EC2.Types.DescribeSpotInstanceRequestsResult, AWSError>;
  /**
   * Waits for the spotInstanceRequestFulfilled state by periodically calling the underlying EC2.describeSpotInstanceRequestsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "spotInstanceRequestFulfilled", callback?: (err: AWSError, data: EC2.Types.DescribeSpotInstanceRequestsResult) => void): Request<EC2.Types.DescribeSpotInstanceRequestsResult, AWSError>;
  /**
   * Waits for the subnetAvailable state by periodically calling the underlying EC2.describeSubnetsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "subnetAvailable", params: EC2.Types.DescribeSubnetsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeSubnetsResult) => void): Request<EC2.Types.DescribeSubnetsResult, AWSError>;
  /**
   * Waits for the subnetAvailable state by periodically calling the underlying EC2.describeSubnetsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "subnetAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeSubnetsResult) => void): Request<EC2.Types.DescribeSubnetsResult, AWSError>;
  /**
   * Waits for the systemStatusOk state by periodically calling the underlying EC2.describeInstanceStatusoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "systemStatusOk", params: EC2.Types.DescribeInstanceStatusRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Waits for the systemStatusOk state by periodically calling the underlying EC2.describeInstanceStatusoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "systemStatusOk", callback?: (err: AWSError, data: EC2.Types.DescribeInstanceStatusResult) => void): Request<EC2.Types.DescribeInstanceStatusResult, AWSError>;
  /**
   * Waits for the volumeAvailable state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeAvailable", params: EC2.Types.DescribeVolumesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the volumeAvailable state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the volumeDeleted state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeDeleted", params: EC2.Types.DescribeVolumesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the volumeDeleted state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeDeleted", callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the volumeInUse state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeInUse", params: EC2.Types.DescribeVolumesRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the volumeInUse state by periodically calling the underlying EC2.describeVolumesoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "volumeInUse", callback?: (err: AWSError, data: EC2.Types.DescribeVolumesResult) => void): Request<EC2.Types.DescribeVolumesResult, AWSError>;
  /**
   * Waits for the vpcAvailable state by periodically calling the underlying EC2.describeVpcsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcAvailable", params: EC2.Types.DescribeVpcsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Waits for the vpcAvailable state by periodically calling the underlying EC2.describeVpcsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Waits for the vpcExists state by periodically calling the underlying EC2.describeVpcsoperation every 1 seconds (at most 5 times).
   */
  waitFor(state: "vpcExists", params: EC2.Types.DescribeVpcsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Waits for the vpcExists state by periodically calling the underlying EC2.describeVpcsoperation every 1 seconds (at most 5 times).
   */
  waitFor(state: "vpcExists", callback?: (err: AWSError, data: EC2.Types.DescribeVpcsResult) => void): Request<EC2.Types.DescribeVpcsResult, AWSError>;
  /**
   * Waits for the vpnConnectionAvailable state by periodically calling the underlying EC2.describeVpnConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpnConnectionAvailable", params: EC2.Types.DescribeVpnConnectionsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Waits for the vpnConnectionAvailable state by periodically calling the underlying EC2.describeVpnConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpnConnectionAvailable", callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Waits for the vpnConnectionDeleted state by periodically calling the underlying EC2.describeVpnConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpnConnectionDeleted", params: EC2.Types.DescribeVpnConnectionsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Waits for the vpnConnectionDeleted state by periodically calling the underlying EC2.describeVpnConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpnConnectionDeleted", callback?: (err: AWSError, data: EC2.Types.DescribeVpnConnectionsResult) => void): Request<EC2.Types.DescribeVpnConnectionsResult, AWSError>;
  /**
   * Waits for the vpcPeeringConnectionExists state by periodically calling the underlying EC2.describeVpcPeeringConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcPeeringConnectionExists", params: EC2.Types.DescribeVpcPeeringConnectionsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
  /**
   * Waits for the vpcPeeringConnectionExists state by periodically calling the underlying EC2.describeVpcPeeringConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcPeeringConnectionExists", callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
  /**
   * Waits for the vpcPeeringConnectionDeleted state by periodically calling the underlying EC2.describeVpcPeeringConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcPeeringConnectionDeleted", params: EC2.Types.DescribeVpcPeeringConnectionsRequest & {$waiter?: WaiterConfiguration}, callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
  /**
   * Waits for the vpcPeeringConnectionDeleted state by periodically calling the underlying EC2.describeVpcPeeringConnectionsoperation every 15 seconds (at most 40 times).
   */
  waitFor(state: "vpcPeeringConnectionDeleted", callback?: (err: AWSError, data: EC2.Types.DescribeVpcPeeringConnectionsResult) => void): Request<EC2.Types.DescribeVpcPeeringConnectionsResult, AWSError>;
}
declare namespace EC2 {
  export interface AcceleratorCount {
    /**
     * The minimum number of accelerators. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum number of accelerators. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface AcceleratorCountRequest {
    /**
     * The minimum number of accelerators. To specify no minimum limit, omit this parameter.
     */
    Min?: Integer;
    /**
     * The maximum number of accelerators. To specify no maximum limit, omit this parameter. To exclude accelerator-enabled instance types, set Max to 0.
     */
    Max?: Integer;
  }
  export type AcceleratorManufacturer = "nvidia"|"amd"|"amazon-web-services"|"xilinx"|string;
  export type AcceleratorManufacturerSet = AcceleratorManufacturer[];
  export type AcceleratorName = "a100"|"v100"|"k80"|"t4"|"m60"|"radeon-pro-v520"|"vu9p"|"inferentia"|"k520"|string;
  export type AcceleratorNameSet = AcceleratorName[];
  export interface AcceleratorTotalMemoryMiB {
    /**
     * The minimum amount of accelerator memory, in MiB. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum amount of accelerator memory, in MiB. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface AcceleratorTotalMemoryMiBRequest {
    /**
     * The minimum amount of accelerator memory, in MiB. To specify no minimum limit, omit this parameter.
     */
    Min?: Integer;
    /**
     * The maximum amount of accelerator memory, in MiB. To specify no maximum limit, omit this parameter.
     */
    Max?: Integer;
  }
  export type AcceleratorType = "gpu"|"fpga"|"inference"|string;
  export type AcceleratorTypeSet = AcceleratorType[];
  export interface AcceptAddressTransferRequest {
    /**
     * The Elastic IP address you are accepting for transfer.
     */
    Address: String;
    /**
     *  tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AcceptAddressTransferResult {
    /**
     * An Elastic IP address transfer.
     */
    AddressTransfer?: AddressTransfer;
  }
  export interface AcceptReservedInstancesExchangeQuoteRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the Convertible Reserved Instances to exchange for another Convertible Reserved Instance of the same or higher value.
     */
    ReservedInstanceIds: ReservedInstanceIdSet;
    /**
     * The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
     */
    TargetConfigurations?: TargetConfigurationRequestSet;
  }
  export interface AcceptReservedInstancesExchangeQuoteResult {
    /**
     * The ID of the successful exchange.
     */
    ExchangeId?: String;
  }
  export interface AcceptTransitGatewayMulticastDomainAssociationsRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: TransitGatewayMulticastDomainId;
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The IDs of the subnets to associate with the transit gateway multicast domain.
     */
    SubnetIds?: ValueStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AcceptTransitGatewayMulticastDomainAssociationsResult {
    /**
     * Information about the multicast domain associations.
     */
    Associations?: TransitGatewayMulticastDomainAssociations;
  }
  export interface AcceptTransitGatewayPeeringAttachmentRequest {
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AcceptTransitGatewayPeeringAttachmentResult {
    /**
     * The transit gateway peering attachment.
     */
    TransitGatewayPeeringAttachment?: TransitGatewayPeeringAttachment;
  }
  export interface AcceptTransitGatewayVpcAttachmentRequest {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AcceptTransitGatewayVpcAttachmentResult {
    /**
     * The VPC attachment.
     */
    TransitGatewayVpcAttachment?: TransitGatewayVpcAttachment;
  }
  export interface AcceptVpcEndpointConnectionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC endpoint service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * The IDs of the interface VPC endpoints.
     */
    VpcEndpointIds: VpcEndpointIdList;
  }
  export interface AcceptVpcEndpointConnectionsResult {
    /**
     * Information about the interface endpoints that were not accepted, if applicable.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface AcceptVpcPeeringConnectionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC peering connection. You must specify this parameter in the request.
     */
    VpcPeeringConnectionId: VpcPeeringConnectionIdWithResolver;
  }
  export interface AcceptVpcPeeringConnectionResult {
    /**
     * Information about the VPC peering connection.
     */
    VpcPeeringConnection?: VpcPeeringConnection;
  }
  export interface AccessScopeAnalysisFinding {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId?: NetworkInsightsAccessScopeAnalysisId;
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
    /**
     * The ID of the finding.
     */
    FindingId?: String;
    /**
     * The finding components.
     */
    FindingComponents?: PathComponentList;
  }
  export type AccessScopeAnalysisFindingList = AccessScopeAnalysisFinding[];
  export interface AccessScopePath {
    /**
     * The source.
     */
    Source?: PathStatement;
    /**
     * The destination.
     */
    Destination?: PathStatement;
    /**
     * The through resources.
     */
    ThroughResources?: ThroughResourcesStatementList;
  }
  export type AccessScopePathList = AccessScopePath[];
  export type AccessScopePathListRequest = AccessScopePathRequest[];
  export interface AccessScopePathRequest {
    /**
     * The source.
     */
    Source?: PathStatementRequest;
    /**
     * The destination.
     */
    Destination?: PathStatementRequest;
    /**
     * The through resources.
     */
    ThroughResources?: ThroughResourcesStatementRequestList;
  }
  export interface AccountAttribute {
    /**
     * The name of the account attribute.
     */
    AttributeName?: String;
    /**
     * The values for the account attribute.
     */
    AttributeValues?: AccountAttributeValueList;
  }
  export type AccountAttributeList = AccountAttribute[];
  export type AccountAttributeName = "supported-platforms"|"default-vpc"|string;
  export type AccountAttributeNameStringList = AccountAttributeName[];
  export interface AccountAttributeValue {
    /**
     * The value of the attribute.
     */
    AttributeValue?: String;
  }
  export type AccountAttributeValueList = AccountAttributeValue[];
  export interface ActiveInstance {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The instance type.
     */
    InstanceType?: String;
    /**
     * The ID of the Spot Instance request.
     */
    SpotInstanceRequestId?: String;
    /**
     * The health status of the instance. If the status of either the instance status check or the system status check is impaired, the health status of the instance is unhealthy. Otherwise, the health status is healthy.
     */
    InstanceHealth?: InstanceHealthStatus;
  }
  export type ActiveInstanceSet = ActiveInstance[];
  export type ActivityStatus = "error"|"pending_fulfillment"|"pending_termination"|"fulfilled"|string;
  export interface AddIpamOperatingRegion {
    /**
     * The name of the operating Region.
     */
    RegionName?: String;
  }
  export type AddIpamOperatingRegionSet = AddIpamOperatingRegion[];
  export type AddPrefixListEntries = AddPrefixListEntry[];
  export interface AddPrefixListEntry {
    /**
     * The CIDR block.
     */
    Cidr: String;
    /**
     * A description for the entry. Constraints: Up to 255 characters in length.
     */
    Description?: String;
  }
  export interface AddedPrincipal {
    /**
     * The type of principal.
     */
    PrincipalType?: PrincipalType;
    /**
     * The Amazon Resource Name (ARN) of the principal.
     */
    Principal?: String;
    /**
     * The ID of the service permission.
     */
    ServicePermissionId?: String;
    /**
     * The ID of the service.
     */
    ServiceId?: String;
  }
  export type AddedPrincipalSet = AddedPrincipal[];
  export interface AdditionalDetail {
    /**
     * The additional detail code.
     */
    AdditionalDetailType?: String;
    /**
     * The path component.
     */
    Component?: AnalysisComponent;
    /**
     * The VPC endpoint service.
     */
    VpcEndpointService?: AnalysisComponent;
    /**
     * The rule options.
     */
    RuleOptions?: RuleOptionList;
    /**
     * The rule group type.
     */
    RuleGroupTypePairs?: RuleGroupTypePairList;
    /**
     * The rule options.
     */
    RuleGroupRuleOptionsPairs?: RuleGroupRuleOptionsPairList;
    /**
     * The name of the VPC endpoint service.
     */
    ServiceName?: String;
    /**
     * The load balancers.
     */
    LoadBalancers?: AnalysisComponentList;
  }
  export type AdditionalDetailList = AdditionalDetail[];
  export interface Address {
    /**
     * The ID of the instance that the address is associated with (if any).
     */
    InstanceId?: String;
    /**
     * The Elastic IP address.
     */
    PublicIp?: String;
    /**
     * The ID representing the allocation of the address for use with EC2-VPC.
     */
    AllocationId?: String;
    /**
     * The ID representing the association of the address with an instance in a VPC.
     */
    AssociationId?: String;
    /**
     * Indicates whether this Elastic IP address is for use with instances in EC2-Classic (standard) or instances in a VPC (vpc).
     */
    Domain?: DomainType;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the network interface.
     */
    NetworkInterfaceOwnerId?: String;
    /**
     * The private IP address associated with the Elastic IP address.
     */
    PrivateIpAddress?: String;
    /**
     * Any tags assigned to the Elastic IP address.
     */
    Tags?: TagList;
    /**
     * The ID of an address pool.
     */
    PublicIpv4Pool?: String;
    /**
     * The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
     */
    NetworkBorderGroup?: String;
    /**
     * The customer-owned IP address.
     */
    CustomerOwnedIp?: String;
    /**
     * The ID of the customer-owned address pool.
     */
    CustomerOwnedIpv4Pool?: String;
    /**
     * The carrier IP address associated. This option is only available for network interfaces which reside in a subnet in a Wavelength Zone (for example an EC2 instance). 
     */
    CarrierIp?: String;
  }
  export interface AddressAttribute {
    /**
     * The public IP address.
     */
    PublicIp?: PublicIpAddress;
    /**
     * [EC2-VPC] The allocation ID.
     */
    AllocationId?: AllocationId;
    /**
     * The pointer (PTR) record for the IP address.
     */
    PtrRecord?: String;
    /**
     * The updated PTR record for the IP address.
     */
    PtrRecordUpdate?: PtrUpdateStatus;
  }
  export type AddressAttributeName = "domain-name"|string;
  export type AddressFamily = "ipv4"|"ipv6"|string;
  export type AddressList = Address[];
  export type AddressMaxResults = number;
  export type AddressSet = AddressAttribute[];
  export interface AddressTransfer {
    /**
     * The Elastic IP address being transferred.
     */
    PublicIp?: String;
    /**
     * The allocation ID of an Elastic IP address.
     */
    AllocationId?: String;
    /**
     * The ID of the account that you want to transfer the Elastic IP address to.
     */
    TransferAccountId?: String;
    /**
     * The timestamp when the Elastic IP address transfer expired. When the source account starts the transfer, the transfer account has seven hours to allocate the Elastic IP address to complete the transfer, or the Elastic IP address will return to its original owner.
     */
    TransferOfferExpirationTimestamp?: MillisecondDateTime;
    /**
     * The timestamp when the Elastic IP address transfer was accepted.
     */
    TransferOfferAcceptedTimestamp?: MillisecondDateTime;
    /**
     * The Elastic IP address transfer status.
     */
    AddressTransferStatus?: AddressTransferStatus;
  }
  export type AddressTransferList = AddressTransfer[];
  export type AddressTransferStatus = "pending"|"disabled"|"accepted"|string;
  export interface AdvertiseByoipCidrRequest {
    /**
     * The address range, in CIDR notation. This must be the exact range that you provisioned. You can't advertise only a portion of the provisioned range.
     */
    Cidr: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AdvertiseByoipCidrResult {
    /**
     * Information about the address range.
     */
    ByoipCidr?: ByoipCidr;
  }
  export type Affinity = "default"|"host"|string;
  export interface AllocateAddressRequest {
    /**
     * Indicates whether the Elastic IP address is for use with instances in a VPC or instances in EC2-Classic. Default: If the Region supports EC2-Classic, the default is standard. Otherwise, the default is vpc.
     */
    Domain?: DomainType;
    /**
     * [EC2-VPC] The Elastic IP address to recover or an IPv4 address from an address pool.
     */
    Address?: PublicIpAddress;
    /**
     * The ID of an address pool that you own. Use this parameter to let Amazon EC2 select an address from the address pool. To specify a specific address from the address pool, use the Address parameter instead.
     */
    PublicIpv4Pool?: Ipv4PoolEc2Id;
    /**
     *  A unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses. Use this parameter to limit the IP address to this location. IP addresses cannot move between network border groups. Use DescribeAvailabilityZones to view the network border groups. You cannot use a network border group with EC2 Classic. If you attempt this operation on EC2 Classic, you receive an InvalidParameterCombination error.
     */
    NetworkBorderGroup?: String;
    /**
     * The ID of a customer-owned address pool. Use this parameter to let Amazon EC2 select an address from the address pool. Alternatively, specify a specific address from the address pool.
     */
    CustomerOwnedIpv4Pool?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to assign to the Elastic IP address.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface AllocateAddressResult {
    /**
     * The Elastic IP address.
     */
    PublicIp?: String;
    /**
     * [EC2-VPC] The ID that Amazon Web Services assigns to represent the allocation of the Elastic IP address for use with instances in a VPC.
     */
    AllocationId?: String;
    /**
     * The ID of an address pool.
     */
    PublicIpv4Pool?: String;
    /**
     * The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses.
     */
    NetworkBorderGroup?: String;
    /**
     * Indicates whether the Elastic IP address is for use with instances in a VPC (vpc) or instances in EC2-Classic (standard).
     */
    Domain?: DomainType;
    /**
     * The customer-owned IP address.
     */
    CustomerOwnedIp?: String;
    /**
     * The ID of the customer-owned address pool.
     */
    CustomerOwnedIpv4Pool?: String;
    /**
     * The carrier IP address. This option is only available for network interfaces which reside in a subnet in a Wavelength Zone (for example an EC2 instance). 
     */
    CarrierIp?: String;
  }
  export interface AllocateHostsRequest {
    /**
     * Indicates whether the host accepts any untargeted instance launches that match its instance type configuration, or if it only accepts Host tenancy instance launches that specify its unique host ID. For more information, see  Understanding auto-placement and affinity in the Amazon EC2 User Guide. Default: on 
     */
    AutoPlacement?: AutoPlacement;
    /**
     * The Availability Zone in which to allocate the Dedicated Host.
     */
    AvailabilityZone: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Specifies the instance type to be supported by the Dedicated Hosts. If you specify an instance type, the Dedicated Hosts support instances of the specified instance type only. If you want the Dedicated Hosts to support multiple instance types in a specific instance family, omit this parameter and specify InstanceFamily instead. You cannot specify InstanceType and InstanceFamily in the same request.
     */
    InstanceType?: String;
    /**
     * Specifies the instance family to be supported by the Dedicated Hosts. If you specify an instance family, the Dedicated Hosts support multiple instance types within that instance family. If you want the Dedicated Hosts to support a specific instance type only, omit this parameter and specify InstanceType instead. You cannot specify InstanceFamily and InstanceType in the same request.
     */
    InstanceFamily?: String;
    /**
     * The number of Dedicated Hosts to allocate to your account with these parameters.
     */
    Quantity: Integer;
    /**
     * The tags to apply to the Dedicated Host during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Indicates whether to enable or disable host recovery for the Dedicated Host. Host recovery is disabled by default. For more information, see  Host recovery in the Amazon EC2 User Guide. Default: off 
     */
    HostRecovery?: HostRecovery;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which to allocate the Dedicated Host.
     */
    OutpostArn?: String;
    /**
     * Indicates whether to enable or disable host maintenance for the Dedicated Host. For more information, see Host maintenance in the Amazon EC2 User Guide.
     */
    HostMaintenance?: HostMaintenance;
  }
  export interface AllocateHostsResult {
    /**
     * The ID of the allocated Dedicated Host. This is used to launch an instance onto a specific host.
     */
    HostIds?: ResponseHostIdList;
  }
  export interface AllocateIpamPoolCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool from which you would like to allocate a CIDR.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The CIDR you would like to allocate from the IPAM pool. Note the following:   If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.   If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.   Possible values: Any available IPv4 or IPv6 CIDR.
     */
    Cidr?: String;
    /**
     * The netmask length of the CIDR you would like to allocate from the IPAM pool. Note the following:   If there is no DefaultNetmaskLength allocation rule set on the pool, you must specify either the NetmaskLength or the CIDR.   If the DefaultNetmaskLength allocation rule is set on the pool, you can specify either the NetmaskLength or the CIDR and the DefaultNetmaskLength allocation rule will be ignored.   Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.
     */
    NetmaskLength?: Integer;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * A description for the allocation.
     */
    Description?: String;
    /**
     * A preview of the next available CIDR in a pool.
     */
    PreviewNextCidr?: Boolean;
    /**
     * Exclude a particular CIDR range from being returned by the pool. Disallowed CIDRs are only allowed if using netmask length for allocation.
     */
    DisallowedCidrs?: IpamPoolAllocationDisallowedCidrs;
  }
  export interface AllocateIpamPoolCidrResult {
    /**
     * Information about the allocation created.
     */
    IpamPoolAllocation?: IpamPoolAllocation;
  }
  export type AllocationId = string;
  export type AllocationIdList = AllocationId[];
  export type AllocationIds = AllocationId[];
  export type AllocationState = "available"|"under-assessment"|"permanent-failure"|"released"|"released-permanent-failure"|"pending"|string;
  export type AllocationStrategy = "lowestPrice"|"diversified"|"capacityOptimized"|"capacityOptimizedPrioritized"|"priceCapacityOptimized"|string;
  export type AllocationType = "used"|string;
  export type AllowedInstanceType = string;
  export type AllowedInstanceTypeSet = AllowedInstanceType[];
  export interface AllowedPrincipal {
    /**
     * The type of principal.
     */
    PrincipalType?: PrincipalType;
    /**
     * The Amazon Resource Name (ARN) of the principal.
     */
    Principal?: String;
    /**
     * The ID of the service permission.
     */
    ServicePermissionId?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
    /**
     * The ID of the service.
     */
    ServiceId?: String;
  }
  export type AllowedPrincipalSet = AllowedPrincipal[];
  export type AllowsMultipleInstanceTypes = "on"|"off"|string;
  export interface AlternatePathHint {
    /**
     * The ID of the component.
     */
    ComponentId?: String;
    /**
     * The Amazon Resource Name (ARN) of the component.
     */
    ComponentArn?: String;
  }
  export type AlternatePathHintList = AlternatePathHint[];
  export interface AnalysisAclRule {
    /**
     * The IPv4 address range, in CIDR notation.
     */
    Cidr?: String;
    /**
     * Indicates whether the rule is an outbound rule.
     */
    Egress?: Boolean;
    /**
     * The range of ports.
     */
    PortRange?: PortRange;
    /**
     * The protocol.
     */
    Protocol?: String;
    /**
     * Indicates whether to allow or deny traffic that matches the rule.
     */
    RuleAction?: String;
    /**
     * The rule number.
     */
    RuleNumber?: Integer;
  }
  export interface AnalysisComponent {
    /**
     * The ID of the component.
     */
    Id?: String;
    /**
     * The Amazon Resource Name (ARN) of the component.
     */
    Arn?: String;
    /**
     * The name of the analysis component.
     */
    Name?: String;
  }
  export type AnalysisComponentList = AnalysisComponent[];
  export interface AnalysisLoadBalancerListener {
    /**
     * The port on which the load balancer is listening.
     */
    LoadBalancerPort?: Port;
    /**
     * [Classic Load Balancers] The back-end port for the listener.
     */
    InstancePort?: Port;
  }
  export interface AnalysisLoadBalancerTarget {
    /**
     * The IP address.
     */
    Address?: IpAddress;
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * Information about the instance.
     */
    Instance?: AnalysisComponent;
    /**
     * The port on which the target is listening.
     */
    Port?: Port;
  }
  export interface AnalysisPacketHeader {
    /**
     * The destination addresses.
     */
    DestinationAddresses?: IpAddressList;
    /**
     * The destination port ranges.
     */
    DestinationPortRanges?: PortRangeList;
    /**
     * The protocol.
     */
    Protocol?: String;
    /**
     * The source addresses.
     */
    SourceAddresses?: IpAddressList;
    /**
     * The source port ranges.
     */
    SourcePortRanges?: PortRangeList;
  }
  export interface AnalysisRouteTableRoute {
    /**
     * The destination IPv4 address, in CIDR notation.
     */
    DestinationCidr?: String;
    /**
     * The prefix of the Amazon Web Service.
     */
    DestinationPrefixListId?: String;
    /**
     * The ID of an egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId?: String;
    /**
     * The ID of the gateway, such as an internet gateway or virtual private gateway.
     */
    GatewayId?: String;
    /**
     * The ID of the instance, such as a NAT instance.
     */
    InstanceId?: String;
    /**
     * The ID of a NAT gateway.
     */
    NatGatewayId?: String;
    /**
     * The ID of a network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * Describes how the route was created. The following are the possible values:   CreateRouteTable - The route was automatically created when the route table was created.   CreateRoute - The route was manually added to the route table.   EnableVgwRoutePropagation - The route was propagated by route propagation.  
     */
    Origin?: String;
    /**
     * The ID of a transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The ID of a VPC peering connection.
     */
    VpcPeeringConnectionId?: String;
    /**
     * The state. The following are the possible values:   active   blackhole  
     */
    State?: String;
    /**
     * The ID of a carrier gateway.
     */
    CarrierGatewayId?: String;
    /**
     * The Amazon Resource Name (ARN) of a core network.
     */
    CoreNetworkArn?: ResourceArn;
    /**
     * The ID of a local gateway.
     */
    LocalGatewayId?: String;
  }
  export interface AnalysisSecurityGroupRule {
    /**
     * The IPv4 address range, in CIDR notation.
     */
    Cidr?: String;
    /**
     * The direction. The following are the possible values:   egress   ingress  
     */
    Direction?: String;
    /**
     * The security group ID.
     */
    SecurityGroupId?: String;
    /**
     * The port range.
     */
    PortRange?: PortRange;
    /**
     * The prefix list ID.
     */
    PrefixListId?: String;
    /**
     * The protocol name.
     */
    Protocol?: String;
  }
  export type AnalysisStatus = "running"|"succeeded"|"failed"|string;
  export type ApplianceModeSupportValue = "enable"|"disable"|string;
  export interface ApplySecurityGroupsToClientVpnTargetNetworkRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ID of the VPC in which the associated target network is located.
     */
    VpcId: VpcId;
    /**
     * The IDs of the security groups to apply to the associated target network. Up to 5 security groups can be applied to an associated target network.
     */
    SecurityGroupIds: ClientVpnSecurityGroupIdSet;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ApplySecurityGroupsToClientVpnTargetNetworkResult {
    /**
     * The IDs of the applied security groups.
     */
    SecurityGroupIds?: ClientVpnSecurityGroupIdSet;
  }
  export type ArchitectureType = "i386"|"x86_64"|"arm64"|"x86_64_mac"|"arm64_mac"|string;
  export type ArchitectureTypeList = ArchitectureType[];
  export type ArchitectureTypeSet = ArchitectureType[];
  export type ArchitectureValues = "i386"|"x86_64"|"arm64"|"x86_64_mac"|"arm64_mac"|string;
  export type ArnList = ResourceArn[];
  export interface AssignIpv6AddressesRequest {
    /**
     * The number of additional IPv6 addresses to assign to the network interface. The specified number of IPv6 addresses are assigned in addition to the existing IPv6 addresses that are already assigned to the network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses.
     */
    Ipv6AddressCount?: Integer;
    /**
     * The IPv6 addresses to be assigned to the network interface. You can't use this option if you're specifying a number of IPv6 addresses.
     */
    Ipv6Addresses?: Ipv6AddressList;
    /**
     * The number of IPv6 prefixes that Amazon Web Services automatically assigns to the network interface. You cannot use this option if you use the Ipv6Prefixes option.
     */
    Ipv6PrefixCount?: Integer;
    /**
     * One or more IPv6 prefixes assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option.
     */
    Ipv6Prefixes?: IpPrefixList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
  }
  export interface AssignIpv6AddressesResult {
    /**
     * The new IPv6 addresses assigned to the network interface. Existing IPv6 addresses that were assigned to the network interface before the request are not included.
     */
    AssignedIpv6Addresses?: Ipv6AddressList;
    /**
     * The IPv6 prefixes that are assigned to the network interface.
     */
    AssignedIpv6Prefixes?: IpPrefixList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
  }
  export interface AssignPrivateIpAddressesRequest {
    /**
     * Indicates whether to allow an IP address that is already assigned to another network interface or instance to be reassigned to the specified network interface.
     */
    AllowReassignment?: Boolean;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The IP addresses to be assigned as a secondary private IP address to the network interface. You can't specify this parameter when also specifying a number of secondary IP addresses. If you don't specify an IP address, Amazon EC2 automatically selects an IP address within the subnet range.
     */
    PrivateIpAddresses?: PrivateIpAddressStringList;
    /**
     * The number of secondary IP addresses to assign to the network interface. You can't specify this parameter when also specifying private IP addresses.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * One or more IPv4 prefixes assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option.
     */
    Ipv4Prefixes?: IpPrefixList;
    /**
     * The number of IPv4 prefixes that Amazon Web Services automatically assigns to the network interface. You cannot use this option if you use the Ipv4 Prefixes option.
     */
    Ipv4PrefixCount?: Integer;
  }
  export interface AssignPrivateIpAddressesResult {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The private IP addresses assigned to the network interface.
     */
    AssignedPrivateIpAddresses?: AssignedPrivateIpAddressList;
    /**
     * The IPv4 prefixes that are assigned to the network interface.
     */
    AssignedIpv4Prefixes?: Ipv4PrefixesList;
  }
  export interface AssignPrivateNatGatewayAddressRequest {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId: NatGatewayId;
    /**
     * The private IPv4 addresses you want to assign to the private NAT gateway.
     */
    PrivateIpAddresses?: IpList;
    /**
     * The number of private IP addresses to assign to the NAT gateway. You can't specify this parameter when also specifying private IP addresses.
     */
    PrivateIpAddressCount?: PrivateIpAddressCount;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssignPrivateNatGatewayAddressResult {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * NAT gateway IP addresses.
     */
    NatGatewayAddresses?: NatGatewayAddressList;
  }
  export interface AssignedPrivateIpAddress {
    /**
     * The private IP address assigned to the network interface.
     */
    PrivateIpAddress?: String;
  }
  export type AssignedPrivateIpAddressList = AssignedPrivateIpAddress[];
  export interface AssociateAddressRequest {
    /**
     * [EC2-VPC] The allocation ID. This is required for EC2-VPC.
     */
    AllocationId?: AllocationId;
    /**
     * The ID of the instance. The instance must have exactly one attached network interface. For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both. For EC2-Classic, you must specify an instance ID and the instance must be in the running state.
     */
    InstanceId?: InstanceId;
    /**
     * [EC2-Classic] The Elastic IP address to associate with the instance. This is required for EC2-Classic.
     */
    PublicIp?: EipAllocationPublicIp;
    /**
     * [EC2-VPC] For a VPC in an EC2-Classic account, specify true to allow an Elastic IP address that is already associated with an instance or network interface to be reassociated with the specified instance or network interface. Otherwise, the operation fails. In a VPC in an EC2-VPC-only account, reassociation is automatic, therefore you can specify false to ensure the operation fails if the Elastic IP address is already associated with another resource.
     */
    AllowReassociation?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * [EC2-VPC] The ID of the network interface. If the instance has more than one network interface, you must specify a network interface ID. For EC2-VPC, you can specify either the instance ID or the network interface ID, but not both. 
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * [EC2-VPC] The primary or secondary private IP address to associate with the Elastic IP address. If no private IP address is specified, the Elastic IP address is associated with the primary private IP address.
     */
    PrivateIpAddress?: String;
  }
  export interface AssociateAddressResult {
    /**
     * [EC2-VPC] The ID that represents the association of the Elastic IP address with an instance.
     */
    AssociationId?: String;
  }
  export interface AssociateClientVpnTargetNetworkRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ID of the subnet to associate with the Client VPN endpoint.
     */
    SubnetId: SubnetId;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateClientVpnTargetNetworkResult {
    /**
     * The unique ID of the target network association.
     */
    AssociationId?: String;
    /**
     * The current state of the target network association.
     */
    Status?: AssociationStatus;
  }
  export interface AssociateDhcpOptionsRequest {
    /**
     * The ID of the DHCP options set, or default to associate no DHCP options with the VPC.
     */
    DhcpOptionsId: DefaultingDhcpOptionsId;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateEnclaveCertificateIamRoleRequest {
    /**
     * The ARN of the ACM certificate with which to associate the IAM role.
     */
    CertificateArn: CertificateId;
    /**
     * The ARN of the IAM role to associate with the ACM certificate. You can associate up to 16 IAM roles with an ACM certificate.
     */
    RoleArn: RoleId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateEnclaveCertificateIamRoleResult {
    /**
     * The name of the Amazon S3 bucket to which the certificate was uploaded.
     */
    CertificateS3BucketName?: String;
    /**
     * The Amazon S3 object key where the certificate, certificate chain, and encrypted private key bundle are stored. The object key is formatted as follows: role_arn/certificate_arn.
     */
    CertificateS3ObjectKey?: String;
    /**
     * The ID of the KMS key used to encrypt the private key of the certificate.
     */
    EncryptionKmsKeyId?: String;
  }
  export interface AssociateIamInstanceProfileRequest {
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile: IamInstanceProfileSpecification;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
  }
  export interface AssociateIamInstanceProfileResult {
    /**
     * Information about the IAM instance profile association.
     */
    IamInstanceProfileAssociation?: IamInstanceProfileAssociation;
  }
  export interface AssociateInstanceEventWindowRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId: InstanceEventWindowId;
    /**
     * One or more targets associated with the specified event window.
     */
    AssociationTarget: InstanceEventWindowAssociationRequest;
  }
  export interface AssociateInstanceEventWindowResult {
    /**
     * Information about the event window.
     */
    InstanceEventWindow?: InstanceEventWindow;
  }
  export interface AssociateIpamResourceDiscoveryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * An IPAM ID.
     */
    IpamId: IpamId;
    /**
     * A resource discovery ID.
     */
    IpamResourceDiscoveryId: IpamResourceDiscoveryId;
    /**
     * Tag specifications.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A client token.
     */
    ClientToken?: String;
  }
  export interface AssociateIpamResourceDiscoveryResult {
    /**
     * A resource discovery association. An associated resource discovery is a resource discovery that has been associated with an IPAM.
     */
    IpamResourceDiscoveryAssociation?: IpamResourceDiscoveryAssociation;
  }
  export interface AssociateNatGatewayAddressRequest {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId: NatGatewayId;
    /**
     * The allocation IDs of EIPs that you want to associate with your NAT gateway.
     */
    AllocationIds: AllocationIdList;
    /**
     * The private IPv4 addresses that you want to assign to the NAT gateway.
     */
    PrivateIpAddresses?: IpList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateNatGatewayAddressResult {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * The IP addresses.
     */
    NatGatewayAddresses?: NatGatewayAddressList;
  }
  export interface AssociateRouteTableRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the route table.
     */
    RouteTableId: RouteTableId;
    /**
     * The ID of the subnet.
     */
    SubnetId?: SubnetId;
    /**
     * The ID of the internet gateway or virtual private gateway.
     */
    GatewayId?: RouteGatewayId;
  }
  export interface AssociateRouteTableResult {
    /**
     * The route table association ID. This ID is required for disassociating the route table.
     */
    AssociationId?: String;
    /**
     * The state of the association.
     */
    AssociationState?: RouteTableAssociationState;
  }
  export interface AssociateSubnetCidrBlockRequest {
    /**
     * The IPv6 CIDR block for your subnet. The subnet must have a /64 prefix length.
     */
    Ipv6CidrBlock: String;
    /**
     * The ID of your subnet.
     */
    SubnetId: SubnetId;
  }
  export interface AssociateSubnetCidrBlockResult {
    /**
     * Information about the IPv6 association.
     */
    Ipv6CidrBlockAssociation?: SubnetIpv6CidrBlockAssociation;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
  }
  export interface AssociateTransitGatewayMulticastDomainRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * The ID of the transit gateway attachment to associate with the transit gateway multicast domain.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * The IDs of the subnets to associate with the transit gateway multicast domain.
     */
    SubnetIds: TransitGatewaySubnetIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateTransitGatewayMulticastDomainResult {
    /**
     * Information about the transit gateway multicast domain associations.
     */
    Associations?: TransitGatewayMulticastDomainAssociations;
  }
  export interface AssociateTransitGatewayPolicyTableRequest {
    /**
     * The ID of the transit gateway policy table to associate with the transit gateway attachment.
     */
    TransitGatewayPolicyTableId: TransitGatewayPolicyTableId;
    /**
     * The ID of the transit gateway attachment to associate with the policy table.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateTransitGatewayPolicyTableResult {
    /**
     * Describes the association of a transit gateway and a transit gateway policy table.
     */
    Association?: TransitGatewayPolicyTableAssociation;
  }
  export interface AssociateTransitGatewayRouteTableRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateTransitGatewayRouteTableResult {
    /**
     * The ID of the association.
     */
    Association?: TransitGatewayAssociation;
  }
  export interface AssociateTrunkInterfaceRequest {
    /**
     * The ID of the branch network interface.
     */
    BranchInterfaceId: NetworkInterfaceId;
    /**
     * The ID of the trunk network interface.
     */
    TrunkInterfaceId: NetworkInterfaceId;
    /**
     * The ID of the VLAN. This applies to the VLAN protocol.
     */
    VlanId?: Integer;
    /**
     * The application key. This applies to the GRE protocol.
     */
    GreKey?: Integer;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AssociateTrunkInterfaceResult {
    /**
     * Information about the association between the trunk network interface and branch network interface.
     */
    InterfaceAssociation?: TrunkInterfaceAssociation;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency.
     */
    ClientToken?: String;
  }
  export interface AssociateVpcCidrBlockRequest {
    /**
     * Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IPv6 addresses, or the size of the CIDR block.
     */
    AmazonProvidedIpv6CidrBlock?: Boolean;
    /**
     * An IPv4 CIDR block to associate with the VPC.
     */
    CidrBlock?: String;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The name of the location from which we advertise the IPV6 CIDR block. Use this parameter to limit the CIDR block to this location.  You must set AmazonProvidedIpv6CidrBlock to true to use this parameter.  You can have one IPv6 CIDR block association per network border group.
     */
    Ipv6CidrBlockNetworkBorderGroup?: String;
    /**
     * The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
     */
    Ipv6Pool?: Ipv6PoolEc2Id;
    /**
     * An IPv6 CIDR block from the IPv6 address pool. You must also specify Ipv6Pool in the request. To let Amazon choose the IPv6 CIDR block for you, omit this parameter.
     */
    Ipv6CidrBlock?: String;
    /**
     * Associate a CIDR allocated from an IPv4 IPAM pool to a VPC. For more information about Amazon VPC IP Address Manager (IPAM), see What is IPAM? in the Amazon VPC IPAM User Guide.
     */
    Ipv4IpamPoolId?: IpamPoolId;
    /**
     * The netmask length of the IPv4 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide. 
     */
    Ipv4NetmaskLength?: NetmaskLength;
    /**
     * Associates a CIDR allocated from an IPv6 IPAM pool to a VPC. For more information about Amazon VPC IP Address Manager (IPAM), see What is IPAM? in the Amazon VPC IPAM User Guide.
     */
    Ipv6IpamPoolId?: IpamPoolId;
    /**
     * The netmask length of the IPv6 CIDR you would like to associate from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide. 
     */
    Ipv6NetmaskLength?: NetmaskLength;
  }
  export interface AssociateVpcCidrBlockResult {
    /**
     * Information about the IPv6 CIDR block association.
     */
    Ipv6CidrBlockAssociation?: VpcIpv6CidrBlockAssociation;
    /**
     * Information about the IPv4 CIDR block association.
     */
    CidrBlockAssociation?: VpcCidrBlockAssociation;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type AssociatedNetworkType = "vpc"|string;
  export interface AssociatedRole {
    /**
     * The ARN of the associated IAM role.
     */
    AssociatedRoleArn?: ResourceArn;
    /**
     * The name of the Amazon S3 bucket in which the Amazon S3 object is stored.
     */
    CertificateS3BucketName?: String;
    /**
     * The key of the Amazon S3 object ey where the certificate, certificate chain, and encrypted private key bundle is stored. The object key is formated as follows: role_arn/certificate_arn. 
     */
    CertificateS3ObjectKey?: String;
    /**
     * The ID of the KMS customer master key (CMK) used to encrypt the private key.
     */
    EncryptionKmsKeyId?: String;
  }
  export type AssociatedRolesList = AssociatedRole[];
  export interface AssociatedTargetNetwork {
    /**
     * The ID of the subnet.
     */
    NetworkId?: String;
    /**
     * The target network type.
     */
    NetworkType?: AssociatedNetworkType;
  }
  export type AssociatedTargetNetworkSet = AssociatedTargetNetwork[];
  export type AssociationIdList = IamInstanceProfileAssociationId[];
  export interface AssociationStatus {
    /**
     * The state of the target network association.
     */
    Code?: AssociationStatusCode;
    /**
     * A message about the status of the target network association, if applicable.
     */
    Message?: String;
  }
  export type AssociationStatusCode = "associating"|"associated"|"association-failed"|"disassociating"|"disassociated"|string;
  export interface AthenaIntegration {
    /**
     * The location in Amazon S3 to store the generated CloudFormation template.
     */
    IntegrationResultS3DestinationArn: String;
    /**
     * The schedule for adding new partitions to the table.
     */
    PartitionLoadFrequency: PartitionLoadFrequency;
    /**
     * The start date for the partition.
     */
    PartitionStartDate?: MillisecondDateTime;
    /**
     * The end date for the partition.
     */
    PartitionEndDate?: MillisecondDateTime;
  }
  export type AthenaIntegrationsSet = AthenaIntegration[];
  export interface AttachClassicLinkVpcRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of one or more of the VPC's security groups. You cannot specify security groups from a different VPC.
     */
    Groups: GroupIdStringList;
    /**
     * The ID of an EC2-Classic instance to link to the ClassicLink-enabled VPC.
     */
    InstanceId: InstanceId;
    /**
     * The ID of a ClassicLink-enabled VPC.
     */
    VpcId: VpcId;
  }
  export interface AttachClassicLinkVpcResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface AttachInternetGatewayRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the internet gateway.
     */
    InternetGatewayId: InternetGatewayId;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
  }
  export interface AttachNetworkInterfaceRequest {
    /**
     * The index of the device for the network interface attachment.
     */
    DeviceIndex: Integer;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0.
     */
    NetworkCardIndex?: Integer;
    /**
     * Configures ENA Express for the network interface that this action attaches to the instance.
     */
    EnaSrdSpecification?: EnaSrdSpecification;
  }
  export interface AttachNetworkInterfaceResult {
    /**
     * The ID of the network interface attachment.
     */
    AttachmentId?: String;
    /**
     * The index of the network card.
     */
    NetworkCardIndex?: Integer;
  }
  export interface AttachVerifiedAccessTrustProviderRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProviderId: VerifiedAccessTrustProviderId;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AttachVerifiedAccessTrustProviderResult {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProvider?: VerifiedAccessTrustProvider;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstance?: VerifiedAccessInstance;
  }
  export interface AttachVolumeRequest {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    Device: String;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The ID of the EBS volume. The volume and instance must be within the same Availability Zone.
     */
    VolumeId: VolumeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AttachVpnGatewayRequest {
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The ID of the virtual private gateway.
     */
    VpnGatewayId: VpnGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AttachVpnGatewayResult {
    /**
     * Information about the attachment.
     */
    VpcAttachment?: VpcAttachment;
  }
  export interface AttachmentEnaSrdSpecification {
    /**
     * Indicates whether ENA Express is enabled for the network interface that's attached to the instance.
     */
    EnaSrdEnabled?: Boolean;
    /**
     * ENA Express configuration for UDP network traffic.
     */
    EnaSrdUdpSpecification?: AttachmentEnaSrdUdpSpecification;
  }
  export interface AttachmentEnaSrdUdpSpecification {
    /**
     * Indicates whether UDP traffic to and from the instance uses ENA Express. To specify this setting, you must first enable ENA Express.
     */
    EnaSrdUdpEnabled?: Boolean;
  }
  export type AttachmentStatus = "attaching"|"attached"|"detaching"|"detached"|string;
  export interface AttributeBooleanValue {
    /**
     * The attribute value. The valid values are true or false.
     */
    Value?: Boolean;
  }
  export interface AttributeValue {
    /**
     * The attribute value. The value is case-sensitive.
     */
    Value?: String;
  }
  export interface AuthorizationRule {
    /**
     * The ID of the Client VPN endpoint with which the authorization rule is associated.
     */
    ClientVpnEndpointId?: String;
    /**
     * A brief description of the authorization rule.
     */
    Description?: String;
    /**
     * The ID of the Active Directory group to which the authorization rule grants access.
     */
    GroupId?: String;
    /**
     * Indicates whether the authorization rule grants access to all clients.
     */
    AccessAll?: Boolean;
    /**
     * The IPv4 address range, in CIDR notation, of the network to which the authorization rule applies.
     */
    DestinationCidr?: String;
    /**
     * The current state of the authorization rule.
     */
    Status?: ClientVpnAuthorizationRuleStatus;
  }
  export type AuthorizationRuleSet = AuthorizationRule[];
  export interface AuthorizeClientVpnIngressRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The IPv4 address range, in CIDR notation, of the network for which access is being authorized.
     */
    TargetNetworkCidr: String;
    /**
     * The ID of the group to grant access to, for example, the Active Directory group or identity provider (IdP) group. Required if AuthorizeAllGroups is false or not specified.
     */
    AccessGroupId?: String;
    /**
     * Indicates whether to grant access to all clients. Specify true to grant all clients who successfully establish a VPN connection access to the network. Must be set to true if AccessGroupId is not specified.
     */
    AuthorizeAllGroups?: Boolean;
    /**
     * A brief description of the authorization rule.
     */
    Description?: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface AuthorizeClientVpnIngressResult {
    /**
     * The current state of the authorization rule.
     */
    Status?: ClientVpnAuthorizationRuleStatus;
  }
  export interface AuthorizeSecurityGroupEgressRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the security group.
     */
    GroupId: SecurityGroupId;
    /**
     * The sets of IP permissions. You can't specify a destination security group and a CIDR IP address range in the same set of permissions.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The tags applied to the security group rule.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Not supported. Use a set of IP permissions to specify the CIDR.
     */
    CidrIp?: String;
    /**
     * Not supported. Use a set of IP permissions to specify the port.
     */
    FromPort?: Integer;
    /**
     * Not supported. Use a set of IP permissions to specify the protocol name or number.
     */
    IpProtocol?: String;
    /**
     * Not supported. Use a set of IP permissions to specify the port.
     */
    ToPort?: Integer;
    /**
     * Not supported. Use a set of IP permissions to specify a destination security group.
     */
    SourceSecurityGroupName?: String;
    /**
     * Not supported. Use a set of IP permissions to specify a destination security group.
     */
    SourceSecurityGroupOwnerId?: String;
  }
  export interface AuthorizeSecurityGroupEgressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
    /**
     * Information about the outbound (egress) security group rules that were added.
     */
    SecurityGroupRules?: SecurityGroupRuleList;
  }
  export interface AuthorizeSecurityGroupIngressRequest {
    /**
     * The IPv4 address range, in CIDR format. You can't specify this parameter when specifying a source security group. To specify an IPv6 address range, use a set of IP permissions. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
     */
    CidrIp?: String;
    /**
     * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP, this is the type number. A value of -1 indicates all ICMP types. If you specify all ICMP types, you must specify all ICMP codes. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
     */
    FromPort?: Integer;
    /**
     * The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupId?: SecurityGroupId;
    /**
     * [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupName?: SecurityGroupName;
    /**
     * The sets of IP permissions.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The IP protocol name (tcp, udp, icmp) or number (see Protocol Numbers). To specify icmpv6, use a set of IP permissions. [VPC only] Use -1 to specify all protocols. If you specify -1 or a protocol other than tcp, udp, or icmp, traffic on all ports is allowed, regardless of any ports you specify. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
     */
    IpProtocol?: String;
    /**
     * [EC2-Classic, default VPC] The name of the source security group. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead. For EC2-VPC, the source security group must be in the same VPC.
     */
    SourceSecurityGroupName?: String;
    /**
     * [nondefault VPC] The Amazon Web Services account ID for the source security group, if the source security group is in a different account. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. Creates rules that grant full ICMP, UDP, and TCP access. To create a rule with a specific IP protocol and port range, use a set of IP permissions instead.
     */
    SourceSecurityGroupOwnerId?: String;
    /**
     * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP, this is the code. A value of -1 indicates all ICMP codes. If you specify all ICMP types, you must specify all ICMP codes. Alternatively, use a set of IP permissions to specify multiple rules and a description for the rule.
     */
    ToPort?: Integer;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * [VPC Only] The tags applied to the security group rule.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface AuthorizeSecurityGroupIngressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
    /**
     * Information about the inbound (ingress) security group rules that were added.
     */
    SecurityGroupRules?: SecurityGroupRuleList;
  }
  export type AutoAcceptSharedAssociationsValue = "enable"|"disable"|string;
  export type AutoAcceptSharedAttachmentsValue = "enable"|"disable"|string;
  export type AutoPlacement = "on"|"off"|string;
  export type AutoRecoveryFlag = boolean;
  export interface AvailabilityZone {
    /**
     * The state of the Availability Zone, Local Zone, or Wavelength Zone. This value is always available.
     */
    State?: AvailabilityZoneState;
    /**
     * For Availability Zones, this parameter always has the value of opt-in-not-required. For Local Zones and Wavelength Zones, this parameter is the opt-in status. The possible values are opted-in, and not-opted-in.
     */
    OptInStatus?: AvailabilityZoneOptInStatus;
    /**
     * Any messages about the Availability Zone, Local Zone, or Wavelength Zone.
     */
    Messages?: AvailabilityZoneMessageList;
    /**
     * The name of the Region.
     */
    RegionName?: String;
    /**
     * The name of the Availability Zone, Local Zone, or Wavelength Zone.
     */
    ZoneName?: String;
    /**
     * The ID of the Availability Zone, Local Zone, or Wavelength Zone.
     */
    ZoneId?: String;
    /**
     *  For Availability Zones, this parameter has the same value as the Region name. For Local Zones, the name of the associated group, for example us-west-2-lax-1. For Wavelength Zones, the name of the associated group, for example us-east-1-wl1-bos-wlz-1.
     */
    GroupName?: String;
    /**
     * The name of the network border group.
     */
    NetworkBorderGroup?: String;
    /**
     * The type of zone. The valid values are availability-zone, local-zone, and wavelength-zone.
     */
    ZoneType?: String;
    /**
     * The name of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
     */
    ParentZoneName?: String;
    /**
     * The ID of the zone that handles some of the Local Zone or Wavelength Zone control plane operations, such as API calls.
     */
    ParentZoneId?: String;
  }
  export type AvailabilityZoneList = AvailabilityZone[];
  export interface AvailabilityZoneMessage {
    /**
     * The message about the Availability Zone, Local Zone, or Wavelength Zone.
     */
    Message?: String;
  }
  export type AvailabilityZoneMessageList = AvailabilityZoneMessage[];
  export type AvailabilityZoneName = string;
  export type AvailabilityZoneOptInStatus = "opt-in-not-required"|"opted-in"|"not-opted-in"|string;
  export type AvailabilityZoneState = "available"|"information"|"impaired"|"unavailable"|string;
  export type AvailabilityZoneStringList = String[];
  export interface AvailableCapacity {
    /**
     * The number of instances that can be launched onto the Dedicated Host depending on the host's available capacity. For Dedicated Hosts that support multiple instance types, this parameter represents the number of instances for each instance size that is supported on the host.
     */
    AvailableInstanceCapacity?: AvailableInstanceCapacityList;
    /**
     * The number of vCPUs available for launching instances onto the Dedicated Host.
     */
    AvailableVCpus?: Integer;
  }
  export type AvailableInstanceCapacityList = InstanceCapacity[];
  export type BareMetal = "included"|"required"|"excluded"|string;
  export type BareMetalFlag = boolean;
  export type BaselineBandwidthInMbps = number;
  export interface BaselineEbsBandwidthMbps {
    /**
     * The minimum baseline bandwidth, in Mbps. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum baseline bandwidth, in Mbps. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface BaselineEbsBandwidthMbpsRequest {
    /**
     * The minimum baseline bandwidth, in Mbps. To specify no minimum limit, omit this parameter.
     */
    Min?: Integer;
    /**
     * The maximum baseline bandwidth, in Mbps. To specify no maximum limit, omit this parameter.
     */
    Max?: Integer;
  }
  export type BaselineIops = number;
  export type BaselineThroughputInMBps = number;
  export type BatchState = "submitted"|"active"|"cancelled"|"failed"|"cancelled_running"|"cancelled_terminating"|"modifying"|string;
  export type BgpStatus = "up"|"down"|string;
  export type BillingProductList = String[];
  export type _Blob = Buffer|Uint8Array|Blob|string;
  export interface BlobAttributeValue {
    Value?: _Blob;
  }
  export interface BlockDeviceMapping {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    DeviceName?: String;
    /**
     * The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume. NVMe instance store volumes are automatically enumerated and assigned a device name. Including them in your block device mapping has no effect. Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
     */
    VirtualName?: String;
    /**
     * Parameters used to automatically set up EBS volumes when the instance is launched.
     */
    Ebs?: EbsBlockDevice;
    /**
     * To omit the device from the block device mapping, specify an empty string. When this property is specified, the device is removed from the block device mapping regardless of the assigned value.
     */
    NoDevice?: String;
  }
  export type BlockDeviceMappingList = BlockDeviceMapping[];
  export type BlockDeviceMappingRequestList = BlockDeviceMapping[];
  export type Boolean = boolean;
  export type BootModeType = "legacy-bios"|"uefi"|string;
  export type BootModeTypeList = BootModeType[];
  export type BootModeValues = "legacy-bios"|"uefi"|"uefi-preferred"|string;
  export type BoxedDouble = number;
  export type BundleId = string;
  export type BundleIdStringList = BundleId[];
  export interface BundleInstanceRequest {
    /**
     * The ID of the instance to bundle. Type: String Default: None Required: Yes
     */
    InstanceId: InstanceId;
    /**
     * The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
     */
    Storage: Storage;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface BundleInstanceResult {
    /**
     * Information about the bundle task.
     */
    BundleTask?: BundleTask;
  }
  export interface BundleTask {
    /**
     * The ID of the bundle task.
     */
    BundleId?: String;
    /**
     * If the task fails, a description of the error.
     */
    BundleTaskError?: BundleTaskError;
    /**
     * The ID of the instance associated with this bundle task.
     */
    InstanceId?: String;
    /**
     * The level of task completion, as a percent (for example, 20%).
     */
    Progress?: String;
    /**
     * The time this task started.
     */
    StartTime?: DateTime;
    /**
     * The state of the task.
     */
    State?: BundleTaskState;
    /**
     * The Amazon S3 storage locations.
     */
    Storage?: Storage;
    /**
     * The time of the most recent update for the task.
     */
    UpdateTime?: DateTime;
  }
  export interface BundleTaskError {
    /**
     * The error code.
     */
    Code?: String;
    /**
     * The error message.
     */
    Message?: String;
  }
  export type BundleTaskList = BundleTask[];
  export type BundleTaskState = "pending"|"waiting-for-shutdown"|"bundling"|"storing"|"cancelling"|"complete"|"failed"|string;
  export type BurstablePerformance = "included"|"required"|"excluded"|string;
  export type BurstablePerformanceFlag = boolean;
  export interface ByoipCidr {
    /**
     * The address range, in CIDR notation.
     */
    Cidr?: String;
    /**
     * The description of the address range.
     */
    Description?: String;
    /**
     * Upon success, contains the ID of the address pool. Otherwise, contains an error message.
     */
    StatusMessage?: String;
    /**
     * The state of the address pool.
     */
    State?: ByoipCidrState;
  }
  export type ByoipCidrSet = ByoipCidr[];
  export type ByoipCidrState = "advertised"|"deprovisioned"|"failed-deprovision"|"failed-provision"|"pending-deprovision"|"pending-provision"|"provisioned"|"provisioned-not-publicly-advertisable"|string;
  export type CancelBatchErrorCode = "fleetRequestIdDoesNotExist"|"fleetRequestIdMalformed"|"fleetRequestNotInCancellableState"|"unexpectedError"|string;
  export interface CancelBundleTaskRequest {
    /**
     * The ID of the bundle task.
     */
    BundleId: BundleId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CancelBundleTaskResult {
    /**
     * Information about the bundle task.
     */
    BundleTask?: BundleTask;
  }
  export interface CancelCapacityReservationFleetError {
    /**
     * The error code.
     */
    Code?: CancelCapacityReservationFleetErrorCode;
    /**
     * The error message.
     */
    Message?: CancelCapacityReservationFleetErrorMessage;
  }
  export type CancelCapacityReservationFleetErrorCode = string;
  export type CancelCapacityReservationFleetErrorMessage = string;
  export interface CancelCapacityReservationFleetsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the Capacity Reservation Fleets to cancel.
     */
    CapacityReservationFleetIds: CapacityReservationFleetIdSet;
  }
  export interface CancelCapacityReservationFleetsResult {
    /**
     * Information about the Capacity Reservation Fleets that were successfully cancelled.
     */
    SuccessfulFleetCancellations?: CapacityReservationFleetCancellationStateSet;
    /**
     * Information about the Capacity Reservation Fleets that could not be cancelled.
     */
    FailedFleetCancellations?: FailedCapacityReservationFleetCancellationResultSet;
  }
  export interface CancelCapacityReservationRequest {
    /**
     * The ID of the Capacity Reservation to be cancelled.
     */
    CapacityReservationId: CapacityReservationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CancelCapacityReservationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface CancelConversionRequest {
    /**
     * The ID of the conversion task.
     */
    ConversionTaskId: ConversionTaskId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The reason for canceling the conversion task.
     */
    ReasonMessage?: String;
  }
  export interface CancelExportTaskRequest {
    /**
     * The ID of the export task. This is the ID returned by CreateInstanceExportTask.
     */
    ExportTaskId: ExportVmTaskId;
  }
  export interface CancelImageLaunchPermissionRequest {
    /**
     * The ID of the AMI that was shared with your Amazon Web Services account.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CancelImageLaunchPermissionResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface CancelImportTaskRequest {
    /**
     * The reason for canceling the task.
     */
    CancelReason?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the import image or import snapshot task to be canceled.
     */
    ImportTaskId?: ImportTaskId;
  }
  export interface CancelImportTaskResult {
    /**
     * The ID of the task being canceled.
     */
    ImportTaskId?: String;
    /**
     * The current state of the task being canceled.
     */
    PreviousState?: String;
    /**
     * The current state of the task being canceled.
     */
    State?: String;
  }
  export interface CancelReservedInstancesListingRequest {
    /**
     * The ID of the Reserved Instance listing.
     */
    ReservedInstancesListingId: ReservedInstancesListingId;
  }
  export interface CancelReservedInstancesListingResult {
    /**
     * The Reserved Instance listing.
     */
    ReservedInstancesListings?: ReservedInstancesListingList;
  }
  export interface CancelSpotFleetRequestsError {
    /**
     * The error code.
     */
    Code?: CancelBatchErrorCode;
    /**
     * The description for the error code.
     */
    Message?: String;
  }
  export interface CancelSpotFleetRequestsErrorItem {
    /**
     * The error.
     */
    Error?: CancelSpotFleetRequestsError;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
  }
  export type CancelSpotFleetRequestsErrorSet = CancelSpotFleetRequestsErrorItem[];
  export interface CancelSpotFleetRequestsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the Spot Fleet requests.
     */
    SpotFleetRequestIds: SpotFleetRequestIdList;
    /**
     * Indicates whether to terminate the associated instances when the Spot Fleet request is canceled. The default is to terminate the instances. To let the instances continue to run after the Spot Fleet request is canceled, specify no-terminate-instances.
     */
    TerminateInstances: Boolean;
  }
  export interface CancelSpotFleetRequestsResponse {
    /**
     * Information about the Spot Fleet requests that are successfully canceled.
     */
    SuccessfulFleetRequests?: CancelSpotFleetRequestsSuccessSet;
    /**
     * Information about the Spot Fleet requests that are not successfully canceled.
     */
    UnsuccessfulFleetRequests?: CancelSpotFleetRequestsErrorSet;
  }
  export interface CancelSpotFleetRequestsSuccessItem {
    /**
     * The current state of the Spot Fleet request.
     */
    CurrentSpotFleetRequestState?: BatchState;
    /**
     * The previous state of the Spot Fleet request.
     */
    PreviousSpotFleetRequestState?: BatchState;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
  }
  export type CancelSpotFleetRequestsSuccessSet = CancelSpotFleetRequestsSuccessItem[];
  export type CancelSpotInstanceRequestState = "active"|"open"|"closed"|"cancelled"|"completed"|string;
  export interface CancelSpotInstanceRequestsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more Spot Instance request IDs.
     */
    SpotInstanceRequestIds: SpotInstanceRequestIdList;
  }
  export interface CancelSpotInstanceRequestsResult {
    /**
     * One or more Spot Instance requests.
     */
    CancelledSpotInstanceRequests?: CancelledSpotInstanceRequestList;
  }
  export interface CancelledSpotInstanceRequest {
    /**
     * The ID of the Spot Instance request.
     */
    SpotInstanceRequestId?: String;
    /**
     * The state of the Spot Instance request.
     */
    State?: CancelSpotInstanceRequestState;
  }
  export type CancelledSpotInstanceRequestList = CancelledSpotInstanceRequest[];
  export interface CapacityAllocation {
    /**
     * The usage type. used indicates that the instance capacity is in use by instances that are running in the Capacity Reservation.
     */
    AllocationType?: AllocationType;
    /**
     * The amount of instance capacity associated with the usage. For example a value of 4 indicates that instance capacity for 4 instances is currently in use.
     */
    Count?: Integer;
  }
  export type CapacityAllocations = CapacityAllocation[];
  export interface CapacityReservation {
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the Capacity Reservation.
     */
    OwnerId?: String;
    /**
     * The Amazon Resource Name (ARN) of the Capacity Reservation.
     */
    CapacityReservationArn?: String;
    /**
     * The Availability Zone ID of the Capacity Reservation.
     */
    AvailabilityZoneId?: String;
    /**
     * The type of instance for which the Capacity Reservation reserves capacity.
     */
    InstanceType?: String;
    /**
     * The type of operating system for which the Capacity Reservation reserves capacity.
     */
    InstancePlatform?: CapacityReservationInstancePlatform;
    /**
     * The Availability Zone in which the capacity is reserved.
     */
    AvailabilityZone?: String;
    /**
     * Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:    default - The Capacity Reservation is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.  
     */
    Tenancy?: CapacityReservationTenancy;
    /**
     * The total number of instances for which the Capacity Reservation reserves capacity.
     */
    TotalInstanceCount?: Integer;
    /**
     * The remaining capacity. Indicates the number of instances that can be launched in the Capacity Reservation.
     */
    AvailableInstanceCount?: Integer;
    /**
     * Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
     */
    EbsOptimized?: Boolean;
    /**
     *  Deprecated. 
     */
    EphemeralStorage?: Boolean;
    /**
     * The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:    active - The Capacity Reservation is active and the capacity is available for your use.    expired - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use.    cancelled - The Capacity Reservation was cancelled. The reserved capacity is no longer available for your use.    pending - The Capacity Reservation request was successful but the capacity provisioning is still pending.    failed - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes.  
     */
    State?: CapacityReservationState;
    /**
     * The date and time at which the Capacity Reservation was started.
     */
    StartDate?: MillisecondDateTime;
    /**
     * The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time.
     */
    EndDate?: DateTime;
    /**
     * Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it.    limited - The Capacity Reservation expires automatically at a specified date and time.  
     */
    EndDateType?: EndDateType;
    /**
     * Indicates the type of instance launches that the Capacity Reservation accepts. The options include:    open - The Capacity Reservation accepts all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes launch into the Capacity Reservation automatically without specifying any additional parameters.    targeted - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.   
     */
    InstanceMatchCriteria?: InstanceMatchCriteria;
    /**
     * The date and time at which the Capacity Reservation was created.
     */
    CreateDate?: DateTime;
    /**
     * Any tags assigned to the Capacity Reservation.
     */
    Tags?: TagList;
    /**
     * The Amazon Resource Name (ARN) of the Outpost on which the Capacity Reservation was created.
     */
    OutpostArn?: OutpostArn;
    /**
     * The ID of the Capacity Reservation Fleet to which the Capacity Reservation belongs. Only valid for Capacity Reservations that were created by a Capacity Reservation Fleet.
     */
    CapacityReservationFleetId?: String;
    /**
     * The Amazon Resource Name (ARN) of the cluster placement group in which the Capacity Reservation was created. For more information, see  Capacity Reservations for cluster placement groups in the Amazon EC2 User Guide.
     */
    PlacementGroupArn?: PlacementGroupArn;
    /**
     * Information about instance capacity usage.
     */
    CapacityAllocations?: CapacityAllocations;
  }
  export interface CapacityReservationFleet {
    /**
     * The ID of the Capacity Reservation Fleet.
     */
    CapacityReservationFleetId?: CapacityReservationFleetId;
    /**
     * The ARN of the Capacity Reservation Fleet.
     */
    CapacityReservationFleetArn?: String;
    /**
     * The state of the Capacity Reservation Fleet. Possible states include:    submitted - The Capacity Reservation Fleet request has been submitted and Amazon Elastic Compute Cloud is preparing to create the Capacity Reservations.    modifying - The Capacity Reservation Fleet is being modified. The Fleet remains in this state until the modification is complete.    active - The Capacity Reservation Fleet has fulfilled its total target capacity and it is attempting to maintain this capacity. The Fleet remains in this state until it is modified or deleted.    partially_fulfilled - The Capacity Reservation Fleet has partially fulfilled its total target capacity. There is insufficient Amazon EC2 to fulfill the total target capacity. The Fleet is attempting to asynchronously fulfill its total target capacity.    expiring - The Capacity Reservation Fleet has reach its end date and it is in the process of expiring. One or more of its Capacity reservations might still be active.    expired - The Capacity Reservation Fleet has reach its end date. The Fleet and its Capacity Reservations are expired. The Fleet can't create new Capacity Reservations.    cancelling - The Capacity Reservation Fleet is in the process of being cancelled. One or more of its Capacity reservations might still be active.    cancelled - The Capacity Reservation Fleet has been manually cancelled. The Fleet and its Capacity Reservations are cancelled and the Fleet can't create new Capacity Reservations.    failed - The Capacity Reservation Fleet failed to reserve capacity for the specified instance types.  
     */
    State?: CapacityReservationFleetState;
    /**
     * The total number of capacity units for which the Capacity Reservation Fleet reserves capacity. For more information, see Total target capacity in the Amazon EC2 User Guide.
     */
    TotalTargetCapacity?: Integer;
    /**
     * The capacity units that have been fulfilled.
     */
    TotalFulfilledCapacity?: Double;
    /**
     * The tenancy of the Capacity Reservation Fleet. Tenancies include:    default - The Capacity Reservation Fleet is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation Fleet is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.  
     */
    Tenancy?: FleetCapacityReservationTenancy;
    /**
     * The date and time at which the Capacity Reservation Fleet expires.
     */
    EndDate?: MillisecondDateTime;
    /**
     * The date and time at which the Capacity Reservation Fleet was created.
     */
    CreateTime?: MillisecondDateTime;
    /**
     * Indicates the type of instance launches that the Capacity Reservation Fleet accepts. All Capacity Reservations in the Fleet inherit this instance matching criteria. Currently, Capacity Reservation Fleets support open instance matching criteria only. This means that instances that have matching attributes (instance type, platform, and Availability Zone) run in the Capacity Reservations automatically. Instances do not need to explicitly target a Capacity Reservation Fleet to use its reserved capacity.
     */
    InstanceMatchCriteria?: FleetInstanceMatchCriteria;
    /**
     * The strategy used by the Capacity Reservation Fleet to determine which of the specified instance types to use. For more information, see For more information, see  Allocation strategy in the Amazon EC2 User Guide.
     */
    AllocationStrategy?: String;
    /**
     * Information about the instance types for which to reserve the capacity.
     */
    InstanceTypeSpecifications?: FleetCapacityReservationSet;
    /**
     * The tags assigned to the Capacity Reservation Fleet.
     */
    Tags?: TagList;
  }
  export interface CapacityReservationFleetCancellationState {
    /**
     * The current state of the Capacity Reservation Fleet.
     */
    CurrentFleetState?: CapacityReservationFleetState;
    /**
     * The previous state of the Capacity Reservation Fleet.
     */
    PreviousFleetState?: CapacityReservationFleetState;
    /**
     * The ID of the Capacity Reservation Fleet that was successfully cancelled.
     */
    CapacityReservationFleetId?: CapacityReservationFleetId;
  }
  export type CapacityReservationFleetCancellationStateSet = CapacityReservationFleetCancellationState[];
  export type CapacityReservationFleetId = string;
  export type CapacityReservationFleetIdSet = CapacityReservationFleetId[];
  export type CapacityReservationFleetSet = CapacityReservationFleet[];
  export type CapacityReservationFleetState = "submitted"|"modifying"|"active"|"partially_fulfilled"|"expiring"|"expired"|"cancelling"|"cancelled"|"failed"|string;
  export interface CapacityReservationGroup {
    /**
     * The ARN of the resource group.
     */
    GroupArn?: String;
    /**
     * The ID of the Amazon Web Services account that owns the resource group.
     */
    OwnerId?: String;
  }
  export type CapacityReservationGroupSet = CapacityReservationGroup[];
  export type CapacityReservationId = string;
  export type CapacityReservationIdSet = CapacityReservationId[];
  export type CapacityReservationInstancePlatform = "Linux/UNIX"|"Red Hat Enterprise Linux"|"SUSE Linux"|"Windows"|"Windows with SQL Server"|"Windows with SQL Server Enterprise"|"Windows with SQL Server Standard"|"Windows with SQL Server Web"|"Linux with SQL Server Standard"|"Linux with SQL Server Web"|"Linux with SQL Server Enterprise"|"RHEL with SQL Server Standard"|"RHEL with SQL Server Enterprise"|"RHEL with SQL Server Web"|"RHEL with HA"|"RHEL with HA and SQL Server Standard"|"RHEL with HA and SQL Server Enterprise"|string;
  export interface CapacityReservationOptions {
    /**
     * Indicates whether to use unused Capacity Reservations for fulfilling On-Demand capacity. If you specify use-capacity-reservations-first, the fleet uses unused Capacity Reservations to fulfill On-Demand capacity up to the target On-Demand capacity. If multiple instance pools have unused Capacity Reservations, the On-Demand allocation strategy (lowest-price or prioritized) is applied. If the number of unused Capacity Reservations is less than the On-Demand target capacity, the remaining On-Demand target capacity is launched according to the On-Demand allocation strategy (lowest-price or prioritized). If you do not specify a value, the fleet fulfils the On-Demand capacity according to the chosen On-Demand allocation strategy.
     */
    UsageStrategy?: FleetCapacityReservationUsageStrategy;
  }
  export interface CapacityReservationOptionsRequest {
    /**
     * Indicates whether to use unused Capacity Reservations for fulfilling On-Demand capacity. If you specify use-capacity-reservations-first, the fleet uses unused Capacity Reservations to fulfill On-Demand capacity up to the target On-Demand capacity. If multiple instance pools have unused Capacity Reservations, the On-Demand allocation strategy (lowest-price or prioritized) is applied. If the number of unused Capacity Reservations is less than the On-Demand target capacity, the remaining On-Demand target capacity is launched according to the On-Demand allocation strategy (lowest-price or prioritized). If you do not specify a value, the fleet fulfils the On-Demand capacity according to the chosen On-Demand allocation strategy.
     */
    UsageStrategy?: FleetCapacityReservationUsageStrategy;
  }
  export type CapacityReservationPreference = "open"|"none"|string;
  export type CapacityReservationSet = CapacityReservation[];
  export interface CapacityReservationSpecification {
    /**
     * Indicates the instance's Capacity Reservation preferences. Possible preferences include:    open - The instance can run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).    none - The instance avoids running in a Capacity Reservation even if one is available. The instance runs as an On-Demand Instance.  
     */
    CapacityReservationPreference?: CapacityReservationPreference;
    /**
     * Information about the target Capacity Reservation or Capacity Reservation group.
     */
    CapacityReservationTarget?: CapacityReservationTarget;
  }
  export interface CapacityReservationSpecificationResponse {
    /**
     * Describes the instance's Capacity Reservation preferences. Possible preferences include:    open - The instance can run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).    none - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.  
     */
    CapacityReservationPreference?: CapacityReservationPreference;
    /**
     * Information about the targeted Capacity Reservation or Capacity Reservation group.
     */
    CapacityReservationTarget?: CapacityReservationTargetResponse;
  }
  export type CapacityReservationState = "active"|"expired"|"cancelled"|"pending"|"failed"|string;
  export interface CapacityReservationTarget {
    /**
     * The ID of the Capacity Reservation in which to run the instance.
     */
    CapacityReservationId?: CapacityReservationId;
    /**
     * The ARN of the Capacity Reservation resource group in which to run the instance.
     */
    CapacityReservationResourceGroupArn?: String;
  }
  export interface CapacityReservationTargetResponse {
    /**
     * The ID of the targeted Capacity Reservation.
     */
    CapacityReservationId?: String;
    /**
     * The ARN of the targeted Capacity Reservation group.
     */
    CapacityReservationResourceGroupArn?: String;
  }
  export type CapacityReservationTenancy = "default"|"dedicated"|string;
  export interface CarrierGateway {
    /**
     * The ID of the carrier gateway.
     */
    CarrierGatewayId?: CarrierGatewayId;
    /**
     * The ID of the VPC associated with the carrier gateway.
     */
    VpcId?: VpcId;
    /**
     * The state of the carrier gateway.
     */
    State?: CarrierGatewayState;
    /**
     * The Amazon Web Services account ID of the owner of the carrier gateway.
     */
    OwnerId?: String;
    /**
     * The tags assigned to the carrier gateway.
     */
    Tags?: TagList;
  }
  export type CarrierGatewayId = string;
  export type CarrierGatewayIdSet = CarrierGatewayId[];
  export type CarrierGatewayMaxResults = number;
  export type CarrierGatewaySet = CarrierGateway[];
  export type CarrierGatewayState = "pending"|"available"|"deleting"|"deleted"|string;
  export type CertificateArn = string;
  export interface CertificateAuthentication {
    /**
     * The ARN of the client certificate. 
     */
    ClientRootCertificateChain?: String;
  }
  export interface CertificateAuthenticationRequest {
    /**
     * The ARN of the client certificate. The certificate must be signed by a certificate authority (CA) and it must be provisioned in Certificate Manager (ACM).
     */
    ClientRootCertificateChainArn?: String;
  }
  export type CertificateId = string;
  export interface CidrAuthorizationContext {
    /**
     * The plain-text authorization message for the prefix and account.
     */
    Message: String;
    /**
     * The signed authorization message for the prefix and account.
     */
    Signature: String;
  }
  export interface CidrBlock {
    /**
     * The IPv4 CIDR block.
     */
    CidrBlock?: String;
  }
  export type CidrBlockSet = CidrBlock[];
  export interface ClassicLinkDnsSupport {
    /**
     * Indicates whether ClassicLink DNS support is enabled for the VPC.
     */
    ClassicLinkDnsSupported?: Boolean;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type ClassicLinkDnsSupportList = ClassicLinkDnsSupport[];
  export interface ClassicLinkInstance {
    /**
     * A list of security groups.
     */
    Groups?: GroupIdentifierList;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * Any tags assigned to the instance.
     */
    Tags?: TagList;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type ClassicLinkInstanceList = ClassicLinkInstance[];
  export interface ClassicLoadBalancer {
    /**
     * The name of the load balancer.
     */
    Name?: String;
  }
  export type ClassicLoadBalancers = ClassicLoadBalancer[];
  export interface ClassicLoadBalancersConfig {
    /**
     * One or more Classic Load Balancers.
     */
    ClassicLoadBalancers?: ClassicLoadBalancers;
  }
  export interface ClientCertificateRevocationListStatus {
    /**
     * The state of the client certificate revocation list.
     */
    Code?: ClientCertificateRevocationListStatusCode;
    /**
     * A message about the status of the client certificate revocation list, if applicable.
     */
    Message?: String;
  }
  export type ClientCertificateRevocationListStatusCode = "pending"|"active"|string;
  export interface ClientConnectOptions {
    /**
     * Indicates whether client connect options are enabled. The default is false (not enabled).
     */
    Enabled?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Lambda function used for connection authorization.
     */
    LambdaFunctionArn?: String;
  }
  export interface ClientConnectResponseOptions {
    /**
     * Indicates whether client connect options are enabled.
     */
    Enabled?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Lambda function used for connection authorization.
     */
    LambdaFunctionArn?: String;
    /**
     * The status of any updates to the client connect options.
     */
    Status?: ClientVpnEndpointAttributeStatus;
  }
  export interface ClientData {
    /**
     * A user-defined comment about the disk upload.
     */
    Comment?: String;
    /**
     * The time that the disk upload ends.
     */
    UploadEnd?: DateTime;
    /**
     * The size of the uploaded disk image, in GiB.
     */
    UploadSize?: Double;
    /**
     * The time that the disk upload starts.
     */
    UploadStart?: DateTime;
  }
  export interface ClientLoginBannerOptions {
    /**
     * Enable or disable a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established. Valid values: true | false  Default value: false 
     */
    Enabled?: Boolean;
    /**
     * Customizable text that will be displayed in a banner on Amazon Web Services provided clients when a VPN session is established. UTF-8 encoded characters only. Maximum of 1400 characters.
     */
    BannerText?: String;
  }
  export interface ClientLoginBannerResponseOptions {
    /**
     * Current state of text banner feature. Valid values: true | false 
     */
    Enabled?: Boolean;
    /**
     * Customizable text that will be displayed in a banner on Amazon Web Services provided clients when a VPN session is established. UTF-8 encoded characters only. Maximum of 1400 characters.
     */
    BannerText?: String;
  }
  export type ClientVpnAssociationId = string;
  export interface ClientVpnAuthentication {
    /**
     * The authentication type used.
     */
    Type?: ClientVpnAuthenticationType;
    /**
     * Information about the Active Directory, if applicable.
     */
    ActiveDirectory?: DirectoryServiceAuthentication;
    /**
     * Information about the authentication certificates, if applicable.
     */
    MutualAuthentication?: CertificateAuthentication;
    /**
     * Information about the IAM SAML identity provider, if applicable.
     */
    FederatedAuthentication?: FederatedAuthentication;
  }
  export type ClientVpnAuthenticationList = ClientVpnAuthentication[];
  export interface ClientVpnAuthenticationRequest {
    /**
     * The type of client authentication to be used.
     */
    Type?: ClientVpnAuthenticationType;
    /**
     * Information about the Active Directory to be used, if applicable. You must provide this information if Type is directory-service-authentication.
     */
    ActiveDirectory?: DirectoryServiceAuthenticationRequest;
    /**
     * Information about the authentication certificates to be used, if applicable. You must provide this information if Type is certificate-authentication.
     */
    MutualAuthentication?: CertificateAuthenticationRequest;
    /**
     * Information about the IAM SAML identity provider to be used, if applicable. You must provide this information if Type is federated-authentication.
     */
    FederatedAuthentication?: FederatedAuthenticationRequest;
  }
  export type ClientVpnAuthenticationRequestList = ClientVpnAuthenticationRequest[];
  export type ClientVpnAuthenticationType = "certificate-authentication"|"directory-service-authentication"|"federated-authentication"|string;
  export interface ClientVpnAuthorizationRuleStatus {
    /**
     * The state of the authorization rule.
     */
    Code?: ClientVpnAuthorizationRuleStatusCode;
    /**
     * A message about the status of the authorization rule, if applicable.
     */
    Message?: String;
  }
  export type ClientVpnAuthorizationRuleStatusCode = "authorizing"|"active"|"failed"|"revoking"|string;
  export interface ClientVpnConnection {
    /**
     * The ID of the Client VPN endpoint to which the client is connected.
     */
    ClientVpnEndpointId?: String;
    /**
     * The current date and time.
     */
    Timestamp?: String;
    /**
     * The ID of the client connection.
     */
    ConnectionId?: String;
    /**
     * The username of the client who established the client connection. This information is only provided if Active Directory client authentication is used.
     */
    Username?: String;
    /**
     * The date and time the client connection was established.
     */
    ConnectionEstablishedTime?: String;
    /**
     * The number of bytes sent by the client.
     */
    IngressBytes?: String;
    /**
     * The number of bytes received by the client.
     */
    EgressBytes?: String;
    /**
     * The number of packets sent by the client.
     */
    IngressPackets?: String;
    /**
     * The number of packets received by the client.
     */
    EgressPackets?: String;
    /**
     * The IP address of the client.
     */
    ClientIp?: String;
    /**
     * The common name associated with the client. This is either the name of the client certificate, or the Active Directory user name.
     */
    CommonName?: String;
    /**
     * The current state of the client connection.
     */
    Status?: ClientVpnConnectionStatus;
    /**
     * The date and time the client connection was terminated.
     */
    ConnectionEndTime?: String;
    /**
     * The statuses returned by the client connect handler for posture compliance, if applicable.
     */
    PostureComplianceStatuses?: ValueStringList;
  }
  export type ClientVpnConnectionSet = ClientVpnConnection[];
  export interface ClientVpnConnectionStatus {
    /**
     * The state of the client connection.
     */
    Code?: ClientVpnConnectionStatusCode;
    /**
     * A message about the status of the client connection, if applicable.
     */
    Message?: String;
  }
  export type ClientVpnConnectionStatusCode = "active"|"failed-to-terminate"|"terminating"|"terminated"|string;
  export interface ClientVpnEndpoint {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId?: String;
    /**
     * A brief description of the endpoint.
     */
    Description?: String;
    /**
     * The current state of the Client VPN endpoint.
     */
    Status?: ClientVpnEndpointStatus;
    /**
     * The date and time the Client VPN endpoint was created.
     */
    CreationTime?: String;
    /**
     * The date and time the Client VPN endpoint was deleted, if applicable.
     */
    DeletionTime?: String;
    /**
     * The DNS name to be used by clients when connecting to the Client VPN endpoint.
     */
    DnsName?: String;
    /**
     * The IPv4 address range, in CIDR notation, from which client IP addresses are assigned.
     */
    ClientCidrBlock?: String;
    /**
     * Information about the DNS servers to be used for DNS resolution. 
     */
    DnsServers?: ValueStringList;
    /**
     * Indicates whether split-tunnel is enabled in the Client VPN endpoint. For information about split-tunnel VPN endpoints, see Split-Tunnel Client VPN endpoint in the Client VPN Administrator Guide.
     */
    SplitTunnel?: Boolean;
    /**
     * The protocol used by the VPN session.
     */
    VpnProtocol?: VpnProtocol;
    /**
     * The transport protocol used by the Client VPN endpoint.
     */
    TransportProtocol?: TransportProtocol;
    /**
     * The port number for the Client VPN endpoint.
     */
    VpnPort?: Integer;
    /**
     * Information about the associated target networks. A target network is a subnet in a VPC.
     */
    AssociatedTargetNetworks?: AssociatedTargetNetworkSet;
    /**
     * The ARN of the server certificate.
     */
    ServerCertificateArn?: String;
    /**
     * Information about the authentication method used by the Client VPN endpoint.
     */
    AuthenticationOptions?: ClientVpnAuthenticationList;
    /**
     * Information about the client connection logging options for the Client VPN endpoint.
     */
    ConnectionLogOptions?: ConnectionLogResponseOptions;
    /**
     * Any tags assigned to the Client VPN endpoint.
     */
    Tags?: TagList;
    /**
     * The IDs of the security groups for the target network.
     */
    SecurityGroupIds?: ClientVpnSecurityGroupIdSet;
    /**
     * The ID of the VPC.
     */
    VpcId?: VpcId;
    /**
     * The URL of the self-service portal.
     */
    SelfServicePortalUrl?: String;
    /**
     * The options for managing connection authorization for new client connections.
     */
    ClientConnectOptions?: ClientConnectResponseOptions;
    /**
     * The maximum VPN session duration time in hours. Valid values: 8 | 10 | 12 | 24  Default value: 24 
     */
    SessionTimeoutHours?: Integer;
    /**
     * Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
     */
    ClientLoginBannerOptions?: ClientLoginBannerResponseOptions;
  }
  export interface ClientVpnEndpointAttributeStatus {
    /**
     * The status code.
     */
    Code?: ClientVpnEndpointAttributeStatusCode;
    /**
     * The status message.
     */
    Message?: String;
  }
  export type ClientVpnEndpointAttributeStatusCode = "applying"|"applied"|string;
  export type ClientVpnEndpointId = string;
  export type ClientVpnEndpointIdList = ClientVpnEndpointId[];
  export interface ClientVpnEndpointStatus {
    /**
     * The state of the Client VPN endpoint. Possible states include:    pending-associate - The Client VPN endpoint has been created but no target networks have been associated. The Client VPN endpoint cannot accept connections.    available - The Client VPN endpoint has been created and a target network has been associated. The Client VPN endpoint can accept connections.    deleting - The Client VPN endpoint is being deleted. The Client VPN endpoint cannot accept connections.    deleted - The Client VPN endpoint has been deleted. The Client VPN endpoint cannot accept connections.  
     */
    Code?: ClientVpnEndpointStatusCode;
    /**
     * A message about the status of the Client VPN endpoint.
     */
    Message?: String;
  }
  export type ClientVpnEndpointStatusCode = "pending-associate"|"available"|"deleting"|"deleted"|string;
  export interface ClientVpnRoute {
    /**
     * The ID of the Client VPN endpoint with which the route is associated.
     */
    ClientVpnEndpointId?: String;
    /**
     * The IPv4 address range, in CIDR notation, of the route destination.
     */
    DestinationCidr?: String;
    /**
     * The ID of the subnet through which traffic is routed.
     */
    TargetSubnet?: String;
    /**
     * The route type.
     */
    Type?: String;
    /**
     * Indicates how the route was associated with the Client VPN endpoint. associate indicates that the route was automatically added when the target network was associated with the Client VPN endpoint. add-route indicates that the route was manually added using the CreateClientVpnRoute action.
     */
    Origin?: String;
    /**
     * The current state of the route.
     */
    Status?: ClientVpnRouteStatus;
    /**
     * A brief description of the route.
     */
    Description?: String;
  }
  export type ClientVpnRouteSet = ClientVpnRoute[];
  export interface ClientVpnRouteStatus {
    /**
     * The state of the Client VPN endpoint route.
     */
    Code?: ClientVpnRouteStatusCode;
    /**
     * A message about the status of the Client VPN endpoint route, if applicable.
     */
    Message?: String;
  }
  export type ClientVpnRouteStatusCode = "creating"|"active"|"failed"|"deleting"|string;
  export type ClientVpnSecurityGroupIdSet = SecurityGroupId[];
  export type CloudWatchLogGroupArn = string;
  export interface CloudWatchLogOptions {
    /**
     * Status of VPN tunnel logging feature. Default value is False. Valid values: True | False 
     */
    LogEnabled?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the CloudWatch log group to send logs to.
     */
    LogGroupArn?: String;
    /**
     * Configured log format. Default format is json. Valid values: json | text 
     */
    LogOutputFormat?: String;
  }
  export interface CloudWatchLogOptionsSpecification {
    /**
     * Enable or disable VPN tunnel logging feature. Default value is False. Valid values: True | False 
     */
    LogEnabled?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the CloudWatch log group to send logs to.
     */
    LogGroupArn?: CloudWatchLogGroupArn;
    /**
     * Set log format. Default format is json. Valid values: json | text 
     */
    LogOutputFormat?: String;
  }
  export interface CoipAddressUsage {
    /**
     * The allocation ID of the address.
     */
    AllocationId?: String;
    /**
     * The Amazon Web Services account ID.
     */
    AwsAccountId?: String;
    /**
     * The Amazon Web Services service.
     */
    AwsService?: String;
    /**
     * The customer-owned IP address.
     */
    CoIp?: String;
  }
  export type CoipAddressUsageSet = CoipAddressUsage[];
  export interface CoipCidr {
    /**
     *  An address range in a customer-owned IP address space. 
     */
    Cidr?: String;
    /**
     *  The ID of the address pool. 
     */
    CoipPoolId?: Ipv4PoolCoipId;
    /**
     *  The ID of the local gateway route table. 
     */
    LocalGatewayRouteTableId?: String;
  }
  export interface CoipPool {
    /**
     * The ID of the address pool.
     */
    PoolId?: Ipv4PoolCoipId;
    /**
     * The address ranges of the address pool.
     */
    PoolCidrs?: ValueStringList;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: LocalGatewayRoutetableId;
    /**
     * The tags.
     */
    Tags?: TagList;
    /**
     * The ARN of the address pool.
     */
    PoolArn?: ResourceArn;
  }
  export type CoipPoolId = string;
  export type CoipPoolIdSet = Ipv4PoolCoipId[];
  export type CoipPoolMaxResults = number;
  export type CoipPoolSet = CoipPool[];
  export type ComponentAccount = string;
  export type ComponentRegion = string;
  export interface ConfirmProductInstanceRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The product code. This must be a product code that you own.
     */
    ProductCode: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ConfirmProductInstanceResult {
    /**
     * The Amazon Web Services account ID of the instance owner. This is only present if the product code is attached to the instance.
     */
    OwnerId?: String;
    /**
     * The return value of the request. Returns true if the specified product code is owned by the requester and associated with the specified instance.
     */
    Return?: Boolean;
  }
  export interface ConnectionLogOptions {
    /**
     * Indicates whether connection logging is enabled.
     */
    Enabled?: Boolean;
    /**
     * The name of the CloudWatch Logs log group. Required if connection logging is enabled.
     */
    CloudwatchLogGroup?: String;
    /**
     * The name of the CloudWatch Logs log stream to which the connection data is published.
     */
    CloudwatchLogStream?: String;
  }
  export interface ConnectionLogResponseOptions {
    /**
     * Indicates whether client connection logging is enabled for the Client VPN endpoint.
     */
    Enabled?: Boolean;
    /**
     * The name of the Amazon CloudWatch Logs log group to which connection logging data is published.
     */
    CloudwatchLogGroup?: String;
    /**
     * The name of the Amazon CloudWatch Logs log stream to which connection logging data is published.
     */
    CloudwatchLogStream?: String;
  }
  export interface ConnectionNotification {
    /**
     * The ID of the notification.
     */
    ConnectionNotificationId?: String;
    /**
     * The ID of the endpoint service.
     */
    ServiceId?: String;
    /**
     * The ID of the VPC endpoint.
     */
    VpcEndpointId?: String;
    /**
     * The type of notification.
     */
    ConnectionNotificationType?: ConnectionNotificationType;
    /**
     * The ARN of the SNS topic for the notification.
     */
    ConnectionNotificationArn?: String;
    /**
     * The events for the notification. Valid values are Accept, Connect, Delete, and Reject.
     */
    ConnectionEvents?: ValueStringList;
    /**
     * The state of the notification.
     */
    ConnectionNotificationState?: ConnectionNotificationState;
  }
  export type ConnectionNotificationId = string;
  export type ConnectionNotificationIdsList = ConnectionNotificationId[];
  export type ConnectionNotificationSet = ConnectionNotification[];
  export type ConnectionNotificationState = "Enabled"|"Disabled"|string;
  export type ConnectionNotificationType = "Topic"|string;
  export type ConnectivityType = "private"|"public"|string;
  export type ContainerFormat = "ova"|string;
  export type ConversionIdStringList = ConversionTaskId[];
  export interface ConversionTask {
    /**
     * The ID of the conversion task.
     */
    ConversionTaskId?: String;
    /**
     * The time when the task expires. If the upload isn't complete before the expiration time, we automatically cancel the task.
     */
    ExpirationTime?: String;
    /**
     * If the task is for importing an instance, this contains information about the import instance task.
     */
    ImportInstance?: ImportInstanceTaskDetails;
    /**
     * If the task is for importing a volume, this contains information about the import volume task.
     */
    ImportVolume?: ImportVolumeTaskDetails;
    /**
     * The state of the conversion task.
     */
    State?: ConversionTaskState;
    /**
     * The status message related to the conversion task.
     */
    StatusMessage?: String;
    /**
     * Any tags assigned to the task.
     */
    Tags?: TagList;
  }
  export type ConversionTaskId = string;
  export type ConversionTaskState = "active"|"cancelling"|"cancelled"|"completed"|string;
  export interface CopyFpgaImageRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the source AFI.
     */
    SourceFpgaImageId: String;
    /**
     * The description for the new AFI.
     */
    Description?: String;
    /**
     * The name for the new AFI. The default is the name of the source AFI.
     */
    Name?: String;
    /**
     * The Region that contains the source AFI.
     */
    SourceRegion: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
     */
    ClientToken?: String;
  }
  export interface CopyFpgaImageResult {
    /**
     * The ID of the new AFI.
     */
    FpgaImageId?: String;
  }
  export interface CopyImageRequest {
    /**
     * Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
     */
    ClientToken?: String;
    /**
     * A description for the new AMI in the destination Region.
     */
    Description?: String;
    /**
     * Specifies whether the destination snapshots of the copied image should be encrypted. You can encrypt a copy of an unencrypted snapshot, but you cannot create an unencrypted copy of an encrypted snapshot. The default KMS key for Amazon EBS is used unless you specify a non-default Key Management Service (KMS) KMS key using KmsKeyId. For more information, see Amazon EBS encryption in the Amazon EC2 User Guide.
     */
    Encrypted?: Boolean;
    /**
     * The identifier of the symmetric Key Management Service (KMS) KMS key to use when creating encrypted volumes. If this parameter is not specified, your Amazon Web Services managed KMS key for Amazon EBS is used. If you specify a KMS key, you must also set the encrypted state to true. You can specify a KMS key using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an identifier that is not valid, the action can appear to complete, but eventually fails. The specified KMS key must exist in the destination Region. Amazon EBS does not support asymmetric KMS keys.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The name of the new AMI in the destination Region.
     */
    Name: String;
    /**
     * The ID of the AMI to copy.
     */
    SourceImageId: String;
    /**
     * The name of the Region that contains the AMI to copy.
     */
    SourceRegion: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost to which to copy the AMI. Only specify this parameter when copying an AMI from an Amazon Web Services Region to an Outpost. The AMI must be in the Region of the destination Outpost. You cannot copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost. For more information, see  Copy AMIs from an Amazon Web Services Region to an Outpost in the Amazon EC2 User Guide.
     */
    DestinationOutpostArn?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to include your user-defined AMI tags when copying the AMI. The following tags will not be copied:   System tags (prefixed with aws:)   For public and shared AMIs, user-defined tags that are attached by other Amazon Web Services accounts   Default: Your user-defined AMI tags are not copied.
     */
    CopyImageTags?: Boolean;
  }
  export interface CopyImageResult {
    /**
     * The ID of the new AMI.
     */
    ImageId?: String;
  }
  export interface CopySnapshotRequest {
    /**
     * A description for the EBS snapshot.
     */
    Description?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost to which to copy the snapshot. Only specify this parameter when copying a snapshot from an Amazon Web Services Region to an Outpost. The snapshot must be in the Region for the destination Outpost. You cannot copy a snapshot from an Outpost to a Region, from one Outpost to another, or within the same Outpost. For more information, see  Copy snapshots from an Amazon Web Services Region to an Outpost in the Amazon Elastic Compute Cloud User Guide.
     */
    DestinationOutpostArn?: String;
    /**
     * The destination Region to use in the PresignedUrl parameter of a snapshot copy operation. This parameter is only valid for specifying the destination Region in a PresignedUrl parameter, where it is required. The snapshot copy is sent to the regional endpoint that you sent the HTTP request to (for example, ec2.us-east-1.amazonaws.com). With the CLI, this is specified using the --region parameter or the default Region in your Amazon Web Services configuration file.
     */
    DestinationRegion?: String;
    /**
     * To encrypt a copy of an unencrypted snapshot if encryption by default is not enabled, enable encryption using this parameter. Otherwise, omit this parameter. Encrypted snapshots are encrypted, even if you omit this parameter and encryption by default is not enabled. You cannot set this parameter to false. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.
     */
    Encrypted?: Boolean;
    /**
     * The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified, the encrypted state must be true. You can specify the KMS key using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the action can appear to complete, but eventually fails.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * When you copy an encrypted source snapshot using the Amazon EC2 Query API, you must supply a pre-signed URL. This parameter is optional for unencrypted snapshots. For more information, see Query requests. The PresignedUrl should use the snapshot source endpoint, the CopySnapshot action, and include the SourceRegion, SourceSnapshotId, and DestinationRegion parameters. The PresignedUrl must be signed using Amazon Web Services Signature Version 4. Because EBS snapshots are stored in Amazon S3, the signing algorithm for this parameter uses the same logic that is described in Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) in the Amazon Simple Storage Service API Reference. An invalid or improperly signed PresignedUrl will cause the copy operation to fail asynchronously, and the snapshot will move to an error state.
     */
    PresignedUrl?: CopySnapshotRequestPSU;
    /**
     * The ID of the Region that contains the snapshot to be copied.
     */
    SourceRegion: String;
    /**
     * The ID of the EBS snapshot to copy.
     */
    SourceSnapshotId: String;
    /**
     * The tags to apply to the new snapshot.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type CopySnapshotRequestPSU = string;
  export interface CopySnapshotResult {
    /**
     * The ID of the new snapshot.
     */
    SnapshotId?: String;
    /**
     * Any tags applied to the new snapshot.
     */
    Tags?: TagList;
  }
  export type CopyTagsFromSource = "volume"|string;
  export type CoreCount = number;
  export type CoreCountList = CoreCount[];
  export type CoreNetworkArn = string;
  export type CpuManufacturer = "intel"|"amd"|"amazon-web-services"|string;
  export type CpuManufacturerSet = CpuManufacturer[];
  export interface CpuOptions {
    /**
     * The number of CPU cores for the instance.
     */
    CoreCount?: Integer;
    /**
     * The number of threads per CPU core.
     */
    ThreadsPerCore?: Integer;
  }
  export interface CpuOptionsRequest {
    /**
     * The number of CPU cores for the instance.
     */
    CoreCount?: Integer;
    /**
     * The number of threads per CPU core. To disable multithreading for the instance, specify a value of 1. Otherwise, specify the default value of 2.
     */
    ThreadsPerCore?: Integer;
  }
  export interface CreateCapacityReservationFleetRequest {
    /**
     * The strategy used by the Capacity Reservation Fleet to determine which of the specified instance types to use. Currently, only the prioritized allocation strategy is supported. For more information, see  Allocation strategy in the Amazon EC2 User Guide. Valid values: prioritized 
     */
    AllocationStrategy?: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
     */
    ClientToken?: String;
    /**
     * Information about the instance types for which to reserve the capacity.
     */
    InstanceTypeSpecifications: ReservationFleetInstanceSpecificationList;
    /**
     * Indicates the tenancy of the Capacity Reservation Fleet. All Capacity Reservations in the Fleet inherit this tenancy. The Capacity Reservation Fleet can have one of the following tenancy settings:    default - The Capacity Reservation Fleet is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservations are created on single-tenant hardware that is dedicated to a single Amazon Web Services account.  
     */
    Tenancy?: FleetCapacityReservationTenancy;
    /**
     * The total number of capacity units to be reserved by the Capacity Reservation Fleet. This value, together with the instance type weights that you assign to each instance type used by the Fleet determine the number of instances for which the Fleet reserves capacity. Both values are based on units that make sense for your workload. For more information, see  Total target capacity in the Amazon EC2 User Guide.
     */
    TotalTargetCapacity: Integer;
    /**
     * The date and time at which the Capacity Reservation Fleet expires. When the Capacity Reservation Fleet expires, its state changes to expired and all of the Capacity Reservations in the Fleet expire. The Capacity Reservation Fleet expires within an hour after the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation Fleet is guaranteed to expire between 13:30:55 and 14:30:55 on 5/31/2019. 
     */
    EndDate?: MillisecondDateTime;
    /**
     * Indicates the type of instance launches that the Capacity Reservation Fleet accepts. All Capacity Reservations in the Fleet inherit this instance matching criteria. Currently, Capacity Reservation Fleets support open instance matching criteria only. This means that instances that have matching attributes (instance type, platform, and Availability Zone) run in the Capacity Reservations automatically. Instances do not need to explicitly target a Capacity Reservation Fleet to use its reserved capacity.
     */
    InstanceMatchCriteria?: FleetInstanceMatchCriteria;
    /**
     * The tags to assign to the Capacity Reservation Fleet. The tags are automatically assigned to the Capacity Reservations in the Fleet.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateCapacityReservationFleetResult {
    /**
     * The ID of the Capacity Reservation Fleet.
     */
    CapacityReservationFleetId?: CapacityReservationFleetId;
    /**
     * The status of the Capacity Reservation Fleet.
     */
    State?: CapacityReservationFleetState;
    /**
     * The total number of capacity units for which the Capacity Reservation Fleet reserves capacity.
     */
    TotalTargetCapacity?: Integer;
    /**
     * The requested capacity units that have been successfully reserved.
     */
    TotalFulfilledCapacity?: Double;
    /**
     * The instance matching criteria for the Capacity Reservation Fleet.
     */
    InstanceMatchCriteria?: FleetInstanceMatchCriteria;
    /**
     * The allocation strategy used by the Capacity Reservation Fleet.
     */
    AllocationStrategy?: String;
    /**
     * The date and time at which the Capacity Reservation Fleet was created.
     */
    CreateTime?: MillisecondDateTime;
    /**
     * The date and time at which the Capacity Reservation Fleet expires.
     */
    EndDate?: MillisecondDateTime;
    /**
     * Indicates the tenancy of Capacity Reservation Fleet.
     */
    Tenancy?: FleetCapacityReservationTenancy;
    /**
     * Information about the individual Capacity Reservations in the Capacity Reservation Fleet.
     */
    FleetCapacityReservations?: FleetCapacityReservationSet;
    /**
     * The tags assigned to the Capacity Reservation Fleet.
     */
    Tags?: TagList;
  }
  export interface CreateCapacityReservationRequest {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
     */
    ClientToken?: String;
    /**
     * The instance type for which to reserve capacity. For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceType: String;
    /**
     * The type of operating system for which to reserve capacity.
     */
    InstancePlatform: CapacityReservationInstancePlatform;
    /**
     * The Availability Zone in which to create the Capacity Reservation.
     */
    AvailabilityZone?: String;
    /**
     * The ID of the Availability Zone in which to create the Capacity Reservation.
     */
    AvailabilityZoneId?: String;
    /**
     * Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:    default - The Capacity Reservation is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.  
     */
    Tenancy?: CapacityReservationTenancy;
    /**
     * The number of instances for which to reserve capacity. Valid range: 1 - 1000
     */
    InstanceCount: Integer;
    /**
     * Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
     */
    EbsOptimized?: Boolean;
    /**
     *  Deprecated. 
     */
    EphemeralStorage?: Boolean;
    /**
     * The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time. You must provide an EndDate value if EndDateType is limited. Omit EndDate if EndDateType is unlimited. If the EndDateType is limited, the Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019.
     */
    EndDate?: DateTime;
    /**
     * Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an EndDate if the EndDateType is unlimited.    limited - The Capacity Reservation expires automatically at a specified date and time. You must provide an EndDate value if the EndDateType value is limited.  
     */
    EndDateType?: EndDateType;
    /**
     * Indicates the type of instance launches that the Capacity Reservation accepts. The options include:    open - The Capacity Reservation automatically matches all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes run in the Capacity Reservation automatically without specifying any additional parameters.    targeted - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.    Default: open 
     */
    InstanceMatchCriteria?: InstanceMatchCriteria;
    /**
     * The tags to apply to the Capacity Reservation during launch.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Outpost on which to create the Capacity Reservation.
     */
    OutpostArn?: OutpostArn;
    /**
     * The Amazon Resource Name (ARN) of the cluster placement group in which to create the Capacity Reservation. For more information, see  Capacity Reservations for cluster placement groups in the Amazon EC2 User Guide.
     */
    PlacementGroupArn?: PlacementGroupArn;
  }
  export interface CreateCapacityReservationResult {
    /**
     * Information about the Capacity Reservation.
     */
    CapacityReservation?: CapacityReservation;
  }
  export interface CreateCarrierGatewayRequest {
    /**
     * The ID of the VPC to associate with the carrier gateway.
     */
    VpcId: VpcId;
    /**
     * The tags to associate with the carrier gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateCarrierGatewayResult {
    /**
     * Information about the carrier gateway.
     */
    CarrierGateway?: CarrierGateway;
  }
  export interface CreateClientVpnEndpointRequest {
    /**
     * The IPv4 address range, in CIDR notation, from which to assign client IP addresses. The address range cannot overlap with the local CIDR of the VPC in which the associated subnet is located, or the routes that you add manually. The address range cannot be changed after the Client VPN endpoint has been created. Client CIDR range must have a size of at least /22 and must not be greater than /12.
     */
    ClientCidrBlock: String;
    /**
     * The ARN of the server certificate. For more information, see the Certificate Manager User Guide.
     */
    ServerCertificateArn: String;
    /**
     * Information about the authentication method to be used to authenticate clients.
     */
    AuthenticationOptions: ClientVpnAuthenticationRequestList;
    /**
     * Information about the client connection logging options. If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:   Client connection requests   Client connection results (successful and unsuccessful)   Reasons for unsuccessful client connection requests   Client connection termination time  
     */
    ConnectionLogOptions: ConnectionLogOptions;
    /**
     * Information about the DNS servers to be used for DNS resolution. A Client VPN endpoint can have up to two DNS servers. If no DNS server is specified, the DNS address configured on the device is used for the DNS server.
     */
    DnsServers?: ValueStringList;
    /**
     * The transport protocol to be used by the VPN session. Default value: udp 
     */
    TransportProtocol?: TransportProtocol;
    /**
     * The port number to assign to the Client VPN endpoint for TCP and UDP traffic. Valid Values: 443 | 1194  Default Value: 443 
     */
    VpnPort?: Integer;
    /**
     * A brief description of the Client VPN endpoint.
     */
    Description?: String;
    /**
     * Indicates whether split-tunnel is enabled on the Client VPN endpoint. By default, split-tunnel on a VPN endpoint is disabled. For information about split-tunnel VPN endpoints, see Split-tunnel Client VPN endpoint in the Client VPN Administrator Guide.
     */
    SplitTunnel?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * The tags to apply to the Client VPN endpoint during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The IDs of one or more security groups to apply to the target network. You must also specify the ID of the VPC that contains the security groups.
     */
    SecurityGroupIds?: ClientVpnSecurityGroupIdSet;
    /**
     * The ID of the VPC to associate with the Client VPN endpoint. If no security group IDs are specified in the request, the default security group for the VPC is applied.
     */
    VpcId?: VpcId;
    /**
     * Specify whether to enable the self-service portal for the Client VPN endpoint. Default Value: enabled 
     */
    SelfServicePortal?: SelfServicePortal;
    /**
     * The options for managing connection authorization for new client connections.
     */
    ClientConnectOptions?: ClientConnectOptions;
    /**
     * The maximum VPN session duration time in hours. Valid values: 8 | 10 | 12 | 24  Default value: 24 
     */
    SessionTimeoutHours?: Integer;
    /**
     * Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
     */
    ClientLoginBannerOptions?: ClientLoginBannerOptions;
  }
  export interface CreateClientVpnEndpointResult {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId?: String;
    /**
     * The current state of the Client VPN endpoint.
     */
    Status?: ClientVpnEndpointStatus;
    /**
     * The DNS name to be used by clients when establishing their VPN session.
     */
    DnsName?: String;
  }
  export interface CreateClientVpnRouteRequest {
    /**
     * The ID of the Client VPN endpoint to which to add the route.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The IPv4 address range, in CIDR notation, of the route destination. For example:   To add a route for Internet access, enter 0.0.0.0/0    To add a route for a peered VPC, enter the peered VPC's IPv4 CIDR range   To add a route for an on-premises network, enter the Amazon Web Services Site-to-Site VPN connection's IPv4 CIDR range   To add a route for the local network, enter the client CIDR range  
     */
    DestinationCidrBlock: String;
    /**
     * The ID of the subnet through which you want to route traffic. The specified subnet must be an existing target network of the Client VPN endpoint. Alternatively, if you're adding a route for the local network, specify local.
     */
    TargetVpcSubnetId: SubnetId;
    /**
     * A brief description of the route.
     */
    Description?: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateClientVpnRouteResult {
    /**
     * The current state of the route.
     */
    Status?: ClientVpnRouteStatus;
  }
  export interface CreateCoipCidrRequest {
    /**
     *  A customer-owned IP address range to create. 
     */
    Cidr: String;
    /**
     *  The ID of the address pool. 
     */
    CoipPoolId: Ipv4PoolCoipId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateCoipCidrResult {
    /**
     *  Information about a range of customer-owned IP addresses. 
     */
    CoipCidr?: CoipCidr;
  }
  export interface CreateCoipPoolRequest {
    /**
     *  The ID of the local gateway route table. 
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     *  The tags to assign to the CoIP address pool. 
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateCoipPoolResult {
    /**
     * Information about the CoIP address pool.
     */
    CoipPool?: CoipPool;
  }
  export interface CreateCustomerGatewayRequest {
    /**
     * For devices that support BGP, the customer gateway's BGP ASN. Default: 65000
     */
    BgpAsn?: Integer;
    /**
     *  This member has been deprecated. The Internet-routable IP address for the customer gateway's outside interface. The address must be static.
     */
    PublicIp?: String;
    /**
     * The Amazon Resource Name (ARN) for the customer gateway certificate.
     */
    CertificateArn?: String;
    /**
     * The type of VPN connection that this customer gateway supports (ipsec.1).
     */
    Type: GatewayType;
    /**
     * The tags to apply to the customer gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A name for the customer gateway device. Length Constraints: Up to 255 characters.
     */
    DeviceName?: String;
    /**
     *  IPv4 address for the customer gateway device's outside interface. The address must be static. 
     */
    IpAddress?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateCustomerGatewayResult {
    /**
     * Information about the customer gateway.
     */
    CustomerGateway?: CustomerGateway;
  }
  export interface CreateDefaultSubnetRequest {
    /**
     * The Availability Zone in which to create the default subnet.
     */
    AvailabilityZone: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to create an IPv6 only subnet. If you already have a default subnet for this Availability Zone, you must delete it before you can create an IPv6 only subnet.
     */
    Ipv6Native?: Boolean;
  }
  export interface CreateDefaultSubnetResult {
    /**
     * Information about the subnet.
     */
    Subnet?: Subnet;
  }
  export interface CreateDefaultVpcRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateDefaultVpcResult {
    /**
     * Information about the VPC.
     */
    Vpc?: Vpc;
  }
  export interface CreateDhcpOptionsRequest {
    /**
     * A DHCP configuration option.
     */
    DhcpConfigurations: NewDhcpConfigurationList;
    /**
     * The tags to assign to the DHCP option.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateDhcpOptionsResult {
    /**
     * A set of DHCP options.
     */
    DhcpOptions?: DhcpOptions;
  }
  export interface CreateEgressOnlyInternetGatewayRequest {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC for which to create the egress-only internet gateway.
     */
    VpcId: VpcId;
    /**
     * The tags to assign to the egress-only internet gateway.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateEgressOnlyInternetGatewayResult {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    ClientToken?: String;
    /**
     * Information about the egress-only internet gateway.
     */
    EgressOnlyInternetGateway?: EgressOnlyInternetGateway;
  }
  export interface CreateFleetError {
    /**
     * The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
     */
    LaunchTemplateAndOverrides?: LaunchTemplateAndOverridesResponse;
    /**
     * Indicates if the instance that could not be launched was a Spot Instance or On-Demand Instance.
     */
    Lifecycle?: InstanceLifecycle;
    /**
     * The error code that indicates why the instance could not be launched. For more information about error codes, see Error codes.
     */
    ErrorCode?: String;
    /**
     * The error message that describes why the instance could not be launched. For more information about error messages, see Error codes.
     */
    ErrorMessage?: String;
  }
  export type CreateFleetErrorsSet = CreateFleetError[];
  export interface CreateFleetInstance {
    /**
     * The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
     */
    LaunchTemplateAndOverrides?: LaunchTemplateAndOverridesResponse;
    /**
     * Indicates if the instance that was launched is a Spot Instance or On-Demand Instance.
     */
    Lifecycle?: InstanceLifecycle;
    /**
     * The IDs of the instances.
     */
    InstanceIds?: InstanceIdsSet;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The value is Windows for Windows instances. Otherwise, the value is blank.
     */
    Platform?: PlatformValues;
  }
  export type CreateFleetInstancesSet = CreateFleetInstance[];
  export interface CreateFleetRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency.
     */
    ClientToken?: String;
    /**
     * Describes the configuration of Spot Instances in an EC2 Fleet.
     */
    SpotOptions?: SpotOptionsRequest;
    /**
     * Describes the configuration of On-Demand Instances in an EC2 Fleet.
     */
    OnDemandOptions?: OnDemandOptionsRequest;
    /**
     * Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet. Supported only for fleets of type maintain.
     */
    ExcessCapacityTerminationPolicy?: FleetExcessCapacityTerminationPolicy;
    /**
     * The configuration for the EC2 Fleet.
     */
    LaunchTemplateConfigs: FleetLaunchTemplateConfigListRequest;
    /**
     * The number of units to request.
     */
    TargetCapacitySpecification: TargetCapacitySpecificationRequest;
    /**
     * Indicates whether running instances should be terminated when the EC2 Fleet expires.
     */
    TerminateInstancesWithExpiration?: Boolean;
    /**
     * The fleet type. The default value is maintain.    maintain - The EC2 Fleet places an asynchronous request for your desired capacity, and continues to maintain your desired Spot capacity by replenishing interrupted Spot Instances.    request - The EC2 Fleet places an asynchronous one-time request for your desired capacity, but does submit Spot requests in alternative capacity pools if Spot capacity is unavailable, and does not maintain Spot capacity if Spot Instances are interrupted.    instant - The EC2 Fleet places a synchronous one-time request for your desired capacity, and returns errors for any instances that could not be launched.   For more information, see EC2 Fleet request types in the Amazon EC2 User Guide.
     */
    Type?: FleetType;
    /**
     * The start date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately.
     */
    ValidFrom?: DateTime;
    /**
     * The end date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new EC2 Fleet requests are placed or able to fulfill the request. If no value is specified, the request remains until you cancel it.
     */
    ValidUntil?: DateTime;
    /**
     * Indicates whether EC2 Fleet should replace unhealthy Spot Instances. Supported only for fleets of type maintain. For more information, see EC2 Fleet health checks in the Amazon EC2 User Guide.
     */
    ReplaceUnhealthyInstances?: Boolean;
    /**
     * The key-value pair for tagging the EC2 Fleet request on creation. For more information, see Tagging your resources. If the fleet type is instant, specify a resource type of fleet to tag the fleet or instance to tag the instances at launch. If the fleet type is maintain or request, specify a resource type of fleet to tag the fleet. You cannot specify a resource type of instance. To tag instances at launch, specify the tags in a launch template.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Reserved.
     */
    Context?: String;
  }
  export interface CreateFleetResult {
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId?: FleetId;
    /**
     * Information about the instances that could not be launched by the fleet. Supported only for fleets of type instant.
     */
    Errors?: CreateFleetErrorsSet;
    /**
     * Information about the instances that were launched by the fleet. Supported only for fleets of type instant.
     */
    Instances?: CreateFleetInstancesSet;
  }
  export interface CreateFlowLogsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * The ARN of the IAM role that allows Amazon EC2 to publish flow logs to a CloudWatch Logs log group in your account. This parameter is required if the destination type is cloud-watch-logs and unsupported otherwise.
     */
    DeliverLogsPermissionArn?: String;
    /**
     * The ARN of the IAM role that allows Amazon EC2 to publish flow logs across accounts.
     */
    DeliverCrossAccountRole?: String;
    /**
     * The name of a new or existing CloudWatch Logs log group where Amazon EC2 publishes your flow logs. This parameter is valid only if the destination type is cloud-watch-logs.
     */
    LogGroupName?: String;
    /**
     * The IDs of the resources to monitor. For example, if the resource type is VPC, specify the IDs of the VPCs. Constraints: Maximum of 25 for transit gateway resource types. Maximum of 1000 for the other resource types.
     */
    ResourceIds: FlowLogResourceIds;
    /**
     * The type of resource to monitor.
     */
    ResourceType: FlowLogsResourceType;
    /**
     * The type of traffic to monitor (accepted traffic, rejected traffic, or all traffic). This parameter is not supported for transit gateway resource types. It is required for the other resource types.
     */
    TrafficType?: TrafficType;
    /**
     * The type of destination for the flow log data. Default: cloud-watch-logs 
     */
    LogDestinationType?: LogDestinationType;
    /**
     * The destination for the flow log data. The meaning of this parameter depends on the destination type.   If the destination type is cloud-watch-logs, specify the ARN of a CloudWatch Logs log group. For example: arn:aws:logs:region:account_id:log-group:my_group  Alternatively, use the LogGroupName parameter.   If the destination type is s3, specify the ARN of an S3 bucket. For example: arn:aws:s3:::my_bucket/my_subfolder/ The subfolder is optional. Note that you can't use AWSLogs as a subfolder name.   If the destination type is kinesis-data-firehose, specify the ARN of a Kinesis Data Firehose delivery stream. For example: arn:aws:firehose:region:account_id:deliverystream:my_stream   
     */
    LogDestination?: String;
    /**
     * The fields to include in the flow log record. List the fields in the order in which they should appear. If you omit this parameter, the flow log is created using the default format. If you specify this parameter, you must include at least one field. For more information about the available fields, see Flow log records in the Amazon VPC User Guide or Transit Gateway Flow Log records in the Amazon Web Services Transit Gateway Guide. Specify the fields using the ${field-id} format, separated by spaces. For the CLI, surround this parameter value with single quotes on Linux or double quotes on Windows.
     */
    LogFormat?: String;
    /**
     * The tags to apply to the flow logs.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The maximum interval of time during which a flow of packets is captured and aggregated into a flow log record. The possible values are 60 seconds (1 minute) or 600 seconds (10 minutes). This parameter must be 60 seconds for transit gateway resource types. When a network interface is attached to a Nitro-based instance, the aggregation interval is always 60 seconds or less, regardless of the value that you specify. Default: 600
     */
    MaxAggregationInterval?: Integer;
    /**
     * The destination options.
     */
    DestinationOptions?: DestinationOptionsRequest;
  }
  export interface CreateFlowLogsResult {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    ClientToken?: String;
    /**
     * The IDs of the flow logs.
     */
    FlowLogIds?: ValueStringList;
    /**
     * Information about the flow logs that could not be created successfully.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface CreateFpgaImageRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The location of the encrypted design checkpoint in Amazon S3. The input must be a tarball.
     */
    InputStorageLocation: StorageLocation;
    /**
     * The location in Amazon S3 for the output logs.
     */
    LogsStorageLocation?: StorageLocation;
    /**
     * A description for the AFI.
     */
    Description?: String;
    /**
     * A name for the AFI.
     */
    Name?: String;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The tags to apply to the FPGA image during creation.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateFpgaImageResult {
    /**
     * The FPGA image identifier (AFI ID).
     */
    FpgaImageId?: String;
    /**
     * The global FPGA image identifier (AGFI ID).
     */
    FpgaImageGlobalId?: String;
  }
  export interface CreateImageRequest {
    /**
     * The block device mappings. This parameter cannot be used to modify the encryption status of existing volumes or snapshots. To create an AMI with encrypted snapshots, use the CopyImage action.
     */
    BlockDeviceMappings?: BlockDeviceMappingRequestList;
    /**
     * A description for the new image.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * A name for the new image. Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_)
     */
    Name: String;
    /**
     * By default, when Amazon EC2 creates the new AMI, it reboots the instance so that it can take snapshots of the attached volumes while data is at rest, in order to ensure a consistent state. You can set the NoReboot parameter to true in the API request, or use the --no-reboot option in the CLI to prevent Amazon EC2 from shutting down and rebooting the instance.  If you choose to bypass the shutdown and reboot process by setting the NoReboot parameter to true in the API request, or by using the --no-reboot option in the CLI, we can't guarantee the file system integrity of the created image.  Default: false (follow standard reboot process)
     */
    NoReboot?: Boolean;
    /**
     * The tags to apply to the AMI and snapshots on creation. You can tag the AMI, the snapshots, or both.   To tag the AMI, the value for ResourceType must be image.   To tag the snapshots that are created of the root volume and of other Amazon EBS volumes that are attached to the instance, the value for ResourceType must be snapshot. The same tag is applied to all of the snapshots that are created.   If you specify other values for ResourceType, the request fails. To tag an AMI or snapshot after it has been created, see CreateTags. 
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateImageResult {
    /**
     * The ID of the new AMI.
     */
    ImageId?: String;
  }
  export interface CreateInstanceEventWindowRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The name of the event window.
     */
    Name?: String;
    /**
     * The time range for the event window. If you specify a time range, you can't specify a cron expression.
     */
    TimeRanges?: InstanceEventWindowTimeRangeRequestSet;
    /**
     * The cron expression for the event window, for example, * 0-4,20-23 * * 1,5. If you specify a cron expression, you can't specify a time range. Constraints:   Only hour and day of the week values are supported.   For day of the week values, you can specify either integers 0 through 6, or alternative single values SUN through SAT.   The minute, month, and year must be specified by *.   The hour value must be one or a multiple range, for example, 0-4 or 0-4,20-23.   Each hour range must be &gt;= 2 hours, for example, 0-2 or 20-23.   The event window must be &gt;= 4 hours. The combined total time ranges in the event window must be &gt;= 4 hours.   For more information about cron expressions, see cron on the Wikipedia website.
     */
    CronExpression?: InstanceEventWindowCronExpression;
    /**
     * The tags to apply to the event window.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateInstanceEventWindowResult {
    /**
     * Information about the event window.
     */
    InstanceEventWindow?: InstanceEventWindow;
  }
  export interface CreateInstanceExportTaskRequest {
    /**
     * A description for the conversion task or the resource being exported. The maximum length is 255 characters.
     */
    Description?: String;
    /**
     * The format and location for an export instance task.
     */
    ExportToS3Task: ExportToS3TaskSpecification;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The target virtualization environment.
     */
    TargetEnvironment: ExportEnvironment;
    /**
     * The tags to apply to the export instance task during creation.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateInstanceExportTaskResult {
    /**
     * Information about the export instance task.
     */
    ExportTask?: ExportTask;
  }
  export interface CreateInternetGatewayRequest {
    /**
     * The tags to assign to the internet gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateInternetGatewayResult {
    /**
     * Information about the internet gateway.
     */
    InternetGateway?: InternetGateway;
  }
  export interface CreateIpamPoolRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the scope in which you would like to create the IPAM pool.
     */
    IpamScopeId: IpamScopeId;
    /**
     * In IPAM, the locale is the Amazon Web Services Region where you want to make an IPAM pool available for allocations. Only resources in the same Region as the locale of the pool can get IP address allocations from the pool. You can only allocate a CIDR for a VPC, for example, from an IPAM pool that shares a locale with the VPC’s Region. Note that once you choose a Locale for a pool, you cannot modify it. If you do not choose a locale, resources in Regions others than the IPAM's home region cannot use CIDRs from this pool. Possible values: Any Amazon Web Services Region, such as us-east-1.
     */
    Locale?: String;
    /**
     * The ID of the source IPAM pool. Use this option to create a pool within an existing pool. Note that the CIDR you provision for the pool within the source pool must be available in the source pool's CIDR range.
     */
    SourceIpamPoolId?: IpamPoolId;
    /**
     * A description for the IPAM pool.
     */
    Description?: String;
    /**
     * The IP protocol assigned to this IPAM pool. You must choose either IPv4 or IPv6 protocol for a pool.
     */
    AddressFamily: AddressFamily;
    /**
     * If selected, IPAM will continuously look for resources within the CIDR range of this pool and automatically import them as allocations into your IPAM. The CIDRs that will be allocated for these resources must not already be allocated to other resources in order for the import to succeed. IPAM will import a CIDR regardless of its compliance with the pool's allocation rules, so a resource might be imported and subsequently marked as noncompliant. If IPAM discovers multiple CIDRs that overlap, IPAM will import the largest CIDR only. If IPAM discovers multiple CIDRs with matching CIDRs, IPAM will randomly import one of them only.  A locale must be set on the pool for this feature to work.
     */
    AutoImport?: Boolean;
    /**
     * Determines if the pool is publicly advertisable. This option is not available for pools with AddressFamily set to ipv4.
     */
    PubliclyAdvertisable?: Boolean;
    /**
     * The minimum netmask length required for CIDR allocations in this IPAM pool to be compliant. The minimum netmask length must be less than the maximum netmask length. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.
     */
    AllocationMinNetmaskLength?: IpamNetmaskLength;
    /**
     * The maximum netmask length possible for CIDR allocations in this IPAM pool to be compliant. The maximum netmask length must be greater than the minimum netmask length. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.
     */
    AllocationMaxNetmaskLength?: IpamNetmaskLength;
    /**
     * The default netmask length for allocations added to this pool. If, for example, the CIDR assigned to this pool is 10.0.0.0/8 and you enter 16 here, new allocations will default to 10.0.0.0/16.
     */
    AllocationDefaultNetmaskLength?: IpamNetmaskLength;
    /**
     * Tags that are required for resources that use CIDRs from this IPAM pool. Resources that do not have these tags will not be allowed to allocate space from the pool. If the resources have their tags changed after they have allocated space or if the allocation tagging requirements are changed on the pool, the resource may be marked as noncompliant.
     */
    AllocationResourceTags?: RequestIpamResourceTagList;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Limits which service in Amazon Web Services that the pool can be used in. "ec2", for example, allows users to use space for Elastic IP addresses and VPCs.
     */
    AwsService?: IpamPoolAwsService;
    /**
     * The IP address source for pools in the public scope. Only used for provisioning IP address CIDRs to pools in the public scope. Default is byoip. For more information, see Create IPv6 pools in the Amazon VPC IPAM User Guide. By default, you can add only one Amazon-provided IPv6 CIDR block to a top-level IPv6 pool if PublicIpSource is amazon. For information on increasing the default limit, see  Quotas for your IPAM in the Amazon VPC IPAM User Guide.
     */
    PublicIpSource?: IpamPoolPublicIpSource;
  }
  export interface CreateIpamPoolResult {
    /**
     * Information about the IPAM pool created.
     */
    IpamPool?: IpamPool;
  }
  export interface CreateIpamRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A description for the IPAM.
     */
    Description?: String;
    /**
     * The operating Regions for the IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.  For more information about operating Regions, see Create an IPAM in the Amazon VPC IPAM User Guide. 
     */
    OperatingRegions?: AddIpamOperatingRegionSet;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateIpamResourceDiscoveryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A description for the IPAM resource discovery.
     */
    Description?: String;
    /**
     * Operating Regions for the IPAM resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
     */
    OperatingRegions?: AddIpamOperatingRegionSet;
    /**
     * Tag specifications for the IPAM resource discovery.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A client token for the IPAM resource discovery.
     */
    ClientToken?: String;
  }
  export interface CreateIpamResourceDiscoveryResult {
    /**
     * An IPAM resource discovery.
     */
    IpamResourceDiscovery?: IpamResourceDiscovery;
  }
  export interface CreateIpamResult {
    /**
     * Information about the IPAM created.
     */
    Ipam?: Ipam;
  }
  export interface CreateIpamScopeRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM for which you're creating this scope.
     */
    IpamId: IpamId;
    /**
     * A description for the scope you're creating.
     */
    Description?: String;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateIpamScopeResult {
    /**
     * Information about the created scope.
     */
    IpamScope?: IpamScope;
  }
  export interface CreateKeyPairRequest {
    /**
     * A unique name for the key pair. Constraints: Up to 255 ASCII characters
     */
    KeyName: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The type of key pair. Note that ED25519 keys are not supported for Windows instances. Default: rsa 
     */
    KeyType?: KeyType;
    /**
     * The tags to apply to the new key pair.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The format of the key pair. Default: pem 
     */
    KeyFormat?: KeyFormat;
  }
  export interface CreateLaunchTemplateRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency. Constraint: Maximum 128 ASCII characters.
     */
    ClientToken?: String;
    /**
     * A name for the launch template.
     */
    LaunchTemplateName: LaunchTemplateName;
    /**
     * A description for the first version of the launch template.
     */
    VersionDescription?: VersionDescription;
    /**
     * The information for the launch template.
     */
    LaunchTemplateData: RequestLaunchTemplateData;
    /**
     * The tags to apply to the launch template on creation. To tag the launch template, the resource type must be launch-template.  To specify the tags for the resources that are created when an instance is launched, you must use the TagSpecifications parameter in the launch template data structure. 
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateLaunchTemplateResult {
    /**
     * Information about the launch template.
     */
    LaunchTemplate?: LaunchTemplate;
    /**
     * If the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.
     */
    Warning?: ValidationWarning;
  }
  export interface CreateLaunchTemplateVersionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency. Constraint: Maximum 128 ASCII characters.
     */
    ClientToken?: String;
    /**
     * The ID of the launch template. You must specify either the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The version number of the launch template version on which to base the new version. The new version inherits the same launch parameters as the source version, except for parameters that you specify in LaunchTemplateData. Snapshots applied to the block device mapping are ignored when creating a new version unless they are explicitly included.
     */
    SourceVersion?: String;
    /**
     * A description for the version of the launch template.
     */
    VersionDescription?: VersionDescription;
    /**
     * The information for the launch template.
     */
    LaunchTemplateData: RequestLaunchTemplateData;
    /**
     * If true, and if a Systems Manager parameter is specified for ImageId, the AMI ID is displayed in the response for imageID. For more information, see Use a Systems Manager parameter instead of an AMI ID in the Amazon Elastic Compute Cloud User Guide. Default: false 
     */
    ResolveAlias?: Boolean;
  }
  export interface CreateLaunchTemplateVersionResult {
    /**
     * Information about the launch template version.
     */
    LaunchTemplateVersion?: LaunchTemplateVersion;
    /**
     * If the new version of the launch template contains parameters or parameter combinations that are not valid, an error code and an error message are returned for each issue that's found.
     */
    Warning?: ValidationWarning;
  }
  export interface CreateLocalGatewayRouteRequest {
    /**
     * The CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    DestinationCidrBlock?: String;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     * The ID of the virtual interface group.
     */
    LocalGatewayVirtualInterfaceGroupId?: LocalGatewayVirtualInterfaceGroupId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     *  The ID of the prefix list. Use a prefix list in place of DestinationCidrBlock. You cannot use DestinationPrefixListId and DestinationCidrBlock in the same request. 
     */
    DestinationPrefixListId?: PrefixListResourceId;
  }
  export interface CreateLocalGatewayRouteResult {
    /**
     * Information about the route.
     */
    Route?: LocalGatewayRoute;
  }
  export interface CreateLocalGatewayRouteTableRequest {
    /**
     *  The ID of the local gateway. 
     */
    LocalGatewayId: LocalGatewayId;
    /**
     *  The mode of the local gateway route table. 
     */
    Mode?: LocalGatewayRouteTableMode;
    /**
     *  The tags assigned to the local gateway route table. 
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateLocalGatewayRouteTableResult {
    /**
     * Information about the local gateway route table.
     */
    LocalGatewayRouteTable?: LocalGatewayRouteTable;
  }
  export interface CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest {
    /**
     *  The ID of the local gateway route table. 
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     *  The ID of the local gateway route table virtual interface group association. 
     */
    LocalGatewayVirtualInterfaceGroupId: LocalGatewayVirtualInterfaceGroupId;
    /**
     *  The tags assigned to the local gateway route table virtual interface group association. 
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult {
    /**
     * Information about the local gateway route table virtual interface group association.
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociation?: LocalGatewayRouteTableVirtualInterfaceGroupAssociation;
  }
  export interface CreateLocalGatewayRouteTableVpcAssociationRequest {
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The tags to assign to the local gateway route table VPC association.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateLocalGatewayRouteTableVpcAssociationResult {
    /**
     * Information about the association.
     */
    LocalGatewayRouteTableVpcAssociation?: LocalGatewayRouteTableVpcAssociation;
  }
  export interface CreateManagedPrefixListRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A name for the prefix list. Constraints: Up to 255 characters in length. The name cannot start with com.amazonaws.
     */
    PrefixListName: String;
    /**
     * One or more entries for the prefix list.
     */
    Entries?: AddPrefixListEntries;
    /**
     * The maximum number of entries for the prefix list.
     */
    MaxEntries: Integer;
    /**
     * The tags to apply to the prefix list during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The IP address type. Valid Values: IPv4 | IPv6 
     */
    AddressFamily: String;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Constraints: Up to 255 UTF-8 characters in length.
     */
    ClientToken?: String;
  }
  export interface CreateManagedPrefixListResult {
    /**
     * Information about the prefix list.
     */
    PrefixList?: ManagedPrefixList;
  }
  export interface CreateNatGatewayRequest {
    /**
     * [Public NAT gateways only] The allocation ID of an Elastic IP address to associate with the NAT gateway. You cannot specify an Elastic IP address with a private NAT gateway. If the Elastic IP address is associated with another resource, you must first disassociate it.
     */
    AllocationId?: AllocationId;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency. Constraint: Maximum 64 ASCII characters.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the subnet in which to create the NAT gateway.
     */
    SubnetId: SubnetId;
    /**
     * The tags to assign to the NAT gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Indicates whether the NAT gateway supports public or private connectivity. The default is public connectivity.
     */
    ConnectivityType?: ConnectivityType;
    /**
     * The private IPv4 address to assign to the NAT gateway. If you don't provide an address, a private IPv4 address will be automatically assigned.
     */
    PrivateIpAddress?: String;
    /**
     * Secondary EIP allocation IDs. For more information about secondary addresses, see Create a NAT gateway in the Amazon Virtual Private Cloud User Guide.
     */
    SecondaryAllocationIds?: AllocationIdList;
    /**
     * Secondary private IPv4 addresses. For more information about secondary addresses, see Create a NAT gateway in the Amazon Virtual Private Cloud User Guide.
     */
    SecondaryPrivateIpAddresses?: IpList;
    /**
     * [Private NAT gateway only] The number of secondary private IPv4 addresses you want to assign to the NAT gateway. For more information about secondary addresses, see Create a NAT gateway in the Amazon Virtual Private Cloud User Guide.
     */
    SecondaryPrivateIpAddressCount?: PrivateIpAddressCount;
  }
  export interface CreateNatGatewayResult {
    /**
     * Unique, case-sensitive identifier to ensure the idempotency of the request. Only returned if a client token was provided in the request.
     */
    ClientToken?: String;
    /**
     * Information about the NAT gateway.
     */
    NatGateway?: NatGateway;
  }
  export interface CreateNetworkAclEntryRequest {
    /**
     * The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24). We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.
     */
    CidrBlock?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether this is an egress rule (rule is applied to traffic leaving the subnet).
     */
    Egress: Boolean;
    /**
     * ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.
     */
    IcmpTypeCode?: IcmpTypeCode;
    /**
     * The IPv6 network range to allow or deny, in CIDR notation (for example 2001:db8:1234:1a00::/64).
     */
    Ipv6CidrBlock?: String;
    /**
     * The ID of the network ACL.
     */
    NetworkAclId: NetworkAclId;
    /**
     * TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).
     */
    PortRange?: PortRange;
    /**
     * The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
     */
    Protocol: String;
    /**
     * Indicates whether to allow or deny the traffic that matches the rule.
     */
    RuleAction: RuleAction;
    /**
     * The rule number for the entry (for example, 100). ACL entries are processed in ascending order by rule number. Constraints: Positive integer from 1 to 32766. The range 32767 to 65535 is reserved for internal use.
     */
    RuleNumber: Integer;
  }
  export interface CreateNetworkAclRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The tags to assign to the network ACL.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateNetworkAclResult {
    /**
     * Information about the network ACL.
     */
    NetworkAcl?: NetworkAcl;
  }
  export interface CreateNetworkInsightsAccessScopeRequest {
    /**
     * The paths to match.
     */
    MatchPaths?: AccessScopePathListRequest;
    /**
     * The paths to exclude.
     */
    ExcludePaths?: AccessScopePathListRequest;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken: String;
    /**
     * The tags to apply.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateNetworkInsightsAccessScopeResult {
    /**
     * The Network Access Scope.
     */
    NetworkInsightsAccessScope?: NetworkInsightsAccessScope;
    /**
     * The Network Access Scope content.
     */
    NetworkInsightsAccessScopeContent?: NetworkInsightsAccessScopeContent;
  }
  export interface CreateNetworkInsightsPathRequest {
    /**
     * The IP address of the source.
     */
    SourceIp?: IpAddress;
    /**
     * The IP address of the destination.
     */
    DestinationIp?: IpAddress;
    /**
     * The ID or ARN of the source. If the resource is in another account, you must specify an ARN.
     */
    Source: NetworkInsightsResourceId;
    /**
     * The ID or ARN of the destination. If the resource is in another account, you must specify an ARN.
     */
    Destination?: NetworkInsightsResourceId;
    /**
     * The protocol.
     */
    Protocol: Protocol;
    /**
     * The destination port.
     */
    DestinationPort?: Port;
    /**
     * The tags to add to the path.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken: String;
    /**
     * Scopes the analysis to network paths that match specific filters at the source. If you specify this parameter, you can't specify the parameters for the source IP address or the destination port.
     */
    FilterAtSource?: PathRequestFilter;
    /**
     * Scopes the analysis to network paths that match specific filters at the destination. If you specify this parameter, you can't specify the parameter for the destination IP address.
     */
    FilterAtDestination?: PathRequestFilter;
  }
  export interface CreateNetworkInsightsPathResult {
    /**
     * Information about the path.
     */
    NetworkInsightsPath?: NetworkInsightsPath;
  }
  export interface CreateNetworkInterfacePermissionRequest {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The Amazon Web Services account ID.
     */
    AwsAccountId?: String;
    /**
     * The Amazon Web Service. Currently not supported.
     */
    AwsService?: String;
    /**
     * The type of permission to grant.
     */
    Permission: InterfacePermissionType;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateNetworkInterfacePermissionResult {
    /**
     * Information about the permission for the network interface.
     */
    InterfacePermission?: NetworkInterfacePermission;
  }
  export interface CreateNetworkInterfaceRequest {
    /**
     * A description for the network interface.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of one or more security groups.
     */
    Groups?: SecurityGroupIdStringList;
    /**
     * The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't specify a count of IPv6 addresses using this parameter if you've specified one of the following: specific IPv6 addresses, specific IPv6 prefixes, or a count of IPv6 prefixes. If your subnet has the AssignIpv6AddressOnCreation attribute set, you can override that setting by specifying 0 as the IPv6 address count.
     */
    Ipv6AddressCount?: Integer;
    /**
     * The IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't specify IPv6 addresses using this parameter if you've specified one of the following: a count of IPv6 addresses, specific IPv6 prefixes, or a count of IPv6 prefixes.
     */
    Ipv6Addresses?: InstanceIpv6AddressList;
    /**
     * The primary private IPv4 address of the network interface. If you don't specify an IPv4 address, Amazon EC2 selects one for you from the subnet's IPv4 CIDR range. If you specify an IP address, you cannot indicate any IP addresses specified in privateIpAddresses as primary (only one IP address can be designated as primary).
     */
    PrivateIpAddress?: String;
    /**
     * The private IPv4 addresses. You can't specify private IPv4 addresses if you've specified one of the following: a count of private IPv4 addresses, specific IPv4 prefixes, or a count of IPv4 prefixes.
     */
    PrivateIpAddresses?: PrivateIpAddressSpecificationList;
    /**
     * The number of secondary private IPv4 addresses to assign to a network interface. When you specify a number of secondary IPv4 addresses, Amazon EC2 selects these IP addresses within the subnet's IPv4 CIDR range. You can't specify this option and specify more than one private IP address using privateIpAddresses. You can't specify a count of private IPv4 addresses if you've specified one of the following: specific private IPv4 addresses, specific IPv4 prefixes, or a count of IPv4 prefixes.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * The IPv4 prefixes assigned to the network interface. You can't specify IPv4 prefixes if you've specified one of the following: a count of IPv4 prefixes, specific private IPv4 addresses, or a count of private IPv4 addresses.
     */
    Ipv4Prefixes?: Ipv4PrefixList;
    /**
     * The number of IPv4 prefixes that Amazon Web Services automatically assigns to the network interface. You can't specify a count of IPv4 prefixes if you've specified one of the following: specific IPv4 prefixes, specific private IPv4 addresses, or a count of private IPv4 addresses.
     */
    Ipv4PrefixCount?: Integer;
    /**
     * The IPv6 prefixes assigned to the network interface. You can't specify IPv6 prefixes if you've specified one of the following: a count of IPv6 prefixes, specific IPv6 addresses, or a count of IPv6 addresses.
     */
    Ipv6Prefixes?: Ipv6PrefixList;
    /**
     * The number of IPv6 prefixes that Amazon Web Services automatically assigns to the network interface. You can't specify a count of IPv6 prefixes if you've specified one of the following: specific IPv6 prefixes, specific IPv6 addresses, or a count of IPv6 addresses.
     */
    Ipv6PrefixCount?: Integer;
    /**
     * The type of network interface. The default is interface. The only supported values are efa and trunk.
     */
    InterfaceType?: NetworkInterfaceCreationType;
    /**
     * The ID of the subnet to associate with the network interface.
     */
    SubnetId: SubnetId;
    /**
     * The tags to apply to the new network interface.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateNetworkInterfaceResult {
    /**
     * Information about the network interface.
     */
    NetworkInterface?: NetworkInterface;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    ClientToken?: String;
  }
  export interface CreatePlacementGroupRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A name for the placement group. Must be unique within the scope of your account for the Region. Constraints: Up to 255 ASCII characters
     */
    GroupName?: String;
    /**
     * The placement strategy.
     */
    Strategy?: PlacementStrategy;
    /**
     * The number of partitions. Valid only when Strategy is set to partition.
     */
    PartitionCount?: Integer;
    /**
     * The tags to apply to the new placement group.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Determines how placement groups spread instances.    Host – You can use host only with Outpost placement groups.   Rack – No usage restrictions.  
     */
    SpreadLevel?: SpreadLevel;
  }
  export interface CreatePlacementGroupResult {
    /**
     * Information about the placement group.
     */
    PlacementGroup?: PlacementGroup;
  }
  export interface CreatePublicIpv4PoolRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreatePublicIpv4PoolResult {
    /**
     * The ID of the public IPv4 pool.
     */
    PoolId?: Ipv4PoolEc2Id;
  }
  export interface CreateReplaceRootVolumeTaskRequest {
    /**
     * The ID of the instance for which to replace the root volume.
     */
    InstanceId: InstanceId;
    /**
     * The ID of the snapshot from which to restore the replacement root volume. The specified snapshot must be a snapshot that you previously created from the original root volume. If you want to restore the replacement root volume to the initial launch state, or if you want to restore the replacement root volume from an AMI, omit this parameter.
     */
    SnapshotId?: SnapshotId;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency. For more information, see Ensuring idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to apply to the root volume replacement task.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The ID of the AMI to use to restore the root volume. The specified AMI must have the same product code, billing information, architecture type, and virtualization type as that of the instance. If you want to restore the replacement volume from a specific snapshot, or if you want to restore it to its launch state, omit this parameter.
     */
    ImageId?: ImageId;
    /**
     * Indicates whether to automatically delete the original root volume after the root volume replacement task completes. To delete the original root volume, specify true. If you choose to keep the original root volume after the replacement task completes, you must manually delete it when you no longer need it.
     */
    DeleteReplacedRootVolume?: Boolean;
  }
  export interface CreateReplaceRootVolumeTaskResult {
    /**
     * Information about the root volume replacement task.
     */
    ReplaceRootVolumeTask?: ReplaceRootVolumeTask;
  }
  export interface CreateReservedInstancesListingRequest {
    /**
     * Unique, case-sensitive identifier you provide to ensure idempotency of your listings. This helps avoid duplicate listings. For more information, see Ensuring Idempotency.
     */
    ClientToken: String;
    /**
     * The number of instances that are a part of a Reserved Instance account to be listed in the Reserved Instance Marketplace. This number should be less than or equal to the instance count associated with the Reserved Instance ID specified in this call.
     */
    InstanceCount: Integer;
    /**
     * A list specifying the price of the Standard Reserved Instance for each month remaining in the Reserved Instance term.
     */
    PriceSchedules: PriceScheduleSpecificationList;
    /**
     * The ID of the active Standard Reserved Instance.
     */
    ReservedInstancesId: ReservationId;
  }
  export interface CreateReservedInstancesListingResult {
    /**
     * Information about the Standard Reserved Instance listing.
     */
    ReservedInstancesListings?: ReservedInstancesListingList;
  }
  export interface CreateRestoreImageTaskRequest {
    /**
     * The name of the Amazon S3 bucket that contains the stored AMI object.
     */
    Bucket: String;
    /**
     * The name of the stored AMI object in the bucket.
     */
    ObjectKey: String;
    /**
     * The name for the restored AMI. The name must be unique for AMIs in the Region for this account. If you do not provide a name, the new AMI gets the same name as the original AMI.
     */
    Name?: String;
    /**
     * The tags to apply to the AMI and snapshots on restoration. You can tag the AMI, the snapshots, or both.   To tag the AMI, the value for ResourceType must be image.   To tag the snapshots, the value for ResourceType must be snapshot. The same tag is applied to all of the snapshots that are created.  
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateRestoreImageTaskResult {
    /**
     * The AMI ID.
     */
    ImageId?: String;
  }
  export interface CreateRouteRequest {
    /**
     * The IPv4 CIDR address block used for the destination match. Routing decisions are based on the most specific match. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.
     */
    DestinationCidrBlock?: String;
    /**
     * The IPv6 CIDR block used for the destination match. Routing decisions are based on the most specific match.
     */
    DestinationIpv6CidrBlock?: String;
    /**
     * The ID of a prefix list used for the destination match.
     */
    DestinationPrefixListId?: PrefixListResourceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
     */
    VpcEndpointId?: VpcEndpointId;
    /**
     * [IPv6 traffic only] The ID of an egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId?: EgressOnlyInternetGatewayId;
    /**
     * The ID of an internet gateway or virtual private gateway attached to your VPC.
     */
    GatewayId?: RouteGatewayId;
    /**
     * The ID of a NAT instance in your VPC. The operation fails if you specify an instance ID unless exactly one network interface is attached.
     */
    InstanceId?: InstanceId;
    /**
     * [IPv4 traffic only] The ID of a NAT gateway.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * The ID of a transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: LocalGatewayId;
    /**
     * The ID of the carrier gateway. You can only use this option when the VPC contains a subnet which is associated with a Wavelength Zone.
     */
    CarrierGatewayId?: CarrierGatewayId;
    /**
     * The ID of a network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The ID of the route table for the route.
     */
    RouteTableId: RouteTableId;
    /**
     * The ID of a VPC peering connection.
     */
    VpcPeeringConnectionId?: VpcPeeringConnectionId;
    /**
     * The Amazon Resource Name (ARN) of the core network.
     */
    CoreNetworkArn?: CoreNetworkArn;
  }
  export interface CreateRouteResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface CreateRouteTableRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The tags to assign to the route table.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateRouteTableResult {
    /**
     * Information about the route table.
     */
    RouteTable?: RouteTable;
  }
  export interface CreateSecurityGroupRequest {
    /**
     * A description for the security group. Constraints: Up to 255 characters in length Constraints for EC2-Classic: ASCII characters Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&amp;;{}!$*
     */
    Description: String;
    /**
     * The name of the security group. Constraints: Up to 255 characters in length. Cannot start with sg-. Constraints for EC2-Classic: ASCII characters Constraints for EC2-VPC: a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&amp;;{}!$*
     */
    GroupName: String;
    /**
     * [EC2-VPC] The ID of the VPC. Required for EC2-VPC.
     */
    VpcId?: VpcId;
    /**
     * The tags to assign to the security group.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateSecurityGroupResult {
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * The tags assigned to the security group.
     */
    Tags?: TagList;
  }
  export interface CreateSnapshotRequest {
    /**
     * A description for the snapshot.
     */
    Description?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost on which to create a local snapshot.   To create a snapshot of a volume in a Region, omit this parameter. The snapshot is created in the same Region as the volume.   To create a snapshot of a volume on an Outpost and store the snapshot in the Region, omit this parameter. The snapshot is created in the Region for the Outpost.   To create a snapshot of a volume on an Outpost and store the snapshot on an Outpost, specify the ARN of the destination Outpost. The snapshot must be created on the same Outpost as the volume.   For more information, see Create local snapshots from volumes on an Outpost in the Amazon Elastic Compute Cloud User Guide.
     */
    OutpostArn?: String;
    /**
     * The ID of the Amazon EBS volume.
     */
    VolumeId: VolumeId;
    /**
     * The tags to apply to the snapshot during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateSnapshotsRequest {
    /**
     *  A description propagated to every snapshot specified by the instance.
     */
    Description?: String;
    /**
     * The instance to specify which volumes should be included in the snapshots.
     */
    InstanceSpecification: InstanceSpecification;
    /**
     * The Amazon Resource Name (ARN) of the Outpost on which to create the local snapshots.   To create snapshots from an instance in a Region, omit this parameter. The snapshots are created in the same Region as the instance.   To create snapshots from an instance on an Outpost and store the snapshots in the Region, omit this parameter. The snapshots are created in the Region for the Outpost.   To create snapshots from an instance on an Outpost and store the snapshots on an Outpost, specify the ARN of the destination Outpost. The snapshots must be created on the same Outpost as the instance.   For more information, see  Create multi-volume local snapshots from instances on an Outpost in the Amazon Elastic Compute Cloud User Guide.
     */
    OutpostArn?: String;
    /**
     * Tags to apply to every snapshot specified by the instance.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Copies the tags from the specified volume to corresponding snapshot.
     */
    CopyTagsFromSource?: CopyTagsFromSource;
  }
  export interface CreateSnapshotsResult {
    /**
     * List of snapshots.
     */
    Snapshots?: SnapshotSet;
  }
  export interface CreateSpotDatafeedSubscriptionRequest {
    /**
     * The name of the Amazon S3 bucket in which to store the Spot Instance data feed. For more information about bucket names, see Rules for bucket naming in the Amazon S3 Developer Guide.
     */
    Bucket: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The prefix for the data feed file names.
     */
    Prefix?: String;
  }
  export interface CreateSpotDatafeedSubscriptionResult {
    /**
     * The Spot Instance data feed subscription.
     */
    SpotDatafeedSubscription?: SpotDatafeedSubscription;
  }
  export interface CreateStoreImageTaskRequest {
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * The name of the Amazon S3 bucket in which the AMI object will be stored. The bucket must be in the Region in which the request is being made. The AMI object appears in the bucket only after the upload task has completed. 
     */
    Bucket: String;
    /**
     * The tags to apply to the AMI object that will be stored in the Amazon S3 bucket. 
     */
    S3ObjectTags?: S3ObjectTagList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateStoreImageTaskResult {
    /**
     * The name of the stored AMI object in the S3 bucket.
     */
    ObjectKey?: String;
  }
  export interface CreateSubnetCidrReservationRequest {
    /**
     * The ID of the subnet.
     */
    SubnetId: SubnetId;
    /**
     * The IPv4 or IPV6 CIDR range to reserve.
     */
    Cidr: String;
    /**
     * The type of reservation. The following are valid values:    prefix: The Amazon EC2 Prefix Delegation feature assigns the IP addresses to network interfaces that are associated with an instance. For information about Prefix Delegation, see Prefix Delegation for Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.    explicit: You manually assign the IP addresses to resources that reside in your subnet.   
     */
    ReservationType: SubnetCidrReservationType;
    /**
     * The description to assign to the subnet CIDR reservation.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to assign to the subnet CIDR reservation.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateSubnetCidrReservationResult {
    /**
     * Information about the created subnet CIDR reservation.
     */
    SubnetCidrReservation?: SubnetCidrReservation;
  }
  export interface CreateSubnetRequest {
    /**
     * The tags to assign to the subnet.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The Availability Zone or Local Zone for the subnet. Default: Amazon Web Services selects one for you. If you create more than one subnet in your VPC, we do not necessarily select a different zone for each subnet. To create a subnet in a Local Zone, set this value to the Local Zone ID, for example us-west-2-lax-1a. For information about the Regions that support Local Zones, see Available Regions in the Amazon Elastic Compute Cloud User Guide. To create a subnet in an Outpost, set this value to the Availability Zone for the Outpost and specify the Outpost ARN.
     */
    AvailabilityZone?: String;
    /**
     * The AZ ID or the Local Zone ID of the subnet.
     */
    AvailabilityZoneId?: String;
    /**
     * The IPv4 network range for the subnet, in CIDR notation. For example, 10.0.0.0/24. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18. This parameter is not supported for an IPv6 only subnet.
     */
    CidrBlock?: String;
    /**
     * The IPv6 network range for the subnet, in CIDR notation. The subnet size must use a /64 prefix length. This parameter is required for an IPv6 only subnet.
     */
    Ipv6CidrBlock?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost. If you specify an Outpost ARN, you must also specify the Availability Zone of the Outpost subnet.
     */
    OutpostArn?: String;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to create an IPv6 only subnet.
     */
    Ipv6Native?: Boolean;
  }
  export interface CreateSubnetResult {
    /**
     * Information about the subnet.
     */
    Subnet?: Subnet;
  }
  export interface CreateTagsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the resources, separated by spaces. Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
     */
    Resources: ResourceIdList;
    /**
     * The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.
     */
    Tags: TagList;
  }
  export interface CreateTrafficMirrorFilterRequest {
    /**
     * The description of the Traffic Mirror filter.
     */
    Description?: String;
    /**
     * The tags to assign to a Traffic Mirror filter.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorFilterResult {
    /**
     * Information about the Traffic Mirror filter.
     */
    TrafficMirrorFilter?: TrafficMirrorFilter;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorFilterRuleRequest {
    /**
     * The ID of the filter that this rule is associated with.
     */
    TrafficMirrorFilterId: TrafficMirrorFilterId;
    /**
     * The type of traffic.
     */
    TrafficDirection: TrafficDirection;
    /**
     * The number of the Traffic Mirror rule. This number must be unique for each Traffic Mirror rule in a given direction. The rules are processed in ascending order by rule number.
     */
    RuleNumber: Integer;
    /**
     * The action to take on the filtered traffic.
     */
    RuleAction: TrafficMirrorRuleAction;
    /**
     * The destination port range.
     */
    DestinationPortRange?: TrafficMirrorPortRangeRequest;
    /**
     * The source port range.
     */
    SourcePortRange?: TrafficMirrorPortRangeRequest;
    /**
     * The protocol, for example UDP, to assign to the Traffic Mirror rule. For information about the protocol value, see Protocol Numbers on the Internet Assigned Numbers Authority (IANA) website.
     */
    Protocol?: Integer;
    /**
     * The destination CIDR block to assign to the Traffic Mirror rule.
     */
    DestinationCidrBlock: String;
    /**
     * The source CIDR block to assign to the Traffic Mirror rule.
     */
    SourceCidrBlock: String;
    /**
     * The description of the Traffic Mirror rule.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorFilterRuleResult {
    /**
     * The Traffic Mirror rule.
     */
    TrafficMirrorFilterRule?: TrafficMirrorFilterRule;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorSessionRequest {
    /**
     * The ID of the source network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The ID of the Traffic Mirror target.
     */
    TrafficMirrorTargetId: TrafficMirrorTargetId;
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId: TrafficMirrorFilterId;
    /**
     * The number of bytes in each packet to mirror. These are bytes after the VXLAN header. Do not specify this parameter when you want to mirror the entire packet. To mirror a subset of the packet, set this to the length (in bytes) that you want to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. If you do not want to mirror the entire packet, use the PacketLength parameter to specify the number of bytes in each packet to mirror.
     */
    PacketLength?: Integer;
    /**
     * The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets. Valid values are 1-32766.
     */
    SessionNumber: Integer;
    /**
     * The VXLAN ID for the Traffic Mirror session. For more information about the VXLAN protocol, see RFC 7348. If you do not specify a VirtualNetworkId, an account-wide unique id is chosen at random.
     */
    VirtualNetworkId?: Integer;
    /**
     * The description of the Traffic Mirror session.
     */
    Description?: String;
    /**
     * The tags to assign to a Traffic Mirror session.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorSessionResult {
    /**
     * Information about the Traffic Mirror session.
     */
    TrafficMirrorSession?: TrafficMirrorSession;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTrafficMirrorTargetRequest {
    /**
     * The network interface ID that is associated with the target.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the target.
     */
    NetworkLoadBalancerArn?: String;
    /**
     * The description of the Traffic Mirror target.
     */
    Description?: String;
    /**
     * The tags to assign to the Traffic Mirror target.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * The ID of the Gateway Load Balancer endpoint.
     */
    GatewayLoadBalancerEndpointId?: VpcEndpointId;
  }
  export interface CreateTrafficMirrorTargetResult {
    /**
     * Information about the Traffic Mirror target.
     */
    TrafficMirrorTarget?: TrafficMirrorTarget;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateTransitGatewayConnectPeerRequest {
    /**
     * The ID of the Connect attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * The peer IP address (GRE outer IP address) on the transit gateway side of the Connect peer, which must be specified from a transit gateway CIDR block. If not specified, Amazon automatically assigns the first available IP address from the transit gateway CIDR block.
     */
    TransitGatewayAddress?: String;
    /**
     * The peer IP address (GRE outer IP address) on the appliance side of the Connect peer.
     */
    PeerAddress: String;
    /**
     * The BGP options for the Connect peer.
     */
    BgpOptions?: TransitGatewayConnectRequestBgpOptions;
    /**
     * The range of inside IP addresses that are used for BGP peering. You must specify a size /29 IPv4 CIDR block from the 169.254.0.0/16 range. The first address from the range must be configured on the appliance as the BGP IP address. You can also optionally specify a size /125 IPv6 CIDR block from the fd00::/8 range.
     */
    InsideCidrBlocks: InsideCidrBlocksStringList;
    /**
     * The tags to apply to the Connect peer.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayConnectPeerResult {
    /**
     * Information about the Connect peer.
     */
    TransitGatewayConnectPeer?: TransitGatewayConnectPeer;
  }
  export interface CreateTransitGatewayConnectRequest {
    /**
     * The ID of the transit gateway attachment. You can specify a VPC attachment or Amazon Web Services Direct Connect attachment.
     */
    TransportTransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * The Connect attachment options.
     */
    Options: CreateTransitGatewayConnectRequestOptions;
    /**
     * The tags to apply to the Connect attachment.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayConnectRequestOptions {
    /**
     * The tunnel protocol.
     */
    Protocol: ProtocolValue;
  }
  export interface CreateTransitGatewayConnectResult {
    /**
     * Information about the Connect attachment.
     */
    TransitGatewayConnect?: TransitGatewayConnect;
  }
  export interface CreateTransitGatewayMulticastDomainRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The options for the transit gateway multicast domain.
     */
    Options?: CreateTransitGatewayMulticastDomainRequestOptions;
    /**
     * The tags for the transit gateway multicast domain.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayMulticastDomainRequestOptions {
    /**
     * Specify whether to enable Internet Group Management Protocol (IGMP) version 2 for the transit gateway multicast domain.
     */
    Igmpv2Support?: Igmpv2SupportValue;
    /**
     * Specify whether to enable support for statically configuring multicast group sources for a domain.
     */
    StaticSourcesSupport?: StaticSourcesSupportValue;
    /**
     * Indicates whether to automatically accept cross-account subnet associations that are associated with the transit gateway multicast domain.
     */
    AutoAcceptSharedAssociations?: AutoAcceptSharedAssociationsValue;
  }
  export interface CreateTransitGatewayMulticastDomainResult {
    /**
     * Information about the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomain?: TransitGatewayMulticastDomain;
  }
  export interface CreateTransitGatewayPeeringAttachmentRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The ID of the peer transit gateway with which to create the peering attachment.
     */
    PeerTransitGatewayId: TransitAssociationGatewayId;
    /**
     * The ID of the Amazon Web Services account that owns the peer transit gateway.
     */
    PeerAccountId: String;
    /**
     * The Region where the peer transit gateway is located.
     */
    PeerRegion: String;
    /**
     * Requests a transit gateway peering attachment.
     */
    Options?: CreateTransitGatewayPeeringAttachmentRequestOptions;
    /**
     * The tags to apply to the transit gateway peering attachment.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayPeeringAttachmentRequestOptions {
    /**
     * Indicates whether dynamic routing is enabled or disabled.
     */
    DynamicRouting?: DynamicRoutingValue;
  }
  export interface CreateTransitGatewayPeeringAttachmentResult {
    /**
     * The transit gateway peering attachment.
     */
    TransitGatewayPeeringAttachment?: TransitGatewayPeeringAttachment;
  }
  export interface CreateTransitGatewayPolicyTableRequest {
    /**
     * The ID of the transit gateway used for the policy table.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The tags specification for the transit gateway policy table created during the request.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayPolicyTableResult {
    /**
     * Describes the created transit gateway policy table.
     */
    TransitGatewayPolicyTable?: TransitGatewayPolicyTable;
  }
  export interface CreateTransitGatewayPrefixListReferenceRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the prefix list that is used for destination matches.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The ID of the attachment to which traffic is routed.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Indicates whether to drop traffic that matches this route.
     */
    Blackhole?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayPrefixListReferenceResult {
    /**
     * Information about the prefix list reference.
     */
    TransitGatewayPrefixListReference?: TransitGatewayPrefixListReference;
  }
  export interface CreateTransitGatewayRequest {
    /**
     * A description of the transit gateway.
     */
    Description?: String;
    /**
     * The transit gateway options.
     */
    Options?: TransitGatewayRequestOptions;
    /**
     * The tags to apply to the transit gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayResult {
    /**
     * Information about the transit gateway.
     */
    TransitGateway?: TransitGateway;
  }
  export interface CreateTransitGatewayRouteRequest {
    /**
     * The CIDR range used for destination matches. Routing decisions are based on the most specific match.
     */
    DestinationCidrBlock: String;
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Indicates whether to drop traffic that matches this route.
     */
    Blackhole?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayRouteResult {
    /**
     * Information about the route.
     */
    Route?: TransitGatewayRoute;
  }
  export interface CreateTransitGatewayRouteTableAnnouncementRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the peering attachment.
     */
    PeeringAttachmentId: TransitGatewayAttachmentId;
    /**
     * The tags specifications applied to the transit gateway route table announcement.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayRouteTableAnnouncementResult {
    /**
     * Provides details about the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncement?: TransitGatewayRouteTableAnnouncement;
  }
  export interface CreateTransitGatewayRouteTableRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The tags to apply to the transit gateway route table.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayRouteTableResult {
    /**
     * Information about the transit gateway route table.
     */
    TransitGatewayRouteTable?: TransitGatewayRouteTable;
  }
  export interface CreateTransitGatewayVpcAttachmentRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The IDs of one or more subnets. You can specify only one subnet per Availability Zone. You must specify at least one subnet, but we recommend that you specify two subnets for better availability. The transit gateway uses one IP address from each specified subnet.
     */
    SubnetIds: TransitGatewaySubnetIdList;
    /**
     * The VPC attachment options.
     */
    Options?: CreateTransitGatewayVpcAttachmentRequestOptions;
    /**
     * The tags to apply to the VPC attachment.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateTransitGatewayVpcAttachmentRequestOptions {
    /**
     * Enable or disable DNS support. The default is enable.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Enable or disable IPv6 support. The default is disable.
     */
    Ipv6Support?: Ipv6SupportValue;
    /**
     * Enable or disable support for appliance mode. If enabled, a traffic flow between a source and destination uses the same Availability Zone for the VPC attachment for the lifetime of that flow. The default is disable.
     */
    ApplianceModeSupport?: ApplianceModeSupportValue;
  }
  export interface CreateTransitGatewayVpcAttachmentResult {
    /**
     * Information about the VPC attachment.
     */
    TransitGatewayVpcAttachment?: TransitGatewayVpcAttachment;
  }
  export interface CreateVerifiedAccessEndpointEniOptions {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
  }
  export interface CreateVerifiedAccessEndpointLoadBalancerOptions {
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
    /**
     * The ARN of the load balancer.
     */
    LoadBalancerArn?: LoadBalancerArn;
    /**
     * The IDs of the subnets.
     */
    SubnetIds?: CreateVerifiedAccessEndpointSubnetIdList;
  }
  export interface CreateVerifiedAccessEndpointRequest {
    /**
     * The ID of the Verified Access group to associate the endpoint with.
     */
    VerifiedAccessGroupId: VerifiedAccessGroupId;
    /**
     * The type of Amazon Web Services Verified Access endpoint to create.
     */
    EndpointType: VerifiedAccessEndpointType;
    /**
     * The Amazon Web Services network component Verified Access attaches to.
     */
    AttachmentType: VerifiedAccessEndpointAttachmentType;
    /**
     * The ARN of the public TLS/SSL certificate in Amazon Web Services Certificate Manager to associate with the endpoint. The CN in the certificate must match the DNS name your end users will use to reach your application.
     */
    DomainCertificateArn: CertificateArn;
    /**
     * The DNS name for users to reach your application.
     */
    ApplicationDomain: String;
    /**
     * A custom identifier that gets prepended to a DNS name that is generated for the endpoint.
     */
    EndpointDomainPrefix: String;
    /**
     * The Amazon EC2 security groups to associate with the Amazon Web Services Verified Access endpoint.
     */
    SecurityGroupIds?: SecurityGroupIdList;
    /**
     * The load balancer details if creating the Amazon Web Services Verified Access endpoint as load-balancertype.
     */
    LoadBalancerOptions?: CreateVerifiedAccessEndpointLoadBalancerOptions;
    /**
     * The network interface details if creating the Amazon Web Services Verified Access endpoint as network-interfacetype.
     */
    NetworkInterfaceOptions?: CreateVerifiedAccessEndpointEniOptions;
    /**
     * A description for the Amazon Web Services Verified Access endpoint.
     */
    Description?: String;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
    /**
     * The tags to assign to the Amazon Web Services Verified Access endpoint.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateVerifiedAccessEndpointResult {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpoint?: VerifiedAccessEndpoint;
  }
  export type CreateVerifiedAccessEndpointSubnetIdList = SubnetId[];
  export interface CreateVerifiedAccessGroupRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * A description for the Amazon Web Services Verified Access group.
     */
    Description?: String;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
    /**
     * The tags to assign to the Amazon Web Services Verified Access group.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateVerifiedAccessGroupResult {
    /**
     * The ID of the Verified Access group.
     */
    VerifiedAccessGroup?: VerifiedAccessGroup;
  }
  export interface CreateVerifiedAccessInstanceRequest {
    /**
     * A description for the Amazon Web Services Verified Access instance.
     */
    Description?: String;
    /**
     * The tags to assign to the Amazon Web Services Verified Access instance.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateVerifiedAccessInstanceResult {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstance?: VerifiedAccessInstance;
  }
  export interface CreateVerifiedAccessTrustProviderDeviceOptions {
    /**
     * The ID of the tenant application with the device-identity provider.
     */
    TenantId?: String;
  }
  export interface CreateVerifiedAccessTrustProviderOidcOptions {
    /**
     * The OIDC issuer.
     */
    Issuer?: String;
    /**
     * The OIDC authorization endpoint.
     */
    AuthorizationEndpoint?: String;
    /**
     * The OIDC token endpoint.
     */
    TokenEndpoint?: String;
    /**
     * The OIDC user info endpoint.
     */
    UserInfoEndpoint?: String;
    /**
     * The client identifier.
     */
    ClientId?: String;
    /**
     * The client secret.
     */
    ClientSecret?: String;
    /**
     * OpenID Connect (OIDC) scopes are used by an application during authentication to authorize access to a user's details. Each scope returns a specific set of user attributes.
     */
    Scope?: String;
  }
  export interface CreateVerifiedAccessTrustProviderRequest {
    /**
     * The type of trust provider can be either user or device-based.
     */
    TrustProviderType: TrustProviderType;
    /**
     * The type of user-based trust provider.
     */
    UserTrustProviderType?: UserTrustProviderType;
    /**
     * The type of device-based trust provider.
     */
    DeviceTrustProviderType?: DeviceTrustProviderType;
    /**
     * The OpenID Connect details for an oidc-type, user-identity based trust provider.
     */
    OidcOptions?: CreateVerifiedAccessTrustProviderOidcOptions;
    /**
     * The options for device identity based trust providers.
     */
    DeviceOptions?: CreateVerifiedAccessTrustProviderDeviceOptions;
    /**
     * The identifier to be used when working with policy rules.
     */
    PolicyReferenceName: String;
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    Description?: String;
    /**
     * The tags to assign to the Amazon Web Services Verified Access trust provider.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateVerifiedAccessTrustProviderResult {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProvider?: VerifiedAccessTrustProvider;
  }
  export interface CreateVolumePermission {
    /**
     * The group to be added or removed. The possible value is all.
     */
    Group?: PermissionGroup;
    /**
     * The ID of the Amazon Web Services account to be added or removed.
     */
    UserId?: String;
  }
  export type CreateVolumePermissionList = CreateVolumePermission[];
  export interface CreateVolumePermissionModifications {
    /**
     * Adds the specified Amazon Web Services account ID or group to the list.
     */
    Add?: CreateVolumePermissionList;
    /**
     * Removes the specified Amazon Web Services account ID or group from the list.
     */
    Remove?: CreateVolumePermissionList;
  }
  export interface CreateVolumeRequest {
    /**
     * The Availability Zone in which to create the volume.
     */
    AvailabilityZone: AvailabilityZoneName;
    /**
     * Indicates whether the volume should be encrypted. The effect of setting the encryption state to true depends on the volume origin (new or from a snapshot), starting encryption state, ownership, and whether encryption by default is enabled. For more information, see Encryption by default in the Amazon Elastic Compute Cloud User Guide. Encrypted Amazon EBS volumes must be attached to instances that support Amazon EBS encryption. For more information, see Supported instance types.
     */
    Encrypted?: Boolean;
    /**
     * The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. The following are the supported values for each volume type:    gp3: 3,000-16,000 IOPS    io1: 100-64,000 IOPS    io2: 100-64,000 IOPS    io1 and io2 volumes support up to 64,000 IOPS only on Instances built on the Nitro System. Other instance families support performance up to 32,000 IOPS. This parameter is required for io1 and io2 volumes. The default for gp3 volumes is 3,000 IOPS. This parameter is not supported for gp2, st1, sc1, or standard volumes.
     */
    Iops?: Integer;
    /**
     * The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified, the encrypted state must be true. You can specify the KMS key using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the action can appear to complete, but eventually fails.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you specify a snapshot, the default is the snapshot size. You can specify a volume size that is equal to or larger than the snapshot size. The following are the supported volumes sizes for each volume type:    gp2 and gp3: 1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384    standard: 1-1,024  
     */
    Size?: Integer;
    /**
     * The snapshot from which to create the volume. You must specify either a snapshot ID or a volume size.
     */
    SnapshotId?: SnapshotId;
    /**
     * The volume type. This parameter can be one of the following values:   General Purpose SSD: gp2 | gp3    Provisioned IOPS SSD: io1 | io2    Throughput Optimized HDD: st1    Cold HDD: sc1    Magnetic: standard     Throughput Optimized HDD (st1) and Cold HDD (sc1) volumes can't be used as boot volumes.  For more information, see Amazon EBS volume types in the Amazon Elastic Compute Cloud User Guide. Default: gp2 
     */
    VolumeType?: VolumeType;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to apply to the volume during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Indicates whether to enable Amazon EBS Multi-Attach. If you enable Multi-Attach, you can attach the volume to up to 16 Instances built on the Nitro System in the same Availability Zone. This parameter is supported with io1 and io2 volumes only. For more information, see  Amazon EBS Multi-Attach in the Amazon Elastic Compute Cloud User Guide.
     */
    MultiAttachEnabled?: Boolean;
    /**
     * The throughput to provision for a volume, with a maximum of 1,000 MiB/s. This parameter is valid only for gp3 volumes. Valid Range: Minimum value of 125. Maximum value of 1000.
     */
    Throughput?: Integer;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensure Idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateVpcEndpointConnectionNotificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the endpoint service.
     */
    ServiceId?: VpcEndpointServiceId;
    /**
     * The ID of the endpoint.
     */
    VpcEndpointId?: VpcEndpointId;
    /**
     * The ARN of the SNS topic for the notifications.
     */
    ConnectionNotificationArn: String;
    /**
     * The endpoint events for which to receive notifications. Valid values are Accept, Connect, Delete, and Reject.
     */
    ConnectionEvents: ValueStringList;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
  }
  export interface CreateVpcEndpointConnectionNotificationResult {
    /**
     * Information about the notification.
     */
    ConnectionNotification?: ConnectionNotification;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    ClientToken?: String;
  }
  export interface CreateVpcEndpointRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The type of endpoint. Default: Gateway
     */
    VpcEndpointType?: VpcEndpointType;
    /**
     * The ID of the VPC for the endpoint.
     */
    VpcId: VpcId;
    /**
     * The service name.
     */
    ServiceName: String;
    /**
     * (Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format. If this parameter is not specified, we attach a default policy that allows full access to the service.
     */
    PolicyDocument?: String;
    /**
     * (Gateway endpoint) The route table IDs.
     */
    RouteTableIds?: VpcEndpointRouteTableIdList;
    /**
     * (Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to create an endpoint network interface. For a Gateway Load Balancer endpoint, you can specify only one subnet.
     */
    SubnetIds?: VpcEndpointSubnetIdList;
    /**
     * (Interface endpoint) The IDs of the security groups to associate with the endpoint network interface. If this parameter is not specified, we use the default security group for the VPC.
     */
    SecurityGroupIds?: VpcEndpointSecurityGroupIdList;
    /**
     * The IP address type for the endpoint.
     */
    IpAddressType?: IpAddressType;
    /**
     * The DNS options for the endpoint.
     */
    DnsOptions?: DnsOptionsSpecification;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * (Interface endpoint) Indicates whether to associate a private hosted zone with the specified VPC. The private hosted zone contains a record set for the default public DNS name for the service for the Region (for example, kinesis.us-east-1.amazonaws.com), which resolves to the private IP addresses of the endpoint network interfaces in the VPC. This enables you to make requests to the default public DNS name for the service instead of the public DNS names that are automatically generated by the VPC endpoint service. To use a private hosted zone, you must set the following VPC attributes to true: enableDnsHostnames and enableDnsSupport. Use ModifyVpcAttribute to set the VPC attributes. Default: true 
     */
    PrivateDnsEnabled?: Boolean;
    /**
     * The tags to associate with the endpoint.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateVpcEndpointResult {
    /**
     * Information about the endpoint.
     */
    VpcEndpoint?: VpcEndpoint;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    ClientToken?: String;
  }
  export interface CreateVpcEndpointServiceConfigurationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether requests from service consumers to create an endpoint to your service must be accepted manually.
     */
    AcceptanceRequired?: Boolean;
    /**
     * (Interface endpoint configuration) The private DNS name to assign to the VPC endpoint service.
     */
    PrivateDnsName?: String;
    /**
     * The Amazon Resource Names (ARNs) of the Network Load Balancers.
     */
    NetworkLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers.
     */
    GatewayLoadBalancerArns?: ValueStringList;
    /**
     * The supported IP address types. The possible values are ipv4 and ipv6.
     */
    SupportedIpAddressTypes?: ValueStringList;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken?: String;
    /**
     * The tags to associate with the service.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateVpcEndpointServiceConfigurationResult {
    /**
     * Information about the service configuration.
     */
    ServiceConfiguration?: ServiceConfiguration;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    ClientToken?: String;
  }
  export interface CreateVpcPeeringConnectionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Amazon Web Services account ID of the owner of the accepter VPC. Default: Your Amazon Web Services account ID
     */
    PeerOwnerId?: String;
    /**
     * The ID of the VPC with which you are creating the VPC peering connection. You must specify this parameter in the request.
     */
    PeerVpcId?: String;
    /**
     * The ID of the requester VPC. You must specify this parameter in the request.
     */
    VpcId: VpcId;
    /**
     * The Region code for the accepter VPC, if the accepter VPC is located in a Region other than the Region in which you make the request. Default: The Region in which you make the request.
     */
    PeerRegion?: String;
    /**
     * The tags to assign to the peering connection.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateVpcPeeringConnectionResult {
    /**
     * Information about the VPC peering connection.
     */
    VpcPeeringConnection?: VpcPeeringConnection;
  }
  export interface CreateVpcRequest {
    /**
     * The IPv4 network range for the VPC, in CIDR notation. For example, 10.0.0.0/16. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.
     */
    CidrBlock?: String;
    /**
     * Requests an Amazon-provided IPv6 CIDR block with a /56 prefix length for the VPC. You cannot specify the range of IP addresses, or the size of the CIDR block.
     */
    AmazonProvidedIpv6CidrBlock?: Boolean;
    /**
     * The ID of an IPv6 address pool from which to allocate the IPv6 CIDR block.
     */
    Ipv6Pool?: Ipv6PoolEc2Id;
    /**
     * The IPv6 CIDR block from the IPv6 address pool. You must also specify Ipv6Pool in the request. To let Amazon choose the IPv6 CIDR block for you, omit this parameter.
     */
    Ipv6CidrBlock?: String;
    /**
     * The ID of an IPv4 IPAM pool you want to use for allocating this VPC's CIDR. For more information, see What is IPAM? in the Amazon VPC IPAM User Guide. 
     */
    Ipv4IpamPoolId?: IpamPoolId;
    /**
     * The netmask length of the IPv4 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide.
     */
    Ipv4NetmaskLength?: NetmaskLength;
    /**
     * The ID of an IPv6 IPAM pool which will be used to allocate this VPC an IPv6 CIDR. IPAM is a VPC feature that you can use to automate your IP address management workflows including assigning, tracking, troubleshooting, and auditing IP addresses across Amazon Web Services Regions and accounts throughout your Amazon Web Services Organization. For more information, see What is IPAM? in the Amazon VPC IPAM User Guide.
     */
    Ipv6IpamPoolId?: IpamPoolId;
    /**
     * The netmask length of the IPv6 CIDR you want to allocate to this VPC from an Amazon VPC IP Address Manager (IPAM) pool. For more information about IPAM, see What is IPAM? in the Amazon VPC IPAM User Guide.
     */
    Ipv6NetmaskLength?: NetmaskLength;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tenancy options for instances launched into the VPC. For default, instances are launched with shared tenancy by default. You can launch instances with any tenancy into a shared tenancy VPC. For dedicated, instances are launched as dedicated tenancy instances by default. You can only launch instances with a tenancy of dedicated or host into a dedicated tenancy VPC.   Important: The host value cannot be used with this parameter. Use the default or dedicated values only. Default: default 
     */
    InstanceTenancy?: Tenancy;
    /**
     * The name of the location from which we advertise the IPV6 CIDR block. Use this parameter to limit the address to this location.  You must set AmazonProvidedIpv6CidrBlock to true to use this parameter.
     */
    Ipv6CidrBlockNetworkBorderGroup?: String;
    /**
     * The tags to assign to the VPC.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateVpcResult {
    /**
     * Information about the VPC.
     */
    Vpc?: Vpc;
  }
  export interface CreateVpnConnectionRequest {
    /**
     * The ID of the customer gateway.
     */
    CustomerGatewayId: CustomerGatewayId;
    /**
     * The type of VPN connection (ipsec.1).
     */
    Type: String;
    /**
     * The ID of the virtual private gateway. If you specify a virtual private gateway, you cannot specify a transit gateway.
     */
    VpnGatewayId?: VpnGatewayId;
    /**
     * The ID of the transit gateway. If you specify a transit gateway, you cannot specify a virtual private gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The options for the VPN connection.
     */
    Options?: VpnConnectionOptionsSpecification;
    /**
     * The tags to apply to the VPN connection.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface CreateVpnConnectionResult {
    /**
     * Information about the VPN connection.
     */
    VpnConnection?: VpnConnection;
  }
  export interface CreateVpnConnectionRouteRequest {
    /**
     * The CIDR block associated with the local subnet of the customer network.
     */
    DestinationCidrBlock: String;
    /**
     * The ID of the VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
  }
  export interface CreateVpnGatewayRequest {
    /**
     * The Availability Zone for the virtual private gateway.
     */
    AvailabilityZone?: String;
    /**
     * The type of VPN connection this virtual private gateway supports.
     */
    Type: GatewayType;
    /**
     * The tags to apply to the virtual private gateway.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * A private Autonomous System Number (ASN) for the Amazon side of a BGP session. If you're using a 16-bit ASN, it must be in the 64512 to 65534 range. If you're using a 32-bit ASN, it must be in the 4200000000 to 4294967294 range. Default: 64512
     */
    AmazonSideAsn?: Long;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface CreateVpnGatewayResult {
    /**
     * Information about the virtual private gateway.
     */
    VpnGateway?: VpnGateway;
  }
  export interface CreditSpecification {
    /**
     * The credit option for CPU usage of a T instance. Valid values: standard | unlimited 
     */
    CpuCredits?: String;
  }
  export interface CreditSpecificationRequest {
    /**
     * The credit option for CPU usage of a T instance. Valid values: standard | unlimited 
     */
    CpuCredits: String;
  }
  export type CurrencyCodeValues = "USD"|string;
  export type CurrentGenerationFlag = boolean;
  export interface CustomerGateway {
    /**
     * The customer gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).
     */
    BgpAsn?: String;
    /**
     * The ID of the customer gateway.
     */
    CustomerGatewayId?: String;
    /**
     * The IP address of the customer gateway device's outside interface.
     */
    IpAddress?: String;
    /**
     * The Amazon Resource Name (ARN) for the customer gateway certificate.
     */
    CertificateArn?: String;
    /**
     * The current state of the customer gateway (pending | available | deleting | deleted).
     */
    State?: String;
    /**
     * The type of VPN connection the customer gateway supports (ipsec.1).
     */
    Type?: String;
    /**
     * The name of customer gateway device.
     */
    DeviceName?: String;
    /**
     * Any tags assigned to the customer gateway.
     */
    Tags?: TagList;
  }
  export type CustomerGatewayId = string;
  export type CustomerGatewayIdStringList = CustomerGatewayId[];
  export type CustomerGatewayList = CustomerGateway[];
  export type DITMaxResults = number;
  export type DITOMaxResults = number;
  export type DataQueries = DataQuery[];
  export interface DataQuery {
    /**
     * A user-defined ID associated with a data query that's returned in the dataResponse identifying the query. For example, if you set the Id to MyQuery01in the query, the dataResponse identifies the query as MyQuery01.
     */
    Id?: String;
    /**
     * The Region or Availability Zone that's the source for the data query. For example, us-east-1.
     */
    Source?: String;
    /**
     * The Region or Availability Zone that's the target for the data query. For example, eu-north-1.
     */
    Destination?: String;
    /**
     * The metric, aggregation-latency, indicating that network latency is aggregated for the query. This is the only supported metric.
     */
    Metric?: MetricType;
    /**
     * The metric data aggregation period, p50, between the specified startDate and endDate. For example, a metric of five_minutes is the median of all the data points gathered within those five minutes. p50 is the only supported metric.
     */
    Statistic?: StatisticType;
    /**
     * The aggregation period used for the data query.
     */
    Period?: PeriodType;
  }
  export interface DataResponse {
    /**
     * The ID passed in the DataQuery.
     */
    Id?: String;
    /**
     * The Region or Availability Zone that's the source for the data query. For example, us-east-1.
     */
    Source?: String;
    /**
     * The Region or Availability Zone that's the destination for the data query. For example, eu-west-1.
     */
    Destination?: String;
    /**
     * The metric used for the network performance request. Only aggregate-latency is supported, which shows network latency during a specified period. 
     */
    Metric?: MetricType;
    /**
     * The statistic used for the network performance request.
     */
    Statistic?: StatisticType;
    /**
     * The period used for the network performance request.
     */
    Period?: PeriodType;
    /**
     * A list of MetricPoint objects.
     */
    MetricPoints?: MetricPoints;
  }
  export type DataResponses = DataResponse[];
  export type DatafeedSubscriptionState = "Active"|"Inactive"|string;
  export type DateTime = Date;
  export type DedicatedHostFlag = boolean;
  export type DedicatedHostId = string;
  export type DedicatedHostIdList = DedicatedHostId[];
  export type DefaultNetworkCardIndex = number;
  export type DefaultRouteTableAssociationValue = "enable"|"disable"|string;
  export type DefaultRouteTablePropagationValue = "enable"|"disable"|string;
  export type DefaultTargetCapacityType = "spot"|"on-demand"|string;
  export type DefaultingDhcpOptionsId = string;
  export interface DeleteCarrierGatewayRequest {
    /**
     * The ID of the carrier gateway.
     */
    CarrierGatewayId: CarrierGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteCarrierGatewayResult {
    /**
     * Information about the carrier gateway.
     */
    CarrierGateway?: CarrierGateway;
  }
  export interface DeleteClientVpnEndpointRequest {
    /**
     * The ID of the Client VPN to be deleted.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteClientVpnEndpointResult {
    /**
     * The current state of the Client VPN endpoint.
     */
    Status?: ClientVpnEndpointStatus;
  }
  export interface DeleteClientVpnRouteRequest {
    /**
     * The ID of the Client VPN endpoint from which the route is to be deleted.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ID of the target subnet used by the route.
     */
    TargetVpcSubnetId?: SubnetId;
    /**
     * The IPv4 address range, in CIDR notation, of the route to be deleted.
     */
    DestinationCidrBlock: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteClientVpnRouteResult {
    /**
     * The current state of the route.
     */
    Status?: ClientVpnRouteStatus;
  }
  export interface DeleteCoipCidrRequest {
    /**
     *  A customer-owned IP address range that you want to delete. 
     */
    Cidr: String;
    /**
     *  The ID of the customer-owned address pool. 
     */
    CoipPoolId: Ipv4PoolCoipId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteCoipCidrResult {
    /**
     *  Information about a range of customer-owned IP addresses. 
     */
    CoipCidr?: CoipCidr;
  }
  export interface DeleteCoipPoolRequest {
    /**
     * The ID of the CoIP pool that you want to delete. 
     */
    CoipPoolId: Ipv4PoolCoipId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteCoipPoolResult {
    /**
     * Information about the CoIP address pool.
     */
    CoipPool?: CoipPool;
  }
  export interface DeleteCustomerGatewayRequest {
    /**
     * The ID of the customer gateway.
     */
    CustomerGatewayId: CustomerGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteDhcpOptionsRequest {
    /**
     * The ID of the DHCP options set.
     */
    DhcpOptionsId: DhcpOptionsId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteEgressOnlyInternetGatewayRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId: EgressOnlyInternetGatewayId;
  }
  export interface DeleteEgressOnlyInternetGatewayResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    ReturnCode?: Boolean;
  }
  export interface DeleteFleetError {
    /**
     * The error code.
     */
    Code?: DeleteFleetErrorCode;
    /**
     * The description for the error code.
     */
    Message?: String;
  }
  export type DeleteFleetErrorCode = "fleetIdDoesNotExist"|"fleetIdMalformed"|"fleetNotInDeletableState"|"unexpectedError"|string;
  export interface DeleteFleetErrorItem {
    /**
     * The error.
     */
    Error?: DeleteFleetError;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId?: FleetId;
  }
  export type DeleteFleetErrorSet = DeleteFleetErrorItem[];
  export interface DeleteFleetSuccessItem {
    /**
     * The current state of the EC2 Fleet.
     */
    CurrentFleetState?: FleetStateCode;
    /**
     * The previous state of the EC2 Fleet.
     */
    PreviousFleetState?: FleetStateCode;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId?: FleetId;
  }
  export type DeleteFleetSuccessSet = DeleteFleetSuccessItem[];
  export interface DeleteFleetsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the EC2 Fleets.
     */
    FleetIds: FleetIdSet;
    /**
     * Indicates whether to terminate the associated instances when the EC2 Fleet is deleted. The default is to terminate the instances. To let the instances continue to run after the EC2 Fleet is deleted, specify no-terminate-instances. Supported only for fleets of type maintain and request. For instant fleets, you cannot specify NoTerminateInstances. A deleted instant fleet with running instances is not supported.
     */
    TerminateInstances: Boolean;
  }
  export interface DeleteFleetsResult {
    /**
     * Information about the EC2 Fleets that are successfully deleted.
     */
    SuccessfulFleetDeletions?: DeleteFleetSuccessSet;
    /**
     * Information about the EC2 Fleets that are not successfully deleted.
     */
    UnsuccessfulFleetDeletions?: DeleteFleetErrorSet;
  }
  export interface DeleteFlowLogsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more flow log IDs. Constraint: Maximum of 1000 flow log IDs.
     */
    FlowLogIds: FlowLogIdList;
  }
  export interface DeleteFlowLogsResult {
    /**
     * Information about the flow logs that could not be deleted successfully.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface DeleteFpgaImageRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the AFI.
     */
    FpgaImageId: FpgaImageId;
  }
  export interface DeleteFpgaImageResult {
    /**
     * Is true if the request succeeds, and an error otherwise.
     */
    Return?: Boolean;
  }
  export interface DeleteInstanceEventWindowRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specify true to force delete the event window. Use the force delete parameter if the event window is currently associated with targets.
     */
    ForceDelete?: Boolean;
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId: InstanceEventWindowId;
  }
  export interface DeleteInstanceEventWindowResult {
    /**
     * The state of the event window.
     */
    InstanceEventWindowState?: InstanceEventWindowStateChange;
  }
  export interface DeleteInternetGatewayRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the internet gateway.
     */
    InternetGatewayId: InternetGatewayId;
  }
  export interface DeleteIpamPoolRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the pool to delete.
     */
    IpamPoolId: IpamPoolId;
  }
  export interface DeleteIpamPoolResult {
    /**
     * Information about the results of the deletion.
     */
    IpamPool?: IpamPool;
  }
  export interface DeleteIpamRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM to delete.
     */
    IpamId: IpamId;
    /**
     * Enables you to quickly delete an IPAM, private scopes, pools in private scopes, and any allocations in the pools in private scopes. You cannot delete the IPAM with this option if there is a pool in your public scope. If you use this option, IPAM does the following:   Deallocates any CIDRs allocated to VPC resources (such as VPCs) in pools in private scopes.  No VPC resources are deleted as a result of enabling this option. The CIDR associated with the resource will no longer be allocated from an IPAM pool, but the CIDR itself will remain unchanged.    Deprovisions all IPv4 CIDRs provisioned to IPAM pools in private scopes.   Deletes all IPAM pools in private scopes.   Deletes all non-default private scopes in the IPAM.   Deletes the default public and private scopes and the IPAM.  
     */
    Cascade?: Boolean;
  }
  export interface DeleteIpamResourceDiscoveryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IPAM resource discovery ID.
     */
    IpamResourceDiscoveryId: IpamResourceDiscoveryId;
  }
  export interface DeleteIpamResourceDiscoveryResult {
    /**
     * The IPAM resource discovery.
     */
    IpamResourceDiscovery?: IpamResourceDiscovery;
  }
  export interface DeleteIpamResult {
    /**
     * Information about the results of the deletion.
     */
    Ipam?: Ipam;
  }
  export interface DeleteIpamScopeRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the scope to delete.
     */
    IpamScopeId: IpamScopeId;
  }
  export interface DeleteIpamScopeResult {
    /**
     * Information about the results of the deletion.
     */
    IpamScope?: IpamScope;
  }
  export interface DeleteKeyPairRequest {
    /**
     * The name of the key pair.
     */
    KeyName?: KeyPairName;
    /**
     * The ID of the key pair.
     */
    KeyPairId?: KeyPairId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteLaunchTemplateRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the launch template. You must specify either the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify either the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
  }
  export interface DeleteLaunchTemplateResult {
    /**
     * Information about the launch template.
     */
    LaunchTemplate?: LaunchTemplate;
  }
  export interface DeleteLaunchTemplateVersionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the launch template. You must specify either the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify either the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The version numbers of one or more launch template versions to delete.
     */
    Versions: VersionStringList;
  }
  export interface DeleteLaunchTemplateVersionsResponseErrorItem {
    /**
     * The ID of the launch template.
     */
    LaunchTemplateId?: String;
    /**
     * The name of the launch template.
     */
    LaunchTemplateName?: String;
    /**
     * The version number of the launch template.
     */
    VersionNumber?: Long;
    /**
     * Information about the error.
     */
    ResponseError?: ResponseError;
  }
  export type DeleteLaunchTemplateVersionsResponseErrorSet = DeleteLaunchTemplateVersionsResponseErrorItem[];
  export interface DeleteLaunchTemplateVersionsResponseSuccessItem {
    /**
     * The ID of the launch template.
     */
    LaunchTemplateId?: String;
    /**
     * The name of the launch template.
     */
    LaunchTemplateName?: String;
    /**
     * The version number of the launch template.
     */
    VersionNumber?: Long;
  }
  export type DeleteLaunchTemplateVersionsResponseSuccessSet = DeleteLaunchTemplateVersionsResponseSuccessItem[];
  export interface DeleteLaunchTemplateVersionsResult {
    /**
     * Information about the launch template versions that were successfully deleted.
     */
    SuccessfullyDeletedLaunchTemplateVersions?: DeleteLaunchTemplateVersionsResponseSuccessSet;
    /**
     * Information about the launch template versions that could not be deleted.
     */
    UnsuccessfullyDeletedLaunchTemplateVersions?: DeleteLaunchTemplateVersionsResponseErrorSet;
  }
  export interface DeleteLocalGatewayRouteRequest {
    /**
     * The CIDR range for the route. This must match the CIDR for the route exactly.
     */
    DestinationCidrBlock?: String;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     *  Use a prefix list in place of DestinationCidrBlock. You cannot use DestinationPrefixListId and DestinationCidrBlock in the same request. 
     */
    DestinationPrefixListId?: PrefixListResourceId;
  }
  export interface DeleteLocalGatewayRouteResult {
    /**
     * Information about the route.
     */
    Route?: LocalGatewayRoute;
  }
  export interface DeleteLocalGatewayRouteTableRequest {
    /**
     *  The ID of the local gateway route table. 
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteLocalGatewayRouteTableResult {
    /**
     * Information about the local gateway route table.
     */
    LocalGatewayRouteTable?: LocalGatewayRouteTable;
  }
  export interface DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationRequest {
    /**
     *  The ID of the local gateway route table virtual interface group association. 
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociationId: LocalGatewayRouteTableVirtualInterfaceGroupAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteLocalGatewayRouteTableVirtualInterfaceGroupAssociationResult {
    /**
     * Information about the association.
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociation?: LocalGatewayRouteTableVirtualInterfaceGroupAssociation;
  }
  export interface DeleteLocalGatewayRouteTableVpcAssociationRequest {
    /**
     * The ID of the association.
     */
    LocalGatewayRouteTableVpcAssociationId: LocalGatewayRouteTableVpcAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteLocalGatewayRouteTableVpcAssociationResult {
    /**
     * Information about the association.
     */
    LocalGatewayRouteTableVpcAssociation?: LocalGatewayRouteTableVpcAssociation;
  }
  export interface DeleteManagedPrefixListRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
  }
  export interface DeleteManagedPrefixListResult {
    /**
     * Information about the prefix list.
     */
    PrefixList?: ManagedPrefixList;
  }
  export interface DeleteNatGatewayRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the NAT gateway.
     */
    NatGatewayId: NatGatewayId;
  }
  export interface DeleteNatGatewayResult {
    /**
     * The ID of the NAT gateway.
     */
    NatGatewayId?: String;
  }
  export interface DeleteNetworkAclEntryRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether the rule is an egress rule.
     */
    Egress: Boolean;
    /**
     * The ID of the network ACL.
     */
    NetworkAclId: NetworkAclId;
    /**
     * The rule number of the entry to delete.
     */
    RuleNumber: Integer;
  }
  export interface DeleteNetworkAclRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network ACL.
     */
    NetworkAclId: NetworkAclId;
  }
  export interface DeleteNetworkInsightsAccessScopeAnalysisRequest {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId: NetworkInsightsAccessScopeAnalysisId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteNetworkInsightsAccessScopeAnalysisResult {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId?: NetworkInsightsAccessScopeAnalysisId;
  }
  export interface DeleteNetworkInsightsAccessScopeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId: NetworkInsightsAccessScopeId;
  }
  export interface DeleteNetworkInsightsAccessScopeResult {
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
  }
  export interface DeleteNetworkInsightsAnalysisRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network insights analysis.
     */
    NetworkInsightsAnalysisId: NetworkInsightsAnalysisId;
  }
  export interface DeleteNetworkInsightsAnalysisResult {
    /**
     * The ID of the network insights analysis.
     */
    NetworkInsightsAnalysisId?: NetworkInsightsAnalysisId;
  }
  export interface DeleteNetworkInsightsPathRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the path.
     */
    NetworkInsightsPathId: NetworkInsightsPathId;
  }
  export interface DeleteNetworkInsightsPathResult {
    /**
     * The ID of the path.
     */
    NetworkInsightsPathId?: NetworkInsightsPathId;
  }
  export interface DeleteNetworkInterfacePermissionRequest {
    /**
     * The ID of the network interface permission.
     */
    NetworkInterfacePermissionId: NetworkInterfacePermissionId;
    /**
     * Specify true to remove the permission even if the network interface is attached to an instance.
     */
    Force?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteNetworkInterfacePermissionResult {
    /**
     * Returns true if the request succeeds, otherwise returns an error.
     */
    Return?: Boolean;
  }
  export interface DeleteNetworkInterfaceRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
  }
  export interface DeletePlacementGroupRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The name of the placement group.
     */
    GroupName: PlacementGroupName;
  }
  export interface DeletePublicIpv4PoolRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the public IPv4 pool you want to delete.
     */
    PoolId: Ipv4PoolEc2Id;
  }
  export interface DeletePublicIpv4PoolResult {
    /**
     * Information about the result of deleting the public IPv4 pool.
     */
    ReturnValue?: Boolean;
  }
  export interface DeleteQueuedReservedInstancesError {
    /**
     * The error code.
     */
    Code?: DeleteQueuedReservedInstancesErrorCode;
    /**
     * The error message.
     */
    Message?: String;
  }
  export type DeleteQueuedReservedInstancesErrorCode = "reserved-instances-id-invalid"|"reserved-instances-not-in-queued-state"|"unexpected-error"|string;
  export type DeleteQueuedReservedInstancesIdList = ReservationId[];
  export interface DeleteQueuedReservedInstancesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the Reserved Instances.
     */
    ReservedInstancesIds: DeleteQueuedReservedInstancesIdList;
  }
  export interface DeleteQueuedReservedInstancesResult {
    /**
     * Information about the queued purchases that were successfully deleted.
     */
    SuccessfulQueuedPurchaseDeletions?: SuccessfulQueuedPurchaseDeletionSet;
    /**
     * Information about the queued purchases that could not be deleted.
     */
    FailedQueuedPurchaseDeletions?: FailedQueuedPurchaseDeletionSet;
  }
  export interface DeleteRouteRequest {
    /**
     * The IPv4 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
     */
    DestinationCidrBlock?: String;
    /**
     * The IPv6 CIDR range for the route. The value you specify must match the CIDR for the route exactly.
     */
    DestinationIpv6CidrBlock?: String;
    /**
     * The ID of the prefix list for the route.
     */
    DestinationPrefixListId?: PrefixListResourceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the route table.
     */
    RouteTableId: RouteTableId;
  }
  export interface DeleteRouteTableRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the route table.
     */
    RouteTableId: RouteTableId;
  }
  export interface DeleteSecurityGroupRequest {
    /**
     * The ID of the security group. Required for a nondefault VPC.
     */
    GroupId?: SecurityGroupId;
    /**
     * [EC2-Classic, default VPC] The name of the security group. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupName?: SecurityGroupName;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteSnapshotRequest {
    /**
     * The ID of the EBS snapshot.
     */
    SnapshotId: SnapshotId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteSpotDatafeedSubscriptionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteSubnetCidrReservationRequest {
    /**
     * The ID of the subnet CIDR reservation.
     */
    SubnetCidrReservationId: SubnetCidrReservationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteSubnetCidrReservationResult {
    /**
     * Information about the deleted subnet CIDR reservation.
     */
    DeletedSubnetCidrReservation?: SubnetCidrReservation;
  }
  export interface DeleteSubnetRequest {
    /**
     * The ID of the subnet.
     */
    SubnetId: SubnetId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTagsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the resources, separated by spaces. Constraints: Up to 1000 resource IDs. We recommend breaking up this request into smaller batches.
     */
    Resources: ResourceIdList;
    /**
     * The tags to delete. Specify a tag key and an optional tag value to delete specific tags. If you specify a tag key without a tag value, we delete any tag with this key regardless of its value. If you specify a tag key with an empty string as the tag value, we delete the tag only if its value is an empty string. If you omit this parameter, we delete all user-defined tags for the specified resources. We do not delete Amazon Web Services-generated tags (tags that have the aws: prefix). Constraints: Up to 1000 tags.
     */
    Tags?: TagList;
  }
  export interface DeleteTrafficMirrorFilterRequest {
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId: TrafficMirrorFilterId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTrafficMirrorFilterResult {
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId?: String;
  }
  export interface DeleteTrafficMirrorFilterRuleRequest {
    /**
     * The ID of the Traffic Mirror rule.
     */
    TrafficMirrorFilterRuleId: TrafficMirrorFilterRuleIdWithResolver;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTrafficMirrorFilterRuleResult {
    /**
     * The ID of the deleted Traffic Mirror rule.
     */
    TrafficMirrorFilterRuleId?: String;
  }
  export interface DeleteTrafficMirrorSessionRequest {
    /**
     * The ID of the Traffic Mirror session.
     */
    TrafficMirrorSessionId: TrafficMirrorSessionId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTrafficMirrorSessionResult {
    /**
     * The ID of the deleted Traffic Mirror session.
     */
    TrafficMirrorSessionId?: String;
  }
  export interface DeleteTrafficMirrorTargetRequest {
    /**
     * The ID of the Traffic Mirror target.
     */
    TrafficMirrorTargetId: TrafficMirrorTargetId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTrafficMirrorTargetResult {
    /**
     * The ID of the deleted Traffic Mirror target.
     */
    TrafficMirrorTargetId?: String;
  }
  export interface DeleteTransitGatewayConnectPeerRequest {
    /**
     * The ID of the Connect peer.
     */
    TransitGatewayConnectPeerId: TransitGatewayConnectPeerId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayConnectPeerResult {
    /**
     * Information about the deleted Connect peer.
     */
    TransitGatewayConnectPeer?: TransitGatewayConnectPeer;
  }
  export interface DeleteTransitGatewayConnectRequest {
    /**
     * The ID of the Connect attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayConnectResult {
    /**
     * Information about the deleted Connect attachment.
     */
    TransitGatewayConnect?: TransitGatewayConnect;
  }
  export interface DeleteTransitGatewayMulticastDomainRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayMulticastDomainResult {
    /**
     * Information about the deleted transit gateway multicast domain.
     */
    TransitGatewayMulticastDomain?: TransitGatewayMulticastDomain;
  }
  export interface DeleteTransitGatewayPeeringAttachmentRequest {
    /**
     * The ID of the transit gateway peering attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayPeeringAttachmentResult {
    /**
     * The transit gateway peering attachment.
     */
    TransitGatewayPeeringAttachment?: TransitGatewayPeeringAttachment;
  }
  export interface DeleteTransitGatewayPolicyTableRequest {
    /**
     * The transit gateway policy table to delete.
     */
    TransitGatewayPolicyTableId: TransitGatewayPolicyTableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayPolicyTableResult {
    /**
     * Provides details about the deleted transit gateway policy table.
     */
    TransitGatewayPolicyTable?: TransitGatewayPolicyTable;
  }
  export interface DeleteTransitGatewayPrefixListReferenceRequest {
    /**
     * The ID of the route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayPrefixListReferenceResult {
    /**
     * Information about the deleted prefix list reference.
     */
    TransitGatewayPrefixListReference?: TransitGatewayPrefixListReference;
  }
  export interface DeleteTransitGatewayRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayResult {
    /**
     * Information about the deleted transit gateway.
     */
    TransitGateway?: TransitGateway;
  }
  export interface DeleteTransitGatewayRouteRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The CIDR range for the route. This must match the CIDR for the route exactly.
     */
    DestinationCidrBlock: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayRouteResult {
    /**
     * Information about the route.
     */
    Route?: TransitGatewayRoute;
  }
  export interface DeleteTransitGatewayRouteTableAnnouncementRequest {
    /**
     * The transit gateway route table ID that's being deleted. 
     */
    TransitGatewayRouteTableAnnouncementId: TransitGatewayRouteTableAnnouncementId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayRouteTableAnnouncementResult {
    /**
     * Provides details about a deleted transit gateway route table.
     */
    TransitGatewayRouteTableAnnouncement?: TransitGatewayRouteTableAnnouncement;
  }
  export interface DeleteTransitGatewayRouteTableRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayRouteTableResult {
    /**
     * Information about the deleted transit gateway route table.
     */
    TransitGatewayRouteTable?: TransitGatewayRouteTable;
  }
  export interface DeleteTransitGatewayVpcAttachmentRequest {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteTransitGatewayVpcAttachmentResult {
    /**
     * Information about the deleted VPC attachment.
     */
    TransitGatewayVpcAttachment?: TransitGatewayVpcAttachment;
  }
  export interface DeleteVerifiedAccessEndpointRequest {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointId: VerifiedAccessEndpointId;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteVerifiedAccessEndpointResult {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpoint?: VerifiedAccessEndpoint;
  }
  export interface DeleteVerifiedAccessGroupRequest {
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId: VerifiedAccessGroupId;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteVerifiedAccessGroupResult {
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroup?: VerifiedAccessGroup;
  }
  export interface DeleteVerifiedAccessInstanceRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface DeleteVerifiedAccessInstanceResult {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstance?: VerifiedAccessInstance;
  }
  export interface DeleteVerifiedAccessTrustProviderRequest {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProviderId: VerifiedAccessTrustProviderId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface DeleteVerifiedAccessTrustProviderResult {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProvider?: VerifiedAccessTrustProvider;
  }
  export interface DeleteVolumeRequest {
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteVpcEndpointConnectionNotificationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the notifications.
     */
    ConnectionNotificationIds: ConnectionNotificationIdsList;
  }
  export interface DeleteVpcEndpointConnectionNotificationsResult {
    /**
     * Information about the notifications that could not be deleted successfully.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface DeleteVpcEndpointServiceConfigurationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the services.
     */
    ServiceIds: VpcEndpointServiceIdList;
  }
  export interface DeleteVpcEndpointServiceConfigurationsResult {
    /**
     * Information about the service configurations that were not deleted, if applicable.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface DeleteVpcEndpointsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the VPC endpoints.
     */
    VpcEndpointIds: VpcEndpointIdList;
  }
  export interface DeleteVpcEndpointsResult {
    /**
     * Information about the VPC endpoints that were not successfully deleted.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface DeleteVpcPeeringConnectionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId: VpcPeeringConnectionId;
  }
  export interface DeleteVpcPeeringConnectionResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DeleteVpcRequest {
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteVpnConnectionRequest {
    /**
     * The ID of the VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeleteVpnConnectionRouteRequest {
    /**
     * The CIDR block associated with the local subnet of the customer network.
     */
    DestinationCidrBlock: String;
    /**
     * The ID of the VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
  }
  export interface DeleteVpnGatewayRequest {
    /**
     * The ID of the virtual private gateway.
     */
    VpnGatewayId: VpnGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeprovisionByoipCidrRequest {
    /**
     * The address range, in CIDR notation. The prefix must be the same prefix that you specified when you provisioned the address range.
     */
    Cidr: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeprovisionByoipCidrResult {
    /**
     * Information about the address range.
     */
    ByoipCidr?: ByoipCidr;
  }
  export interface DeprovisionIpamPoolCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the pool that has the CIDR you want to deprovision.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The CIDR which you want to deprovision from the pool.
     */
    Cidr?: String;
  }
  export interface DeprovisionIpamPoolCidrResult {
    /**
     * The deprovisioned pool CIDR.
     */
    IpamPoolCidr?: IpamPoolCidr;
  }
  export interface DeprovisionPublicIpv4PoolCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the pool that you want to deprovision the CIDR from.
     */
    PoolId: Ipv4PoolEc2Id;
    /**
     * The CIDR you want to deprovision from the pool. Enter the CIDR you want to deprovision with a netmask of /32. You must rerun this command for each IP address in the CIDR range. If your CIDR is a /24, you will have to run this command to deprovision each of the 256 IP addresses in the /24 CIDR.
     */
    Cidr: String;
  }
  export interface DeprovisionPublicIpv4PoolCidrResult {
    /**
     * The ID of the pool that you deprovisioned the CIDR from.
     */
    PoolId?: Ipv4PoolEc2Id;
    /**
     * The deprovisioned CIDRs.
     */
    DeprovisionedAddresses?: DeprovisionedAddressSet;
  }
  export type DeprovisionedAddressSet = String[];
  export interface DeregisterImageRequest {
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeregisterInstanceEventNotificationAttributesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Information about the tag keys to deregister.
     */
    InstanceTagAttribute?: DeregisterInstanceTagAttributeRequest;
  }
  export interface DeregisterInstanceEventNotificationAttributesResult {
    /**
     * The resulting set of tag keys.
     */
    InstanceTagAttribute?: InstanceTagNotificationAttribute;
  }
  export interface DeregisterInstanceTagAttributeRequest {
    /**
     * Indicates whether to deregister all tag keys in the current Region. Specify false to deregister all tag keys.
     */
    IncludeAllTagsOfInstance?: Boolean;
    /**
     * Information about the tag keys to deregister.
     */
    InstanceTagKeys?: InstanceTagKeySet;
  }
  export interface DeregisterTransitGatewayMulticastGroupMembersRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: TransitGatewayMulticastDomainId;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
    /**
     * The IDs of the group members' network interfaces.
     */
    NetworkInterfaceIds?: TransitGatewayNetworkInterfaceIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeregisterTransitGatewayMulticastGroupMembersResult {
    /**
     * Information about the deregistered members.
     */
    DeregisteredMulticastGroupMembers?: TransitGatewayMulticastDeregisteredGroupMembers;
  }
  export interface DeregisterTransitGatewayMulticastGroupSourcesRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: TransitGatewayMulticastDomainId;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
    /**
     * The IDs of the group sources' network interfaces.
     */
    NetworkInterfaceIds?: TransitGatewayNetworkInterfaceIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeregisterTransitGatewayMulticastGroupSourcesResult {
    /**
     * Information about the deregistered group sources.
     */
    DeregisteredMulticastGroupSources?: TransitGatewayMulticastDeregisteredGroupSources;
  }
  export interface DescribeAccountAttributesRequest {
    /**
     * The account attribute names.
     */
    AttributeNames?: AccountAttributeNameStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAccountAttributesResult {
    /**
     * Information about the account attributes.
     */
    AccountAttributes?: AccountAttributeList;
  }
  export type DescribeAddressTransfersMaxResults = number;
  export interface DescribeAddressTransfersRequest {
    /**
     * The allocation IDs of Elastic IP addresses.
     */
    AllocationIds?: AllocationIdList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of address transfers to return in one page of results.
     */
    MaxResults?: DescribeAddressTransfersMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAddressTransfersResult {
    /**
     * The Elastic IP address transfer.
     */
    AddressTransfers?: AddressTransferList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeAddressesAttributeRequest {
    /**
     * [EC2-VPC] The allocation IDs.
     */
    AllocationIds?: AllocationIds;
    /**
     * The attribute of the IP address.
     */
    Attribute?: AddressAttributeName;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: AddressMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAddressesAttributeResult {
    /**
     * Information about the IP addresses.
     */
    Addresses?: AddressSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeAddressesRequest {
    /**
     * One or more filters. Filter names and values are case-sensitive.    allocation-id - [EC2-VPC] The allocation ID for the address.    association-id - [EC2-VPC] The association ID for the address.    domain - Indicates whether the address is for use in EC2-Classic (standard) or in a VPC (vpc).    instance-id - The ID of the instance the address is associated with, if any.    network-border-group - A unique set of Availability Zones, Local Zones, or Wavelength Zones from where Amazon Web Services advertises IP addresses.     network-interface-id - [EC2-VPC] The ID of the network interface that the address is associated with, if any.    network-interface-owner-id - The Amazon Web Services account ID of the owner.    private-ip-address - [EC2-VPC] The private IP address associated with the Elastic IP address.    public-ip - The Elastic IP address, or the carrier IP address.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * One or more Elastic IP addresses. Default: Describes all your Elastic IP addresses.
     */
    PublicIps?: PublicIpStringList;
    /**
     * [EC2-VPC] Information about the allocation IDs.
     */
    AllocationIds?: AllocationIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAddressesResult {
    /**
     * Information about the Elastic IP addresses.
     */
    Addresses?: AddressList;
  }
  export interface DescribeAggregateIdFormatRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAggregateIdFormatResult {
    /**
     * Indicates whether all resource types in the Region are configured to use longer IDs. This value is only true if all users are configured to use longer IDs for all resources types in the Region.
     */
    UseLongIdsAggregated?: Boolean;
    /**
     * Information about each resource's ID format.
     */
    Statuses?: IdFormatList;
  }
  export interface DescribeAvailabilityZonesRequest {
    /**
     * The filters.    group-name - For Availability Zones, use the Region name. For Local Zones, use the name of the group associated with the Local Zone (for example, us-west-2-lax-1) For Wavelength Zones, use the name of the group associated with the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    message - The Zone message.    opt-in-status - The opt-in status (opted-in | not-opted-in | opt-in-not-required).    parent-zoneID - The ID of the zone that handles some of the Local Zone and Wavelength Zone control plane operations, such as API calls.    parent-zoneName - The ID of the zone that handles some of the Local Zone and Wavelength Zone control plane operations, such as API calls.    region-name - The name of the Region for the Zone (for example, us-east-1).    state - The state of the Availability Zone, the Local Zone, or the Wavelength Zone (available).    zone-id - The ID of the Availability Zone (for example, use1-az1), the Local Zone (for example, usw2-lax1-az1), or the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    zone-name - The name of the Availability Zone (for example, us-east-1a), the Local Zone (for example, us-west-2-lax-1a), or the Wavelength Zone (for example, us-east-1-wl1-bos-wlz-1).    zone-type - The type of zone (availability-zone | local-zone | wavelength-zone).  
     */
    Filters?: FilterList;
    /**
     * The names of the Availability Zones, Local Zones, and Wavelength Zones.
     */
    ZoneNames?: ZoneNameStringList;
    /**
     * The IDs of the Availability Zones, Local Zones, and Wavelength Zones.
     */
    ZoneIds?: ZoneIdStringList;
    /**
     * Include all Availability Zones, Local Zones, and Wavelength Zones regardless of your opt-in status. If you do not use this parameter, the results include only the zones for the Regions where you have chosen the option to opt in.
     */
    AllAvailabilityZones?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAvailabilityZonesResult {
    /**
     * Information about the Availability Zones, Local Zones, and Wavelength Zones.
     */
    AvailabilityZones?: AvailabilityZoneList;
  }
  export interface DescribeAwsNetworkPerformanceMetricSubscriptionsRequest {
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: MaxResultsParam;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * One or more filters.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeAwsNetworkPerformanceMetricSubscriptionsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Describes the current Infrastructure Performance subscriptions.
     */
    Subscriptions?: SubscriptionList;
  }
  export interface DescribeBundleTasksRequest {
    /**
     * The bundle task IDs. Default: Describes all your bundle tasks.
     */
    BundleIds?: BundleIdStringList;
    /**
     * The filters.    bundle-id - The ID of the bundle task.    error-code - If the task failed, the error code returned.    error-message - If the task failed, the error message returned.    instance-id - The ID of the instance.    progress - The level of task completion, as a percentage (for example, 20%).    s3-bucket - The Amazon S3 bucket to store the AMI.    s3-prefix - The beginning of the AMI name.    start-time - The time the task started (for example, 2013-09-15T17:15:20.000Z).    state - The state of the task (pending | waiting-for-shutdown | bundling | storing | cancelling | complete | failed).    update-time - The time of the most recent update for the task.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeBundleTasksResult {
    /**
     * Information about the bundle tasks.
     */
    BundleTasks?: BundleTaskList;
  }
  export type DescribeByoipCidrsMaxResults = number;
  export interface DescribeByoipCidrsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults: DescribeByoipCidrsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeByoipCidrsResult {
    /**
     * Information about your address ranges.
     */
    ByoipCidrs?: ByoipCidrSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeCapacityReservationFleetsMaxResults = number;
  export interface DescribeCapacityReservationFleetsRequest {
    /**
     * The IDs of the Capacity Reservation Fleets to describe.
     */
    CapacityReservationFleetIds?: CapacityReservationFleetIdSet;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.
     */
    MaxResults?: DescribeCapacityReservationFleetsMaxResults;
    /**
     * One or more filters.    state - The state of the Fleet (submitted | modifying | active | partially_fulfilled | expiring | expired | cancelling | cancelled | failed).    instance-match-criteria - The instance matching criteria for the Fleet. Only open is supported.    tenancy - The tenancy of the Fleet (default | dedicated).    allocation-strategy - The allocation strategy used by the Fleet. Only prioritized is supported.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeCapacityReservationFleetsResult {
    /**
     * Information about the Capacity Reservation Fleets.
     */
    CapacityReservationFleets?: CapacityReservationFleetSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeCapacityReservationsMaxResults = number;
  export interface DescribeCapacityReservationsRequest {
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationIds?: CapacityReservationIdSet;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.
     */
    MaxResults?: DescribeCapacityReservationsMaxResults;
    /**
     * One or more filters.    instance-type - The type of instance for which the Capacity Reservation reserves capacity.    owner-id - The ID of the Amazon Web Services account that owns the Capacity Reservation.    instance-platform - The type of operating system for which the Capacity Reservation reserves capacity.    availability-zone - The Availability Zone of the Capacity Reservation.    tenancy - Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:    default - The Capacity Reservation is created on hardware that is shared with other Amazon Web Services accounts.    dedicated - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single Amazon Web Services account.      outpost-arn - The Amazon Resource Name (ARN) of the Outpost on which the Capacity Reservation was created.    state - The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:    active- The Capacity Reservation is active and the capacity is available for your use.    expired - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use.    cancelled - The Capacity Reservation was cancelled. The reserved capacity is no longer available for your use.    pending - The Capacity Reservation request was successful but the capacity provisioning is still pending.    failed - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes.      start-date - The date and time at which the Capacity Reservation was started.    end-date - The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time.    end-date-type - Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it.    limited - The Capacity Reservation expires automatically at a specified date and time.      instance-match-criteria - Indicates the type of instance launches that the Capacity Reservation accepts. The options include:    open - The Capacity Reservation accepts all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes launch into the Capacity Reservation automatically without specifying any additional parameters.    targeted - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.      placement-group-arn - The ARN of the cluster placement group in which the Capacity Reservation was created.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeCapacityReservationsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Information about the Capacity Reservations.
     */
    CapacityReservations?: CapacityReservationSet;
  }
  export interface DescribeCarrierGatewaysRequest {
    /**
     * One or more carrier gateway IDs.
     */
    CarrierGatewayIds?: CarrierGatewayIdSet;
    /**
     * One or more filters.    carrier-gateway-id - The ID of the carrier gateway.    state - The state of the carrier gateway (pending | failed | available | deleting | deleted).    owner-id - The Amazon Web Services account ID of the owner of the carrier gateway.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC associated with the carrier gateway.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: CarrierGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeCarrierGatewaysResult {
    /**
     * Information about the carrier gateway.
     */
    CarrierGateways?: CarrierGatewaySet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeClassicLinkInstancesMaxResults = number;
  export interface DescribeClassicLinkInstancesRequest {
    /**
     * One or more filters.    group-id - The ID of a VPC security group that's associated with the instance.    instance-id - The ID of the instance.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC to which the instance is linked.  vpc-id - The ID of the VPC that the instance is linked to.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more instance IDs. Must be instances linked to a VPC through ClassicLink.
     */
    InstanceIds?: InstanceIdStringList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination. Constraint: If the value is greater than 1000, we return only 1000 items.
     */
    MaxResults?: DescribeClassicLinkInstancesMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeClassicLinkInstancesResult {
    /**
     * Information about one or more linked EC2-Classic instances.
     */
    Instances?: ClassicLinkInstanceList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeClientVpnAuthorizationRulesMaxResults = number;
  export interface DescribeClientVpnAuthorizationRulesRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.    description - The description of the authorization rule.    destination-cidr - The CIDR of the network to which the authorization rule applies.    group-id - The ID of the Active Directory group to which the authorization rule grants access.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
     */
    MaxResults?: DescribeClientVpnAuthorizationRulesMaxResults;
  }
  export interface DescribeClientVpnAuthorizationRulesResult {
    /**
     * Information about the authorization rules.
     */
    AuthorizationRules?: AuthorizationRuleSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeClientVpnConnectionsMaxResults = number;
  export interface DescribeClientVpnConnectionsRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * One or more filters. Filter names and values are case-sensitive.    connection-id - The ID of the connection.    username - For Active Directory client authentication, the user name of the client who established the client connection.  
     */
    Filters?: FilterList;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
     */
    MaxResults?: DescribeClientVpnConnectionsMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeClientVpnConnectionsResult {
    /**
     * Information about the active and terminated client connections.
     */
    Connections?: ClientVpnConnectionSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeClientVpnEndpointMaxResults = number;
  export interface DescribeClientVpnEndpointsRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointIds?: ClientVpnEndpointIdList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
     */
    MaxResults?: DescribeClientVpnEndpointMaxResults;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.    endpoint-id - The ID of the Client VPN endpoint.    transport-protocol - The transport protocol (tcp | udp).  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeClientVpnEndpointsResult {
    /**
     * Information about the Client VPN endpoints.
     */
    ClientVpnEndpoints?: EndpointSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeClientVpnRoutesMaxResults = number;
  export interface DescribeClientVpnRoutesRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * One or more filters. Filter names and values are case-sensitive.    destination-cidr - The CIDR of the route destination.    origin - How the route was associated with the Client VPN endpoint (associate | add-route).    target-subnet - The ID of the subnet through which traffic is routed.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
     */
    MaxResults?: DescribeClientVpnRoutesMaxResults;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeClientVpnRoutesResult {
    /**
     * Information about the Client VPN endpoint routes.
     */
    Routes?: ClientVpnRouteSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeClientVpnTargetNetworksMaxResults = number;
  export interface DescribeClientVpnTargetNetworksRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The IDs of the target network associations.
     */
    AssociationIds?: ValueStringList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the nextToken value.
     */
    MaxResults?: DescribeClientVpnTargetNetworksMaxResults;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.    association-id - The ID of the association.    target-network-id - The ID of the subnet specified as the target network.    vpc-id - The ID of the VPC in which the target network is located.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeClientVpnTargetNetworksResult {
    /**
     * Information about the associated target networks.
     */
    ClientVpnTargetNetworks?: TargetNetworkSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeCoipPoolsRequest {
    /**
     * The IDs of the address pools.
     */
    PoolIds?: CoipPoolIdSet;
    /**
     * One or more filters.    coip-pool.local-gateway-route-table-id - The ID of the local gateway route table.    coip-pool.pool-id - The ID of the address pool.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: CoipPoolMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeCoipPoolsResult {
    /**
     * Information about the address pools.
     */
    CoipPools?: CoipPoolSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeConversionTaskList = ConversionTask[];
  export interface DescribeConversionTasksRequest {
    /**
     * The conversion task IDs.
     */
    ConversionTaskIds?: ConversionIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeConversionTasksResult {
    /**
     * Information about the conversion tasks.
     */
    ConversionTasks?: DescribeConversionTaskList;
  }
  export interface DescribeCustomerGatewaysRequest {
    /**
     * One or more customer gateway IDs. Default: Describes all your customer gateways.
     */
    CustomerGatewayIds?: CustomerGatewayIdStringList;
    /**
     * One or more filters.    bgp-asn - The customer gateway's Border Gateway Protocol (BGP) Autonomous System Number (ASN).    customer-gateway-id - The ID of the customer gateway.    ip-address - The IP address of the customer gateway device's external interface.    state - The state of the customer gateway (pending | available | deleting | deleted).    type - The type of customer gateway. Currently, the only supported type is ipsec.1.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeCustomerGatewaysResult {
    /**
     * Information about one or more customer gateways.
     */
    CustomerGateways?: CustomerGatewayList;
  }
  export type DescribeDhcpOptionsMaxResults = number;
  export interface DescribeDhcpOptionsRequest {
    /**
     * The IDs of one or more DHCP options sets. Default: Describes all your DHCP options sets.
     */
    DhcpOptionsIds?: DhcpOptionsIdStringList;
    /**
     * One or more filters.    dhcp-options-id - The ID of a DHCP options set.    key - The key for one of the options (for example, domain-name).    value - The value for one of the options.    owner-id - The ID of the Amazon Web Services account that owns the DHCP options set.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeDhcpOptionsMaxResults;
  }
  export interface DescribeDhcpOptionsResult {
    /**
     * Information about one or more DHCP options sets.
     */
    DhcpOptions?: DhcpOptionsList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeEgressOnlyInternetGatewaysMaxResults = number;
  export interface DescribeEgressOnlyInternetGatewaysRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more egress-only internet gateway IDs.
     */
    EgressOnlyInternetGatewayIds?: EgressOnlyInternetGatewayIdList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeEgressOnlyInternetGatewaysMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * One or more filters.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
  }
  export interface DescribeEgressOnlyInternetGatewaysResult {
    /**
     * Information about the egress-only internet gateways.
     */
    EgressOnlyInternetGateways?: EgressOnlyInternetGatewayList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeElasticGpusMaxResults = number;
  export interface DescribeElasticGpusRequest {
    /**
     * The Elastic Graphics accelerator IDs.
     */
    ElasticGpuIds?: ElasticGpuIdSet;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    availability-zone - The Availability Zone in which the Elastic Graphics accelerator resides.    elastic-gpu-health - The status of the Elastic Graphics accelerator (OK | IMPAIRED).    elastic-gpu-state - The state of the Elastic Graphics accelerator (ATTACHED).    elastic-gpu-type - The type of Elastic Graphics accelerator; for example, eg1.medium.    instance-id - The ID of the instance to which the Elastic Graphics accelerator is associated.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 5 and 1000.
     */
    MaxResults?: DescribeElasticGpusMaxResults;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeElasticGpusResult {
    /**
     * Information about the Elastic Graphics accelerators.
     */
    ElasticGpuSet?: ElasticGpuSet;
    /**
     * The total number of items to return. If the total number of items available is more than the value specified in max-items then a Next-Token will be provided in the output that you can use to resume pagination.
     */
    MaxResults?: Integer;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeExportImageTasksMaxResults = number;
  export interface DescribeExportImageTasksRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Filter tasks using the task-state filter and one of the following values: active, completed, deleting, or deleted.
     */
    Filters?: FilterList;
    /**
     * The IDs of the export image tasks.
     */
    ExportImageTaskIds?: ExportImageTaskIdList;
    /**
     * The maximum number of results to return in a single call.
     */
    MaxResults?: DescribeExportImageTasksMaxResults;
    /**
     * A token that indicates the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeExportImageTasksResult {
    /**
     * Information about the export image tasks.
     */
    ExportImageTasks?: ExportImageTaskList;
    /**
     * The token to use to get the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeExportTasksRequest {
    /**
     * The export task IDs.
     */
    ExportTaskIds?: ExportTaskIdStringList;
    /**
     * the filters for the export tasks.
     */
    Filters?: FilterList;
  }
  export interface DescribeExportTasksResult {
    /**
     * Information about the export tasks.
     */
    ExportTasks?: ExportTaskList;
  }
  export interface DescribeFastLaunchImagesRequest {
    /**
     * Details for one or more Windows AMI image IDs.
     */
    ImageIds?: FastLaunchImageIdList;
    /**
     * Use the following filters to streamline results.    resource-type - The resource type for pre-provisioning.    launch-template - The launch template that is associated with the pre-provisioned Windows AMI.    owner-id - The owner ID for the pre-provisioning resource.    state - The current state of fast launching for the Windows AMI.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeFastLaunchImagesRequestMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type DescribeFastLaunchImagesRequestMaxResults = number;
  export interface DescribeFastLaunchImagesResult {
    /**
     * A collection of details about the fast-launch enabled Windows images that meet the requested criteria.
     */
    FastLaunchImages?: DescribeFastLaunchImagesSuccessSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeFastLaunchImagesSuccessItem {
    /**
     * The image ID that identifies the fast-launch enabled Windows image.
     */
    ImageId?: ImageId;
    /**
     * The resource type that is used for pre-provisioning the Windows AMI. Supported values include: snapshot.
     */
    ResourceType?: FastLaunchResourceType;
    /**
     * A group of parameters that are used for pre-provisioning the associated Windows AMI using snapshots.
     */
    SnapshotConfiguration?: FastLaunchSnapshotConfigurationResponse;
    /**
     * The launch template that the fast-launch enabled Windows AMI uses when it launches Windows instances from pre-provisioned snapshots.
     */
    LaunchTemplate?: FastLaunchLaunchTemplateSpecificationResponse;
    /**
     * The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows faster launching.
     */
    MaxParallelLaunches?: Integer;
    /**
     * The owner ID for the fast-launch enabled Windows AMI.
     */
    OwnerId?: String;
    /**
     * The current state of faster launching for the specified Windows AMI.
     */
    State?: FastLaunchStateCode;
    /**
     * The reason that faster launching for the Windows AMI changed to the current state.
     */
    StateTransitionReason?: String;
    /**
     * The time that faster launching for the Windows AMI changed to the current state.
     */
    StateTransitionTime?: MillisecondDateTime;
  }
  export type DescribeFastLaunchImagesSuccessSet = DescribeFastLaunchImagesSuccessItem[];
  export interface DescribeFastSnapshotRestoreSuccessItem {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The state of fast snapshot restores.
     */
    State?: FastSnapshotRestoreStateCode;
    /**
     * The reason for the state transition. The possible values are as follows:    Client.UserInitiated - The state successfully transitioned to enabling or disabling.    Client.UserInitiated - Lifecycle state transition - The state successfully transitioned to optimizing, enabled, or disabled.  
     */
    StateTransitionReason?: String;
    /**
     * The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
     */
    OwnerId?: String;
    /**
     * The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
     */
    OwnerAlias?: String;
    /**
     * The time at which fast snapshot restores entered the enabling state.
     */
    EnablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the optimizing state.
     */
    OptimizingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the enabled state.
     */
    EnabledTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabling state.
     */
    DisablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabled state.
     */
    DisabledTime?: MillisecondDateTime;
  }
  export type DescribeFastSnapshotRestoreSuccessSet = DescribeFastSnapshotRestoreSuccessItem[];
  export type DescribeFastSnapshotRestoresMaxResults = number;
  export interface DescribeFastSnapshotRestoresRequest {
    /**
     * The filters. The possible values are:    availability-zone: The Availability Zone of the snapshot.    owner-id: The ID of the Amazon Web Services account that enabled fast snapshot restore on the snapshot.    snapshot-id: The ID of the snapshot.    state: The state of fast snapshot restores for the snapshot (enabling | optimizing | enabled | disabling | disabled).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeFastSnapshotRestoresMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeFastSnapshotRestoresResult {
    /**
     * Information about the state of fast snapshot restores.
     */
    FastSnapshotRestores?: DescribeFastSnapshotRestoreSuccessSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeFleetError {
    /**
     * The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
     */
    LaunchTemplateAndOverrides?: LaunchTemplateAndOverridesResponse;
    /**
     * Indicates if the instance that could not be launched was a Spot Instance or On-Demand Instance.
     */
    Lifecycle?: InstanceLifecycle;
    /**
     * The error code that indicates why the instance could not be launched. For more information about error codes, see Error codes.
     */
    ErrorCode?: String;
    /**
     * The error message that describes why the instance could not be launched. For more information about error messages, see Error codes.
     */
    ErrorMessage?: String;
  }
  export interface DescribeFleetHistoryRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The type of events to describe. By default, all events are described.
     */
    EventType?: FleetEventType;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId: FleetId;
    /**
     * The start date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    StartTime: DateTime;
  }
  export interface DescribeFleetHistoryResult {
    /**
     * Information about the events in the history of the EC2 Fleet.
     */
    HistoryRecords?: HistoryRecordSet;
    /**
     * The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). All records up to this time were retrieved. If nextToken indicates that there are more items, this value is not present.
     */
    LastEvaluatedTime?: DateTime;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the EC Fleet.
     */
    FleetId?: FleetId;
    /**
     * The start date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    StartTime?: DateTime;
  }
  export interface DescribeFleetInstancesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId: FleetId;
    /**
     * The filters.    instance-type - The instance type.  
     */
    Filters?: FilterList;
  }
  export interface DescribeFleetInstancesResult {
    /**
     * The running instances. This list is refreshed periodically and might be out of date.
     */
    ActiveInstances?: ActiveInstanceSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId?: FleetId;
  }
  export type DescribeFleetsErrorSet = DescribeFleetError[];
  export interface DescribeFleetsInstances {
    /**
     * The launch templates and overrides that were used for launching the instances. The values that you specify in the Overrides replace the values in the launch template.
     */
    LaunchTemplateAndOverrides?: LaunchTemplateAndOverridesResponse;
    /**
     * Indicates if the instance that was launched is a Spot Instance or On-Demand Instance.
     */
    Lifecycle?: InstanceLifecycle;
    /**
     * The IDs of the instances.
     */
    InstanceIds?: InstanceIdsSet;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The value is Windows for Windows instances. Otherwise, the value is blank.
     */
    Platform?: PlatformValues;
  }
  export type DescribeFleetsInstancesSet = DescribeFleetsInstances[];
  export interface DescribeFleetsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The IDs of the EC2 Fleets.  If a fleet is of type instant, you must specify the fleet ID, otherwise it does not appear in the response. 
     */
    FleetIds?: FleetIdSet;
    /**
     * The filters.    activity-status - The progress of the EC2 Fleet ( error | pending-fulfillment | pending-termination | fulfilled).    excess-capacity-termination-policy - Indicates whether to terminate running instances if the target capacity is decreased below the current EC2 Fleet size (true | false).    fleet-state - The state of the EC2 Fleet (submitted | active | deleted | failed | deleted-running | deleted-terminating | modifying).    replace-unhealthy-instances - Indicates whether EC2 Fleet should replace unhealthy instances (true | false).    type - The type of request (instant | request | maintain).  
     */
    Filters?: FilterList;
  }
  export interface DescribeFleetsResult {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * Information about the EC2 Fleets.
     */
    Fleets?: FleetSet;
  }
  export interface DescribeFlowLogsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    deliver-log-status - The status of the logs delivery (SUCCESS | FAILED).    log-destination-type - The type of destination for the flow log data (cloud-watch-logs | s3 | kinesis-data-firehose).    flow-log-id - The ID of the flow log.    log-group-name - The name of the log group.    resource-id - The ID of the VPC, subnet, or network interface.    traffic-type - The type of traffic (ACCEPT | REJECT | ALL).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filter?: FilterList;
    /**
     * One or more flow log IDs. Constraint: Maximum of 1000 flow log IDs.
     */
    FlowLogIds?: FlowLogIdList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token to request the next page of items. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeFlowLogsResult {
    /**
     * Information about the flow logs.
     */
    FlowLogs?: FlowLogSet;
    /**
     * The token to request the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeFpgaImageAttributeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the AFI.
     */
    FpgaImageId: FpgaImageId;
    /**
     * The AFI attribute.
     */
    Attribute: FpgaImageAttributeName;
  }
  export interface DescribeFpgaImageAttributeResult {
    /**
     * Information about the attribute.
     */
    FpgaImageAttribute?: FpgaImageAttribute;
  }
  export type DescribeFpgaImagesMaxResults = number;
  export interface DescribeFpgaImagesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The AFI IDs.
     */
    FpgaImageIds?: FpgaImageIdList;
    /**
     * Filters the AFI by owner. Specify an Amazon Web Services account ID, self (owner is the sender of the request), or an Amazon Web Services owner alias (valid values are amazon | aws-marketplace).
     */
    Owners?: OwnerStringList;
    /**
     * The filters.    create-time - The creation time of the AFI.    fpga-image-id - The FPGA image identifier (AFI ID).    fpga-image-global-id - The global FPGA image identifier (AGFI ID).    name - The name of the AFI.    owner-id - The Amazon Web Services account ID of the AFI owner.    product-code - The product code.    shell-version - The version of the Amazon Web Services Shell that was used to create the bitstream.    state - The state of the AFI (pending | failed | available | unavailable).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    update-time - The time of the most recent update.  
     */
    Filters?: FilterList;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return in a single call.
     */
    MaxResults?: DescribeFpgaImagesMaxResults;
  }
  export interface DescribeFpgaImagesResult {
    /**
     * Information about the FPGA images.
     */
    FpgaImages?: FpgaImageList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeHostReservationOfferingsRequest {
    /**
     * The filters.    instance-family - The instance family of the offering (for example, m4).    payment-option - The payment option (NoUpfront | PartialUpfront | AllUpfront).  
     */
    Filter?: FilterList;
    /**
     * This is the maximum duration of the reservation to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 94608000 for three years.
     */
    MaxDuration?: Integer;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.
     */
    MaxResults?: DescribeHostReservationsMaxResults;
    /**
     * This is the minimum duration of the reservation you'd like to purchase, specified in seconds. Reservations are available in one-year and three-year terms. The number of seconds specified must be the number of seconds in a year (365x24x60x60) times one of the supported durations (1 or 3). For example, specify 31536000 for one year.
     */
    MinDuration?: Integer;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The ID of the reservation offering.
     */
    OfferingId?: OfferingId;
  }
  export interface DescribeHostReservationOfferingsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Information about the offerings.
     */
    OfferingSet?: HostOfferingSet;
  }
  export type DescribeHostReservationsMaxResults = number;
  export interface DescribeHostReservationsRequest {
    /**
     * The filters.    instance-family - The instance family (for example, m4).    payment-option - The payment option (NoUpfront | PartialUpfront | AllUpfront).    state - The state of the reservation (payment-pending | payment-failed | active | retired).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filter?: FilterList;
    /**
     * The host reservation IDs.
     */
    HostReservationIdSet?: HostReservationIdSet;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.
     */
    MaxResults?: Integer;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeHostReservationsResult {
    /**
     * Details about the reservation's configuration.
     */
    HostReservationSet?: HostReservationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeHostsRequest {
    /**
     * The filters.    auto-placement - Whether auto-placement is enabled or disabled (on | off).    availability-zone - The Availability Zone of the host.    client-token - The idempotency token that you provided when you allocated the host.    host-reservation-id - The ID of the reservation assigned to this host.    instance-type - The instance type size that the Dedicated Host is configured to support.    state - The allocation state of the Dedicated Host (available | under-assessment | permanent-failure | released | released-permanent-failure).    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filter?: FilterList;
    /**
     * The IDs of the Dedicated Hosts. The IDs are used for targeted instance launches.
     */
    HostIds?: RequestHostIdList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. You cannot specify this parameter and the host IDs parameter in the same request.
     */
    MaxResults?: Integer;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeHostsResult {
    /**
     * Information about the Dedicated Hosts.
     */
    Hosts?: HostList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeIamInstanceProfileAssociationsMaxResults = number;
  export interface DescribeIamInstanceProfileAssociationsRequest {
    /**
     * The IAM instance profile associations.
     */
    AssociationIds?: AssociationIdList;
    /**
     * The filters.    instance-id - The ID of the instance.    state - The state of the association (associating | associated | disassociating).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeIamInstanceProfileAssociationsMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
  }
  export interface DescribeIamInstanceProfileAssociationsResult {
    /**
     * Information about the IAM instance profile associations.
     */
    IamInstanceProfileAssociations?: IamInstanceProfileAssociationSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeIdFormatRequest {
    /**
     * The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway 
     */
    Resource?: String;
  }
  export interface DescribeIdFormatResult {
    /**
     * Information about the ID format for the resource.
     */
    Statuses?: IdFormatList;
  }
  export interface DescribeIdentityIdFormatRequest {
    /**
     * The ARN of the principal, which can be an IAM role, IAM user, or the root user.
     */
    PrincipalArn: String;
    /**
     * The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway 
     */
    Resource?: String;
  }
  export interface DescribeIdentityIdFormatResult {
    /**
     * Information about the ID format for the resources.
     */
    Statuses?: IdFormatList;
  }
  export interface DescribeImageAttributeRequest {
    /**
     * The AMI attribute.  Note: The blockDeviceMapping attribute is deprecated. Using this attribute returns the Client.AuthFailure error. To get information about the block device mappings for an AMI, use the DescribeImages action.
     */
    Attribute: ImageAttributeName;
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeImagesRequest {
    /**
     * Scopes the images by users with explicit launch permissions. Specify an Amazon Web Services account ID, self (the sender of the request), or all (public AMIs).   If you specify an Amazon Web Services account ID that is not your own, only AMIs shared with that specific Amazon Web Services account ID are returned. However, AMIs that are shared with the account’s organization or organizational unit (OU) are not returned.   If you specify self or your own Amazon Web Services account ID, AMIs shared with your account are returned. In addition, AMIs that are shared with the organization or OU of which you are member are also returned.    If you specify all, all public AMIs are returned.  
     */
    ExecutableUsers?: ExecutableByStringList;
    /**
     * The filters.    architecture - The image architecture (i386 | x86_64 | arm64).    block-device-mapping.delete-on-termination - A Boolean value that indicates whether the Amazon EBS volume is deleted on instance termination.    block-device-mapping.device-name - The device name specified in the block device mapping (for example, /dev/sdh or xvdh).    block-device-mapping.snapshot-id - The ID of the snapshot used for the Amazon EBS volume.    block-device-mapping.volume-size - The volume size of the Amazon EBS volume, in GiB.    block-device-mapping.volume-type - The volume type of the Amazon EBS volume (io1 | io2 | gp2 | gp3 | sc1 | st1 | standard).    block-device-mapping.encrypted - A Boolean that indicates whether the Amazon EBS volume is encrypted.    creation-date - The time when the image was created, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, 2021-09-29T11:04:43.305Z. You can use a wildcard (*), for example, 2021-09-29T*, which matches an entire day.    description - The description of the image (provided during image creation).    ena-support - A Boolean that indicates whether enhanced networking with ENA is enabled.    hypervisor - The hypervisor type (ovm | xen).    image-id - The ID of the image.    image-type - The image type (machine | kernel | ramdisk).    is-public - A Boolean that indicates whether the image is public.    kernel-id - The kernel ID.    manifest-location - The location of the image manifest.    name - The name of the AMI (provided during image creation).    owner-alias - The owner alias (amazon | aws-marketplace). The valid aliases are defined in an Amazon-maintained list. This is not the Amazon Web Services account alias that can be set using the IAM console. We recommend that you use the Owner request parameter instead of this filter.    owner-id - The Amazon Web Services account ID of the owner. We recommend that you use the Owner request parameter instead of this filter.    platform - The platform. The only supported value is windows.    product-code - The product code.    product-code.type - The type of the product code (marketplace).    ramdisk-id - The RAM disk ID.    root-device-name - The device name of the root device volume (for example, /dev/sda1).    root-device-type - The type of the root device volume (ebs | instance-store).    state - The state of the image (available | pending | failed).    state-reason-code - The reason code for the state change.    state-reason-message - The message for the state change.    sriov-net-support - A value of simple indicates that enhanced networking with the Intel 82599 VF interface is enabled.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    virtualization-type - The virtualization type (paravirtual | hvm).  
     */
    Filters?: FilterList;
    /**
     * The image IDs. Default: Describes all images available to you.
     */
    ImageIds?: ImageIdStringList;
    /**
     * Scopes the results to images with the specified owners. You can specify a combination of Amazon Web Services account IDs, self, amazon, and aws-marketplace. If you omit this parameter, the results include all images for which you have launch permissions, regardless of ownership.
     */
    Owners?: OwnerStringList;
    /**
     * Specifies whether to include deprecated AMIs. Default: No deprecated AMIs are included in the response.  If you are the AMI owner, all deprecated AMIs appear in the response regardless of what you specify for this parameter. 
     */
    IncludeDeprecated?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeImagesResult {
    /**
     * Information about the images.
     */
    Images?: ImageList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeImportImageTasksRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Filter tasks using the task-state filter and one of the following values: active, completed, deleting, or deleted.
     */
    Filters?: FilterList;
    /**
     * The IDs of the import image tasks.
     */
    ImportTaskIds?: ImportTaskIdList;
    /**
     * The maximum number of results to return in a single call.
     */
    MaxResults?: Integer;
    /**
     * A token that indicates the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeImportImageTasksResult {
    /**
     * A list of zero or more import image tasks that are currently active or were completed or canceled in the previous 7 days.
     */
    ImportImageTasks?: ImportImageTaskList;
    /**
     * The token to use to get the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeImportSnapshotTasksRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.
     */
    Filters?: FilterList;
    /**
     * A list of import snapshot task IDs.
     */
    ImportTaskIds?: ImportSnapshotTaskIdList;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value.
     */
    MaxResults?: Integer;
    /**
     * A token that indicates the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeImportSnapshotTasksResult {
    /**
     * A list of zero or more import snapshot tasks that are currently active or were completed or canceled in the previous 7 days.
     */
    ImportSnapshotTasks?: ImportSnapshotTaskList;
    /**
     * The token to use to get the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeInstanceAttributeRequest {
    /**
     * The instance attribute. Note: The enaSupport attribute is not supported at this time.
     */
    Attribute: InstanceAttributeName;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
  }
  export type DescribeInstanceCreditSpecificationsMaxResults = number;
  export interface DescribeInstanceCreditSpecificationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    instance-id - The ID of the instance.  
     */
    Filters?: FilterList;
    /**
     * The instance IDs. Default: Describes all your instances. Constraints: Maximum 1000 explicitly specified instance IDs.
     */
    InstanceIds?: InstanceIdStringList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination. You cannot specify this parameter and the instance IDs parameter in the same call.
     */
    MaxResults?: DescribeInstanceCreditSpecificationsMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeInstanceCreditSpecificationsResult {
    /**
     * Information about the credit option for CPU usage of an instance.
     */
    InstanceCreditSpecifications?: InstanceCreditSpecificationList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeInstanceEventNotificationAttributesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeInstanceEventNotificationAttributesResult {
    /**
     * Information about the registered tag keys.
     */
    InstanceTagAttribute?: InstanceTagNotificationAttribute;
  }
  export interface DescribeInstanceEventWindowsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the event windows.
     */
    InstanceEventWindowIds?: InstanceEventWindowIdSet;
    /**
     * One or more filters.    dedicated-host-id - The event windows associated with the specified Dedicated Host ID.    event-window-name - The event windows associated with the specified names.     instance-id - The event windows associated with the specified instance ID.    instance-tag - The event windows associated with the specified tag and value.    instance-tag-key - The event windows associated with the specified tag key, regardless of the value.    instance-tag-value - The event windows associated with the specified tag value, regardless of the key.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the event window. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value CMX, specify tag:Owner for the filter name and CMX for the filter value.     tag-key - The key of a tag assigned to the event window. Use this filter to find all event windows that have a tag with a specific key, regardless of the tag value.     tag-value - The value of a tag assigned to the event window. Use this filter to find all event windows that have a tag with a specific value, regardless of the tag key.   
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 20 and 500. You cannot specify this parameter and the event window IDs parameter in the same call.
     */
    MaxResults?: ResultRange;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeInstanceEventWindowsResult {
    /**
     * Information about the event windows.
     */
    InstanceEventWindows?: InstanceEventWindowSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return. 
     */
    NextToken?: String;
  }
  export interface DescribeInstanceStatusRequest {
    /**
     * The filters.    availability-zone - The Availability Zone of the instance.    event.code - The code for the scheduled event (instance-reboot | system-reboot | system-maintenance | instance-retirement | instance-stop).    event.description - A description of the event.    event.instance-event-id - The ID of the event whose date and time you are modifying.    event.not-after - The latest end time for the scheduled event (for example, 2014-09-15T17:15:20.000Z).    event.not-before - The earliest start time for the scheduled event (for example, 2014-09-15T17:15:20.000Z).    event.not-before-deadline - The deadline for starting the event (for example, 2014-09-15T17:15:20.000Z).    instance-state-code - The code for the instance state, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).    instance-state-name - The state of the instance (pending | running | shutting-down | terminated | stopping | stopped).    instance-status.reachability - Filters on instance status where the name is reachability (passed | failed | initializing | insufficient-data).    instance-status.status - The status of the instance (ok | impaired | initializing | insufficient-data | not-applicable).    system-status.reachability - Filters on system status where the name is reachability (passed | failed | initializing | insufficient-data).    system-status.status - The system status of the instance (ok | impaired | initializing | insufficient-data | not-applicable).  
     */
    Filters?: FilterList;
    /**
     * The instance IDs. Default: Describes all your instances. Constraints: Maximum 100 explicitly specified instance IDs.
     */
    InstanceIds?: InstanceIdStringList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination. You cannot specify this parameter and the instance IDs parameter in the same request.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * When true, includes the health status for all instances. When false, includes the health status for running instances only. Default: false 
     */
    IncludeAllInstances?: Boolean;
  }
  export interface DescribeInstanceStatusResult {
    /**
     * Information about the status of the instances.
     */
    InstanceStatuses?: InstanceStatusList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeInstanceTypeOfferingsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The location type.
     */
    LocationType?: LocationType;
    /**
     * One or more filters. Filter names and values are case-sensitive.    location - This depends on the location type. For example, if the location type is region (default), the location is the Region code (for example, us-east-2.)    instance-type - The instance type. For example, c5.2xlarge.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DITOMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
  }
  export interface DescribeInstanceTypeOfferingsResult {
    /**
     * The instance types offered.
     */
    InstanceTypeOfferings?: InstanceTypeOfferingsList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeInstanceTypesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The instance types. For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceTypes?: RequestInstanceTypeList;
    /**
     * One or more filters. Filter names and values are case-sensitive.    auto-recovery-supported - Indicates whether auto recovery is supported (true | false).    bare-metal - Indicates whether it is a bare metal instance type (true | false).    burstable-performance-supported - Indicates whether it is a burstable performance instance type (true | false).    current-generation - Indicates whether this instance type is the latest generation instance type of an instance family (true | false).    ebs-info.ebs-optimized-info.baseline-bandwidth-in-mbps - The baseline bandwidth performance for an EBS-optimized instance type, in Mbps.    ebs-info.ebs-optimized-info.baseline-iops - The baseline input/output storage operations per second for an EBS-optimized instance type.    ebs-info.ebs-optimized-info.baseline-throughput-in-mbps - The baseline throughput performance for an EBS-optimized instance type, in MB/s.    ebs-info.ebs-optimized-info.maximum-bandwidth-in-mbps - The maximum bandwidth performance for an EBS-optimized instance type, in Mbps.    ebs-info.ebs-optimized-info.maximum-iops - The maximum input/output storage operations per second for an EBS-optimized instance type.    ebs-info.ebs-optimized-info.maximum-throughput-in-mbps - The maximum throughput performance for an EBS-optimized instance type, in MB/s.    ebs-info.ebs-optimized-support - Indicates whether the instance type is EBS-optimized (supported | unsupported | default).    ebs-info.encryption-support - Indicates whether EBS encryption is supported (supported | unsupported).    ebs-info.nvme-support - Indicates whether non-volatile memory express (NVMe) is supported for EBS volumes (required | supported | unsupported).    free-tier-eligible - Indicates whether the instance type is eligible to use in the free tier (true | false).    hibernation-supported - Indicates whether On-Demand hibernation is supported (true | false).    hypervisor - The hypervisor (nitro | xen).    instance-storage-info.disk.count - The number of local disks.    instance-storage-info.disk.size-in-gb - The storage size of each instance storage disk, in GB.    instance-storage-info.disk.type - The storage technology for the local instance storage disks (hdd | ssd).    instance-storage-info.encryption-support - Indicates whether data is encrypted at rest (required | supported | unsupported).    instance-storage-info.nvme-support - Indicates whether non-volatile memory express (NVMe) is supported for instance store (required | supported | unsupported).    instance-storage-info.total-size-in-gb - The total amount of storage available from all local instance storage, in GB.    instance-storage-supported - Indicates whether the instance type has local instance storage (true | false).    instance-type - The instance type (for example c5.2xlarge or c5*).    memory-info.size-in-mib - The memory size.    network-info.efa-info.maximum-efa-interfaces - The maximum number of Elastic Fabric Adapters (EFAs) per instance.    network-info.efa-supported - Indicates whether the instance type supports Elastic Fabric Adapter (EFA) (true | false).    network-info.ena-support - Indicates whether Elastic Network Adapter (ENA) is supported or required (required | supported | unsupported).    network-info.encryption-in-transit-supported - Indicates whether the instance type automatically encrypts in-transit traffic between instances (true | false).    network-info.ipv4-addresses-per-interface - The maximum number of private IPv4 addresses per network interface.    network-info.ipv6-addresses-per-interface - The maximum number of private IPv6 addresses per network interface.    network-info.ipv6-supported - Indicates whether the instance type supports IPv6 (true | false).    network-info.maximum-network-cards - The maximum number of network cards per instance.    network-info.maximum-network-interfaces - The maximum number of network interfaces per instance.    network-info.network-performance - The network performance (for example, "25 Gigabit").    processor-info.supported-architecture - The CPU architecture (arm64 | i386 | x86_64).    processor-info.sustained-clock-speed-in-ghz - The CPU clock speed, in GHz.    supported-boot-mode - The boot mode (legacy-bios | uefi).    supported-root-device-type - The root device type (ebs | instance-store).    supported-usage-class - The usage class (on-demand | spot).    supported-virtualization-type - The virtualization type (hvm | paravirtual).    vcpu-info.default-cores - The default number of cores for the instance type.    vcpu-info.default-threads-per-core - The default number of threads per core for the instance type.    vcpu-info.default-vcpus - The default number of vCPUs for the instance type.    vcpu-info.valid-cores - The number of cores that can be configured for the instance type.    vcpu-info.valid-threads-per-core - The number of threads per core that can be configured for the instance type. For example, "1" or "1,2".  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DITMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
  }
  export interface DescribeInstanceTypesResult {
    /**
     * The instance type. For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceTypes?: InstanceTypeInfoList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeInstancesRequest {
    /**
     * The filters.    affinity - The affinity setting for an instance running on a Dedicated Host (default | host).    architecture - The instance architecture (i386 | x86_64 | arm64).    availability-zone - The Availability Zone of the instance.    block-device-mapping.attach-time - The attach time for an EBS volume mapped to the instance, for example, 2010-09-15T17:15:20.000Z.    block-device-mapping.delete-on-termination - A Boolean that indicates whether the EBS volume is deleted on instance termination.    block-device-mapping.device-name - The device name specified in the block device mapping (for example, /dev/sdh or xvdh).    block-device-mapping.status - The status for the EBS volume (attaching | attached | detaching | detached).    block-device-mapping.volume-id - The volume ID of the EBS volume.    capacity-reservation-id - The ID of the Capacity Reservation into which the instance was launched.    client-token - The idempotency token you provided when you launched the instance.    dns-name - The public DNS name of the instance.    group-id - The ID of the security group for the instance. EC2-Classic only.    group-name - The name of the security group for the instance. EC2-Classic only.    hibernation-options.configured - A Boolean that indicates whether the instance is enabled for hibernation. A value of true means that the instance is enabled for hibernation.     host-id - The ID of the Dedicated Host on which the instance is running, if applicable.    hypervisor - The hypervisor type of the instance (ovm | xen). The value xen is used for both Xen and Nitro hypervisors.    iam-instance-profile.arn - The instance profile associated with the instance. Specified as an ARN.    image-id - The ID of the image used to launch the instance.    instance-id - The ID of the instance.    instance-lifecycle - Indicates whether this is a Spot Instance or a Scheduled Instance (spot | scheduled).    instance-state-code - The state of the instance, as a 16-bit unsigned integer. The high byte is used for internal purposes and should be ignored. The low byte is set based on the state represented. The valid values are: 0 (pending), 16 (running), 32 (shutting-down), 48 (terminated), 64 (stopping), and 80 (stopped).    instance-state-name - The state of the instance (pending | running | shutting-down | terminated | stopping | stopped).    instance-type - The type of instance (for example, t2.micro).    instance.group-id - The ID of the security group for the instance.     instance.group-name - The name of the security group for the instance.     ip-address - The public IPv4 address of the instance.    kernel-id - The kernel ID.    key-name - The name of the key pair used when the instance was launched.    launch-index - When launching multiple instances, this is the index for the instance in the launch group (for example, 0, 1, 2, and so on).     launch-time - The time when the instance was launched, in the ISO 8601 format in the UTC time zone (YYYY-MM-DDThh:mm:ss.sssZ), for example, 2021-09-29T11:04:43.305Z. You can use a wildcard (*), for example, 2021-09-29T*, which matches an entire day.    metadata-options.http-tokens - The metadata request authorization state (optional | required)    metadata-options.http-put-response-hop-limit - The HTTP metadata request put response hop limit (integer, possible values 1 to 64)    metadata-options.http-endpoint - The status of access to the HTTP metadata endpoint on your instance (enabled | disabled)    metadata-options.instance-metadata-tags - The status of access to instance tags from the instance metadata (enabled | disabled)    monitoring-state - Indicates whether detailed monitoring is enabled (disabled | enabled).    network-interface.addresses.private-ip-address - The private IPv4 address associated with the network interface.    network-interface.addresses.primary - Specifies whether the IPv4 address of the network interface is the primary private IPv4 address.    network-interface.addresses.association.public-ip - The ID of the association of an Elastic IP address (IPv4) with a network interface.    network-interface.addresses.association.ip-owner-id - The owner ID of the private IPv4 address associated with the network interface.    network-interface.association.public-ip - The address of the Elastic IP address (IPv4) bound to the network interface.    network-interface.association.ip-owner-id - The owner of the Elastic IP address (IPv4) associated with the network interface.    network-interface.association.allocation-id - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.    network-interface.association.association-id - The association ID returned when the network interface was associated with an IPv4 address.    network-interface.attachment.attachment-id - The ID of the interface attachment.    network-interface.attachment.instance-id - The ID of the instance to which the network interface is attached.    network-interface.attachment.instance-owner-id - The owner ID of the instance to which the network interface is attached.    network-interface.attachment.device-index - The device index to which the network interface is attached.    network-interface.attachment.status - The status of the attachment (attaching | attached | detaching | detached).    network-interface.attachment.attach-time - The time that the network interface was attached to an instance.    network-interface.attachment.delete-on-termination - Specifies whether the attachment is deleted when an instance is terminated.    network-interface.availability-zone - The Availability Zone for the network interface.    network-interface.description - The description of the network interface.    network-interface.group-id - The ID of a security group associated with the network interface.    network-interface.group-name - The name of a security group associated with the network interface.    network-interface.ipv6-addresses.ipv6-address - The IPv6 address associated with the network interface.    network-interface.mac-address - The MAC address of the network interface.    network-interface.network-interface-id - The ID of the network interface.    network-interface.owner-id - The ID of the owner of the network interface.    network-interface.private-dns-name - The private DNS name of the network interface.    network-interface.requester-id - The requester ID for the network interface.    network-interface.requester-managed - Indicates whether the network interface is being managed by Amazon Web Services.    network-interface.status - The status of the network interface (available) | in-use).    network-interface.source-dest-check - Whether the network interface performs source/destination checking. A value of true means that checking is enabled, and false means that checking is disabled. The value must be false for the network interface to perform network address translation (NAT) in your VPC.    network-interface.subnet-id - The ID of the subnet for the network interface.    network-interface.vpc-id - The ID of the VPC for the network interface.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The Amazon Web Services account ID of the instance owner.    placement-group-name - The name of the placement group for the instance.    placement-partition-number - The partition in which the instance is located.    platform - The platform. To list only Windows instances, use windows.    private-dns-name - The private IPv4 DNS name of the instance.    private-ip-address - The private IPv4 address of the instance.    product-code - The product code associated with the AMI used to launch the instance.    product-code.type - The type of product code (devpay | marketplace).    ramdisk-id - The RAM disk ID.    reason - The reason for the current state of the instance (for example, shows "User Initiated [date]" when you stop or terminate the instance). Similar to the state-reason-code filter.    requester-id - The ID of the entity that launched the instance on your behalf (for example, Amazon Web Services Management Console, Auto Scaling, and so on).    reservation-id - The ID of the instance's reservation. A reservation ID is created any time you launch an instance. A reservation ID has a one-to-one relationship with an instance launch request, but can be associated with more than one instance if you launch multiple instances using the same launch request. For example, if you launch one instance, you get one reservation ID. If you launch ten instances using the same launch request, you also get one reservation ID.    root-device-name - The device name of the root device volume (for example, /dev/sda1).    root-device-type - The type of the root device volume (ebs | instance-store).    source-dest-check - Indicates whether the instance performs source/destination checking. A value of true means that checking is enabled, and false means that checking is disabled. The value must be false for the instance to perform network address translation (NAT) in your VPC.     spot-instance-request-id - The ID of the Spot Instance request.    state-reason-code - The reason code for the state change.    state-reason-message - A message that describes the state change.    subnet-id - The ID of the subnet for the instance.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.    tenancy - The tenancy of an instance (dedicated | default | host).    virtualization-type - The virtualization type of the instance (paravirtual | hvm).    vpc-id - The ID of the VPC that the instance is running in.  
     */
    Filters?: FilterList;
    /**
     * The instance IDs. Default: Describes all your instances.
     */
    InstanceIds?: InstanceIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination. You cannot specify this parameter and the instance IDs parameter in the same request.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeInstancesResult {
    /**
     * Information about the reservations.
     */
    Reservations?: ReservationList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeInternetGatewaysMaxResults = number;
  export interface DescribeInternetGatewaysRequest {
    /**
     * One or more filters.    attachment.state - The current state of the attachment between the gateway and the VPC (available). Present only if a VPC is attached.    attachment.vpc-id - The ID of an attached VPC.    internet-gateway-id - The ID of the Internet gateway.    owner-id - The ID of the Amazon Web Services account that owns the internet gateway.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more internet gateway IDs. Default: Describes all your internet gateways.
     */
    InternetGatewayIds?: InternetGatewayIdList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeInternetGatewaysMaxResults;
  }
  export interface DescribeInternetGatewaysResult {
    /**
     * Information about one or more internet gateways.
     */
    InternetGateways?: InternetGatewayList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeIpamPoolsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in the request.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The IDs of the IPAM pools you would like information on.
     */
    IpamPoolIds?: ValueStringList;
  }
  export interface DescribeIpamPoolsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
    /**
     * Information about the IPAM pools.
     */
    IpamPools?: IpamPoolSet;
  }
  export interface DescribeIpamResourceDiscoveriesRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IPAM resource discovery IDs.
     */
    IpamResourceDiscoveryIds?: ValueStringList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of resource discoveries to return in one page of results.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The resource discovery filters.
     */
    Filters?: FilterList;
  }
  export interface DescribeIpamResourceDiscoveriesResult {
    /**
     * The resource discoveries.
     */
    IpamResourceDiscoveries?: IpamResourceDiscoverySet;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeIpamResourceDiscoveryAssociationsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The resource discovery association IDs.
     */
    IpamResourceDiscoveryAssociationIds?: ValueStringList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of resource discovery associations to return in one page of results.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The resource discovery association filters.
     */
    Filters?: FilterList;
  }
  export interface DescribeIpamResourceDiscoveryAssociationsResult {
    /**
     * The resource discovery associations.
     */
    IpamResourceDiscoveryAssociations?: IpamResourceDiscoveryAssociationSet;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeIpamScopesRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in the request.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The IDs of the scopes you want information on.
     */
    IpamScopeIds?: ValueStringList;
  }
  export interface DescribeIpamScopesResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
    /**
     * The scopes you want information on.
     */
    IpamScopes?: IpamScopeSet;
  }
  export interface DescribeIpamsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in the request.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The IDs of the IPAMs you want information on.
     */
    IpamIds?: ValueStringList;
  }
  export interface DescribeIpamsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
    /**
     * Information about the IPAMs.
     */
    Ipams?: IpamSet;
  }
  export interface DescribeIpv6PoolsRequest {
    /**
     * The IDs of the IPv6 address pools.
     */
    PoolIds?: Ipv6PoolIdList;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: Ipv6PoolMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
  }
  export interface DescribeIpv6PoolsResult {
    /**
     * Information about the IPv6 address pools.
     */
    Ipv6Pools?: Ipv6PoolSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeKeyPairsRequest {
    /**
     * The filters.    key-pair-id - The ID of the key pair.    fingerprint - The fingerprint of the key pair.    key-name - The name of the key pair.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.  
     */
    Filters?: FilterList;
    /**
     * The key pair names. Default: Describes all of your key pairs.
     */
    KeyNames?: KeyNameStringList;
    /**
     * The IDs of the key pairs.
     */
    KeyPairIds?: KeyPairIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * If true, the public key material is included in the response. Default: false 
     */
    IncludePublicKey?: Boolean;
  }
  export interface DescribeKeyPairsResult {
    /**
     * Information about the key pairs.
     */
    KeyPairs?: KeyPairList;
  }
  export interface DescribeLaunchTemplateVersionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the launch template. To describe one or more versions of a specified launch template, you must specify either the LaunchTemplateId or the LaunchTemplateName, but not both. To describe all the latest or default launch template versions in your account, you must omit this parameter.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. To describe one or more versions of a specified launch template, you must specify either the LaunchTemplateName or the LaunchTemplateId, but not both. To describe all the latest or default launch template versions in your account, you must omit this parameter.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * One or more versions of the launch template. Valid values depend on whether you are describing a specified launch template (by ID or name) or all launch templates in your account. To describe one or more versions of a specified launch template, valid values are $Latest, $Default, and numbers. To describe all launch templates in your account that are defined as the latest version, the valid value is $Latest. To describe all launch templates in your account that are defined as the default version, the valid value is $Default. You can specify $Latest and $Default in the same request. You cannot specify numbers.
     */
    Versions?: VersionStringList;
    /**
     * The version number after which to describe launch template versions.
     */
    MinVersion?: String;
    /**
     * The version number up to which to describe launch template versions.
     */
    MaxVersion?: String;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 1 and 200.
     */
    MaxResults?: Integer;
    /**
     * One or more filters.    create-time - The time the launch template version was created.    ebs-optimized - A boolean that indicates whether the instance is optimized for Amazon EBS I/O.    http-endpoint - Indicates whether the HTTP metadata endpoint on your instances is enabled (enabled | disabled).    http-protocol-ipv4 - Indicates whether the IPv4 endpoint for the instance metadata service is enabled (enabled | disabled).    host-resource-group-arn - The ARN of the host resource group in which to launch the instances.    http-tokens - The state of token usage for your instance metadata requests (optional | required).    iam-instance-profile - The ARN of the IAM instance profile.    image-id - The ID of the AMI.    instance-type - The instance type.    is-default-version - A boolean that indicates whether the launch template version is the default version.    kernel-id - The kernel ID.    license-configuration-arn - The ARN of the license configuration.    network-card-index - The index of the network card.    ram-disk-id - The RAM disk ID.  
     */
    Filters?: FilterList;
    /**
     * If true, and if a Systems Manager parameter is specified for ImageId, the AMI ID is displayed in the response for imageId. If false, and if a Systems Manager parameter is specified for ImageId, the parameter is displayed in the response for imageId.  For more information, see Use a Systems Manager parameter instead of an AMI ID in the Amazon Elastic Compute Cloud User Guide. Default: false 
     */
    ResolveAlias?: Boolean;
  }
  export interface DescribeLaunchTemplateVersionsResult {
    /**
     * Information about the launch template versions.
     */
    LaunchTemplateVersions?: LaunchTemplateVersionSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeLaunchTemplatesMaxResults = number;
  export interface DescribeLaunchTemplatesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more launch template IDs.
     */
    LaunchTemplateIds?: LaunchTemplateIdStringList;
    /**
     * One or more launch template names.
     */
    LaunchTemplateNames?: LaunchTemplateNameStringList;
    /**
     * One or more filters.    create-time - The time the launch template was created.    launch-template-name - The name of the launch template.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 1 and 200.
     */
    MaxResults?: DescribeLaunchTemplatesMaxResults;
  }
  export interface DescribeLaunchTemplatesResult {
    /**
     * Information about the launch templates.
     */
    LaunchTemplates?: LaunchTemplateSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsRequest {
    /**
     * The IDs of the associations.
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociationIds?: LocalGatewayRouteTableVirtualInterfaceGroupAssociationIdSet;
    /**
     * One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-route-table-arn - The Amazon Resource Name (ARN) of the local gateway route table for the virtual interface group.    local-gateway-route-table-id - The ID of the local gateway route table.    local-gateway-route-table-virtual-interface-group-association-id - The ID of the association.    local-gateway-route-table-virtual-interface-group-id - The ID of the virtual interface group.    owner-id - The ID of the Amazon Web Services account that owns the local gateway virtual interface group association.    state - The state of the association.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewayRouteTableVirtualInterfaceGroupAssociationsResult {
    /**
     * Information about the associations.
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociations?: LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewayRouteTableVpcAssociationsRequest {
    /**
     * The IDs of the associations.
     */
    LocalGatewayRouteTableVpcAssociationIds?: LocalGatewayRouteTableVpcAssociationIdSet;
    /**
     * One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-route-table-arn - The Amazon Resource Name (ARN) of the local gateway route table for the association.    local-gateway-route-table-id - The ID of the local gateway route table.    local-gateway-route-table-vpc-association-id - The ID of the association.    owner-id - The ID of the Amazon Web Services account that owns the local gateway route table for the association.    state - The state of the association.    vpc-id - The ID of the VPC.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewayRouteTableVpcAssociationsResult {
    /**
     * Information about the associations.
     */
    LocalGatewayRouteTableVpcAssociations?: LocalGatewayRouteTableVpcAssociationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewayRouteTablesRequest {
    /**
     * The IDs of the local gateway route tables.
     */
    LocalGatewayRouteTableIds?: LocalGatewayRouteTableIdSet;
    /**
     * One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-route-table-arn - The Amazon Resource Name (ARN) of the local gateway route table.    local-gateway-route-table-id - The ID of a local gateway route table.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The ID of the Amazon Web Services account that owns the local gateway route table.    state - The state of the local gateway route table.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewayRouteTablesResult {
    /**
     * Information about the local gateway route tables.
     */
    LocalGatewayRouteTables?: LocalGatewayRouteTableSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewayVirtualInterfaceGroupsRequest {
    /**
     * The IDs of the virtual interface groups.
     */
    LocalGatewayVirtualInterfaceGroupIds?: LocalGatewayVirtualInterfaceGroupIdSet;
    /**
     * One or more filters.    local-gateway-id - The ID of a local gateway.    local-gateway-virtual-interface-group-id - The ID of the virtual interface group.    local-gateway-virtual-interface-id - The ID of the virtual interface.    owner-id - The ID of the Amazon Web Services account that owns the local gateway virtual interface group.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewayVirtualInterfaceGroupsResult {
    /**
     * The virtual interface groups.
     */
    LocalGatewayVirtualInterfaceGroups?: LocalGatewayVirtualInterfaceGroupSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewayVirtualInterfacesRequest {
    /**
     * The IDs of the virtual interfaces.
     */
    LocalGatewayVirtualInterfaceIds?: LocalGatewayVirtualInterfaceIdSet;
    /**
     * One or more filters.    local-address - The local address.    local-bgp-asn - The Border Gateway Protocol (BGP) Autonomous System Number (ASN) of the local gateway.    local-gateway-id - The ID of the local gateway.    local-gateway-virtual-interface-id - The ID of the virtual interface.    owner-id - The ID of the Amazon Web Services account that owns the local gateway virtual interface.    peer-address - The peer address.    peer-bgp-asn - The peer BGP ASN.    vlan - The ID of the VLAN.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewayVirtualInterfacesResult {
    /**
     * Information about the virtual interfaces.
     */
    LocalGatewayVirtualInterfaces?: LocalGatewayVirtualInterfaceSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeLocalGatewaysRequest {
    /**
     * The IDs of the local gateways.
     */
    LocalGatewayIds?: LocalGatewayIdSet;
    /**
     * One or more filters.    local-gateway-id - The ID of a local gateway.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The ID of the Amazon Web Services account that owns the local gateway.    state - The state of the association.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: LocalGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeLocalGatewaysResult {
    /**
     * Information about the local gateways.
     */
    LocalGateways?: LocalGatewaySet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeManagedPrefixListsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    owner-id - The ID of the prefix list owner.    prefix-list-id - The ID of the prefix list.    prefix-list-name - The name of the prefix list.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: PrefixListMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more prefix list IDs.
     */
    PrefixListIds?: ValueStringList;
  }
  export interface DescribeManagedPrefixListsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
    /**
     * Information about the prefix lists.
     */
    PrefixLists?: ManagedPrefixListSet;
  }
  export type DescribeMovingAddressesMaxResults = number;
  export interface DescribeMovingAddressesRequest {
    /**
     * One or more filters.    moving-status - The status of the Elastic IP address (MovingToVpc | RestoringToClassic).  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1000; if MaxResults is given a value outside of this range, an error is returned. Default: If no value is provided, the default is 1000.
     */
    MaxResults?: DescribeMovingAddressesMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * One or more Elastic IP addresses.
     */
    PublicIps?: ValueStringList;
  }
  export interface DescribeMovingAddressesResult {
    /**
     * The status for each Elastic IP address.
     */
    MovingAddressStatuses?: MovingAddressStatusSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeNatGatewaysMaxResults = number;
  export interface DescribeNatGatewaysRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    nat-gateway-id - The ID of the NAT gateway.    state - The state of the NAT gateway (pending | failed | available | deleting | deleted).    subnet-id - The ID of the subnet in which the NAT gateway resides.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC in which the NAT gateway resides.  
     */
    Filter?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeNatGatewaysMaxResults;
    /**
     * One or more NAT gateway IDs.
     */
    NatGatewayIds?: NatGatewayIdStringList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeNatGatewaysResult {
    /**
     * Information about the NAT gateways.
     */
    NatGateways?: NatGatewayList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeNetworkAclsMaxResults = number;
  export interface DescribeNetworkAclsRequest {
    /**
     * One or more filters.    association.association-id - The ID of an association ID for the ACL.    association.network-acl-id - The ID of the network ACL involved in the association.    association.subnet-id - The ID of the subnet involved in the association.    default - Indicates whether the ACL is the default network ACL for the VPC.    entry.cidr - The IPv4 CIDR range specified in the entry.    entry.icmp.code - The ICMP code specified in the entry, if any.    entry.icmp.type - The ICMP type specified in the entry, if any.    entry.ipv6-cidr - The IPv6 CIDR range specified in the entry.    entry.port-range.from - The start of the port range specified in the entry.     entry.port-range.to - The end of the port range specified in the entry.     entry.protocol - The protocol specified in the entry (tcp | udp | icmp or a protocol number).    entry.rule-action - Allows or denies the matching traffic (allow | deny).    entry.egress - A Boolean that indicates the type of rule. Specify true for egress rules, or false for ingress rules.    entry.rule-number - The number of an entry (in other words, rule) in the set of ACL entries.    network-acl-id - The ID of the network ACL.    owner-id - The ID of the Amazon Web Services account that owns the network ACL.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the network ACL.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more network ACL IDs. Default: Describes all your network ACLs.
     */
    NetworkAclIds?: NetworkAclIdStringList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeNetworkAclsMaxResults;
  }
  export interface DescribeNetworkAclsResult {
    /**
     * Information about one or more network ACLs.
     */
    NetworkAcls?: NetworkAclList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeNetworkInsightsAccessScopeAnalysesRequest {
    /**
     * The IDs of the Network Access Scope analyses.
     */
    NetworkInsightsAccessScopeAnalysisIds?: NetworkInsightsAccessScopeAnalysisIdList;
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
    /**
     * Filters the results based on the start time. The analysis must have started on or after this time.
     */
    AnalysisStartTimeBegin?: MillisecondDateTime;
    /**
     * Filters the results based on the start time. The analysis must have started on or before this time.
     */
    AnalysisStartTimeEnd?: MillisecondDateTime;
    /**
     * There are no supported filters.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: NetworkInsightsMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeNetworkInsightsAccessScopeAnalysesResult {
    /**
     * The Network Access Scope analyses.
     */
    NetworkInsightsAccessScopeAnalyses?: NetworkInsightsAccessScopeAnalysisList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeNetworkInsightsAccessScopesRequest {
    /**
     * The IDs of the Network Access Scopes.
     */
    NetworkInsightsAccessScopeIds?: NetworkInsightsAccessScopeIdList;
    /**
     * There are no supported filters.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: NetworkInsightsMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeNetworkInsightsAccessScopesResult {
    /**
     * The Network Access Scopes.
     */
    NetworkInsightsAccessScopes?: NetworkInsightsAccessScopeList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeNetworkInsightsAnalysesRequest {
    /**
     * The ID of the network insights analyses. You must specify either analysis IDs or a path ID.
     */
    NetworkInsightsAnalysisIds?: NetworkInsightsAnalysisIdList;
    /**
     * The ID of the path. You must specify either a path ID or analysis IDs.
     */
    NetworkInsightsPathId?: NetworkInsightsPathId;
    /**
     * The time when the network insights analyses started.
     */
    AnalysisStartTime?: MillisecondDateTime;
    /**
     * The time when the network insights analyses ended.
     */
    AnalysisEndTime?: MillisecondDateTime;
    /**
     * The filters. The following are the possible values:   path-found - A Boolean value that indicates whether a feasible path is found.   status - The status of the analysis (running | succeeded | failed).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: NetworkInsightsMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeNetworkInsightsAnalysesResult {
    /**
     * Information about the network insights analyses.
     */
    NetworkInsightsAnalyses?: NetworkInsightsAnalysisList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeNetworkInsightsPathsRequest {
    /**
     * The IDs of the paths.
     */
    NetworkInsightsPathIds?: NetworkInsightsPathIdList;
    /**
     * The filters. The following are the possible values:   destination - The ID of the resource.   filter-at-source.source-address - The source IPv4 address at the source.   filter-at-source.source-port-range - The source port range at the source.   filter-at-source.destination-address - The destination IPv4 address at the source.   filter-at-source.destination-port-range - The destination port range at the source.   filter-at-destination.source-address - The source IPv4 address at the destination.   filter-at-destination.source-port-range - The source port range at the destination.   filter-at-destination.destination-address - The destination IPv4 address at the destination.   filter-at-destination.destination-port-range - The destination port range at the destination.   protocol - The protocol.   source - The ID of the resource.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: NetworkInsightsMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeNetworkInsightsPathsResult {
    /**
     * Information about the paths.
     */
    NetworkInsightsPaths?: NetworkInsightsPathList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeNetworkInterfaceAttributeRequest {
    /**
     * The attribute of the network interface. This parameter is required.
     */
    Attribute?: NetworkInterfaceAttribute;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
  }
  export interface DescribeNetworkInterfaceAttributeResult {
    /**
     * The attachment (if any) of the network interface.
     */
    Attachment?: NetworkInterfaceAttachment;
    /**
     * The description of the network interface.
     */
    Description?: AttributeValue;
    /**
     * The security groups associated with the network interface.
     */
    Groups?: GroupIdentifierList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * Indicates whether source/destination checking is enabled.
     */
    SourceDestCheck?: AttributeBooleanValue;
  }
  export type DescribeNetworkInterfacePermissionsMaxResults = number;
  export interface DescribeNetworkInterfacePermissionsRequest {
    /**
     * The network interface permission IDs.
     */
    NetworkInterfacePermissionIds?: NetworkInterfacePermissionIdList;
    /**
     * One or more filters.    network-interface-permission.network-interface-permission-id - The ID of the permission.    network-interface-permission.network-interface-id - The ID of the network interface.    network-interface-permission.aws-account-id - The Amazon Web Services account ID.    network-interface-permission.aws-service - The Amazon Web Service.    network-interface-permission.permission - The type of permission (INSTANCE-ATTACH | EIP-ASSOCIATE).  
     */
    Filters?: FilterList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. If this parameter is not specified, up to 50 results are returned by default. For more information, see Pagination.
     */
    MaxResults?: DescribeNetworkInterfacePermissionsMaxResults;
  }
  export interface DescribeNetworkInterfacePermissionsResult {
    /**
     * The network interface permissions.
     */
    NetworkInterfacePermissions?: NetworkInterfacePermissionList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeNetworkInterfacesMaxResults = number;
  export interface DescribeNetworkInterfacesRequest {
    /**
     * One or more filters.    addresses.private-ip-address - The private IPv4 addresses associated with the network interface.    addresses.primary - Whether the private IPv4 address is the primary IP address associated with the network interface.     addresses.association.public-ip - The association ID returned when the network interface was associated with the Elastic IP address (IPv4).    addresses.association.owner-id - The owner ID of the addresses associated with the network interface.    association.association-id - The association ID returned when the network interface was associated with an IPv4 address.    association.allocation-id - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.    association.ip-owner-id - The owner of the Elastic IP address (IPv4) associated with the network interface.    association.public-ip - The address of the Elastic IP address (IPv4) bound to the network interface.    association.public-dns-name - The public DNS name for the network interface (IPv4).    attachment.attachment-id - The ID of the interface attachment.    attachment.attach-time - The time that the network interface was attached to an instance.    attachment.delete-on-termination - Indicates whether the attachment is deleted when an instance is terminated.    attachment.device-index - The device index to which the network interface is attached.    attachment.instance-id - The ID of the instance to which the network interface is attached.    attachment.instance-owner-id - The owner ID of the instance to which the network interface is attached.    attachment.status - The status of the attachment (attaching | attached | detaching | detached).    availability-zone - The Availability Zone of the network interface.    description - The description of the network interface.    group-id - The ID of a security group associated with the network interface.    group-name - The name of a security group associated with the network interface.    ipv6-addresses.ipv6-address - An IPv6 address associated with the network interface.    interface-type - The type of network interface (api_gateway_managed | aws_codestar_connections_managed | branch | efa | gateway_load_balancer | gateway_load_balancer_endpoint | global_accelerator_managed | interface | iot_rules_managed | lambda | load_balancer | nat_gateway | network_load_balancer | quicksight | transit_gateway | trunk | vpc_endpoint).    mac-address - The MAC address of the network interface.    network-interface-id - The ID of the network interface.    owner-id - The Amazon Web Services account ID of the network interface owner.    private-ip-address - The private IPv4 address or addresses of the network interface.    private-dns-name - The private DNS name of the network interface (IPv4).    requester-id - The alias or Amazon Web Services account ID of the principal or service that created the network interface.    requester-managed - Indicates whether the network interface is being managed by an Amazon Web Service (for example, Amazon Web Services Management Console, Auto Scaling, and so on).    source-dest-check - Indicates whether the network interface performs source/destination checking. A value of true means checking is enabled, and false means checking is disabled. The value must be false for the network interface to perform network address translation (NAT) in your VPC.     status - The status of the network interface. If the network interface is not attached to an instance, the status is available; if a network interface is attached to an instance the status is in-use.    subnet-id - The ID of the subnet for the network interface.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the network interface.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The network interface IDs. Default: Describes all your network interfaces.
     */
    NetworkInterfaceIds?: NetworkInterfaceIdList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. You cannot specify this parameter and the network interface IDs parameter in the same request. For more information, see Pagination.
     */
    MaxResults?: DescribeNetworkInterfacesMaxResults;
  }
  export interface DescribeNetworkInterfacesResult {
    /**
     * Information about one or more network interfaces.
     */
    NetworkInterfaces?: NetworkInterfaceList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribePlacementGroupsRequest {
    /**
     * The filters.    group-name - The name of the placement group.    group-arn - The Amazon Resource Name (ARN) of the placement group.    spread-level - The spread level for the placement group (host | rack).     state - The state of the placement group (pending | available | deleting | deleted).    strategy - The strategy of the placement group (cluster | spread | partition).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The names of the placement groups. Default: Describes all your placement groups, or only those otherwise specified.
     */
    GroupNames?: PlacementGroupStringList;
    /**
     * The IDs of the placement groups.
     */
    GroupIds?: PlacementGroupIdStringList;
  }
  export interface DescribePlacementGroupsResult {
    /**
     * Information about the placement groups.
     */
    PlacementGroups?: PlacementGroupList;
  }
  export interface DescribePrefixListsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    prefix-list-id: The ID of a prefix list.    prefix-list-name: The name of a prefix list.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: Integer;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * One or more prefix list IDs.
     */
    PrefixListIds?: PrefixListResourceIdStringList;
  }
  export interface DescribePrefixListsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * All available prefix lists.
     */
    PrefixLists?: PrefixListSet;
  }
  export type DescribePrincipalIdFormatMaxResults = number;
  export interface DescribePrincipalIdFormatRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway 
     */
    Resources?: ResourceList;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. 
     */
    MaxResults?: DescribePrincipalIdFormatMaxResults;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribePrincipalIdFormatResult {
    /**
     * Information about the ID format settings for the ARN.
     */
    Principals?: PrincipalIdFormatList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribePublicIpv4PoolsRequest {
    /**
     * The IDs of the address pools.
     */
    PoolIds?: PublicIpv4PoolIdStringList;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: PoolMaxResults;
    /**
     * One or more filters.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
  }
  export interface DescribePublicIpv4PoolsResult {
    /**
     * Information about the address pools.
     */
    PublicIpv4Pools?: PublicIpv4PoolSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeRegionsRequest {
    /**
     * The filters.    endpoint - The endpoint of the Region (for example, ec2.us-east-1.amazonaws.com).    opt-in-status - The opt-in status of the Region (opt-in-not-required | opted-in | not-opted-in).    region-name - The name of the Region (for example, us-east-1).  
     */
    Filters?: FilterList;
    /**
     * The names of the Regions. You can specify any Regions, whether they are enabled and disabled for your account.
     */
    RegionNames?: RegionNameStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to display all Regions, including Regions that are disabled for your account.
     */
    AllRegions?: Boolean;
  }
  export interface DescribeRegionsResult {
    /**
     * Information about the Regions.
     */
    Regions?: RegionList;
  }
  export type DescribeReplaceRootVolumeTasksMaxResults = number;
  export interface DescribeReplaceRootVolumeTasksRequest {
    /**
     * The ID of the root volume replacement task to view.
     */
    ReplaceRootVolumeTaskIds?: ReplaceRootVolumeTaskIds;
    /**
     * Filter to use:    instance-id - The ID of the instance for which the root volume replacement task was created.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeReplaceRootVolumeTasksMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeReplaceRootVolumeTasksResult {
    /**
     * Information about the root volume replacement task.
     */
    ReplaceRootVolumeTasks?: ReplaceRootVolumeTasks;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeReservedInstancesListingsRequest {
    /**
     * One or more filters.    reserved-instances-id - The ID of the Reserved Instances.    reserved-instances-listing-id - The ID of the Reserved Instances listing.    status - The status of the Reserved Instance listing (pending | active | cancelled | closed).    status-message - The reason for the status.  
     */
    Filters?: FilterList;
    /**
     * One or more Reserved Instance IDs.
     */
    ReservedInstancesId?: ReservationId;
    /**
     * One or more Reserved Instance listing IDs.
     */
    ReservedInstancesListingId?: ReservedInstancesListingId;
  }
  export interface DescribeReservedInstancesListingsResult {
    /**
     * Information about the Reserved Instance listing.
     */
    ReservedInstancesListings?: ReservedInstancesListingList;
  }
  export interface DescribeReservedInstancesModificationsRequest {
    /**
     * One or more filters.    client-token - The idempotency token for the modification request.    create-date - The time when the modification request was created.    effective-date - The time when the modification becomes effective.    modification-result.reserved-instances-id - The ID for the Reserved Instances created as part of the modification request. This ID is only available when the status of the modification is fulfilled.    modification-result.target-configuration.availability-zone - The Availability Zone for the new Reserved Instances.    modification-result.target-configuration.instance-count  - The number of new Reserved Instances.    modification-result.target-configuration.instance-type - The instance type of the new Reserved Instances.    modification-result.target-configuration.platform - The network platform of the new Reserved Instances (EC2-Classic | EC2-VPC).    reserved-instances-id - The ID of the Reserved Instances modified.    reserved-instances-modification-id - The ID of the modification request.    status - The status of the Reserved Instances modification request (processing | fulfilled | failed).    status-message - The reason for the status.    update-date - The time when the modification request was last updated.  
     */
    Filters?: FilterList;
    /**
     * IDs for the submitted modification request.
     */
    ReservedInstancesModificationIds?: ReservedInstancesModificationIdStringList;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeReservedInstancesModificationsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * The Reserved Instance modification information.
     */
    ReservedInstancesModifications?: ReservedInstancesModificationList;
  }
  export interface DescribeReservedInstancesOfferingsRequest {
    /**
     * The Availability Zone in which the Reserved Instance can be used.
     */
    AvailabilityZone?: String;
    /**
     * One or more filters.    availability-zone - The Availability Zone where the Reserved Instance can be used.    duration - The duration of the Reserved Instance (for example, one year or three years), in seconds (31536000 | 94608000).    fixed-price - The purchase price of the Reserved Instance (for example, 9800.0).    instance-type - The instance type that is covered by the reservation.    marketplace - Set to true to show only Reserved Instance Marketplace offerings. When this filter is not used, which is the default behavior, all offerings from both Amazon Web Services and the Reserved Instance Marketplace are listed.    product-description - The Reserved Instance product platform description. Instances that include (Amazon VPC) in the product platform description will only be displayed to EC2-Classic account holders and are for use with Amazon VPC. (Linux/UNIX | Linux/UNIX (Amazon VPC) | SUSE Linux | SUSE Linux (Amazon VPC) | Red Hat Enterprise Linux | Red Hat Enterprise Linux (Amazon VPC) | Red Hat Enterprise Linux with HA (Amazon VPC) | Windows | Windows (Amazon VPC) | Windows with SQL Server Standard | Windows with SQL Server Standard (Amazon VPC) | Windows with SQL Server Web |  Windows with SQL Server Web (Amazon VPC) | Windows with SQL Server Enterprise | Windows with SQL Server Enterprise (Amazon VPC))     reserved-instances-offering-id - The Reserved Instances offering ID.    scope - The scope of the Reserved Instance (Availability Zone or Region).    usage-price - The usage price of the Reserved Instance, per hour (for example, 0.84).  
     */
    Filters?: FilterList;
    /**
     * Include Reserved Instance Marketplace offerings in the response.
     */
    IncludeMarketplace?: Boolean;
    /**
     * The instance type that the reservation will cover (for example, m1.small). For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceType?: InstanceType;
    /**
     * The maximum duration (in seconds) to filter when searching for offerings. Default: 94608000 (3 years)
     */
    MaxDuration?: Long;
    /**
     * The maximum number of instances to filter when searching for offerings. Default: 20
     */
    MaxInstanceCount?: Integer;
    /**
     * The minimum duration (in seconds) to filter when searching for offerings. Default: 2592000 (1 month)
     */
    MinDuration?: Long;
    /**
     * The offering class of the Reserved Instance. Can be standard or convertible.
     */
    OfferingClass?: OfferingClassType;
    /**
     * The Reserved Instance product platform description. Instances that include (Amazon VPC) in the description are for use with Amazon VPC.
     */
    ProductDescription?: RIProductDescription;
    /**
     * One or more Reserved Instances offering IDs.
     */
    ReservedInstancesOfferingIds?: ReservedInstancesOfferingIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tenancy of the instances covered by the reservation. A Reserved Instance with a tenancy of dedicated is applied to instances that run in a VPC on single-tenant hardware (i.e., Dedicated Instances).  Important: The host value cannot be used with this parameter. Use the default or dedicated values only. Default: default 
     */
    InstanceTenancy?: Tenancy;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. The maximum is 100. Default: 100
     */
    MaxResults?: Integer;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The Reserved Instance offering type. If you are using tools that predate the 2011-11-01 API version, you only have access to the Medium Utilization Reserved Instance offering type. 
     */
    OfferingType?: OfferingTypeValues;
  }
  export interface DescribeReservedInstancesOfferingsResult {
    /**
     * A list of Reserved Instances offerings.
     */
    ReservedInstancesOfferings?: ReservedInstancesOfferingList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeReservedInstancesRequest {
    /**
     * One or more filters.    availability-zone - The Availability Zone where the Reserved Instance can be used.    duration - The duration of the Reserved Instance (one year or three years), in seconds (31536000 | 94608000).    end - The time when the Reserved Instance expires (for example, 2015-08-07T11:54:42.000Z).    fixed-price - The purchase price of the Reserved Instance (for example, 9800.0).    instance-type - The instance type that is covered by the reservation.    scope - The scope of the Reserved Instance (Region or Availability Zone).    product-description - The Reserved Instance product platform description. Instances that include (Amazon VPC) in the product platform description will only be displayed to EC2-Classic account holders and are for use with Amazon VPC (Linux/UNIX | Linux/UNIX (Amazon VPC) | SUSE Linux | SUSE Linux (Amazon VPC) | Red Hat Enterprise Linux | Red Hat Enterprise Linux (Amazon VPC) | Red Hat Enterprise Linux with HA (Amazon VPC) | Windows | Windows (Amazon VPC) | Windows with SQL Server Standard | Windows with SQL Server Standard (Amazon VPC) | Windows with SQL Server Web | Windows with SQL Server Web (Amazon VPC) | Windows with SQL Server Enterprise | Windows with SQL Server Enterprise (Amazon VPC)).    reserved-instances-id - The ID of the Reserved Instance.    start - The time at which the Reserved Instance purchase request was placed (for example, 2014-08-07T11:54:42.000Z).    state - The state of the Reserved Instance (payment-pending | active | payment-failed | retired).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    usage-price - The usage price of the Reserved Instance, per hour (for example, 0.84).  
     */
    Filters?: FilterList;
    /**
     * Describes whether the Reserved Instance is Standard or Convertible.
     */
    OfferingClass?: OfferingClassType;
    /**
     * One or more Reserved Instance IDs. Default: Describes all your Reserved Instances, or only those otherwise specified.
     */
    ReservedInstancesIds?: ReservedInstancesIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Reserved Instance offering type. If you are using tools that predate the 2011-11-01 API version, you only have access to the Medium Utilization Reserved Instance offering type.
     */
    OfferingType?: OfferingTypeValues;
  }
  export interface DescribeReservedInstancesResult {
    /**
     * A list of Reserved Instances.
     */
    ReservedInstances?: ReservedInstancesList;
  }
  export type DescribeRouteTablesMaxResults = number;
  export interface DescribeRouteTablesRequest {
    /**
     * One or more filters.    association.route-table-association-id - The ID of an association ID for the route table.    association.route-table-id - The ID of the route table involved in the association.    association.subnet-id - The ID of the subnet involved in the association.    association.main - Indicates whether the route table is the main route table for the VPC (true | false). Route tables that do not have an association ID are not returned in the response.    owner-id - The ID of the Amazon Web Services account that owns the route table.    route-table-id - The ID of the route table.    route.destination-cidr-block - The IPv4 CIDR range specified in a route in the table.    route.destination-ipv6-cidr-block - The IPv6 CIDR range specified in a route in the route table.    route.destination-prefix-list-id - The ID (prefix) of the Amazon Web Service specified in a route in the table.    route.egress-only-internet-gateway-id - The ID of an egress-only Internet gateway specified in a route in the route table.    route.gateway-id - The ID of a gateway specified in a route in the table.    route.instance-id - The ID of an instance specified in a route in the table.    route.nat-gateway-id - The ID of a NAT gateway.    route.transit-gateway-id - The ID of a transit gateway.    route.origin - Describes how the route was created. CreateRouteTable indicates that the route was automatically created when the route table was created; CreateRoute indicates that the route was manually added to the route table; EnableVgwRoutePropagation indicates that the route was propagated by route propagation.    route.state - The state of a route in the route table (active | blackhole). The blackhole state indicates that the route's target isn't available (for example, the specified gateway isn't attached to the VPC, the specified NAT instance has been terminated, and so on).    route.vpc-peering-connection-id - The ID of a VPC peering connection specified in a route in the table.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the route table.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more route table IDs. Default: Describes all your route tables.
     */
    RouteTableIds?: RouteTableIdStringList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeRouteTablesMaxResults;
  }
  export interface DescribeRouteTablesResult {
    /**
     * Information about one or more route tables.
     */
    RouteTables?: RouteTableList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeScheduledInstanceAvailabilityMaxResults = number;
  export interface DescribeScheduledInstanceAvailabilityRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    availability-zone - The Availability Zone (for example, us-west-2a).    instance-type - The instance type (for example, c4.large).    network-platform - The network platform (EC2-Classic or EC2-VPC).    platform - The platform (Linux/UNIX or Windows).  
     */
    Filters?: FilterList;
    /**
     * The time period for the first schedule to start.
     */
    FirstSlotStartTimeRange: SlotDateTimeRangeRequest;
    /**
     * The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 300. To retrieve the remaining results, make another call with the returned NextToken value.
     */
    MaxResults?: DescribeScheduledInstanceAvailabilityMaxResults;
    /**
     * The maximum available duration, in hours. This value must be greater than MinSlotDurationInHours and less than 1,720.
     */
    MaxSlotDurationInHours?: Integer;
    /**
     * The minimum available duration, in hours. The minimum required duration is 1,200 hours per year. For example, the minimum daily schedule is 4 hours, the minimum weekly schedule is 24 hours, and the minimum monthly schedule is 100 hours.
     */
    MinSlotDurationInHours?: Integer;
    /**
     * The token for the next set of results.
     */
    NextToken?: String;
    /**
     * The schedule recurrence.
     */
    Recurrence: ScheduledInstanceRecurrenceRequest;
  }
  export interface DescribeScheduledInstanceAvailabilityResult {
    /**
     * The token required to retrieve the next set of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Information about the available Scheduled Instances.
     */
    ScheduledInstanceAvailabilitySet?: ScheduledInstanceAvailabilitySet;
  }
  export interface DescribeScheduledInstancesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    availability-zone - The Availability Zone (for example, us-west-2a).    instance-type - The instance type (for example, c4.large).    network-platform - The network platform (EC2-Classic or EC2-VPC).    platform - The platform (Linux/UNIX or Windows).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in a single call. This value can be between 5 and 300. The default value is 100. To retrieve the remaining results, make another call with the returned NextToken value.
     */
    MaxResults?: Integer;
    /**
     * The token for the next set of results.
     */
    NextToken?: String;
    /**
     * The Scheduled Instance IDs.
     */
    ScheduledInstanceIds?: ScheduledInstanceIdRequestSet;
    /**
     * The time period for the first schedule to start.
     */
    SlotStartTimeRange?: SlotStartTimeRangeRequest;
  }
  export interface DescribeScheduledInstancesResult {
    /**
     * The token required to retrieve the next set of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Information about the Scheduled Instances.
     */
    ScheduledInstanceSet?: ScheduledInstanceSet;
  }
  export interface DescribeSecurityGroupReferencesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the security groups in your account.
     */
    GroupId: GroupIds;
  }
  export interface DescribeSecurityGroupReferencesResult {
    /**
     * Information about the VPCs with the referencing security groups.
     */
    SecurityGroupReferenceSet?: SecurityGroupReferences;
  }
  export type DescribeSecurityGroupRulesMaxResults = number;
  export interface DescribeSecurityGroupRulesRequest {
    /**
     * One or more filters.    group-id - The ID of the security group.    security-group-rule-id - The ID of the security group rule.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.  
     */
    Filters?: FilterList;
    /**
     * The IDs of the security group rules.
     */
    SecurityGroupRuleIds?: SecurityGroupRuleIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. This value can be between 5 and 1000. If this parameter is not specified, then all items are returned. For more information, see Pagination.
     */
    MaxResults?: DescribeSecurityGroupRulesMaxResults;
  }
  export interface DescribeSecurityGroupRulesResult {
    /**
     * Information about security group rules.
     */
    SecurityGroupRules?: SecurityGroupRuleList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeSecurityGroupsMaxResults = number;
  export interface DescribeSecurityGroupsRequest {
    /**
     * The filters. If using multiple filters for rules, the results include security groups for which any combination of rules - not necessarily a single rule - match all filters.    description - The description of the security group.    egress.ip-permission.cidr - An IPv4 CIDR block for an outbound security group rule.    egress.ip-permission.from-port - For an outbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.    egress.ip-permission.group-id - The ID of a security group that has been referenced in an outbound security group rule.    egress.ip-permission.group-name - The name of a security group that is referenced in an outbound security group rule.    egress.ip-permission.ipv6-cidr - An IPv6 CIDR block for an outbound security group rule.    egress.ip-permission.prefix-list-id - The ID of a prefix list to which a security group rule allows outbound access.    egress.ip-permission.protocol - The IP protocol for an outbound security group rule (tcp | udp | icmp, a protocol number, or -1 for all protocols).    egress.ip-permission.to-port - For an outbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.    egress.ip-permission.user-id - The ID of an Amazon Web Services account that has been referenced in an outbound security group rule.    group-id - The ID of the security group.     group-name - The name of the security group.    ip-permission.cidr - An IPv4 CIDR block for an inbound security group rule.    ip-permission.from-port - For an inbound rule, the start of port range for the TCP and UDP protocols, or an ICMP type number.    ip-permission.group-id - The ID of a security group that has been referenced in an inbound security group rule.    ip-permission.group-name - The name of a security group that is referenced in an inbound security group rule.    ip-permission.ipv6-cidr - An IPv6 CIDR block for an inbound security group rule.    ip-permission.prefix-list-id - The ID of a prefix list from which a security group rule allows inbound access.    ip-permission.protocol - The IP protocol for an inbound security group rule (tcp | udp | icmp, a protocol number, or -1 for all protocols).    ip-permission.to-port - For an inbound rule, the end of port range for the TCP and UDP protocols, or an ICMP code.    ip-permission.user-id - The ID of an Amazon Web Services account that has been referenced in an inbound security group rule.    owner-id - The Amazon Web Services account ID of the owner of the security group.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC specified when the security group was created.  
     */
    Filters?: FilterList;
    /**
     * The IDs of the security groups. Required for security groups in a nondefault VPC. Default: Describes all of your security groups.
     */
    GroupIds?: GroupIdStringList;
    /**
     * [EC2-Classic and default VPC only] The names of the security groups. You can specify either the security group name or the security group ID. For security groups in a nondefault VPC, use the group-name filter to describe security groups by name. Default: Describes all of your security groups.
     */
    GroupNames?: GroupNameStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. This value can be between 5 and 1000. If this parameter is not specified, then all items are returned. For more information, see Pagination.
     */
    MaxResults?: DescribeSecurityGroupsMaxResults;
  }
  export interface DescribeSecurityGroupsResult {
    /**
     * Information about the security groups.
     */
    SecurityGroups?: SecurityGroupList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeSnapshotAttributeRequest {
    /**
     * The snapshot attribute you would like to view.
     */
    Attribute: SnapshotAttributeName;
    /**
     * The ID of the EBS snapshot.
     */
    SnapshotId: SnapshotId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeSnapshotAttributeResult {
    /**
     * The users and groups that have the permissions for creating volumes from the snapshot.
     */
    CreateVolumePermissions?: CreateVolumePermissionList;
    /**
     * The product codes.
     */
    ProductCodes?: ProductCodeList;
    /**
     * The ID of the EBS snapshot.
     */
    SnapshotId?: String;
  }
  export type DescribeSnapshotTierStatusMaxResults = number;
  export interface DescribeSnapshotTierStatusRequest {
    /**
     * The filters.    snapshot-id - The snapshot ID.    volume-id - The ID of the volume the snapshot is for.    last-tiering-operation - The state of the last archive or restore action. (archival-in-progress | archival-completed | archival-failed | permanent-restore-in-progress | permanent-restore-completed | permanent-restore-failed | temporary-restore-in-progress | temporary-restore-completed | temporary-restore-failed)  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeSnapshotTierStatusMaxResults;
  }
  export interface DescribeSnapshotTierStatusResult {
    /**
     * Information about the snapshot's storage tier.
     */
    SnapshotTierStatuses?: snapshotTierStatusSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeSnapshotsRequest {
    /**
     * The filters.    description - A description of the snapshot.    encrypted - Indicates whether the snapshot is encrypted (true | false)    owner-alias - The owner alias, from an Amazon-maintained list (amazon). This is not the user-configured Amazon Web Services account alias set using the IAM console. We recommend that you use the related parameter instead of this filter.    owner-id - The Amazon Web Services account ID of the owner. We recommend that you use the related parameter instead of this filter.    progress - The progress of the snapshot, as a percentage (for example, 80%).    snapshot-id - The snapshot ID.    start-time - The time stamp when the snapshot was initiated.    status - The status of the snapshot (pending | completed | error).    storage-tier - The storage tier of the snapshot (archive | standard).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    volume-id - The ID of the volume the snapshot is for.    volume-size - The size of the volume, in GiB.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of snapshots to return for this request. This value can be between 5 and 1,000; if this value is larger than 1,000, only 1,000 results are returned. If this parameter is not used, then the request returns all snapshots. You cannot specify this parameter and the snapshot IDs parameter in the same request. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * Scopes the results to snapshots with the specified owners. You can specify a combination of Amazon Web Services account IDs, self, and amazon.
     */
    OwnerIds?: OwnerStringList;
    /**
     * The IDs of the Amazon Web Services accounts that can create volumes from the snapshot.
     */
    RestorableByUserIds?: RestorableByStringList;
    /**
     * The snapshot IDs. Default: Describes the snapshots for which you have create volume permissions.
     */
    SnapshotIds?: SnapshotIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeSnapshotsResult {
    /**
     * Information about the snapshots.
     */
    Snapshots?: SnapshotList;
    /**
     * The token to include in another request to return the next page of snapshots. This value is null when there are no more snapshots to return.
     */
    NextToken?: String;
  }
  export interface DescribeSpotDatafeedSubscriptionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeSpotDatafeedSubscriptionResult {
    /**
     * The Spot Instance data feed subscription.
     */
    SpotDatafeedSubscription?: SpotDatafeedSubscription;
  }
  export type DescribeSpotFleetInstancesMaxResults = number;
  export interface DescribeSpotFleetInstancesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeSpotFleetInstancesMaxResults;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId: SpotFleetRequestId;
  }
  export interface DescribeSpotFleetInstancesResponse {
    /**
     * The running instances. This list is refreshed periodically and might be out of date.
     */
    ActiveInstances?: ActiveInstanceSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
  }
  export type DescribeSpotFleetRequestHistoryMaxResults = number;
  export interface DescribeSpotFleetRequestHistoryRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The type of events to describe. By default, all events are described.
     */
    EventType?: EventType;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeSpotFleetRequestHistoryMaxResults;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId: SpotFleetRequestId;
    /**
     * The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    StartTime: DateTime;
  }
  export interface DescribeSpotFleetRequestHistoryResponse {
    /**
     * Information about the events in the history of the Spot Fleet request.
     */
    HistoryRecords?: HistoryRecords;
    /**
     * The last date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). All records up to this time were retrieved. If nextToken indicates that there are more items, this value is not present.
     */
    LastEvaluatedTime?: DateTime;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
    /**
     * The starting date and time for the events, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    StartTime?: DateTime;
  }
  export interface DescribeSpotFleetRequestsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The IDs of the Spot Fleet requests.
     */
    SpotFleetRequestIds?: SpotFleetRequestIdList;
  }
  export interface DescribeSpotFleetRequestsResponse {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * Information about the configuration of your Spot Fleet.
     */
    SpotFleetRequestConfigs?: SpotFleetRequestConfigSet;
  }
  export interface DescribeSpotInstanceRequestsRequest {
    /**
     * One or more filters.    availability-zone-group - The Availability Zone group.    create-time - The time stamp when the Spot Instance request was created.    fault-code - The fault code related to the request.    fault-message - The fault message related to the request.    instance-id - The ID of the instance that fulfilled the request.    launch-group - The Spot Instance launch group.    launch.block-device-mapping.delete-on-termination - Indicates whether the EBS volume is deleted on instance termination.    launch.block-device-mapping.device-name - The device name for the volume in the block device mapping (for example, /dev/sdh or xvdh).    launch.block-device-mapping.snapshot-id - The ID of the snapshot for the EBS volume.    launch.block-device-mapping.volume-size - The size of the EBS volume, in GiB.    launch.block-device-mapping.volume-type - The type of EBS volume: gp2 for General Purpose SSD, io1 or io2 for Provisioned IOPS SSD, st1 for Throughput Optimized HDD, sc1for Cold HDD, or standard for Magnetic.    launch.group-id - The ID of the security group for the instance.    launch.group-name - The name of the security group for the instance.    launch.image-id - The ID of the AMI.    launch.instance-type - The type of instance (for example, m3.medium).    launch.kernel-id - The kernel ID.    launch.key-name - The name of the key pair the instance launched with.    launch.monitoring-enabled - Whether detailed monitoring is enabled for the Spot Instance.    launch.ramdisk-id - The RAM disk ID.    launched-availability-zone - The Availability Zone in which the request is launched.    network-interface.addresses.primary - Indicates whether the IP address is the primary private IP address.    network-interface.delete-on-termination - Indicates whether the network interface is deleted when the instance is terminated.    network-interface.description - A description of the network interface.    network-interface.device-index - The index of the device for the network interface attachment on the instance.    network-interface.group-id - The ID of the security group associated with the network interface.    network-interface.network-interface-id - The ID of the network interface.    network-interface.private-ip-address - The primary private IP address of the network interface.    network-interface.subnet-id - The ID of the subnet for the instance.    product-description - The product description associated with the instance (Linux/UNIX | Windows).    spot-instance-request-id - The Spot Instance request ID.    spot-price - The maximum hourly price for any Spot Instance launched to fulfill the request.    state - The state of the Spot Instance request (open | active | closed | cancelled | failed). Spot request status information can help you track your Amazon EC2 Spot Instance requests. For more information, see Spot request status in the Amazon EC2 User Guide for Linux Instances.    status-code - The short code describing the most recent evaluation of your Spot Instance request.    status-message - The message explaining the status of the Spot Instance request.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of Spot Instance request (one-time | persistent).    valid-from - The start date of the request.    valid-until - The end date of the request.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more Spot Instance request IDs.
     */
    SpotInstanceRequestIds?: SpotInstanceRequestIdList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
  }
  export interface DescribeSpotInstanceRequestsResult {
    /**
     * One or more Spot Instance requests.
     */
    SpotInstanceRequests?: SpotInstanceRequestList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeSpotPriceHistoryRequest {
    /**
     * One or more filters.    availability-zone - The Availability Zone for which prices should be returned.    instance-type - The type of instance (for example, m3.medium).    product-description - The product description for the Spot price (Linux/UNIX | Red Hat Enterprise Linux | SUSE Linux | Windows | Linux/UNIX (Amazon VPC) | Red Hat Enterprise Linux (Amazon VPC) | SUSE Linux (Amazon VPC) | Windows (Amazon VPC)).    spot-price - The Spot price. The value must match exactly (or use wildcards; greater than or less than comparison is not supported).    timestamp - The time stamp of the Spot price history, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). You can use wildcards (* and ?). Greater than or less than comparison is not supported.  
     */
    Filters?: FilterList;
    /**
     * Filters the results by the specified Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The date and time, up to the current date, from which to stop retrieving the price history data, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    EndTime?: DateTime;
    /**
     * Filters the results by the specified instance types.
     */
    InstanceTypes?: InstanceTypeList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * Filters the results by the specified basic product descriptions.
     */
    ProductDescriptions?: ProductDescriptionList;
    /**
     * The date and time, up to the past 90 days, from which to start retrieving the price history data, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    StartTime?: DateTime;
  }
  export interface DescribeSpotPriceHistoryResult {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The historical Spot prices.
     */
    SpotPriceHistory?: SpotPriceHistoryList;
  }
  export type DescribeStaleSecurityGroupsMaxResults = number;
  export type DescribeStaleSecurityGroupsNextToken = string;
  export interface DescribeStaleSecurityGroupsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeStaleSecurityGroupsMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: DescribeStaleSecurityGroupsNextToken;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
  }
  export interface DescribeStaleSecurityGroupsResult {
    /**
     * The token to include in another request to get the next page of items. If there are no additional items to return, the string is empty.
     */
    NextToken?: String;
    /**
     * Information about the stale security groups.
     */
    StaleSecurityGroupSet?: StaleSecurityGroupSet;
  }
  export interface DescribeStoreImageTasksRequest {
    /**
     * The AMI IDs for which to show progress. Up to 20 AMI IDs can be included in a request.
     */
    ImageIds?: ImageIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    task-state - Returns tasks in a certain state (InProgress | Completed | Failed)    bucket - Returns task information for tasks that targeted a specific bucket. For the filter value, specify the bucket name.  
     */
    Filters?: FilterList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination. You cannot specify this parameter and the ImageIDs parameter in the same call.
     */
    MaxResults?: DescribeStoreImageTasksRequestMaxResults;
  }
  export type DescribeStoreImageTasksRequestMaxResults = number;
  export interface DescribeStoreImageTasksResult {
    /**
     * The information about the AMI store tasks.
     */
    StoreImageTaskResults?: StoreImageTaskResultSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeSubnetsMaxResults = number;
  export interface DescribeSubnetsRequest {
    /**
     * One or more filters.    availability-zone - The Availability Zone for the subnet. You can also use availabilityZone as the filter name.    availability-zone-id - The ID of the Availability Zone for the subnet. You can also use availabilityZoneId as the filter name.    available-ip-address-count - The number of IPv4 addresses in the subnet that are available.    cidr-block - The IPv4 CIDR block of the subnet. The CIDR block you specify must exactly match the subnet's CIDR block for information to be returned for the subnet. You can also use cidr or cidrBlock as the filter names.    customer-owned-ipv4-pool - The customer-owned IPv4 address pool associated with the subnet.    default-for-az - Indicates whether this is the default subnet for the Availability Zone (true | false). You can also use defaultForAz as the filter name.    enable-dns64 - Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.    enable-lni-at-device-index - Indicates the device position for local network interfaces in this subnet. For example, 1 indicates local network interfaces in this subnet are the secondary network interface (eth1).     ipv6-cidr-block-association.ipv6-cidr-block - An IPv6 CIDR block associated with the subnet.    ipv6-cidr-block-association.association-id - An association ID for an IPv6 CIDR block associated with the subnet.    ipv6-cidr-block-association.state - The state of an IPv6 CIDR block associated with the subnet.    ipv6-native - Indicates whether this is an IPv6 only subnet (true | false).    map-customer-owned-ip-on-launch - Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives a customer-owned IPv4 address.    map-public-ip-on-launch - Indicates whether instances launched in this subnet receive a public IPv4 address.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The ID of the Amazon Web Services account that owns the subnet.    private-dns-name-options-on-launch.hostname-type - The type of hostname to assign to instances in the subnet at launch. For IPv4-only and dual-stack (IPv4 and IPv6) subnets, an instance DNS name can be based on the instance IPv4 address (ip-name) or the instance ID (resource-name). For IPv6 only subnets, an instance DNS name must be based on the instance ID (resource-name).    private-dns-name-options-on-launch.enable-resource-name-dns-a-record - Indicates whether to respond to DNS queries for instance hostnames with DNS A records.    private-dns-name-options-on-launch.enable-resource-name-dns-aaaa-record - Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.    state - The state of the subnet (pending | available).    subnet-arn - The Amazon Resource Name (ARN) of the subnet.    subnet-id - The ID of the subnet.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the subnet.  
     */
    Filters?: FilterList;
    /**
     * One or more subnet IDs. Default: Describes all your subnets.
     */
    SubnetIds?: SubnetIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeSubnetsMaxResults;
  }
  export interface DescribeSubnetsResult {
    /**
     * Information about one or more subnets.
     */
    Subnets?: SubnetList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeTagsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    key - The tag key.    resource-id - The ID of the resource.    resource-type - The resource type (customer-gateway | dedicated-host | dhcp-options | elastic-ip | fleet | fpga-image | host-reservation | image | instance | internet-gateway | key-pair | launch-template | natgateway | network-acl | network-interface | placement-group | reserved-instances | route-table | security-group | snapshot | spot-instances-request | subnet | volume | vpc | vpc-endpoint | vpc-endpoint-service | vpc-peering-connection | vpn-connection | vpn-gateway).    tag:&lt;key&gt; - The key/value combination of the tag. For example, specify "tag:Owner" for the filter name and "TeamA" for the filter value to find resources with the tag "Owner=TeamA".    value - The tag value.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. This value can be between 5 and 1000. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeTagsResult {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * The tags.
     */
    Tags?: TagDescriptionList;
  }
  export interface DescribeTrafficMirrorFiltersRequest {
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterIds?: TrafficMirrorFilterIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters. The possible values are:    description: The Traffic Mirror filter description.    traffic-mirror-filter-id: The ID of the Traffic Mirror filter.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TrafficMirroringMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeTrafficMirrorFiltersResult {
    /**
     * Information about one or more Traffic Mirror filters.
     */
    TrafficMirrorFilters?: TrafficMirrorFilterSet;
    /**
     * The token to use to retrieve the next page of results. The value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTrafficMirrorSessionsRequest {
    /**
     * The ID of the Traffic Mirror session.
     */
    TrafficMirrorSessionIds?: TrafficMirrorSessionIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters. The possible values are:    description: The Traffic Mirror session description.    network-interface-id: The ID of the Traffic Mirror session network interface.    owner-id: The ID of the account that owns the Traffic Mirror session.    packet-length: The assigned number of packets to mirror.     session-number: The assigned session number.     traffic-mirror-filter-id: The ID of the Traffic Mirror filter.    traffic-mirror-session-id: The ID of the Traffic Mirror session.    traffic-mirror-target-id: The ID of the Traffic Mirror target.    virtual-network-id: The virtual network ID of the Traffic Mirror session.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TrafficMirroringMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeTrafficMirrorSessionsResult {
    /**
     * Describes one or more Traffic Mirror sessions. By default, all Traffic Mirror sessions are described. Alternatively, you can filter the results.
     */
    TrafficMirrorSessions?: TrafficMirrorSessionSet;
    /**
     * The token to use to retrieve the next page of results. The value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTrafficMirrorTargetsRequest {
    /**
     * The ID of the Traffic Mirror targets.
     */
    TrafficMirrorTargetIds?: TrafficMirrorTargetIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters. The possible values are:    description: The Traffic Mirror target description.    network-interface-id: The ID of the Traffic Mirror session network interface.    network-load-balancer-arn: The Amazon Resource Name (ARN) of the Network Load Balancer that is associated with the session.    owner-id: The ID of the account that owns the Traffic Mirror session.    traffic-mirror-target-id: The ID of the Traffic Mirror target.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TrafficMirroringMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface DescribeTrafficMirrorTargetsResult {
    /**
     * Information about one or more Traffic Mirror targets.
     */
    TrafficMirrorTargets?: TrafficMirrorTargetSet;
    /**
     * The token to use to retrieve the next page of results. The value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayAttachmentsRequest {
    /**
     * The IDs of the attachments.
     */
    TransitGatewayAttachmentIds?: TransitGatewayAttachmentIdStringList;
    /**
     * One or more filters. The possible values are:    association.state - The state of the association (associating | associated | disassociating).    association.transit-gateway-route-table-id - The ID of the route table for the transit gateway.    resource-id - The ID of the resource.    resource-owner-id - The ID of the Amazon Web Services account that owns the resource.    resource-type - The resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    state - The state of the attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting.    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-id - The ID of the transit gateway.    transit-gateway-owner-id - The ID of the Amazon Web Services account that owns the transit gateway.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayAttachmentsResult {
    /**
     * Information about the attachments.
     */
    TransitGatewayAttachments?: TransitGatewayAttachmentList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayConnectPeersRequest {
    /**
     * The IDs of the Connect peers.
     */
    TransitGatewayConnectPeerIds?: TransitGatewayConnectPeerIdStringList;
    /**
     * One or more filters. The possible values are:    state - The state of the Connect peer (pending | available | deleting | deleted).    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-connect-peer-id - The ID of the Connect peer.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayConnectPeersResult {
    /**
     * Information about the Connect peers.
     */
    TransitGatewayConnectPeers?: TransitGatewayConnectPeerList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayConnectsRequest {
    /**
     * The IDs of the attachments.
     */
    TransitGatewayAttachmentIds?: TransitGatewayAttachmentIdStringList;
    /**
     * One or more filters. The possible values are:    options.protocol - The tunnel protocol (gre).    state - The state of the attachment (initiating | initiatingRequest | pendingAcceptance | rollingBack | pending | available | modifying | deleting | deleted | failed | rejected | rejecting | failing).    transit-gateway-attachment-id - The ID of the Connect attachment.    transit-gateway-id - The ID of the transit gateway.    transport-transit-gateway-attachment-id - The ID of the transit gateway attachment from which the Connect attachment was created.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayConnectsResult {
    /**
     * Information about the Connect attachments.
     */
    TransitGatewayConnects?: TransitGatewayConnectList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayMulticastDomainsRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainIds?: TransitGatewayMulticastDomainIdStringList;
    /**
     * One or more filters. The possible values are:    state - The state of the transit gateway multicast domain. Valid values are pending | available | deleting | deleted.    transit-gateway-id - The ID of the transit gateway.    transit-gateway-multicast-domain-id - The ID of the transit gateway multicast domain.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayMulticastDomainsResult {
    /**
     * Information about the transit gateway multicast domains.
     */
    TransitGatewayMulticastDomains?: TransitGatewayMulticastDomainList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayPeeringAttachmentsRequest {
    /**
     * One or more IDs of the transit gateway peering attachments.
     */
    TransitGatewayAttachmentIds?: TransitGatewayAttachmentIdStringList;
    /**
     * One or more filters. The possible values are:    transit-gateway-attachment-id - The ID of the transit gateway attachment.    local-owner-id - The ID of your Amazon Web Services account.    remote-owner-id - The ID of the Amazon Web Services account in the remote Region that owns the transit gateway.    state - The state of the peering attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources that have a tag with a specific key, regardless of the tag value.    transit-gateway-id - The ID of the transit gateway.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayPeeringAttachmentsResult {
    /**
     * The transit gateway peering attachments.
     */
    TransitGatewayPeeringAttachments?: TransitGatewayPeeringAttachmentList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayPolicyTablesRequest {
    /**
     * The IDs of the transit gateway policy tables.
     */
    TransitGatewayPolicyTableIds?: TransitGatewayPolicyTableIdStringList;
    /**
     * The filters associated with the transit gateway policy table.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayPolicyTablesResult {
    /**
     * Describes the transit gateway policy tables.
     */
    TransitGatewayPolicyTables?: TransitGatewayPolicyTableList;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayRouteTableAnnouncementsRequest {
    /**
     * The IDs of the transit gateway route tables that are being advertised.
     */
    TransitGatewayRouteTableAnnouncementIds?: TransitGatewayRouteTableAnnouncementIdStringList;
    /**
     * The filters associated with the transit gateway policy table.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayRouteTableAnnouncementsResult {
    /**
     * Describes the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncements?: TransitGatewayRouteTableAnnouncementList;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayRouteTablesRequest {
    /**
     * The IDs of the transit gateway route tables.
     */
    TransitGatewayRouteTableIds?: TransitGatewayRouteTableIdStringList;
    /**
     * One or more filters. The possible values are:    default-association-route-table - Indicates whether this is the default association route table for the transit gateway (true | false).    default-propagation-route-table - Indicates whether this is the default propagation route table for the transit gateway (true | false).    state - The state of the route table (available | deleting | deleted | pending).    transit-gateway-id - The ID of the transit gateway.    transit-gateway-route-table-id - The ID of the transit gateway route table.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayRouteTablesResult {
    /**
     * Information about the transit gateway route tables.
     */
    TransitGatewayRouteTables?: TransitGatewayRouteTableList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewayVpcAttachmentsRequest {
    /**
     * The IDs of the attachments.
     */
    TransitGatewayAttachmentIds?: TransitGatewayAttachmentIdStringList;
    /**
     * One or more filters. The possible values are:    state - The state of the attachment. Valid values are available | deleted | deleting | failed | failing | initiatingRequest | modifying | pendingAcceptance | pending | rollingBack | rejected | rejecting.    transit-gateway-attachment-id - The ID of the attachment.    transit-gateway-id - The ID of the transit gateway.    vpc-id - The ID of the VPC.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewayVpcAttachmentsResult {
    /**
     * Information about the VPC attachments.
     */
    TransitGatewayVpcAttachments?: TransitGatewayVpcAttachmentList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeTransitGatewaysRequest {
    /**
     * The IDs of the transit gateways.
     */
    TransitGatewayIds?: TransitGatewayIdStringList;
    /**
     * One or more filters. The possible values are:    options.propagation-default-route-table-id - The ID of the default propagation route table.    options.amazon-side-asn - The private ASN for the Amazon side of a BGP session.    options.association-default-route-table-id - The ID of the default association route table.    options.auto-accept-shared-attachments - Indicates whether there is automatic acceptance of attachment requests (enable | disable).    options.default-route-table-association - Indicates whether resource attachments are automatically associated with the default association route table (enable | disable).    options.default-route-table-propagation - Indicates whether resource attachments automatically propagate routes to the default propagation route table (enable | disable).    options.dns-support - Indicates whether DNS support is enabled (enable | disable).    options.vpn-ecmp-support - Indicates whether Equal Cost Multipath Protocol support is enabled (enable | disable).    owner-id - The ID of the Amazon Web Services account that owns the transit gateway.    state - The state of the transit gateway (available | deleted | deleting | modifying | pending).    transit-gateway-id - The ID of the transit gateway.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeTransitGatewaysResult {
    /**
     * Information about the transit gateways.
     */
    TransitGateways?: TransitGatewayList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeTrunkInterfaceAssociationsMaxResults = number;
  export interface DescribeTrunkInterfaceAssociationsRequest {
    /**
     * The IDs of the associations.
     */
    AssociationIds?: TrunkInterfaceAssociationIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters.    gre-key - The ID of a trunk interface association.    interface-protocol - The interface protocol. Valid values are VLAN and GRE.  
     */
    Filters?: FilterList;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeTrunkInterfaceAssociationsMaxResults;
  }
  export interface DescribeTrunkInterfaceAssociationsResult {
    /**
     * Information about the trunk associations.
     */
    InterfaceAssociations?: TrunkInterfaceAssociationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export type DescribeVerifiedAccessEndpointsMaxResults = number;
  export interface DescribeVerifiedAccessEndpointsRequest {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointIds?: VerifiedAccessEndpointIdList;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: VerifiedAccessInstanceId;
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId?: VerifiedAccessGroupId;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeVerifiedAccessEndpointsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVerifiedAccessEndpointsResult {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpoints?: VerifiedAccessEndpointList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeVerifiedAccessGroupMaxResults = number;
  export interface DescribeVerifiedAccessGroupsRequest {
    /**
     * The ID of the Amazon Web Services Verified Access groups.
     */
    VerifiedAccessGroupIds?: VerifiedAccessGroupIdList;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: VerifiedAccessInstanceId;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeVerifiedAccessGroupMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVerifiedAccessGroupsResult {
    /**
     * The ID of the Verified Access group.
     */
    VerifiedAccessGroups?: VerifiedAccessGroupList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeVerifiedAccessInstanceLoggingConfigurationsMaxResults = number;
  export interface DescribeVerifiedAccessInstanceLoggingConfigurationsRequest {
    /**
     * The IDs of the Amazon Web Services Verified Access instances.
     */
    VerifiedAccessInstanceIds?: VerifiedAccessInstanceIdList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeVerifiedAccessInstanceLoggingConfigurationsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVerifiedAccessInstanceLoggingConfigurationsResult {
    /**
     * The current logging configuration for the Amazon Web Services Verified Access instances.
     */
    LoggingConfigurations?: VerifiedAccessInstanceLoggingConfigurationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeVerifiedAccessInstancesMaxResults = number;
  export interface DescribeVerifiedAccessInstancesRequest {
    /**
     * The IDs of the Amazon Web Services Verified Access instances.
     */
    VerifiedAccessInstanceIds?: VerifiedAccessInstanceIdList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeVerifiedAccessInstancesMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVerifiedAccessInstancesResult {
    /**
     * The IDs of the Amazon Web Services Verified Access instances.
     */
    VerifiedAccessInstances?: VerifiedAccessInstanceList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export type DescribeVerifiedAccessTrustProvidersMaxResults = number;
  export interface DescribeVerifiedAccessTrustProvidersRequest {
    /**
     * The IDs of the Amazon Web Services Verified Access trust providers.
     */
    VerifiedAccessTrustProviderIds?: VerifiedAccessTrustProviderIdList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: DescribeVerifiedAccessTrustProvidersMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * One or more filters. Filter names and values are case-sensitive.
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVerifiedAccessTrustProvidersResult {
    /**
     * The IDs of the Amazon Web Services Verified Access trust providers.
     */
    VerifiedAccessTrustProviders?: VerifiedAccessTrustProviderList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface DescribeVolumeAttributeRequest {
    /**
     * The attribute of the volume. This parameter is required.
     */
    Attribute: VolumeAttributeName;
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVolumeAttributeResult {
    /**
     * The state of autoEnableIO attribute.
     */
    AutoEnableIO?: AttributeBooleanValue;
    /**
     * A list of product codes.
     */
    ProductCodes?: ProductCodeList;
    /**
     * The ID of the volume.
     */
    VolumeId?: String;
  }
  export interface DescribeVolumeStatusRequest {
    /**
     * The filters.    action.code - The action code for the event (for example, enable-volume-io).    action.description - A description of the action.    action.event-id - The event ID associated with the action.    availability-zone - The Availability Zone of the instance.    event.description - A description of the event.    event.event-id - The event ID.    event.event-type - The event type (for io-enabled: passed | failed; for io-performance: io-performance:degraded | io-performance:severely-degraded | io-performance:stalled).    event.not-after - The latest end time for the event.    event.not-before - The earliest start time for the event.    volume-status.details-name - The cause for volume-status.status (io-enabled | io-performance).    volume-status.details-status - The status of volume-status.details-name (for io-enabled: passed | failed; for io-performance: normal | degraded | severely-degraded | stalled).    volume-status.status - The status of the volume (ok | impaired | warning | insufficient-data).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. This value can be between 5 and 1,000; if the value is larger than 1,000, only 1,000 results are returned. If this parameter is not used, then all items are returned. You cannot specify this parameter and the volume IDs parameter in the same request. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The IDs of the volumes. Default: Describes all your volumes.
     */
    VolumeIds?: VolumeIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVolumeStatusResult {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
    /**
     * Information about the status of the volumes.
     */
    VolumeStatuses?: VolumeStatusList;
  }
  export interface DescribeVolumesModificationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the volumes.
     */
    VolumeIds?: VolumeIdStringList;
    /**
     * The filters.    modification-state - The current modification state (modifying | optimizing | completed | failed).    original-iops - The original IOPS rate of the volume.    original-size - The original size of the volume, in GiB.    original-volume-type - The original volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).    originalMultiAttachEnabled - Indicates whether Multi-Attach support was enabled (true | false).    start-time - The modification start time.    target-iops - The target IOPS rate of the volume.    target-size - The target size of the volume, in GiB.    target-volume-type - The target volume type of the volume (standard | io1 | io2 | gp2 | sc1 | st1).    targetMultiAttachEnabled - Indicates whether Multi-Attach support is to be enabled (true | false).    volume-id - The ID of the volume.  
     */
    Filters?: FilterList;
    /**
     * The token returned by a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of results (up to a limit of 500) to be returned in a paginated request. For more information, see Pagination.
     */
    MaxResults?: Integer;
  }
  export interface DescribeVolumesModificationsResult {
    /**
     * Information about the volume modifications.
     */
    VolumesModifications?: VolumeModificationList;
    /**
     * The token to include in another request to get the next page of items. This value is null if there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeVolumesRequest {
    /**
     * The filters.    attachment.attach-time - The time stamp when the attachment initiated.    attachment.delete-on-termination - Whether the volume is deleted on instance termination.    attachment.device - The device name specified in the block device mapping (for example, /dev/sda1).    attachment.instance-id - The ID of the instance the volume is attached to.    attachment.status - The attachment state (attaching | attached | detaching).    availability-zone - The Availability Zone in which the volume was created.    create-time - The time stamp when the volume was created.    encrypted - Indicates whether the volume is encrypted (true | false)    multi-attach-enabled - Indicates whether the volume is enabled for Multi-Attach (true | false)    fast-restored - Indicates whether the volume was created from a snapshot that is enabled for fast snapshot restore (true | false).    size - The size of the volume, in GiB.    snapshot-id - The snapshot from which the volume was created.    status - The state of the volume (creating | available | in-use | deleting | deleted | error).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    volume-id - The volume ID.    volume-type - The Amazon EBS volume type (gp2 | gp3 | io1 | io2 | st1 | sc1| standard)  
     */
    Filters?: FilterList;
    /**
     * The volume IDs.
     */
    VolumeIds?: VolumeIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of volumes to return for this request. This value can be between 5 and 500; if you specify a value larger than 500, only 500 items are returned. If this parameter is not used, then all items are returned. You cannot specify this parameter and the volume IDs parameter in the same request. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned from the previous request.
     */
    NextToken?: String;
  }
  export interface DescribeVolumesResult {
    /**
     * Information about the volumes.
     */
    Volumes?: VolumeList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpcAttributeRequest {
    /**
     * The VPC attribute.
     */
    Attribute: VpcAttributeName;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVpcAttributeResult {
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * Indicates whether the instances launched in the VPC get DNS hostnames. If this attribute is true, instances in the VPC get DNS hostnames; otherwise, they do not.
     */
    EnableDnsHostnames?: AttributeBooleanValue;
    /**
     * Indicates whether DNS resolution is enabled for the VPC. If this attribute is true, the Amazon DNS server resolves DNS hostnames for your instances to their corresponding IP addresses; otherwise, it does not.
     */
    EnableDnsSupport?: AttributeBooleanValue;
    /**
     * Indicates whether Network Address Usage metrics are enabled for your VPC.
     */
    EnableNetworkAddressUsageMetrics?: AttributeBooleanValue;
  }
  export type DescribeVpcClassicLinkDnsSupportMaxResults = number;
  export type DescribeVpcClassicLinkDnsSupportNextToken = string;
  export interface DescribeVpcClassicLinkDnsSupportRequest {
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeVpcClassicLinkDnsSupportMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: DescribeVpcClassicLinkDnsSupportNextToken;
    /**
     * One or more VPC IDs.
     */
    VpcIds?: VpcClassicLinkIdList;
  }
  export interface DescribeVpcClassicLinkDnsSupportResult {
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: DescribeVpcClassicLinkDnsSupportNextToken;
    /**
     * Information about the ClassicLink DNS support status of the VPCs.
     */
    Vpcs?: ClassicLinkDnsSupportList;
  }
  export interface DescribeVpcClassicLinkRequest {
    /**
     * One or more filters.    is-classic-link-enabled - Whether the VPC is enabled for ClassicLink (true | false).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more VPCs for which you want to describe the ClassicLink status.
     */
    VpcIds?: VpcClassicLinkIdList;
  }
  export interface DescribeVpcClassicLinkResult {
    /**
     * The ClassicLink status of one or more VPCs.
     */
    Vpcs?: VpcClassicLinkList;
  }
  export interface DescribeVpcEndpointConnectionNotificationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the notification.
     */
    ConnectionNotificationId?: ConnectionNotificationId;
    /**
     * The filters.    connection-notification-arn - The ARN of the SNS topic for the notification.    connection-notification-id - The ID of the notification.    connection-notification-state - The state of the notification (Enabled | Disabled).    connection-notification-type - The type of notification (Topic).    service-id - The ID of the endpoint service.    vpc-endpoint-id - The ID of the VPC endpoint.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in a single call. To retrieve the remaining results, make another request with the returned NextToken value.
     */
    MaxResults?: Integer;
    /**
     * The token to request the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointConnectionNotificationsResult {
    /**
     * The notifications.
     */
    ConnectionNotificationSet?: ConnectionNotificationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointConnectionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The filters.    ip-address-type - The IP address type (ipv4 | ipv6).    service-id - The ID of the service.    vpc-endpoint-owner - The ID of the Amazon Web Services account ID that owns the endpoint.    vpc-endpoint-state - The state of the endpoint (pendingAcceptance | pending | available | deleting | deleted | rejected | failed).    vpc-endpoint-id - The ID of the endpoint.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned.
     */
    MaxResults?: Integer;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointConnectionsResult {
    /**
     * Information about the VPC endpoint connections.
     */
    VpcEndpointConnections?: VpcEndpointConnectionSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServiceConfigurationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the endpoint services.
     */
    ServiceIds?: VpcEndpointServiceIdList;
    /**
     * The filters.    service-name - The name of the service.    service-id - The ID of the service.    service-state - The state of the service (Pending | Available | Deleting | Deleted | Failed).     supported-ip-address-types - The IP address type (ipv4 | ipv6).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned.
     */
    MaxResults?: Integer;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServiceConfigurationsResult {
    /**
     * Information about the services.
     */
    ServiceConfigurations?: ServiceConfigurationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServicePermissionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * The filters.    principal - The ARN of the principal.    principal-type - The principal type (All | Service | OrganizationUnit | Account | User | Role).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results of the initial request can be seen by sending another request with the returned NextToken value. This value can be between 5 and 1,000; if MaxResults is given a value larger than 1,000, only 1,000 results are returned.
     */
    MaxResults?: Integer;
    /**
     * The token to retrieve the next page of results.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServicePermissionsResult {
    /**
     * Information about the allowed principals.
     */
    AllowedPrincipals?: AllowedPrincipalSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServicesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The service names.
     */
    ServiceNames?: ValueStringList;
    /**
     * The filters.    owner - The ID or alias of the Amazon Web Services account that owns the service.    service-name - The name of the service.    service-type - The type of service (Interface | Gateway | GatewayLoadBalancer).    supported-ip-address-types - The IP address type (ipv4 | ipv6).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. Constraint: If the value is greater than 1,000, we return only 1,000 items.
     */
    MaxResults?: Integer;
    /**
     * The token for the next set of items to return. (You received this token from a prior call.)
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointServicesResult {
    /**
     * The supported services.
     */
    ServiceNames?: ValueStringList;
    /**
     * Information about the service.
     */
    ServiceDetails?: ServiceDetailSet;
    /**
     * The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the VPC endpoints.
     */
    VpcEndpointIds?: VpcEndpointIdList;
    /**
     * The filters.    ip-address-type - The IP address type (ipv4 | ipv6).    service-name - The name of the service.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC in which the endpoint resides.    vpc-endpoint-id - The ID of the endpoint.    vpc-endpoint-state - The state of the endpoint (pendingAcceptance | pending | available | deleting | deleted | rejected | failed).    vpc-endpoint-type - The type of VPC endpoint (Interface | Gateway | GatewayLoadBalancer).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. Constraint: If the value is greater than 1,000, we return only 1,000 items.
     */
    MaxResults?: Integer;
    /**
     * The token for the next set of items to return. (You received this token from a prior call.)
     */
    NextToken?: String;
  }
  export interface DescribeVpcEndpointsResult {
    /**
     * Information about the endpoints.
     */
    VpcEndpoints?: VpcEndpointSet;
    /**
     * The token to use when requesting the next set of items. If there are no additional items to return, the string is empty.
     */
    NextToken?: String;
  }
  export type DescribeVpcPeeringConnectionsMaxResults = number;
  export interface DescribeVpcPeeringConnectionsRequest {
    /**
     * One or more filters.    accepter-vpc-info.cidr-block - The IPv4 CIDR block of the accepter VPC.    accepter-vpc-info.owner-id - The ID of the Amazon Web Services account that owns the accepter VPC.    accepter-vpc-info.vpc-id - The ID of the accepter VPC.    expiration-time - The expiration date and time for the VPC peering connection.    requester-vpc-info.cidr-block - The IPv4 CIDR block of the requester's VPC.    requester-vpc-info.owner-id - The ID of the Amazon Web Services account that owns the requester VPC.    requester-vpc-info.vpc-id - The ID of the requester VPC.    status-code - The status of the VPC peering connection (pending-acceptance | failed | expired | provisioning | active | deleting | deleted | rejected).    status-message - A message that provides more information about the status of the VPC peering connection, if applicable.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-peering-connection-id - The ID of the VPC peering connection.  
     */
    Filters?: FilterList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more VPC peering connection IDs. Default: Describes all your VPC peering connections.
     */
    VpcPeeringConnectionIds?: VpcPeeringConnectionIdList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeVpcPeeringConnectionsMaxResults;
  }
  export interface DescribeVpcPeeringConnectionsResult {
    /**
     * Information about the VPC peering connections.
     */
    VpcPeeringConnections?: VpcPeeringConnectionList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type DescribeVpcsMaxResults = number;
  export interface DescribeVpcsRequest {
    /**
     * One or more filters.    cidr - The primary IPv4 CIDR block of the VPC. The CIDR block you specify must exactly match the VPC's CIDR block for information to be returned for the VPC. Must contain the slash followed by one or two digits (for example, /28).    cidr-block-association.cidr-block - An IPv4 CIDR block associated with the VPC.    cidr-block-association.association-id - The association ID for an IPv4 CIDR block associated with the VPC.    cidr-block-association.state - The state of an IPv4 CIDR block associated with the VPC.    dhcp-options-id - The ID of a set of DHCP options.    ipv6-cidr-block-association.ipv6-cidr-block - An IPv6 CIDR block associated with the VPC.    ipv6-cidr-block-association.ipv6-pool - The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.    ipv6-cidr-block-association.association-id - The association ID for an IPv6 CIDR block associated with the VPC.    ipv6-cidr-block-association.state - The state of an IPv6 CIDR block associated with the VPC.    is-default - Indicates whether the VPC is the default VPC.    owner-id - The ID of the Amazon Web Services account that owns the VPC.    state - The state of the VPC (pending | available).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC.  
     */
    Filters?: FilterList;
    /**
     * One or more VPC IDs. Default: Describes all your VPCs.
     */
    VpcIds?: VpcIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: DescribeVpcsMaxResults;
  }
  export interface DescribeVpcsResult {
    /**
     * Information about one or more VPCs.
     */
    Vpcs?: VpcList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface DescribeVpnConnectionsRequest {
    /**
     * One or more filters.    customer-gateway-configuration - The configuration information for the customer gateway.    customer-gateway-id - The ID of a customer gateway associated with the VPN connection.    state - The state of the VPN connection (pending | available | deleting | deleted).    option.static-routes-only - Indicates whether the connection has static routes only. Used for devices that do not support Border Gateway Protocol (BGP).    route.destination-cidr-block - The destination CIDR block. This corresponds to the subnet used in a customer data center.    bgp-asn - The BGP Autonomous System Number (ASN) associated with a BGP device.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of VPN connection. Currently the only supported type is ipsec.1.    vpn-connection-id - The ID of the VPN connection.    vpn-gateway-id - The ID of a virtual private gateway associated with the VPN connection.    transit-gateway-id - The ID of a transit gateway associated with the VPN connection.  
     */
    Filters?: FilterList;
    /**
     * One or more VPN connection IDs. Default: Describes your VPN connections.
     */
    VpnConnectionIds?: VpnConnectionIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVpnConnectionsResult {
    /**
     * Information about one or more VPN connections.
     */
    VpnConnections?: VpnConnectionList;
  }
  export interface DescribeVpnGatewaysRequest {
    /**
     * One or more filters.    amazon-side-asn - The Autonomous System Number (ASN) for the Amazon side of the gateway.    attachment.state - The current state of the attachment between the gateway and the VPC (attaching | attached | detaching | detached).    attachment.vpc-id - The ID of an attached VPC.    availability-zone - The Availability Zone for the virtual private gateway (if applicable).    state - The state of the virtual private gateway (pending | available | deleting | deleted).    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    type - The type of virtual private gateway. Currently the only supported type is ipsec.1.    vpn-gateway-id - The ID of the virtual private gateway.  
     */
    Filters?: FilterList;
    /**
     * One or more virtual private gateway IDs. Default: Describes all your virtual private gateways.
     */
    VpnGatewayIds?: VpnGatewayIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DescribeVpnGatewaysResult {
    /**
     * Information about one or more virtual private gateways.
     */
    VpnGateways?: VpnGatewayList;
  }
  export type DestinationFileFormat = "plain-text"|"parquet"|string;
  export interface DestinationOptionsRequest {
    /**
     * The format for the flow log. The default is plain-text.
     */
    FileFormat?: DestinationFileFormat;
    /**
     * Indicates whether to use Hive-compatible prefixes for flow logs stored in Amazon S3. The default is false.
     */
    HiveCompatiblePartitions?: Boolean;
    /**
     * Indicates whether to partition the flow log per hour. This reduces the cost and response time for queries. The default is false.
     */
    PerHourPartition?: Boolean;
  }
  export interface DestinationOptionsResponse {
    /**
     * The format for the flow log.
     */
    FileFormat?: DestinationFileFormat;
    /**
     * Indicates whether to use Hive-compatible prefixes for flow logs stored in Amazon S3.
     */
    HiveCompatiblePartitions?: Boolean;
    /**
     * Indicates whether to partition the flow log per hour.
     */
    PerHourPartition?: Boolean;
  }
  export interface DetachClassicLinkVpcRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance to unlink from the VPC.
     */
    InstanceId: InstanceId;
    /**
     * The ID of the VPC to which the instance is linked.
     */
    VpcId: VpcId;
  }
  export interface DetachClassicLinkVpcResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DetachInternetGatewayRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the internet gateway.
     */
    InternetGatewayId: InternetGatewayId;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
  }
  export interface DetachNetworkInterfaceRequest {
    /**
     * The ID of the attachment.
     */
    AttachmentId: NetworkInterfaceAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specifies whether to force a detachment.    Use the Force parameter only as a last resort to detach a network interface from a failed instance.    If you use the Force parameter to detach a network interface, you might not be able to attach a different network interface to the same index on the instance without first stopping and starting the instance.   If you force the detachment of a network interface, the instance metadata might not get updated. This means that the attributes associated with the detached network interface might still be visible. The instance metadata will get updated when you stop and start the instance.   
     */
    Force?: Boolean;
  }
  export interface DetachVerifiedAccessTrustProviderRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProviderId: VerifiedAccessTrustProviderId;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DetachVerifiedAccessTrustProviderResult {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProvider?: VerifiedAccessTrustProvider;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstance?: VerifiedAccessInstance;
  }
  export interface DetachVolumeRequest {
    /**
     * The device name.
     */
    Device?: String;
    /**
     * Forces detachment if the previous detachment attempt did not occur cleanly (for example, logging into an instance, unmounting the volume, and detaching normally). This option can lead to data loss or a corrupted file system. Use this option only as a last resort to detach a volume from a failed instance. The instance won't have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures.
     */
    Force?: Boolean;
    /**
     * The ID of the instance. If you are detaching a Multi-Attach enabled volume, you must specify an instance ID.
     */
    InstanceId?: InstanceIdForResolver;
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeIdWithResolver;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DetachVpnGatewayRequest {
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The ID of the virtual private gateway.
     */
    VpnGatewayId: VpnGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DeviceOptions {
    /**
     * The ID of the tenant application with the device-identity provider.
     */
    TenantId?: String;
  }
  export type DeviceTrustProviderType = "jamf"|"crowdstrike"|string;
  export type DeviceType = "ebs"|"instance-store"|string;
  export interface DhcpConfiguration {
    /**
     * The name of a DHCP option.
     */
    Key?: String;
    /**
     * One or more values for the DHCP option.
     */
    Values?: DhcpConfigurationValueList;
  }
  export type DhcpConfigurationList = DhcpConfiguration[];
  export type DhcpConfigurationValueList = AttributeValue[];
  export interface DhcpOptions {
    /**
     * One or more DHCP options in the set.
     */
    DhcpConfigurations?: DhcpConfigurationList;
    /**
     * The ID of the set of DHCP options.
     */
    DhcpOptionsId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the DHCP options set.
     */
    OwnerId?: String;
    /**
     * Any tags assigned to the DHCP options set.
     */
    Tags?: TagList;
  }
  export type DhcpOptionsId = string;
  export type DhcpOptionsIdStringList = DhcpOptionsId[];
  export type DhcpOptionsList = DhcpOptions[];
  export interface DirectoryServiceAuthentication {
    /**
     * The ID of the Active Directory used for authentication.
     */
    DirectoryId?: String;
  }
  export interface DirectoryServiceAuthenticationRequest {
    /**
     * The ID of the Active Directory to be used for authentication.
     */
    DirectoryId?: String;
  }
  export interface DisableAddressTransferRequest {
    /**
     * The allocation ID of an Elastic IP address.
     */
    AllocationId: AllocationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableAddressTransferResult {
    /**
     * An Elastic IP address transfer.
     */
    AddressTransfer?: AddressTransfer;
  }
  export interface DisableAwsNetworkPerformanceMetricSubscriptionRequest {
    /**
     * The source Region or Availability Zone that the metric subscription is disabled for. For example, us-east-1.
     */
    Source?: String;
    /**
     * The target Region or Availability Zone that the metric subscription is disabled for. For example, eu-north-1.
     */
    Destination?: String;
    /**
     * The metric used for the disabled subscription.
     */
    Metric?: MetricType;
    /**
     * The statistic used for the disabled subscription. 
     */
    Statistic?: StatisticType;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableAwsNetworkPerformanceMetricSubscriptionResult {
    /**
     * Indicates whether the unsubscribe action was successful.
     */
    Output?: Boolean;
  }
  export interface DisableEbsEncryptionByDefaultRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableEbsEncryptionByDefaultResult {
    /**
     * The updated status of encryption by default.
     */
    EbsEncryptionByDefault?: Boolean;
  }
  export interface DisableFastLaunchRequest {
    /**
     * The ID of the image for which you’re turning off faster launching, and removing pre-provisioned snapshots.
     */
    ImageId: ImageId;
    /**
     * Forces the image settings to turn off faster launching for your Windows AMI. This parameter overrides any errors that are encountered while cleaning up resources in your account.
     */
    Force?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableFastLaunchResult {
    /**
     * The ID of the image for which faster-launching has been turned off.
     */
    ImageId?: ImageId;
    /**
     * The pre-provisioning resource type that must be cleaned after turning off faster launching for the Windows AMI. Supported values include: snapshot.
     */
    ResourceType?: FastLaunchResourceType;
    /**
     * Parameters that were used for faster launching for the Windows AMI before faster launching was turned off. This informs the clean-up process.
     */
    SnapshotConfiguration?: FastLaunchSnapshotConfigurationResponse;
    /**
     * The launch template that was used to launch Windows instances from pre-provisioned snapshots.
     */
    LaunchTemplate?: FastLaunchLaunchTemplateSpecificationResponse;
    /**
     * The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows faster launching.
     */
    MaxParallelLaunches?: Integer;
    /**
     * The owner of the Windows AMI for which faster launching was turned off.
     */
    OwnerId?: String;
    /**
     * The current state of faster launching for the specified Windows AMI.
     */
    State?: FastLaunchStateCode;
    /**
     * The reason that the state changed for faster launching for the Windows AMI.
     */
    StateTransitionReason?: String;
    /**
     * The time that the state changed for faster launching for the Windows AMI.
     */
    StateTransitionTime?: MillisecondDateTime;
  }
  export interface DisableFastSnapshotRestoreErrorItem {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The errors.
     */
    FastSnapshotRestoreStateErrors?: DisableFastSnapshotRestoreStateErrorSet;
  }
  export type DisableFastSnapshotRestoreErrorSet = DisableFastSnapshotRestoreErrorItem[];
  export interface DisableFastSnapshotRestoreStateError {
    /**
     * The error code.
     */
    Code?: String;
    /**
     * The error message.
     */
    Message?: String;
  }
  export interface DisableFastSnapshotRestoreStateErrorItem {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The error.
     */
    Error?: DisableFastSnapshotRestoreStateError;
  }
  export type DisableFastSnapshotRestoreStateErrorSet = DisableFastSnapshotRestoreStateErrorItem[];
  export interface DisableFastSnapshotRestoreSuccessItem {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The state of fast snapshot restores for the snapshot.
     */
    State?: FastSnapshotRestoreStateCode;
    /**
     * The reason for the state transition. The possible values are as follows:    Client.UserInitiated - The state successfully transitioned to enabling or disabling.    Client.UserInitiated - Lifecycle state transition - The state successfully transitioned to optimizing, enabled, or disabled.  
     */
    StateTransitionReason?: String;
    /**
     * The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
     */
    OwnerId?: String;
    /**
     * The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
     */
    OwnerAlias?: String;
    /**
     * The time at which fast snapshot restores entered the enabling state.
     */
    EnablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the optimizing state.
     */
    OptimizingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the enabled state.
     */
    EnabledTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabling state.
     */
    DisablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabled state.
     */
    DisabledTime?: MillisecondDateTime;
  }
  export type DisableFastSnapshotRestoreSuccessSet = DisableFastSnapshotRestoreSuccessItem[];
  export interface DisableFastSnapshotRestoresRequest {
    /**
     * One or more Availability Zones. For example, us-east-2a.
     */
    AvailabilityZones: AvailabilityZoneStringList;
    /**
     * The IDs of one or more snapshots. For example, snap-1234567890abcdef0.
     */
    SourceSnapshotIds: SnapshotIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableFastSnapshotRestoresResult {
    /**
     * Information about the snapshots for which fast snapshot restores were successfully disabled.
     */
    Successful?: DisableFastSnapshotRestoreSuccessSet;
    /**
     * Information about the snapshots for which fast snapshot restores could not be disabled.
     */
    Unsuccessful?: DisableFastSnapshotRestoreErrorSet;
  }
  export interface DisableImageDeprecationRequest {
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableImageDeprecationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DisableIpamOrganizationAdminAccountRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Organizations member account ID that you want to disable as IPAM account.
     */
    DelegatedAdminAccountId: String;
  }
  export interface DisableIpamOrganizationAdminAccountResult {
    /**
     * The result of disabling the IPAM account.
     */
    Success?: Boolean;
  }
  export interface DisableSerialConsoleAccessRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableSerialConsoleAccessResult {
    /**
     * If true, access to the EC2 serial console of all instances is enabled for your account. If false, access to the EC2 serial console of all instances is disabled for your account.
     */
    SerialConsoleAccessEnabled?: Boolean;
  }
  export interface DisableTransitGatewayRouteTablePropagationRequest {
    /**
     * The ID of the propagation route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the route table announcement.
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
  }
  export interface DisableTransitGatewayRouteTablePropagationResult {
    /**
     * Information about route propagation.
     */
    Propagation?: TransitGatewayPropagation;
  }
  export interface DisableVgwRoutePropagationRequest {
    /**
     * The ID of the virtual private gateway.
     */
    GatewayId: VpnGatewayId;
    /**
     * The ID of the route table.
     */
    RouteTableId: RouteTableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisableVpcClassicLinkDnsSupportRequest {
    /**
     * The ID of the VPC.
     */
    VpcId?: VpcId;
  }
  export interface DisableVpcClassicLinkDnsSupportResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DisableVpcClassicLinkRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
  }
  export interface DisableVpcClassicLinkResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DisassociateAddressRequest {
    /**
     * [EC2-VPC] The association ID. Required for EC2-VPC.
     */
    AssociationId?: ElasticIpAssociationId;
    /**
     * [EC2-Classic] The Elastic IP address. Required for EC2-Classic.
     */
    PublicIp?: EipAllocationPublicIp;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateClientVpnTargetNetworkRequest {
    /**
     * The ID of the Client VPN endpoint from which to disassociate the target network.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ID of the target network association.
     */
    AssociationId: ClientVpnAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateClientVpnTargetNetworkResult {
    /**
     * The ID of the target network association.
     */
    AssociationId?: String;
    /**
     * The current state of the target network association.
     */
    Status?: AssociationStatus;
  }
  export interface DisassociateEnclaveCertificateIamRoleRequest {
    /**
     * The ARN of the ACM certificate from which to disassociate the IAM role.
     */
    CertificateArn: CertificateId;
    /**
     * The ARN of the IAM role to disassociate.
     */
    RoleArn: RoleId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateEnclaveCertificateIamRoleResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface DisassociateIamInstanceProfileRequest {
    /**
     * The ID of the IAM instance profile association.
     */
    AssociationId: IamInstanceProfileAssociationId;
  }
  export interface DisassociateIamInstanceProfileResult {
    /**
     * Information about the IAM instance profile association.
     */
    IamInstanceProfileAssociation?: IamInstanceProfileAssociation;
  }
  export interface DisassociateInstanceEventWindowRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId: InstanceEventWindowId;
    /**
     * One or more targets to disassociate from the specified event window.
     */
    AssociationTarget: InstanceEventWindowDisassociationRequest;
  }
  export interface DisassociateInstanceEventWindowResult {
    /**
     * Information about the event window.
     */
    InstanceEventWindow?: InstanceEventWindow;
  }
  export interface DisassociateIpamResourceDiscoveryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A resource discovery association ID.
     */
    IpamResourceDiscoveryAssociationId: IpamResourceDiscoveryAssociationId;
  }
  export interface DisassociateIpamResourceDiscoveryResult {
    /**
     * A resource discovery association.
     */
    IpamResourceDiscoveryAssociation?: IpamResourceDiscoveryAssociation;
  }
  export interface DisassociateNatGatewayAddressRequest {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId: NatGatewayId;
    /**
     * The association IDs of EIPs that have been associated with the NAT gateway.
     */
    AssociationIds: EipAssociationIdList;
    /**
     * The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.
     */
    MaxDrainDurationSeconds?: DrainSeconds;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateNatGatewayAddressResult {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * Information about the NAT gateway IP addresses.
     */
    NatGatewayAddresses?: NatGatewayAddressList;
  }
  export interface DisassociateRouteTableRequest {
    /**
     * The association ID representing the current association between the route table and subnet or gateway.
     */
    AssociationId: RouteTableAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateSubnetCidrBlockRequest {
    /**
     * The association ID for the CIDR block.
     */
    AssociationId: SubnetCidrAssociationId;
  }
  export interface DisassociateSubnetCidrBlockResult {
    /**
     * Information about the IPv6 CIDR block association.
     */
    Ipv6CidrBlockAssociation?: SubnetIpv6CidrBlockAssociation;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
  }
  export interface DisassociateTransitGatewayMulticastDomainRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * The IDs of the subnets;
     */
    SubnetIds: TransitGatewaySubnetIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateTransitGatewayMulticastDomainResult {
    /**
     * Information about the association.
     */
    Associations?: TransitGatewayMulticastDomainAssociations;
  }
  export interface DisassociateTransitGatewayPolicyTableRequest {
    /**
     * The ID of the disassociated policy table.
     */
    TransitGatewayPolicyTableId: TransitGatewayPolicyTableId;
    /**
     * The ID of the transit gateway attachment to disassociate from the policy table.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateTransitGatewayPolicyTableResult {
    /**
     * Returns details about the transit gateway policy table disassociation.
     */
    Association?: TransitGatewayPolicyTableAssociation;
  }
  export interface DisassociateTransitGatewayRouteTableRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateTransitGatewayRouteTableResult {
    /**
     * Information about the association.
     */
    Association?: TransitGatewayAssociation;
  }
  export interface DisassociateTrunkInterfaceRequest {
    /**
     * The ID of the association
     */
    AssociationId: TrunkInterfaceAssociationId;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface DisassociateTrunkInterfaceResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency.
     */
    ClientToken?: String;
  }
  export interface DisassociateVpcCidrBlockRequest {
    /**
     * The association ID for the CIDR block.
     */
    AssociationId: VpcCidrAssociationId;
  }
  export interface DisassociateVpcCidrBlockResult {
    /**
     * Information about the IPv6 CIDR block association.
     */
    Ipv6CidrBlockAssociation?: VpcIpv6CidrBlockAssociation;
    /**
     * Information about the IPv4 CIDR block association.
     */
    CidrBlockAssociation?: VpcCidrBlockAssociation;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type DiskCount = number;
  export interface DiskImage {
    /**
     * A description of the disk image.
     */
    Description?: String;
    /**
     * Information about the disk image.
     */
    Image?: DiskImageDetail;
    /**
     * Information about the volume.
     */
    Volume?: VolumeDetail;
  }
  export interface DiskImageDescription {
    /**
     * The checksum computed for the disk image.
     */
    Checksum?: String;
    /**
     * The disk image format.
     */
    Format?: DiskImageFormat;
    /**
     * A presigned URL for the import manifest stored in Amazon S3. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide. For information about the import manifest referenced by this API action, see VM Import Manifest.
     */
    ImportManifestUrl?: String;
    /**
     * The size of the disk image, in GiB.
     */
    Size?: Long;
  }
  export interface DiskImageDetail {
    /**
     * The size of the disk image, in GiB.
     */
    Bytes: Long;
    /**
     * The disk image format.
     */
    Format: DiskImageFormat;
    /**
     * A presigned URL for the import manifest stored in Amazon S3 and presented here as an Amazon S3 presigned URL. For information about creating a presigned URL for an Amazon S3 object, read the "Query String Request Authentication Alternative" section of the Authenticating REST Requests topic in the Amazon Simple Storage Service Developer Guide. For information about the import manifest referenced by this API action, see VM Import Manifest.
     */
    ImportManifestUrl: ImportManifestUrl;
  }
  export type DiskImageFormat = "VMDK"|"RAW"|"VHD"|string;
  export type DiskImageList = DiskImage[];
  export interface DiskImageVolumeDescription {
    /**
     * The volume identifier.
     */
    Id?: String;
    /**
     * The size of the volume, in GiB.
     */
    Size?: Long;
  }
  export interface DiskInfo {
    /**
     * The size of the disk in GB.
     */
    SizeInGB?: DiskSize;
    /**
     * The number of disks with this configuration.
     */
    Count?: DiskCount;
    /**
     * The type of disk.
     */
    Type?: DiskType;
  }
  export type DiskInfoList = DiskInfo[];
  export type DiskSize = number;
  export type DiskType = "hdd"|"ssd"|string;
  export interface DnsEntry {
    /**
     * The DNS name.
     */
    DnsName?: String;
    /**
     * The ID of the private hosted zone.
     */
    HostedZoneId?: String;
  }
  export type DnsEntrySet = DnsEntry[];
  export type DnsNameState = "pendingVerification"|"verified"|"failed"|string;
  export interface DnsOptions {
    /**
     * The DNS records created for the endpoint.
     */
    DnsRecordIpType?: DnsRecordIpType;
    /**
     * Indicates whether to enable private DNS only for inbound endpoints.
     */
    PrivateDnsOnlyForInboundResolverEndpoint?: Boolean;
  }
  export interface DnsOptionsSpecification {
    /**
     * The DNS records created for the endpoint.
     */
    DnsRecordIpType?: DnsRecordIpType;
    /**
     * Indicates whether to enable private DNS only for inbound endpoints. This option is available only for services that support both gateway and interface endpoints. It routes traffic that originates from the VPC to the gateway endpoint and traffic that originates from on-premises to the interface endpoint.
     */
    PrivateDnsOnlyForInboundResolverEndpoint?: Boolean;
  }
  export type DnsRecordIpType = "ipv4"|"dualstack"|"ipv6"|"service-defined"|string;
  export interface DnsServersOptionsModifyStructure {
    /**
     * The IPv4 address range, in CIDR notation, of the DNS servers to be used. You can specify up to two DNS servers. Ensure that the DNS servers can be reached by the clients. The specified values overwrite the existing values.
     */
    CustomDnsServers?: ValueStringList;
    /**
     * Indicates whether DNS servers should be used. Specify False to delete the existing DNS servers.
     */
    Enabled?: Boolean;
  }
  export type DnsSupportValue = "enable"|"disable"|string;
  export type DomainType = "vpc"|"standard"|string;
  export type Double = number;
  export type DoubleWithConstraints = number;
  export type DrainSeconds = number;
  export type DynamicRoutingValue = "enable"|"disable"|string;
  export interface EbsBlockDevice {
    /**
     * Indicates whether the EBS volume is deleted on instance termination. For more information, see Preserving Amazon EBS volumes on instance termination in the Amazon EC2 User Guide.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. The following are the supported values for each volume type:    gp3: 3,000-16,000 IOPS    io1: 100-64,000 IOPS    io2: 100-64,000 IOPS   For io1 and io2 volumes, we guarantee 64,000 IOPS only for Instances built on the Nitro System. Other instance families guarantee performance up to 32,000 IOPS. This parameter is required for io1 and io2 volumes. The default for gp3 volumes is 3,000 IOPS. This parameter is not supported for gp2, st1, sc1, or standard volumes.
     */
    Iops?: Integer;
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. If you specify a snapshot, the default is the snapshot size. You can specify a volume size that is equal to or larger than the snapshot size. The following are the supported volumes sizes for each volume type:    gp2 and gp3:1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384    standard: 1-1,024  
     */
    VolumeSize?: Integer;
    /**
     * The volume type. For more information, see Amazon EBS volume types in the Amazon EC2 User Guide. If the volume type is io1 or io2, you must specify the IOPS that the volume supports.
     */
    VolumeType?: VolumeType;
    /**
     * Identifier (key ID, key alias, ID ARN, or alias ARN) for a customer managed CMK under which the EBS volume is encrypted. This parameter is only supported on BlockDeviceMapping objects called by RunInstances, RequestSpotFleet, and RequestSpotInstances.
     */
    KmsKeyId?: String;
    /**
     * The throughput that the volume supports, in MiB/s. This parameter is valid only for gp3 volumes. Valid Range: Minimum value of 125. Maximum value of 1000.
     */
    Throughput?: Integer;
    /**
     * The ARN of the Outpost on which the snapshot is stored. This parameter is only supported on BlockDeviceMapping objects called by  CreateImage.
     */
    OutpostArn?: String;
    /**
     * Indicates whether the encryption state of an EBS volume is changed while being restored from a backing snapshot. The effect of setting the encryption state to true depends on the volume origin (new or from a snapshot), starting encryption state, ownership, and whether encryption by default is enabled. For more information, see Amazon EBS encryption in the Amazon EC2 User Guide. In no case can you remove encryption from an encrypted volume. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. For more information, see Supported instance types. This parameter is not returned by DescribeImageAttribute. For CreateImage and RegisterImage, whether you can include this parameter, and the allowed values differ depending on the type of block device mapping you are creating.   If you are creating a block device mapping for a new (empty) volume, you can include this parameter, and specify either true for an encrypted volume, or false for an unencrypted volume. If you omit this parameter, it defaults to false (unencrypted).   If you are creating a block device mapping from an existing encrypted or unencrypted snapshot, you must omit this parameter. If you include this parameter, the request will fail, regardless of the value that you specify.   If you are creating a block device mapping from an existing unencrypted volume, you can include this parameter, but you must specify false. If you specify true, the request will fail. In this case, we recommend that you omit the parameter.   If you are creating a block device mapping from an existing encrypted volume, you can include this parameter, and specify either true or false. However, if you specify false, the parameter is ignored and the block device mapping is always encrypted. In this case, we recommend that you omit the parameter.  
     */
    Encrypted?: Boolean;
  }
  export type EbsEncryptionSupport = "unsupported"|"supported"|string;
  export interface EbsInfo {
    /**
     * Indicates whether the instance type is Amazon EBS-optimized. For more information, see Amazon EBS-optimized instances in Amazon EC2 User Guide.
     */
    EbsOptimizedSupport?: EbsOptimizedSupport;
    /**
     * Indicates whether Amazon EBS encryption is supported.
     */
    EncryptionSupport?: EbsEncryptionSupport;
    /**
     * Describes the optimized EBS performance for the instance type.
     */
    EbsOptimizedInfo?: EbsOptimizedInfo;
    /**
     * Indicates whether non-volatile memory express (NVMe) is supported.
     */
    NvmeSupport?: EbsNvmeSupport;
  }
  export interface EbsInstanceBlockDevice {
    /**
     * The time stamp when the attachment initiated.
     */
    AttachTime?: DateTime;
    /**
     * Indicates whether the volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The attachment state.
     */
    Status?: AttachmentStatus;
    /**
     * The ID of the EBS volume.
     */
    VolumeId?: String;
  }
  export interface EbsInstanceBlockDeviceSpecification {
    /**
     * Indicates whether the volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The ID of the EBS volume.
     */
    VolumeId?: VolumeId;
  }
  export type EbsNvmeSupport = "unsupported"|"supported"|"required"|string;
  export interface EbsOptimizedInfo {
    /**
     * The baseline bandwidth performance for an EBS-optimized instance type, in Mbps.
     */
    BaselineBandwidthInMbps?: BaselineBandwidthInMbps;
    /**
     * The baseline throughput performance for an EBS-optimized instance type, in MB/s.
     */
    BaselineThroughputInMBps?: BaselineThroughputInMBps;
    /**
     * The baseline input/output storage operations per seconds for an EBS-optimized instance type.
     */
    BaselineIops?: BaselineIops;
    /**
     * The maximum bandwidth performance for an EBS-optimized instance type, in Mbps.
     */
    MaximumBandwidthInMbps?: MaximumBandwidthInMbps;
    /**
     * The maximum throughput performance for an EBS-optimized instance type, in MB/s.
     */
    MaximumThroughputInMBps?: MaximumThroughputInMBps;
    /**
     * The maximum input/output storage operations per second for an EBS-optimized instance type.
     */
    MaximumIops?: MaximumIops;
  }
  export type EbsOptimizedSupport = "unsupported"|"supported"|"default"|string;
  export interface EfaInfo {
    /**
     * The maximum number of Elastic Fabric Adapters for the instance type.
     */
    MaximumEfaInterfaces?: MaximumEfaInterfaces;
  }
  export type EfaSupportedFlag = boolean;
  export interface EgressOnlyInternetGateway {
    /**
     * Information about the attachment of the egress-only internet gateway.
     */
    Attachments?: InternetGatewayAttachmentList;
    /**
     * The ID of the egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId?: EgressOnlyInternetGatewayId;
    /**
     * The tags assigned to the egress-only internet gateway.
     */
    Tags?: TagList;
  }
  export type EgressOnlyInternetGatewayId = string;
  export type EgressOnlyInternetGatewayIdList = EgressOnlyInternetGatewayId[];
  export type EgressOnlyInternetGatewayList = EgressOnlyInternetGateway[];
  export type EipAllocationPublicIp = string;
  export type EipAssociationIdList = ElasticIpAssociationId[];
  export interface ElasticGpuAssociation {
    /**
     * The ID of the Elastic Graphics accelerator.
     */
    ElasticGpuId?: ElasticGpuId;
    /**
     * The ID of the association.
     */
    ElasticGpuAssociationId?: String;
    /**
     * The state of the association between the instance and the Elastic Graphics accelerator.
     */
    ElasticGpuAssociationState?: String;
    /**
     * The time the Elastic Graphics accelerator was associated with the instance.
     */
    ElasticGpuAssociationTime?: String;
  }
  export type ElasticGpuAssociationList = ElasticGpuAssociation[];
  export interface ElasticGpuHealth {
    /**
     * The health status.
     */
    Status?: ElasticGpuStatus;
  }
  export type ElasticGpuId = string;
  export type ElasticGpuIdSet = ElasticGpuId[];
  export type ElasticGpuSet = ElasticGpus[];
  export interface ElasticGpuSpecification {
    /**
     * The type of Elastic Graphics accelerator. For more information about the values to specify for Type, see Elastic Graphics Basics, specifically the Elastic Graphics accelerator column, in the Amazon Elastic Compute Cloud User Guide for Windows Instances.
     */
    Type: String;
  }
  export type ElasticGpuSpecificationList = ElasticGpuSpecification[];
  export interface ElasticGpuSpecificationResponse {
    /**
     * The elastic GPU type.
     */
    Type?: String;
  }
  export type ElasticGpuSpecificationResponseList = ElasticGpuSpecificationResponse[];
  export type ElasticGpuSpecifications = ElasticGpuSpecification[];
  export type ElasticGpuState = "ATTACHED"|string;
  export type ElasticGpuStatus = "OK"|"IMPAIRED"|string;
  export interface ElasticGpus {
    /**
     * The ID of the Elastic Graphics accelerator.
     */
    ElasticGpuId?: String;
    /**
     * The Availability Zone in the which the Elastic Graphics accelerator resides.
     */
    AvailabilityZone?: String;
    /**
     * The type of Elastic Graphics accelerator.
     */
    ElasticGpuType?: String;
    /**
     * The status of the Elastic Graphics accelerator.
     */
    ElasticGpuHealth?: ElasticGpuHealth;
    /**
     * The state of the Elastic Graphics accelerator.
     */
    ElasticGpuState?: ElasticGpuState;
    /**
     * The ID of the instance to which the Elastic Graphics accelerator is attached.
     */
    InstanceId?: String;
    /**
     * The tags assigned to the Elastic Graphics accelerator.
     */
    Tags?: TagList;
  }
  export interface ElasticInferenceAccelerator {
    /**
     *  The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, eia1.xlarge, eia2.medium, eia2.large, and eia2.xlarge. 
     */
    Type: String;
    /**
     *  The number of elastic inference accelerators to attach to the instance.  Default: 1
     */
    Count?: ElasticInferenceAcceleratorCount;
  }
  export interface ElasticInferenceAcceleratorAssociation {
    /**
     *  The Amazon Resource Name (ARN) of the elastic inference accelerator. 
     */
    ElasticInferenceAcceleratorArn?: String;
    /**
     *  The ID of the association. 
     */
    ElasticInferenceAcceleratorAssociationId?: String;
    /**
     *  The state of the elastic inference accelerator. 
     */
    ElasticInferenceAcceleratorAssociationState?: String;
    /**
     *  The time at which the elastic inference accelerator is associated with an instance. 
     */
    ElasticInferenceAcceleratorAssociationTime?: DateTime;
  }
  export type ElasticInferenceAcceleratorAssociationList = ElasticInferenceAcceleratorAssociation[];
  export type ElasticInferenceAcceleratorCount = number;
  export type ElasticInferenceAccelerators = ElasticInferenceAccelerator[];
  export type ElasticIpAssociationId = string;
  export interface EnaSrdSpecification {
    /**
     * Indicates whether ENA Express is enabled for the network interface.
     */
    EnaSrdEnabled?: Boolean;
    /**
     * Configures ENA Express for UDP network traffic.
     */
    EnaSrdUdpSpecification?: EnaSrdUdpSpecification;
  }
  export type EnaSrdSupported = boolean;
  export interface EnaSrdUdpSpecification {
    /**
     * Indicates whether UDP traffic uses ENA Express. To specify this setting, you must first enable ENA Express.
     */
    EnaSrdUdpEnabled?: Boolean;
  }
  export type EnaSupport = "unsupported"|"supported"|"required"|string;
  export interface EnableAddressTransferRequest {
    /**
     * The allocation ID of an Elastic IP address.
     */
    AllocationId: AllocationId;
    /**
     * The ID of the account that you want to transfer the Elastic IP address to.
     */
    TransferAccountId: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableAddressTransferResult {
    /**
     * An Elastic IP address transfer.
     */
    AddressTransfer?: AddressTransfer;
  }
  export interface EnableAwsNetworkPerformanceMetricSubscriptionRequest {
    /**
     * The source Region or Availability Zone that the metric subscription is enabled for. For example, us-east-1.
     */
    Source?: String;
    /**
     * The target Region or Availability Zone that the metric subscription is enabled for. For example, eu-west-1.
     */
    Destination?: String;
    /**
     * The metric used for the enabled subscription.
     */
    Metric?: MetricType;
    /**
     * The statistic used for the enabled subscription.
     */
    Statistic?: StatisticType;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableAwsNetworkPerformanceMetricSubscriptionResult {
    /**
     * Indicates whether the subscribe action was successful.
     */
    Output?: Boolean;
  }
  export interface EnableEbsEncryptionByDefaultRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableEbsEncryptionByDefaultResult {
    /**
     * The updated status of encryption by default.
     */
    EbsEncryptionByDefault?: Boolean;
  }
  export interface EnableFastLaunchRequest {
    /**
     * The ID of the image for which you’re enabling faster launching.
     */
    ImageId: ImageId;
    /**
     * The type of resource to use for pre-provisioning the Windows AMI for faster launching. Supported values include: snapshot, which is the default value.
     */
    ResourceType?: String;
    /**
     * Configuration settings for creating and managing the snapshots that are used for pre-provisioning the Windows AMI for faster launching. The associated ResourceType must be snapshot.
     */
    SnapshotConfiguration?: FastLaunchSnapshotConfigurationRequest;
    /**
     * The launch template to use when launching Windows instances from pre-provisioned snapshots. Launch template parameters can include either the name or ID of the launch template, but not both.
     */
    LaunchTemplate?: FastLaunchLaunchTemplateSpecificationRequest;
    /**
     * The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows faster launching. Value must be 6 or greater.
     */
    MaxParallelLaunches?: Integer;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableFastLaunchResult {
    /**
     * The image ID that identifies the Windows AMI for which faster launching was enabled.
     */
    ImageId?: ImageId;
    /**
     * The type of resource that was defined for pre-provisioning the Windows AMI for faster launching.
     */
    ResourceType?: FastLaunchResourceType;
    /**
     * Settings to create and manage the pre-provisioned snapshots that Amazon EC2 uses for faster launches from the Windows AMI. This property is returned when the associated resourceType is snapshot.
     */
    SnapshotConfiguration?: FastLaunchSnapshotConfigurationResponse;
    /**
     * The launch template that is used when launching Windows instances from pre-provisioned snapshots.
     */
    LaunchTemplate?: FastLaunchLaunchTemplateSpecificationResponse;
    /**
     * The maximum number of instances that Amazon EC2 can launch at the same time to create pre-provisioned snapshots for Windows faster launching.
     */
    MaxParallelLaunches?: Integer;
    /**
     * The owner ID for the Windows AMI for which faster launching was enabled.
     */
    OwnerId?: String;
    /**
     * The current state of faster launching for the specified Windows AMI.
     */
    State?: FastLaunchStateCode;
    /**
     * The reason that the state changed for faster launching for the Windows AMI.
     */
    StateTransitionReason?: String;
    /**
     * The time that the state changed for faster launching for the Windows AMI.
     */
    StateTransitionTime?: MillisecondDateTime;
  }
  export interface EnableFastSnapshotRestoreErrorItem {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The errors.
     */
    FastSnapshotRestoreStateErrors?: EnableFastSnapshotRestoreStateErrorSet;
  }
  export type EnableFastSnapshotRestoreErrorSet = EnableFastSnapshotRestoreErrorItem[];
  export interface EnableFastSnapshotRestoreStateError {
    /**
     * The error code.
     */
    Code?: String;
    /**
     * The error message.
     */
    Message?: String;
  }
  export interface EnableFastSnapshotRestoreStateErrorItem {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The error.
     */
    Error?: EnableFastSnapshotRestoreStateError;
  }
  export type EnableFastSnapshotRestoreStateErrorSet = EnableFastSnapshotRestoreStateErrorItem[];
  export interface EnableFastSnapshotRestoreSuccessItem {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The state of fast snapshot restores.
     */
    State?: FastSnapshotRestoreStateCode;
    /**
     * The reason for the state transition. The possible values are as follows:    Client.UserInitiated - The state successfully transitioned to enabling or disabling.    Client.UserInitiated - Lifecycle state transition - The state successfully transitioned to optimizing, enabled, or disabled.  
     */
    StateTransitionReason?: String;
    /**
     * The ID of the Amazon Web Services account that enabled fast snapshot restores on the snapshot.
     */
    OwnerId?: String;
    /**
     * The Amazon Web Services owner alias that enabled fast snapshot restores on the snapshot. This is intended for future use.
     */
    OwnerAlias?: String;
    /**
     * The time at which fast snapshot restores entered the enabling state.
     */
    EnablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the optimizing state.
     */
    OptimizingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the enabled state.
     */
    EnabledTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabling state.
     */
    DisablingTime?: MillisecondDateTime;
    /**
     * The time at which fast snapshot restores entered the disabled state.
     */
    DisabledTime?: MillisecondDateTime;
  }
  export type EnableFastSnapshotRestoreSuccessSet = EnableFastSnapshotRestoreSuccessItem[];
  export interface EnableFastSnapshotRestoresRequest {
    /**
     * One or more Availability Zones. For example, us-east-2a.
     */
    AvailabilityZones: AvailabilityZoneStringList;
    /**
     * The IDs of one or more snapshots. For example, snap-1234567890abcdef0. You can specify a snapshot that was shared with you from another Amazon Web Services account.
     */
    SourceSnapshotIds: SnapshotIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableFastSnapshotRestoresResult {
    /**
     * Information about the snapshots for which fast snapshot restores were successfully enabled.
     */
    Successful?: EnableFastSnapshotRestoreSuccessSet;
    /**
     * Information about the snapshots for which fast snapshot restores could not be enabled.
     */
    Unsuccessful?: EnableFastSnapshotRestoreErrorSet;
  }
  export interface EnableImageDeprecationRequest {
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ. If you specify a value for seconds, Amazon EC2 rounds the seconds to the nearest minute. You can’t specify a date in the past. The upper limit for DeprecateAt is 10 years from now, except for public AMIs, where the upper limit is 2 years from the creation date.
     */
    DeprecateAt: MillisecondDateTime;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableImageDeprecationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface EnableIpamOrganizationAdminAccountRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Organizations member account ID that you want to enable as the IPAM account.
     */
    DelegatedAdminAccountId: String;
  }
  export interface EnableIpamOrganizationAdminAccountResult {
    /**
     * The result of enabling the IPAM account.
     */
    Success?: Boolean;
  }
  export interface EnableReachabilityAnalyzerOrganizationSharingRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableReachabilityAnalyzerOrganizationSharingResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    ReturnValue?: Boolean;
  }
  export interface EnableSerialConsoleAccessRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableSerialConsoleAccessResult {
    /**
     * If true, access to the EC2 serial console of all instances is enabled for your account. If false, access to the EC2 serial console of all instances is disabled for your account.
     */
    SerialConsoleAccessEnabled?: Boolean;
  }
  export interface EnableTransitGatewayRouteTablePropagationRequest {
    /**
     * The ID of the propagation route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
  }
  export interface EnableTransitGatewayRouteTablePropagationResult {
    /**
     * Information about route propagation.
     */
    Propagation?: TransitGatewayPropagation;
  }
  export interface EnableVgwRoutePropagationRequest {
    /**
     * The ID of the virtual private gateway that is attached to a VPC. The virtual private gateway must be attached to the same VPC that the routing tables are associated with. 
     */
    GatewayId: VpnGatewayId;
    /**
     * The ID of the route table. The routing table must be associated with the same VPC that the virtual private gateway is attached to. 
     */
    RouteTableId: RouteTableId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface EnableVolumeIORequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeId;
  }
  export interface EnableVpcClassicLinkDnsSupportRequest {
    /**
     * The ID of the VPC.
     */
    VpcId?: VpcId;
  }
  export interface EnableVpcClassicLinkDnsSupportResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface EnableVpcClassicLinkRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
  }
  export interface EnableVpcClassicLinkResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface EnclaveOptions {
    /**
     * If this parameter is set to true, the instance is enabled for Amazon Web Services Nitro Enclaves; otherwise, it is not enabled for Amazon Web Services Nitro Enclaves.
     */
    Enabled?: Boolean;
  }
  export interface EnclaveOptionsRequest {
    /**
     * To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to true.
     */
    Enabled?: Boolean;
  }
  export type EncryptionInTransitSupported = boolean;
  export type EndDateType = "unlimited"|"limited"|string;
  export type EndpointSet = ClientVpnEndpoint[];
  export type EphemeralNvmeSupport = "unsupported"|"supported"|"required"|string;
  export type ErrorSet = ValidationError[];
  export type EventCode = "instance-reboot"|"system-reboot"|"system-maintenance"|"instance-retirement"|"instance-stop"|string;
  export interface EventInformation {
    /**
     * The description of the event.
     */
    EventDescription?: String;
    /**
     * The event.  error events:    iamFleetRoleInvalid - The EC2 Fleet or Spot Fleet does not have the required permissions either to launch or terminate an instance.    allLaunchSpecsTemporarilyBlacklisted - None of the configurations are valid, and several attempts to launch instances have failed. For more information, see the description of the event.    spotInstanceCountLimitExceeded - You've reached the limit on the number of Spot Instances that you can launch.    spotFleetRequestConfigurationInvalid - The configuration is not valid. For more information, see the description of the event.    fleetRequestChange events:    active - The EC2 Fleet or Spot Fleet request has been validated and Amazon EC2 is attempting to maintain the target number of running instances.    deleted (EC2 Fleet) / cancelled (Spot Fleet) - The EC2 Fleet is deleted or the Spot Fleet request is canceled and has no running instances. The EC2 Fleet or Spot Fleet will be deleted two days after its instances are terminated.    deleted_running (EC2 Fleet) / cancelled_running (Spot Fleet) - The EC2 Fleet is deleted or the Spot Fleet request is canceled and does not launch additional instances. Its existing instances continue to run until they are interrupted or terminated. The request remains in this state until all instances are interrupted or terminated.    deleted_terminating (EC2 Fleet) / cancelled_terminating (Spot Fleet) - The EC2 Fleet is deleted or the Spot Fleet request is canceled and its instances are terminating. The request remains in this state until all instances are terminated.    expired - The EC2 Fleet or Spot Fleet request has expired. If the request was created with TerminateInstancesWithExpiration set, a subsequent terminated event indicates that the instances are terminated.    modify_in_progress - The EC2 Fleet or Spot Fleet request is being modified. The request remains in this state until the modification is fully processed.    modify_succeeded - The EC2 Fleet or Spot Fleet request was modified.    submitted - The EC2 Fleet or Spot Fleet request is being evaluated and Amazon EC2 is preparing to launch the target number of instances.    progress - The EC2 Fleet or Spot Fleet request is in the process of being fulfilled.    instanceChange events:    launched - A new instance was launched.    terminated - An instance was terminated by the user.    termination_notified - An instance termination notification was sent when a Spot Instance was terminated by Amazon EC2 during scale-down, when the target capacity of the fleet was modified down, for example, from a target capacity of 4 to a target capacity of 3.    Information events:    fleetProgressHalted - The price in every launch specification is not valid because it is below the Spot price (all the launch specifications have produced launchSpecUnusable events). A launch specification might become valid if the Spot price changes.    launchSpecTemporarilyBlacklisted - The configuration is not valid and several attempts to launch instances have failed. For more information, see the description of the event.    launchSpecUnusable - The price in a launch specification is not valid because it is below the Spot price.    registerWithLoadBalancersFailed - An attempt to register instances with load balancers failed. For more information, see the description of the event.  
     */
    EventSubType?: String;
    /**
     * The ID of the instance. This information is available only for instanceChange events.
     */
    InstanceId?: String;
  }
  export type EventType = "instanceChange"|"fleetRequestChange"|"error"|"information"|string;
  export type ExcessCapacityTerminationPolicy = "noTermination"|"default"|string;
  export type ExcludedInstanceType = string;
  export type ExcludedInstanceTypeSet = ExcludedInstanceType[];
  export type ExecutableByStringList = String[];
  export interface Explanation {
    /**
     * The network ACL.
     */
    Acl?: AnalysisComponent;
    /**
     * The network ACL rule.
     */
    AclRule?: AnalysisAclRule;
    /**
     * The IPv4 address, in CIDR notation.
     */
    Address?: IpAddress;
    /**
     * The IPv4 addresses, in CIDR notation.
     */
    Addresses?: IpAddressList;
    /**
     * The resource to which the component is attached.
     */
    AttachedTo?: AnalysisComponent;
    /**
     * The Availability Zones.
     */
    AvailabilityZones?: ValueStringList;
    /**
     * The CIDR ranges.
     */
    Cidrs?: ValueStringList;
    /**
     * The component.
     */
    Component?: AnalysisComponent;
    /**
     * The customer gateway.
     */
    CustomerGateway?: AnalysisComponent;
    /**
     * The destination.
     */
    Destination?: AnalysisComponent;
    /**
     * The destination VPC.
     */
    DestinationVpc?: AnalysisComponent;
    /**
     * The direction. The following are the possible values:   egress   ingress  
     */
    Direction?: String;
    /**
     * The explanation code.
     */
    ExplanationCode?: String;
    /**
     * The route table.
     */
    IngressRouteTable?: AnalysisComponent;
    /**
     * The internet gateway.
     */
    InternetGateway?: AnalysisComponent;
    /**
     * The Amazon Resource Name (ARN) of the load balancer.
     */
    LoadBalancerArn?: ResourceArn;
    /**
     * The listener for a Classic Load Balancer.
     */
    ClassicLoadBalancerListener?: AnalysisLoadBalancerListener;
    /**
     * The listener port of the load balancer.
     */
    LoadBalancerListenerPort?: Port;
    /**
     * The target.
     */
    LoadBalancerTarget?: AnalysisLoadBalancerTarget;
    /**
     * The target group.
     */
    LoadBalancerTargetGroup?: AnalysisComponent;
    /**
     * The target groups.
     */
    LoadBalancerTargetGroups?: AnalysisComponentList;
    /**
     * The target port.
     */
    LoadBalancerTargetPort?: Port;
    /**
     * The load balancer listener.
     */
    ElasticLoadBalancerListener?: AnalysisComponent;
    /**
     * The missing component.
     */
    MissingComponent?: String;
    /**
     * The NAT gateway.
     */
    NatGateway?: AnalysisComponent;
    /**
     * The network interface.
     */
    NetworkInterface?: AnalysisComponent;
    /**
     * The packet field.
     */
    PacketField?: String;
    /**
     * The VPC peering connection.
     */
    VpcPeeringConnection?: AnalysisComponent;
    /**
     * The port.
     */
    Port?: Port;
    /**
     * The port ranges.
     */
    PortRanges?: PortRangeList;
    /**
     * The prefix list.
     */
    PrefixList?: AnalysisComponent;
    /**
     * The protocols.
     */
    Protocols?: StringList;
    /**
     * The route table route.
     */
    RouteTableRoute?: AnalysisRouteTableRoute;
    /**
     * The route table.
     */
    RouteTable?: AnalysisComponent;
    /**
     * The security group.
     */
    SecurityGroup?: AnalysisComponent;
    /**
     * The security group rule.
     */
    SecurityGroupRule?: AnalysisSecurityGroupRule;
    /**
     * The security groups.
     */
    SecurityGroups?: AnalysisComponentList;
    /**
     * The source VPC.
     */
    SourceVpc?: AnalysisComponent;
    /**
     * The state.
     */
    State?: String;
    /**
     * The subnet.
     */
    Subnet?: AnalysisComponent;
    /**
     * The route table for the subnet.
     */
    SubnetRouteTable?: AnalysisComponent;
    /**
     * The component VPC.
     */
    Vpc?: AnalysisComponent;
    /**
     * The VPC endpoint.
     */
    VpcEndpoint?: AnalysisComponent;
    /**
     * The VPN connection.
     */
    VpnConnection?: AnalysisComponent;
    /**
     * The VPN gateway.
     */
    VpnGateway?: AnalysisComponent;
    /**
     * The transit gateway.
     */
    TransitGateway?: AnalysisComponent;
    /**
     * The transit gateway route table.
     */
    TransitGatewayRouteTable?: AnalysisComponent;
    /**
     * The transit gateway route table route.
     */
    TransitGatewayRouteTableRoute?: TransitGatewayRouteTableRoute;
    /**
     * The transit gateway attachment.
     */
    TransitGatewayAttachment?: AnalysisComponent;
    /**
     * The Amazon Web Services account for the component.
     */
    ComponentAccount?: ComponentAccount;
    /**
     * The Region for the component.
     */
    ComponentRegion?: ComponentRegion;
    /**
     * The Network Firewall stateless rule.
     */
    FirewallStatelessRule?: FirewallStatelessRule;
    /**
     * The Network Firewall stateful rule.
     */
    FirewallStatefulRule?: FirewallStatefulRule;
  }
  export type ExplanationList = Explanation[];
  export interface ExportClientVpnClientCertificateRevocationListRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ExportClientVpnClientCertificateRevocationListResult {
    /**
     * Information about the client certificate revocation list.
     */
    CertificateRevocationList?: String;
    /**
     * The current state of the client certificate revocation list.
     */
    Status?: ClientCertificateRevocationListStatus;
  }
  export interface ExportClientVpnClientConfigurationRequest {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ExportClientVpnClientConfigurationResult {
    /**
     * The contents of the Client VPN endpoint configuration file.
     */
    ClientConfiguration?: String;
  }
  export type ExportEnvironment = "citrix"|"vmware"|"microsoft"|string;
  export interface ExportImageRequest {
    /**
     * Token to enable idempotency for export image requests.
     */
    ClientToken?: String;
    /**
     * A description of the image being exported. The maximum length is 255 characters.
     */
    Description?: String;
    /**
     * The disk image format.
     */
    DiskImageFormat: DiskImageFormat;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the image.
     */
    ImageId: ImageId;
    /**
     * The Amazon S3 bucket for the destination image. The destination bucket must exist.
     */
    S3ExportLocation: ExportTaskS3LocationRequest;
    /**
     * The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket. If this parameter is not specified, the default role is named 'vmimport'.
     */
    RoleName?: String;
    /**
     * The tags to apply to the export image task during creation.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface ExportImageResult {
    /**
     * A description of the image being exported.
     */
    Description?: String;
    /**
     * The disk image format for the exported image.
     */
    DiskImageFormat?: DiskImageFormat;
    /**
     * The ID of the export image task.
     */
    ExportImageTaskId?: String;
    /**
     * The ID of the image.
     */
    ImageId?: String;
    /**
     * The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket.
     */
    RoleName?: String;
    /**
     * The percent complete of the export image task.
     */
    Progress?: String;
    /**
     * Information about the destination Amazon S3 bucket.
     */
    S3ExportLocation?: ExportTaskS3Location;
    /**
     * The status of the export image task. The possible values are active, completed, deleting, and deleted.
     */
    Status?: String;
    /**
     * The status message for the export image task.
     */
    StatusMessage?: String;
    /**
     * Any tags assigned to the export image task.
     */
    Tags?: TagList;
  }
  export interface ExportImageTask {
    /**
     * A description of the image being exported.
     */
    Description?: String;
    /**
     * The ID of the export image task.
     */
    ExportImageTaskId?: String;
    /**
     * The ID of the image.
     */
    ImageId?: String;
    /**
     * The percent complete of the export image task.
     */
    Progress?: String;
    /**
     * Information about the destination Amazon S3 bucket.
     */
    S3ExportLocation?: ExportTaskS3Location;
    /**
     * The status of the export image task. The possible values are active, completed, deleting, and deleted.
     */
    Status?: String;
    /**
     * The status message for the export image task.
     */
    StatusMessage?: String;
    /**
     * Any tags assigned to the export image task.
     */
    Tags?: TagList;
  }
  export type ExportImageTaskId = string;
  export type ExportImageTaskIdList = ExportImageTaskId[];
  export type ExportImageTaskList = ExportImageTask[];
  export interface ExportTask {
    /**
     * A description of the resource being exported.
     */
    Description?: String;
    /**
     * The ID of the export task.
     */
    ExportTaskId?: String;
    /**
     * Information about the export task.
     */
    ExportToS3Task?: ExportToS3Task;
    /**
     * Information about the instance to export.
     */
    InstanceExportDetails?: InstanceExportDetails;
    /**
     * The state of the export task.
     */
    State?: ExportTaskState;
    /**
     * The status message related to the export task.
     */
    StatusMessage?: String;
    /**
     * The tags for the export task.
     */
    Tags?: TagList;
  }
  export type ExportTaskId = string;
  export type ExportTaskIdStringList = ExportTaskId[];
  export type ExportTaskList = ExportTask[];
  export interface ExportTaskS3Location {
    /**
     * The destination Amazon S3 bucket.
     */
    S3Bucket?: String;
    /**
     * The prefix (logical hierarchy) in the bucket.
     */
    S3Prefix?: String;
  }
  export interface ExportTaskS3LocationRequest {
    /**
     * The destination Amazon S3 bucket.
     */
    S3Bucket: String;
    /**
     * The prefix (logical hierarchy) in the bucket.
     */
    S3Prefix?: String;
  }
  export type ExportTaskState = "active"|"cancelling"|"cancelled"|"completed"|string;
  export interface ExportToS3Task {
    /**
     * The container format used to combine disk images with metadata (such as OVF). If absent, only the disk image is exported.
     */
    ContainerFormat?: ContainerFormat;
    /**
     * The format for the exported image.
     */
    DiskImageFormat?: DiskImageFormat;
    /**
     * The Amazon S3 bucket for the destination image. The destination bucket must exist and have an access control list (ACL) attached that specifies the Region-specific canonical account ID for the Grantee. For more information about the ACL to your S3 bucket, see Prerequisites in the VM Import/Export User Guide.
     */
    S3Bucket?: String;
    /**
     * The encryption key for your S3 bucket.
     */
    S3Key?: String;
  }
  export interface ExportToS3TaskSpecification {
    /**
     * The container format used to combine disk images with metadata (such as OVF). If absent, only the disk image is exported.
     */
    ContainerFormat?: ContainerFormat;
    /**
     * The format for the exported image.
     */
    DiskImageFormat?: DiskImageFormat;
    /**
     * The Amazon S3 bucket for the destination image. The destination bucket must exist and have an access control list (ACL) attached that specifies the Region-specific canonical account ID for the Grantee. For more information about the ACL to your S3 bucket, see Prerequisites in the VM Import/Export User Guide.
     */
    S3Bucket?: String;
    /**
     * The image is written to a single object in the Amazon S3 bucket at the S3 key s3prefix + exportTaskId + '.' + diskImageFormat.
     */
    S3Prefix?: String;
  }
  export interface ExportTransitGatewayRoutesRequest {
    /**
     * The ID of the route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * One or more filters. The possible values are:    attachment.transit-gateway-attachment-id - The id of the transit gateway attachment.    attachment.resource-id - The resource id of the transit gateway attachment.    route-search.exact-match - The exact match of the specified filter.    route-search.longest-prefix-match - The longest prefix that matches the route.    route-search.subnet-of-match - The routes with a subnet that match the specified CIDR filter.    route-search.supernet-of-match - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.    state - The state of the route (active | blackhole).    transit-gateway-route-destination-cidr-block - The CIDR range.    type - The type of route (propagated | static).  
     */
    Filters?: FilterList;
    /**
     * The name of the S3 bucket.
     */
    S3Bucket: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ExportTransitGatewayRoutesResult {
    /**
     * The URL of the exported file in Amazon S3. For example, s3://bucket_name/VPCTransitGateway/TransitGatewayRouteTables/file_name.
     */
    S3Location?: String;
  }
  export type ExportVmTaskId = string;
  export interface FailedCapacityReservationFleetCancellationResult {
    /**
     * The ID of the Capacity Reservation Fleet that could not be cancelled.
     */
    CapacityReservationFleetId?: CapacityReservationFleetId;
    /**
     * Information about the Capacity Reservation Fleet cancellation error.
     */
    CancelCapacityReservationFleetError?: CancelCapacityReservationFleetError;
  }
  export type FailedCapacityReservationFleetCancellationResultSet = FailedCapacityReservationFleetCancellationResult[];
  export interface FailedQueuedPurchaseDeletion {
    /**
     * The error.
     */
    Error?: DeleteQueuedReservedInstancesError;
    /**
     * The ID of the Reserved Instance.
     */
    ReservedInstancesId?: String;
  }
  export type FailedQueuedPurchaseDeletionSet = FailedQueuedPurchaseDeletion[];
  export type FastLaunchImageIdList = ImageId[];
  export interface FastLaunchLaunchTemplateSpecificationRequest {
    /**
     * The ID of the launch template to use for faster launching for a Windows AMI.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template to use for faster launching for a Windows AMI.
     */
    LaunchTemplateName?: String;
    /**
     * The version of the launch template to use for faster launching for a Windows AMI.
     */
    Version: String;
  }
  export interface FastLaunchLaunchTemplateSpecificationResponse {
    /**
     * The ID of the launch template for faster launching of the associated Windows AMI.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template for faster launching of the associated Windows AMI.
     */
    LaunchTemplateName?: String;
    /**
     * The version of the launch template for faster launching of the associated Windows AMI.
     */
    Version?: String;
  }
  export type FastLaunchResourceType = "snapshot"|string;
  export interface FastLaunchSnapshotConfigurationRequest {
    /**
     * The number of pre-provisioned snapshots to keep on hand for a fast-launch enabled Windows AMI.
     */
    TargetResourceCount?: Integer;
  }
  export interface FastLaunchSnapshotConfigurationResponse {
    /**
     * The number of pre-provisioned snapshots requested to keep on hand for a fast-launch enabled Windows AMI.
     */
    TargetResourceCount?: Integer;
  }
  export type FastLaunchStateCode = "enabling"|"enabling-failed"|"enabled"|"enabled-failed"|"disabling"|"disabling-failed"|string;
  export type FastSnapshotRestoreStateCode = "enabling"|"optimizing"|"enabled"|"disabling"|"disabled"|string;
  export interface FederatedAuthentication {
    /**
     * The Amazon Resource Name (ARN) of the IAM SAML identity provider.
     */
    SamlProviderArn?: String;
    /**
     * The Amazon Resource Name (ARN) of the IAM SAML identity provider for the self-service portal.
     */
    SelfServiceSamlProviderArn?: String;
  }
  export interface FederatedAuthenticationRequest {
    /**
     * The Amazon Resource Name (ARN) of the IAM SAML identity provider.
     */
    SAMLProviderArn?: String;
    /**
     * The Amazon Resource Name (ARN) of the IAM SAML identity provider for the self-service portal.
     */
    SelfServiceSAMLProviderArn?: String;
  }
  export interface Filter {
    /**
     * The name of the filter. Filter names are case-sensitive.
     */
    Name?: String;
    /**
     * The filter values. Filter values are case-sensitive. If you specify multiple values for a filter, the values are joined with an OR, and the request returns all results that match any of the specified values.
     */
    Values?: ValueStringList;
  }
  export type FilterList = Filter[];
  export interface FilterPortRange {
    /**
     * The first port in the range.
     */
    FromPort?: Port;
    /**
     * The last port in the range.
     */
    ToPort?: Port;
  }
  export type FindingsFound = "true"|"false"|"unknown"|string;
  export interface FirewallStatefulRule {
    /**
     * The ARN of the stateful rule group.
     */
    RuleGroupArn?: ResourceArn;
    /**
     * The source IP addresses, in CIDR notation.
     */
    Sources?: ValueStringList;
    /**
     * The destination IP addresses, in CIDR notation.
     */
    Destinations?: ValueStringList;
    /**
     * The source ports.
     */
    SourcePorts?: PortRangeList;
    /**
     * The destination ports.
     */
    DestinationPorts?: PortRangeList;
    /**
     * The protocol.
     */
    Protocol?: String;
    /**
     * The rule action. The possible values are pass, drop, and alert.
     */
    RuleAction?: String;
    /**
     * The direction. The possible values are FORWARD and ANY.
     */
    Direction?: String;
  }
  export interface FirewallStatelessRule {
    /**
     * The ARN of the stateless rule group.
     */
    RuleGroupArn?: ResourceArn;
    /**
     * The source IP addresses, in CIDR notation.
     */
    Sources?: ValueStringList;
    /**
     * The destination IP addresses, in CIDR notation.
     */
    Destinations?: ValueStringList;
    /**
     * The source ports.
     */
    SourcePorts?: PortRangeList;
    /**
     * The destination ports.
     */
    DestinationPorts?: PortRangeList;
    /**
     * The protocols.
     */
    Protocols?: ProtocolIntList;
    /**
     * The rule action. The possible values are pass, drop, and forward_to_site.
     */
    RuleAction?: String;
    /**
     * The rule priority.
     */
    Priority?: Priority;
  }
  export type FleetActivityStatus = "error"|"pending_fulfillment"|"pending_termination"|"fulfilled"|string;
  export interface FleetCapacityReservation {
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId?: CapacityReservationId;
    /**
     * The ID of the Availability Zone in which the Capacity Reservation reserves capacity.
     */
    AvailabilityZoneId?: String;
    /**
     * The instance type for which the Capacity Reservation reserves capacity.
     */
    InstanceType?: InstanceType;
    /**
     * The type of operating system for which the Capacity Reservation reserves capacity.
     */
    InstancePlatform?: CapacityReservationInstancePlatform;
    /**
     * The Availability Zone in which the Capacity Reservation reserves capacity.
     */
    AvailabilityZone?: String;
    /**
     * The total number of instances for which the Capacity Reservation reserves capacity.
     */
    TotalInstanceCount?: Integer;
    /**
     * The number of capacity units fulfilled by the Capacity Reservation. For more information, see  Total target capacity in the Amazon EC2 User Guide.
     */
    FulfilledCapacity?: Double;
    /**
     * Indicates whether the Capacity Reservation reserves capacity for EBS-optimized instance types.
     */
    EbsOptimized?: Boolean;
    /**
     * The date and time at which the Capacity Reservation was created.
     */
    CreateDate?: MillisecondDateTime;
    /**
     * The weight of the instance type in the Capacity Reservation Fleet. For more information, see  Instance type weight in the Amazon EC2 User Guide.
     */
    Weight?: DoubleWithConstraints;
    /**
     * The priority of the instance type in the Capacity Reservation Fleet. For more information, see  Instance type priority in the Amazon EC2 User Guide.
     */
    Priority?: IntegerWithConstraints;
  }
  export type FleetCapacityReservationSet = FleetCapacityReservation[];
  export type FleetCapacityReservationTenancy = "default"|string;
  export type FleetCapacityReservationUsageStrategy = "use-capacity-reservations-first"|string;
  export interface FleetData {
    /**
     * The progress of the EC2 Fleet. If there is an error, the status is error. After all requests are placed, the status is pending_fulfillment. If the size of the EC2 Fleet is equal to or greater than its target capacity, the status is fulfilled. If the size of the EC2 Fleet is decreased, the status is pending_termination while instances are terminating.
     */
    ActivityStatus?: FleetActivityStatus;
    /**
     * The creation date and time of the EC2 Fleet.
     */
    CreateTime?: DateTime;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId?: FleetId;
    /**
     * The state of the EC2 Fleet.
     */
    FleetState?: FleetStateCode;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency. Constraints: Maximum 64 ASCII characters
     */
    ClientToken?: String;
    /**
     * Indicates whether running instances should be terminated if the target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet. Supported only for fleets of type maintain.
     */
    ExcessCapacityTerminationPolicy?: FleetExcessCapacityTerminationPolicy;
    /**
     * The number of units fulfilled by this request compared to the set target capacity.
     */
    FulfilledCapacity?: Double;
    /**
     * The number of units fulfilled by this request compared to the set target On-Demand capacity.
     */
    FulfilledOnDemandCapacity?: Double;
    /**
     * The launch template and overrides.
     */
    LaunchTemplateConfigs?: FleetLaunchTemplateConfigList;
    /**
     * The number of units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is maintain, you can specify a target capacity of 0 and add capacity later.
     */
    TargetCapacitySpecification?: TargetCapacitySpecification;
    /**
     * Indicates whether running instances should be terminated when the EC2 Fleet expires. 
     */
    TerminateInstancesWithExpiration?: Boolean;
    /**
     * The type of request. Indicates whether the EC2 Fleet only requests the target capacity, or also attempts to maintain it. If you request a certain target capacity, EC2 Fleet only places the required requests; it does not attempt to replenish instances if capacity is diminished, and it does not submit requests in alternative capacity pools if capacity is unavailable. To maintain a certain target capacity, EC2 Fleet places the required requests to meet this target capacity. It also automatically replenishes any interrupted Spot Instances. Default: maintain.
     */
    Type?: FleetType;
    /**
     * The start date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). The default is to start fulfilling the request immediately. 
     */
    ValidFrom?: DateTime;
    /**
     * The end date and time of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). At this point, no new instance requests are placed or able to fulfill the request. The default end date is 7 days from the current date. 
     */
    ValidUntil?: DateTime;
    /**
     * Indicates whether EC2 Fleet should replace unhealthy Spot Instances. Supported only for fleets of type maintain. For more information, see EC2 Fleet health checks in the Amazon EC2 User Guide.
     */
    ReplaceUnhealthyInstances?: Boolean;
    /**
     * The configuration of Spot Instances in an EC2 Fleet.
     */
    SpotOptions?: SpotOptions;
    /**
     * The allocation strategy of On-Demand Instances in an EC2 Fleet.
     */
    OnDemandOptions?: OnDemandOptions;
    /**
     * The tags for an EC2 Fleet resource.
     */
    Tags?: TagList;
    /**
     * Information about the instances that could not be launched by the fleet. Valid only when Type is set to instant.
     */
    Errors?: DescribeFleetsErrorSet;
    /**
     * Information about the instances that were launched by the fleet. Valid only when Type is set to instant.
     */
    Instances?: DescribeFleetsInstancesSet;
    /**
     * Reserved.
     */
    Context?: String;
  }
  export type FleetEventType = "instance-change"|"fleet-change"|"service-error"|string;
  export type FleetExcessCapacityTerminationPolicy = "no-termination"|"termination"|string;
  export type FleetId = string;
  export type FleetIdSet = FleetId[];
  export type FleetInstanceMatchCriteria = "open"|string;
  export interface FleetLaunchTemplateConfig {
    /**
     * The launch template.
     */
    LaunchTemplateSpecification?: FleetLaunchTemplateSpecification;
    /**
     * Any parameters that you specify override the same parameters in the launch template.
     */
    Overrides?: FleetLaunchTemplateOverridesList;
  }
  export type FleetLaunchTemplateConfigList = FleetLaunchTemplateConfig[];
  export type FleetLaunchTemplateConfigListRequest = FleetLaunchTemplateConfigRequest[];
  export interface FleetLaunchTemplateConfigRequest {
    /**
     * The launch template to use. You must specify either the launch template ID or launch template name in the request. 
     */
    LaunchTemplateSpecification?: FleetLaunchTemplateSpecificationRequest;
    /**
     * Any parameters that you specify override the same parameters in the launch template. For fleets of type request and maintain, a maximum of 300 items is allowed across all launch templates.
     */
    Overrides?: FleetLaunchTemplateOverridesListRequest;
  }
  export interface FleetLaunchTemplateOverrides {
    /**
     * The instance type.  mac1.metal is not supported as a launch template override.  If you specify InstanceType, you can't specify InstanceRequirements. 
     */
    InstanceType?: InstanceType;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.   If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxPrice?: String;
    /**
     * The ID of the subnet in which to launch the instances.
     */
    SubnetId?: String;
    /**
     * The Availability Zone in which to launch the instances.
     */
    AvailabilityZone?: String;
    /**
     * The number of units provided by the specified instance type.
     */
    WeightedCapacity?: Double;
    /**
     * The priority for the launch template override. The highest priority is launched first. If the On-Demand AllocationStrategy is set to prioritized, EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. If the Spot AllocationStrategy is set to capacity-optimized-prioritized, EC2 Fleet uses priority on a best-effort basis to determine which launch template override to use in fulfilling Spot capacity, but optimizes for capacity first. Valid values are whole numbers starting at 0. The lower the number, the higher the priority. If no number is set, the override has the lowest priority. You can set the same priority for different launch template overrides.
     */
    Priority?: Double;
    /**
     * The location where the instance launched, if applicable.
     */
    Placement?: PlacementResponse;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.  If you specify InstanceRequirements, you can't specify InstanceType. 
     */
    InstanceRequirements?: InstanceRequirements;
    /**
     * The ID of the AMI. An AMI is required to launch an instance. The AMI ID must be specified here or in the launch template.
     */
    ImageId?: ImageId;
  }
  export type FleetLaunchTemplateOverridesList = FleetLaunchTemplateOverrides[];
  export type FleetLaunchTemplateOverridesListRequest = FleetLaunchTemplateOverridesRequest[];
  export interface FleetLaunchTemplateOverridesRequest {
    /**
     * The instance type.  mac1.metal is not supported as a launch template override.  If you specify InstanceType, you can't specify InstanceRequirements. 
     */
    InstanceType?: InstanceType;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.   If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxPrice?: String;
    /**
     * The IDs of the subnets in which to launch the instances. Separate multiple subnet IDs using commas (for example, subnet-1234abcdeexample1, subnet-0987cdef6example2). A request of type instant can have only one subnet ID.
     */
    SubnetId?: SubnetId;
    /**
     * The Availability Zone in which to launch the instances.
     */
    AvailabilityZone?: String;
    /**
     * The number of units provided by the specified instance type.
     */
    WeightedCapacity?: Double;
    /**
     * The priority for the launch template override. The highest priority is launched first. If the On-Demand AllocationStrategy is set to prioritized, EC2 Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. If the Spot AllocationStrategy is set to capacity-optimized-prioritized, EC2 Fleet uses priority on a best-effort basis to determine which launch template override to use in fulfilling Spot capacity, but optimizes for capacity first. Valid values are whole numbers starting at 0. The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. You can set the same priority for different launch template overrides.
     */
    Priority?: Double;
    /**
     * The location where the instance launched, if applicable.
     */
    Placement?: Placement;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.  If you specify InstanceRequirements, you can't specify InstanceType. 
     */
    InstanceRequirements?: InstanceRequirementsRequest;
    /**
     * The ID of the AMI. An AMI is required to launch an instance. The AMI ID must be specified here or in the launch template.
     */
    ImageId?: ImageId;
  }
  export interface FleetLaunchTemplateSpecification {
    /**
     * The ID of the launch template. You must specify the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: String;
    /**
     * The name of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The launch template version number, $Latest, or $Default. You must specify a value, otherwise the request fails. If the value is $Latest, Amazon EC2 uses the latest version of the launch template. If the value is $Default, Amazon EC2 uses the default version of the launch template.
     */
    Version?: String;
  }
  export interface FleetLaunchTemplateSpecificationRequest {
    /**
     * The ID of the launch template. You must specify the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The launch template version number, $Latest, or $Default. You must specify a value, otherwise the request fails. If the value is $Latest, Amazon EC2 uses the latest version of the launch template. If the value is $Default, Amazon EC2 uses the default version of the launch template.
     */
    Version?: String;
  }
  export type FleetOnDemandAllocationStrategy = "lowest-price"|"prioritized"|string;
  export type FleetReplacementStrategy = "launch"|"launch-before-terminate"|string;
  export type FleetSet = FleetData[];
  export interface FleetSpotCapacityRebalance {
    /**
     * The replacement strategy to use. Only available for fleets of type maintain.  launch - EC2 Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet. EC2 Fleet does not terminate the instances that receive a rebalance notification. You can terminate the old instances, or you can leave them running. You are charged for all instances while they are running.   launch-before-terminate - EC2 Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet, and then, after a delay that you specify (in TerminationDelay), terminates the instances that received a rebalance notification.
     */
    ReplacementStrategy?: FleetReplacementStrategy;
    /**
     * The amount of time (in seconds) that Amazon EC2 waits before terminating the old Spot Instance after launching a new replacement Spot Instance. Required when ReplacementStrategy is set to launch-before-terminate. Not valid when ReplacementStrategy is set to launch. Valid values: Minimum value of 120 seconds. Maximum value of 7200 seconds.
     */
    TerminationDelay?: Integer;
  }
  export interface FleetSpotCapacityRebalanceRequest {
    /**
     * The replacement strategy to use. Only available for fleets of type maintain.  launch - EC2 Fleet launches a replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet. EC2 Fleet does not terminate the instances that receive a rebalance notification. You can terminate the old instances, or you can leave them running. You are charged for all instances while they are running.   launch-before-terminate - EC2 Fleet launches a replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet, and then, after a delay that you specify (in TerminationDelay), terminates the instances that received a rebalance notification.
     */
    ReplacementStrategy?: FleetReplacementStrategy;
    /**
     * The amount of time (in seconds) that Amazon EC2 waits before terminating the old Spot Instance after launching a new replacement Spot Instance. Required when ReplacementStrategy is set to launch-before-terminate. Not valid when ReplacementStrategy is set to launch. Valid values: Minimum value of 120 seconds. Maximum value of 7200 seconds.
     */
    TerminationDelay?: Integer;
  }
  export interface FleetSpotMaintenanceStrategies {
    /**
     * The strategy to use when Amazon EC2 emits a signal that your Spot Instance is at an elevated risk of being interrupted.
     */
    CapacityRebalance?: FleetSpotCapacityRebalance;
  }
  export interface FleetSpotMaintenanceStrategiesRequest {
    /**
     * The strategy to use when Amazon EC2 emits a signal that your Spot Instance is at an elevated risk of being interrupted.
     */
    CapacityRebalance?: FleetSpotCapacityRebalanceRequest;
  }
  export type FleetStateCode = "submitted"|"active"|"deleted"|"failed"|"deleted_running"|"deleted_terminating"|"modifying"|string;
  export type FleetType = "request"|"maintain"|"instant"|string;
  export type Float = number;
  export interface FlowLog {
    /**
     * The date and time the flow log was created.
     */
    CreationTime?: MillisecondDateTime;
    /**
     * Information about the error that occurred. Rate limited indicates that CloudWatch Logs throttling has been applied for one or more network interfaces, or that you've reached the limit on the number of log groups that you can create. Access error indicates that the IAM role associated with the flow log does not have sufficient permissions to publish to CloudWatch Logs. Unknown error indicates an internal error.
     */
    DeliverLogsErrorMessage?: String;
    /**
     * The ARN of the IAM role allows the service to publish logs to CloudWatch Logs.
     */
    DeliverLogsPermissionArn?: String;
    /**
     * The ARN of the IAM role that allows the service to publish flow logs across accounts.
     */
    DeliverCrossAccountRole?: String;
    /**
     * The status of the logs delivery (SUCCESS | FAILED).
     */
    DeliverLogsStatus?: String;
    /**
     * The ID of the flow log.
     */
    FlowLogId?: String;
    /**
     * The status of the flow log (ACTIVE).
     */
    FlowLogStatus?: String;
    /**
     * The name of the flow log group.
     */
    LogGroupName?: String;
    /**
     * The ID of the resource being monitored.
     */
    ResourceId?: String;
    /**
     * The type of traffic captured for the flow log.
     */
    TrafficType?: TrafficType;
    /**
     * The type of destination for the flow log data.
     */
    LogDestinationType?: LogDestinationType;
    /**
     * The Amazon Resource Name (ARN) of the destination for the flow log data.
     */
    LogDestination?: String;
    /**
     * The format of the flow log record.
     */
    LogFormat?: String;
    /**
     * The tags for the flow log.
     */
    Tags?: TagList;
    /**
     * The maximum interval of time, in seconds, during which a flow of packets is captured and aggregated into a flow log record. When a network interface is attached to a Nitro-based instance, the aggregation interval is always 60 seconds (1 minute) or less, regardless of the specified value. Valid Values: 60 | 600 
     */
    MaxAggregationInterval?: Integer;
    /**
     * The destination options.
     */
    DestinationOptions?: DestinationOptionsResponse;
  }
  export type FlowLogIdList = VpcFlowLogId[];
  export type FlowLogResourceId = string;
  export type FlowLogResourceIds = FlowLogResourceId[];
  export type FlowLogSet = FlowLog[];
  export type FlowLogsResourceType = "VPC"|"Subnet"|"NetworkInterface"|"TransitGateway"|"TransitGatewayAttachment"|string;
  export type FpgaDeviceCount = number;
  export interface FpgaDeviceInfo {
    /**
     * The name of the FPGA accelerator.
     */
    Name?: FpgaDeviceName;
    /**
     * The manufacturer of the FPGA accelerator.
     */
    Manufacturer?: FpgaDeviceManufacturerName;
    /**
     * The count of FPGA accelerators for the instance type.
     */
    Count?: FpgaDeviceCount;
    /**
     * Describes the memory for the FPGA accelerator for the instance type.
     */
    MemoryInfo?: FpgaDeviceMemoryInfo;
  }
  export type FpgaDeviceInfoList = FpgaDeviceInfo[];
  export type FpgaDeviceManufacturerName = string;
  export interface FpgaDeviceMemoryInfo {
    /**
     * The size of the memory available to the FPGA accelerator, in MiB.
     */
    SizeInMiB?: FpgaDeviceMemorySize;
  }
  export type FpgaDeviceMemorySize = number;
  export type FpgaDeviceName = string;
  export interface FpgaImage {
    /**
     * The FPGA image identifier (AFI ID).
     */
    FpgaImageId?: String;
    /**
     * The global FPGA image identifier (AGFI ID).
     */
    FpgaImageGlobalId?: String;
    /**
     * The name of the AFI.
     */
    Name?: String;
    /**
     * The description of the AFI.
     */
    Description?: String;
    /**
     * The version of the Amazon Web Services Shell that was used to create the bitstream.
     */
    ShellVersion?: String;
    /**
     * Information about the PCI bus.
     */
    PciId?: PciId;
    /**
     * Information about the state of the AFI.
     */
    State?: FpgaImageState;
    /**
     * The date and time the AFI was created.
     */
    CreateTime?: DateTime;
    /**
     * The time of the most recent update to the AFI.
     */
    UpdateTime?: DateTime;
    /**
     * The ID of the Amazon Web Services account that owns the AFI.
     */
    OwnerId?: String;
    /**
     * The alias of the AFI owner. Possible values include self, amazon, and aws-marketplace.
     */
    OwnerAlias?: String;
    /**
     * The product codes for the AFI.
     */
    ProductCodes?: ProductCodeList;
    /**
     * Any tags assigned to the AFI.
     */
    Tags?: TagList;
    /**
     * Indicates whether the AFI is public.
     */
    Public?: Boolean;
    /**
     * Indicates whether data retention support is enabled for the AFI.
     */
    DataRetentionSupport?: Boolean;
    /**
     * The instance types supported by the AFI.
     */
    InstanceTypes?: InstanceTypesList;
  }
  export interface FpgaImageAttribute {
    /**
     * The ID of the AFI.
     */
    FpgaImageId?: String;
    /**
     * The name of the AFI.
     */
    Name?: String;
    /**
     * The description of the AFI.
     */
    Description?: String;
    /**
     * The load permissions.
     */
    LoadPermissions?: LoadPermissionList;
    /**
     * The product codes.
     */
    ProductCodes?: ProductCodeList;
  }
  export type FpgaImageAttributeName = "description"|"name"|"loadPermission"|"productCodes"|string;
  export type FpgaImageId = string;
  export type FpgaImageIdList = FpgaImageId[];
  export type FpgaImageList = FpgaImage[];
  export interface FpgaImageState {
    /**
     * The state. The following are the possible values:    pending - AFI bitstream generation is in progress.    available - The AFI is available for use.    failed - AFI bitstream generation failed.    unavailable - The AFI is no longer available for use.  
     */
    Code?: FpgaImageStateCode;
    /**
     * If the state is failed, this is the error message.
     */
    Message?: String;
  }
  export type FpgaImageStateCode = "pending"|"failed"|"available"|"unavailable"|string;
  export interface FpgaInfo {
    /**
     * Describes the FPGAs for the instance type.
     */
    Fpgas?: FpgaDeviceInfoList;
    /**
     * The total memory of all FPGA accelerators for the instance type.
     */
    TotalFpgaMemoryInMiB?: totalFpgaMemory;
  }
  export type FreeTierEligibleFlag = boolean;
  export type GVCDMaxResults = number;
  export type GatewayAssociationState = "associated"|"not-associated"|"associating"|"disassociating"|string;
  export type GatewayType = "ipsec.1"|string;
  export interface GetAssociatedEnclaveCertificateIamRolesRequest {
    /**
     * The ARN of the ACM certificate for which to view the associated IAM roles, encryption keys, and Amazon S3 object information.
     */
    CertificateArn: CertificateId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetAssociatedEnclaveCertificateIamRolesResult {
    /**
     * Information about the associated IAM roles.
     */
    AssociatedRoles?: AssociatedRolesList;
  }
  export interface GetAssociatedIpv6PoolCidrsRequest {
    /**
     * The ID of the IPv6 address pool.
     */
    PoolId: Ipv6PoolEc2Id;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: Ipv6PoolMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetAssociatedIpv6PoolCidrsResult {
    /**
     * Information about the IPv6 CIDR block associations.
     */
    Ipv6CidrAssociations?: Ipv6CidrAssociationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetAwsNetworkPerformanceDataRequest {
    /**
     * A list of network performance data queries.
     */
    DataQueries?: DataQueries;
    /**
     * The starting time for the performance data request. The starting time must be formatted as yyyy-mm-ddThh:mm:ss. For example, 2022-06-10T12:00:00.000Z.
     */
    StartTime?: MillisecondDateTime;
    /**
     * The ending time for the performance data request. The end time must be formatted as yyyy-mm-ddThh:mm:ss. For example, 2022-06-12T12:00:00.000Z.
     */
    EndTime?: MillisecondDateTime;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: Integer;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetAwsNetworkPerformanceDataResult {
    /**
     * The list of data responses.
     */
    DataResponses?: DataResponses;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetCapacityReservationUsageRequest {
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId: CapacityReservationId;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error. Valid range: Minimum value of 1. Maximum value of 1000.
     */
    MaxResults?: GetCapacityReservationUsageRequestMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type GetCapacityReservationUsageRequestMaxResults = number;
  export interface GetCapacityReservationUsageResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId?: String;
    /**
     * The type of instance for which the Capacity Reservation reserves capacity.
     */
    InstanceType?: String;
    /**
     * The number of instances for which the Capacity Reservation reserves capacity.
     */
    TotalInstanceCount?: Integer;
    /**
     * The remaining capacity. Indicates the number of instances that can be launched in the Capacity Reservation.
     */
    AvailableInstanceCount?: Integer;
    /**
     * The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:    active - The Capacity Reservation is active and the capacity is available for your use.    expired - The Capacity Reservation expired automatically at the date and time specified in your request. The reserved capacity is no longer available for your use.    cancelled - The Capacity Reservation was cancelled. The reserved capacity is no longer available for your use.    pending - The Capacity Reservation request was successful but the capacity provisioning is still pending.    failed - The Capacity Reservation request has failed. A request might fail due to invalid request parameters, capacity constraints, or instance limit constraints. Failed requests are retained for 60 minutes.  
     */
    State?: CapacityReservationState;
    /**
     * Information about the Capacity Reservation usage.
     */
    InstanceUsages?: InstanceUsageSet;
  }
  export interface GetCoipPoolUsageRequest {
    /**
     * The ID of the address pool.
     */
    PoolId: Ipv4PoolCoipId;
    /**
     * One or more filters.    coip-address-usage.allocation-id - The allocation ID of the address.    coip-address-usage.aws-account-id - The ID of the Amazon Web Services account that is using the customer-owned IP address.    coip-address-usage.aws-service - The Amazon Web Services service that is using the customer-owned IP address.    coip-address-usage.co-ip - The customer-owned IP address.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: CoipPoolMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetCoipPoolUsageResult {
    /**
     * The ID of the customer-owned address pool.
     */
    CoipPoolId?: String;
    /**
     * Information about the address usage.
     */
    CoipAddressUsages?: CoipAddressUsageSet;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: String;
  }
  export interface GetConsoleOutputRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * When enabled, retrieves the latest console output for the instance. Default: disabled (false)
     */
    Latest?: Boolean;
  }
  export interface GetConsoleOutputResult {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The console output, base64-encoded. If you are using a command line tool, the tool decodes the output for you.
     */
    Output?: String;
    /**
     * The time at which the output was last updated.
     */
    Timestamp?: DateTime;
  }
  export interface GetConsoleScreenshotRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * When set to true, acts as keystroke input and wakes up an instance that's in standby or "sleep" mode.
     */
    WakeUp?: Boolean;
  }
  export interface GetConsoleScreenshotResult {
    /**
     * The data that comprises the image.
     */
    ImageData?: String;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
  }
  export interface GetDefaultCreditSpecificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The instance family.
     */
    InstanceFamily: UnlimitedSupportedInstanceFamily;
  }
  export interface GetDefaultCreditSpecificationResult {
    /**
     * The default credit option for CPU usage of the instance family.
     */
    InstanceFamilyCreditSpecification?: InstanceFamilyCreditSpecification;
  }
  export interface GetEbsDefaultKmsKeyIdRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetEbsDefaultKmsKeyIdResult {
    /**
     * The Amazon Resource Name (ARN) of the default KMS key for encryption by default.
     */
    KmsKeyId?: String;
  }
  export interface GetEbsEncryptionByDefaultRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetEbsEncryptionByDefaultResult {
    /**
     * Indicates whether encryption by default is enabled.
     */
    EbsEncryptionByDefault?: Boolean;
  }
  export interface GetFlowLogsIntegrationTemplateRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the flow log.
     */
    FlowLogId: VpcFlowLogId;
    /**
     * To store the CloudFormation template in Amazon S3, specify the location in Amazon S3.
     */
    ConfigDeliveryS3DestinationArn: String;
    /**
     * Information about the service integration.
     */
    IntegrateServices: IntegrateServices;
  }
  export interface GetFlowLogsIntegrationTemplateResult {
    /**
     * The generated CloudFormation template.
     */
    Result?: String;
  }
  export interface GetGroupsForCapacityReservationRequest {
    /**
     * The ID of the Capacity Reservation. If you specify a Capacity Reservation that is shared with you, the operation returns only Capacity Reservation groups that you own.
     */
    CapacityReservationId: CapacityReservationId;
    /**
     * The token to use to retrieve the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return for the request in a single page. The remaining results can be seen by sending another request with the returned nextToken value. This value can be between 5 and 500. If maxResults is given a larger value than 500, you receive an error.
     */
    MaxResults?: GetGroupsForCapacityReservationRequestMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type GetGroupsForCapacityReservationRequestMaxResults = number;
  export interface GetGroupsForCapacityReservationResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
    /**
     * Information about the resource groups to which the Capacity Reservation has been added.
     */
    CapacityReservationGroups?: CapacityReservationGroupSet;
  }
  export interface GetHostReservationPurchasePreviewRequest {
    /**
     * The IDs of the Dedicated Hosts with which the reservation is associated.
     */
    HostIdSet: RequestHostIdSet;
    /**
     * The offering ID of the reservation.
     */
    OfferingId: OfferingId;
  }
  export interface GetHostReservationPurchasePreviewResult {
    /**
     * The currency in which the totalUpfrontPrice and totalHourlyPrice amounts are specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The purchase information of the Dedicated Host reservation and the Dedicated Hosts associated with it.
     */
    Purchase?: PurchaseSet;
    /**
     * The potential total hourly price of the reservation per hour.
     */
    TotalHourlyPrice?: String;
    /**
     * The potential total upfront price. This is billed immediately.
     */
    TotalUpfrontPrice?: String;
  }
  export interface GetInstanceTypesFromInstanceRequirementsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The processor architecture type.
     */
    ArchitectureTypes: ArchitectureTypeSet;
    /**
     * The virtualization type.
     */
    VirtualizationTypes: VirtualizationTypeSet;
    /**
     * The attributes required for the instance types.
     */
    InstanceRequirements: InstanceRequirementsRequest;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: Integer;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface GetInstanceTypesFromInstanceRequirementsResult {
    /**
     * The instance types with the specified instance attributes.
     */
    InstanceTypes?: InstanceTypeInfoFromInstanceRequirementsSet;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export interface GetInstanceUefiDataRequest {
    /**
     * The ID of the instance from which to retrieve the UEFI data.
     */
    InstanceId: InstanceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetInstanceUefiDataResult {
    /**
     * The ID of the instance from which to retrieve the UEFI data.
     */
    InstanceId?: InstanceId;
    /**
     * Base64 representation of the non-volatile UEFI variable store.
     */
    UefiData?: String;
  }
  export interface GetIpamAddressHistoryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The CIDR you want the history of. The CIDR can be an IPv4 or IPv6 IP address range. If you enter a /16 IPv4 CIDR, you will get records that match it exactly. You will not get records for any subnets within the /16 CIDR.
     */
    Cidr: String;
    /**
     * The ID of the IPAM scope that the CIDR is in.
     */
    IpamScopeId: IpamScopeId;
    /**
     * The ID of the VPC you want your history records filtered by.
     */
    VpcId?: String;
    /**
     * The start of the time period for which you are looking for history. If you omit this option, it will default to the value of EndTime.
     */
    StartTime?: MillisecondDateTime;
    /**
     * The end of the time period for which you are looking for history. If you omit this option, it will default to the current time.
     */
    EndTime?: MillisecondDateTime;
    /**
     * The maximum number of historical results you would like returned per page. Defaults to 100.
     */
    MaxResults?: IpamAddressHistoryMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamAddressHistoryResult {
    /**
     * A historical record for a CIDR within an IPAM scope. If the CIDR is associated with an EC2 instance, you will see an object in the response for the instance and one for the network interface.
     */
    HistoryRecords?: IpamAddressHistoryRecordSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamDiscoveredAccountsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A resource discovery ID.
     */
    IpamResourceDiscoveryId: IpamResourceDiscoveryId;
    /**
     * The Amazon Web Services Region that the account information is returned from.
     */
    DiscoveryRegion: String;
    /**
     * Discovered account filters.
     */
    Filters?: FilterList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of discovered accounts to return in one page of results.
     */
    MaxResults?: IpamMaxResults;
  }
  export interface GetIpamDiscoveredAccountsResult {
    /**
     * Discovered accounts.
     */
    IpamDiscoveredAccounts?: IpamDiscoveredAccountSet;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamDiscoveredResourceCidrsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A resource discovery ID.
     */
    IpamResourceDiscoveryId: IpamResourceDiscoveryId;
    /**
     * A resource Region.
     */
    ResourceRegion: String;
    /**
     * Filters.
     */
    Filters?: FilterList;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The maximum number of discovered resource CIDRs to return in one page of results.
     */
    MaxResults?: IpamMaxResults;
  }
  export interface GetIpamDiscoveredResourceCidrsResult {
    /**
     * Discovered resource CIDRs.
     */
    IpamDiscoveredResourceCidrs?: IpamDiscoveredResourceCidrSet;
    /**
     * Specify the pagination token from a previous request to retrieve the next page of results.
     */
    NextToken?: NextToken;
  }
  export type GetIpamPoolAllocationsMaxResults = number;
  export interface GetIpamPoolAllocationsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool you want to see the allocations for.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The ID of the allocation.
     */
    IpamPoolAllocationId?: IpamPoolAllocationId;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results you would like returned per page.
     */
    MaxResults?: GetIpamPoolAllocationsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamPoolAllocationsResult {
    /**
     * The IPAM pool allocations you want information on.
     */
    IpamPoolAllocations?: IpamPoolAllocationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamPoolCidrsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool you want the CIDR for.
     */
    IpamPoolId: IpamPoolId;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in the request.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamPoolCidrsResult {
    /**
     * Information about the CIDRs provisioned to an IPAM pool.
     */
    IpamPoolCidrs?: IpamPoolCidrSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface GetIpamResourceCidrsRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * One or more filters for the request. For more information about filtering, see Filtering CLI output.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return in the request.
     */
    MaxResults?: IpamMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * The ID of the scope that the resource is in.
     */
    IpamScopeId: IpamScopeId;
    /**
     * The ID of the IPAM pool that the resource is in.
     */
    IpamPoolId?: IpamPoolId;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The resource type.
     */
    ResourceType?: IpamResourceType;
    /**
     * The resource tag.
     */
    ResourceTag?: RequestIpamResourceTag;
    /**
     * The ID of the Amazon Web Services account that owns the resource.
     */
    ResourceOwner?: String;
  }
  export interface GetIpamResourceCidrsResult {
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
    /**
     * The resource CIDRs.
     */
    IpamResourceCidrs?: IpamResourceCidrSet;
  }
  export interface GetLaunchTemplateDataRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
  }
  export interface GetLaunchTemplateDataResult {
    /**
     * The instance data.
     */
    LaunchTemplateData?: ResponseLaunchTemplateData;
  }
  export type GetManagedPrefixListAssociationsMaxResults = number;
  export interface GetManagedPrefixListAssociationsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: GetManagedPrefixListAssociationsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetManagedPrefixListAssociationsResult {
    /**
     * Information about the associations.
     */
    PrefixListAssociations?: PrefixListAssociationSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetManagedPrefixListEntriesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The version of the prefix list for which to return the entries. The default is the current version.
     */
    TargetVersion?: Long;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: PrefixListMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
  }
  export interface GetManagedPrefixListEntriesResult {
    /**
     * Information about the prefix list entries.
     */
    Entries?: PrefixListEntrySet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface GetNetworkInsightsAccessScopeAnalysisFindingsRequest {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId: NetworkInsightsAccessScopeAnalysisId;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: NetworkInsightsMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetNetworkInsightsAccessScopeAnalysisFindingsResult {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId?: NetworkInsightsAccessScopeAnalysisId;
    /**
     * The status of Network Access Scope Analysis.
     */
    AnalysisStatus?: AnalysisStatus;
    /**
     * The findings associated with Network Access Scope Analysis.
     */
    AnalysisFindings?: AccessScopeAnalysisFindingList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetNetworkInsightsAccessScopeContentRequest {
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId: NetworkInsightsAccessScopeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetNetworkInsightsAccessScopeContentResult {
    /**
     * The Network Access Scope content.
     */
    NetworkInsightsAccessScopeContent?: NetworkInsightsAccessScopeContent;
  }
  export interface GetPasswordDataRequest {
    /**
     * The ID of the Windows instance.
     */
    InstanceId: InstanceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetPasswordDataResult {
    /**
     * The ID of the Windows instance.
     */
    InstanceId?: String;
    /**
     * The password of the instance. Returns an empty string if the password is not available.
     */
    PasswordData?: String;
    /**
     * The time the data was last updated.
     */
    Timestamp?: DateTime;
  }
  export interface GetReservedInstancesExchangeQuoteRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the Convertible Reserved Instances to exchange.
     */
    ReservedInstanceIds: ReservedInstanceIdSet;
    /**
     * The configuration of the target Convertible Reserved Instance to exchange for your current Convertible Reserved Instances.
     */
    TargetConfigurations?: TargetConfigurationRequestSet;
  }
  export interface GetReservedInstancesExchangeQuoteResult {
    /**
     * The currency of the transaction.
     */
    CurrencyCode?: String;
    /**
     * If true, the exchange is valid. If false, the exchange cannot be completed.
     */
    IsValidExchange?: Boolean;
    /**
     * The new end date of the reservation term.
     */
    OutputReservedInstancesWillExpireAt?: DateTime;
    /**
     * The total true upfront charge for the exchange.
     */
    PaymentDue?: String;
    /**
     * The cost associated with the Reserved Instance.
     */
    ReservedInstanceValueRollup?: ReservationValue;
    /**
     * The configuration of your Convertible Reserved Instances.
     */
    ReservedInstanceValueSet?: ReservedInstanceReservationValueSet;
    /**
     * The cost associated with the Reserved Instance.
     */
    TargetConfigurationValueRollup?: ReservationValue;
    /**
     * The values of the target Convertible Reserved Instances.
     */
    TargetConfigurationValueSet?: TargetReservationValueSet;
    /**
     * Describes the reason why the exchange cannot be completed.
     */
    ValidationFailureReason?: String;
  }
  export interface GetSerialConsoleAccessStatusRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetSerialConsoleAccessStatusResult {
    /**
     * If true, access to the EC2 serial console of all instances is enabled for your account. If false, access to the EC2 serial console of all instances is disabled for your account.
     */
    SerialConsoleAccessEnabled?: Boolean;
  }
  export interface GetSpotPlacementScoresRequest {
    /**
     * The instance types. We recommend that you specify at least three instance types. If you specify one or two instance types, or specify variations of a single instance type (for example, an m3.xlarge with and without instance storage), the returned placement score will always be low.  If you specify InstanceTypes, you can't specify InstanceRequirementsWithMetadata.
     */
    InstanceTypes?: InstanceTypes;
    /**
     * The target capacity.
     */
    TargetCapacity: SpotPlacementScoresTargetCapacity;
    /**
     * The unit for the target capacity. Default: units (translates to number of instances)
     */
    TargetCapacityUnitType?: TargetCapacityUnitType;
    /**
     * Specify true so that the response returns a list of scored Availability Zones. Otherwise, the response returns a list of scored Regions. A list of scored Availability Zones is useful if you want to launch all of your Spot capacity into a single Availability Zone.
     */
    SingleAvailabilityZone?: Boolean;
    /**
     * The Regions used to narrow down the list of Regions to be scored. Enter the Region code, for example, us-east-1.
     */
    RegionNames?: RegionNames;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes. If you specify InstanceRequirementsWithMetadata, you can't specify InstanceTypes.
     */
    InstanceRequirementsWithMetadata?: InstanceRequirementsWithMetadataRequest;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: SpotPlacementScoresMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
  }
  export interface GetSpotPlacementScoresResult {
    /**
     * The Spot placement score for the top 10 Regions or Availability Zones, scored on a scale from 1 to 10. Each score&#x2028; reflects how likely it is that each Region or Availability Zone will succeed at fulfilling the specified target capacity&#x2028; at the time of the Spot placement score request. A score of 10 means that your Spot capacity request is highly likely to succeed in that Region or Availability Zone.  If you request a Spot placement score for Regions, a high score assumes that your fleet request will be configured to use all Availability Zones and the capacity-optimized allocation strategy. If you request a Spot placement score for Availability Zones, a high score assumes that your fleet request will be configured to use a single Availability Zone and the capacity-optimized allocation strategy. Different&#x2028; Regions or Availability Zones might return the same score.  The Spot placement score serves as a recommendation only. No score guarantees that your Spot request will be fully or partially fulfilled. 
     */
    SpotPlacementScores?: SpotPlacementScores;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type GetSubnetCidrReservationsMaxResults = number;
  export interface GetSubnetCidrReservationsRequest {
    /**
     * One or more filters.    reservationType - The type of reservation (prefix | explicit).    subnet-id - The ID of the subnet.    tag:&lt;key&gt; - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.  
     */
    Filters?: FilterList;
    /**
     * The ID of the subnet.
     */
    SubnetId: SubnetId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: GetSubnetCidrReservationsMaxResults;
  }
  export interface GetSubnetCidrReservationsResult {
    /**
     * Information about the IPv4 subnet CIDR reservations.
     */
    SubnetIpv4CidrReservations?: SubnetCidrReservationList;
    /**
     * Information about the IPv6 subnet CIDR reservations.
     */
    SubnetIpv6CidrReservations?: SubnetCidrReservationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayAttachmentPropagationsRequest {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * One or more filters. The possible values are:    transit-gateway-route-table-id - The ID of the transit gateway route table.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayAttachmentPropagationsResult {
    /**
     * Information about the propagation route tables.
     */
    TransitGatewayAttachmentPropagations?: TransitGatewayAttachmentPropagationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayMulticastDomainAssociationsRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * One or more filters. The possible values are:    resource-id - The ID of the resource.    resource-type - The type of resource. The valid value is: vpc.    state - The state of the subnet association. Valid values are associated | associating | disassociated | disassociating.    subnet-id - The ID of the subnet.    transit-gateway-attachment-id - The id of the transit gateway attachment.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayMulticastDomainAssociationsResult {
    /**
     * Information about the multicast domain associations.
     */
    MulticastDomainAssociations?: TransitGatewayMulticastDomainAssociationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayPolicyTableAssociationsRequest {
    /**
     * The ID of the transit gateway policy table.
     */
    TransitGatewayPolicyTableId: TransitGatewayPolicyTableId;
    /**
     * The filters associated with the transit gateway policy table.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayPolicyTableAssociationsResult {
    /**
     * Returns details about the transit gateway policy table association.
     */
    Associations?: TransitGatewayPolicyTableAssociationList;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayPolicyTableEntriesRequest {
    /**
     * The ID of the transit gateway policy table.
     */
    TransitGatewayPolicyTableId: TransitGatewayPolicyTableId;
    /**
     * The filters associated with the transit gateway policy table.
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayPolicyTableEntriesResult {
    /**
     * The entries for the transit gateway policy table.
     */
    TransitGatewayPolicyTableEntries?: TransitGatewayPolicyTableEntryList;
  }
  export interface GetTransitGatewayPrefixListReferencesRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * One or more filters. The possible values are:    attachment.resource-id - The ID of the resource for the attachment.    attachment.resource-type - The type of resource for the attachment. Valid values are vpc | vpn | direct-connect-gateway | peering.    attachment.transit-gateway-attachment-id - The ID of the attachment.    is-blackhole - Whether traffic matching the route is blocked (true | false).    prefix-list-id - The ID of the prefix list.    prefix-list-owner-id - The ID of the owner of the prefix list.    state - The state of the prefix list reference (pending | available | modifying | deleting).  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayPrefixListReferencesResult {
    /**
     * Information about the prefix list references.
     */
    TransitGatewayPrefixListReferences?: TransitGatewayPrefixListReferenceSet;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayRouteTableAssociationsRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * One or more filters. The possible values are:    resource-id - The ID of the resource.    resource-type - The resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    transit-gateway-attachment-id - The ID of the attachment.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayRouteTableAssociationsResult {
    /**
     * Information about the associations.
     */
    Associations?: TransitGatewayRouteTableAssociationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetTransitGatewayRouteTablePropagationsRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * One or more filters. The possible values are:    resource-id - The ID of the resource.    resource-type - The resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    transit-gateway-attachment-id - The ID of the attachment.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetTransitGatewayRouteTablePropagationsResult {
    /**
     * Information about the route table propagations.
     */
    TransitGatewayRouteTablePropagations?: TransitGatewayRouteTablePropagationList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface GetVerifiedAccessEndpointPolicyRequest {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointId: VerifiedAccessEndpointId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetVerifiedAccessEndpointPolicyResult {
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled?: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
  }
  export interface GetVerifiedAccessGroupPolicyRequest {
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId: VerifiedAccessGroupId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetVerifiedAccessGroupPolicyResult {
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled?: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
  }
  export interface GetVpnConnectionDeviceSampleConfigurationRequest {
    /**
     * The VpnConnectionId specifies the Site-to-Site VPN connection used for the sample configuration.
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * Device identifier provided by the GetVpnConnectionDeviceTypes API.
     */
    VpnConnectionDeviceTypeId: VpnConnectionDeviceTypeId;
    /**
     * The IKE version to be used in the sample configuration file for your customer gateway device. You can specify one of the following versions: ikev1 or ikev2.
     */
    InternetKeyExchangeVersion?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetVpnConnectionDeviceSampleConfigurationResult {
    /**
     * Sample configuration file for the specified customer gateway device.
     */
    VpnConnectionDeviceSampleConfiguration?: VpnConnectionDeviceSampleConfiguration;
  }
  export interface GetVpnConnectionDeviceTypesRequest {
    /**
     * The maximum number of results returned by GetVpnConnectionDeviceTypes in paginated output. When this parameter is used, GetVpnConnectionDeviceTypes only returns MaxResults results in a single page along with a NextToken response element. The remaining results of the initial request can be seen by sending another GetVpnConnectionDeviceTypes request with the returned NextToken value. This value can be between 200 and 1000. If this parameter is not used, then GetVpnConnectionDeviceTypes returns all results.
     */
    MaxResults?: GVCDMaxResults;
    /**
     * The NextToken value returned from a previous paginated GetVpnConnectionDeviceTypes request where MaxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the NextToken value. This value is null when there are no more results to return. 
     */
    NextToken?: NextToken;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetVpnConnectionDeviceTypesResult {
    /**
     * List of customer gateway devices that have a sample configuration file available for use.
     */
    VpnConnectionDeviceTypes?: VpnConnectionDeviceTypeList;
    /**
     * The NextToken value to include in a future GetVpnConnectionDeviceTypes request. When the results of a GetVpnConnectionDeviceTypes request exceed MaxResults, this value can be used to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: NextToken;
  }
  export interface GetVpnTunnelReplacementStatusRequest {
    /**
     * The ID of the Site-to-Site VPN connection. 
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The external IP address of the VPN tunnel.
     */
    VpnTunnelOutsideIpAddress: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface GetVpnTunnelReplacementStatusResult {
    /**
     * The ID of the Site-to-Site VPN connection. 
     */
    VpnConnectionId?: VpnConnectionId;
    /**
     * The ID of the transit gateway associated with the VPN connection.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the customer gateway.
     */
    CustomerGatewayId?: CustomerGatewayId;
    /**
     * The ID of the virtual private gateway.
     */
    VpnGatewayId?: VpnGatewayId;
    /**
     * The external IP address of the VPN tunnel.
     */
    VpnTunnelOutsideIpAddress?: String;
    /**
     * Get details of pending tunnel endpoint maintenance.
     */
    MaintenanceDetails?: MaintenanceDetails;
  }
  export type GpuDeviceCount = number;
  export interface GpuDeviceInfo {
    /**
     * The name of the GPU accelerator.
     */
    Name?: GpuDeviceName;
    /**
     * The manufacturer of the GPU accelerator.
     */
    Manufacturer?: GpuDeviceManufacturerName;
    /**
     * The number of GPUs for the instance type.
     */
    Count?: GpuDeviceCount;
    /**
     * Describes the memory available to the GPU accelerator.
     */
    MemoryInfo?: GpuDeviceMemoryInfo;
  }
  export type GpuDeviceInfoList = GpuDeviceInfo[];
  export type GpuDeviceManufacturerName = string;
  export interface GpuDeviceMemoryInfo {
    /**
     * The size of the memory available to the GPU accelerator, in MiB.
     */
    SizeInMiB?: GpuDeviceMemorySize;
  }
  export type GpuDeviceMemorySize = number;
  export type GpuDeviceName = string;
  export interface GpuInfo {
    /**
     * Describes the GPU accelerators for the instance type.
     */
    Gpus?: GpuDeviceInfoList;
    /**
     * The total size of the memory for the GPU accelerators for the instance type, in MiB.
     */
    TotalGpuMemoryInMiB?: totalGpuMemory;
  }
  export type GroupIdStringList = SecurityGroupId[];
  export interface GroupIdentifier {
    /**
     * The name of the security group.
     */
    GroupName?: String;
    /**
     * The ID of the security group.
     */
    GroupId?: String;
  }
  export type GroupIdentifierList = GroupIdentifier[];
  export type GroupIdentifierSet = SecurityGroupIdentifier[];
  export type GroupIds = SecurityGroupId[];
  export type GroupNameStringList = SecurityGroupName[];
  export type HibernationFlag = boolean;
  export interface HibernationOptions {
    /**
     * If this parameter is set to true, your instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
     */
    Configured?: Boolean;
  }
  export interface HibernationOptionsRequest {
    /**
     * If you set this parameter to true, your instance is enabled for hibernation. Default: false 
     */
    Configured?: Boolean;
  }
  export interface HistoryRecord {
    /**
     * Information about the event.
     */
    EventInformation?: EventInformation;
    /**
     * The event type.    error - An error with the Spot Fleet request.    fleetRequestChange - A change in the status or configuration of the Spot Fleet request.    instanceChange - An instance was launched or terminated.    Information - An informational event.  
     */
    EventType?: EventType;
    /**
     * The date and time of the event, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    Timestamp?: DateTime;
  }
  export interface HistoryRecordEntry {
    /**
     * Information about the event.
     */
    EventInformation?: EventInformation;
    /**
     * The event type.
     */
    EventType?: FleetEventType;
    /**
     * The date and time of the event, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    Timestamp?: DateTime;
  }
  export type HistoryRecordSet = HistoryRecordEntry[];
  export type HistoryRecords = HistoryRecord[];
  export interface Host {
    /**
     * Whether auto-placement is on or off.
     */
    AutoPlacement?: AutoPlacement;
    /**
     * The Availability Zone of the Dedicated Host.
     */
    AvailabilityZone?: String;
    /**
     * Information about the instances running on the Dedicated Host.
     */
    AvailableCapacity?: AvailableCapacity;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The ID of the Dedicated Host.
     */
    HostId?: String;
    /**
     * The hardware specifications of the Dedicated Host.
     */
    HostProperties?: HostProperties;
    /**
     * The reservation ID of the Dedicated Host. This returns a null response if the Dedicated Host doesn't have an associated reservation.
     */
    HostReservationId?: String;
    /**
     * The IDs and instance type that are currently running on the Dedicated Host.
     */
    Instances?: HostInstanceList;
    /**
     * The Dedicated Host's state.
     */
    State?: AllocationState;
    /**
     * The time that the Dedicated Host was allocated.
     */
    AllocationTime?: DateTime;
    /**
     * The time that the Dedicated Host was released.
     */
    ReleaseTime?: DateTime;
    /**
     * Any tags assigned to the Dedicated Host.
     */
    Tags?: TagList;
    /**
     * Indicates whether host recovery is enabled or disabled for the Dedicated Host.
     */
    HostRecovery?: HostRecovery;
    /**
     * Indicates whether the Dedicated Host supports multiple instance types of the same instance family. If the value is on, the Dedicated Host supports multiple instance types in the instance family. If the value is off, the Dedicated Host supports a single instance type only.
     */
    AllowsMultipleInstanceTypes?: AllowsMultipleInstanceTypes;
    /**
     * The ID of the Amazon Web Services account that owns the Dedicated Host.
     */
    OwnerId?: String;
    /**
     * The ID of the Availability Zone in which the Dedicated Host is allocated.
     */
    AvailabilityZoneId?: String;
    /**
     * Indicates whether the Dedicated Host is in a host resource group. If memberOfServiceLinkedResourceGroup is true, the host is in a host resource group; otherwise, it is not.
     */
    MemberOfServiceLinkedResourceGroup?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Web Services Outpost on which the Dedicated Host is allocated.
     */
    OutpostArn?: String;
    /**
     * Indicates whether host maintenance is enabled or disabled for the Dedicated Host.
     */
    HostMaintenance?: HostMaintenance;
  }
  export interface HostInstance {
    /**
     * The ID of instance that is running on the Dedicated Host.
     */
    InstanceId?: String;
    /**
     * The instance type (for example, m3.medium) of the running instance.
     */
    InstanceType?: String;
    /**
     * The ID of the Amazon Web Services account that owns the instance.
     */
    OwnerId?: String;
  }
  export type HostInstanceList = HostInstance[];
  export type HostList = Host[];
  export type HostMaintenance = "on"|"off"|string;
  export interface HostOffering {
    /**
     * The currency of the offering.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The duration of the offering (in seconds).
     */
    Duration?: Integer;
    /**
     * The hourly price of the offering.
     */
    HourlyPrice?: String;
    /**
     * The instance family of the offering.
     */
    InstanceFamily?: String;
    /**
     * The ID of the offering.
     */
    OfferingId?: OfferingId;
    /**
     * The available payment option.
     */
    PaymentOption?: PaymentOption;
    /**
     * The upfront price of the offering. Does not apply to No Upfront offerings.
     */
    UpfrontPrice?: String;
  }
  export type HostOfferingSet = HostOffering[];
  export interface HostProperties {
    /**
     * The number of cores on the Dedicated Host.
     */
    Cores?: Integer;
    /**
     * The instance type supported by the Dedicated Host. For example, m5.large. If the host supports multiple instance types, no instanceType is returned.
     */
    InstanceType?: String;
    /**
     * The instance family supported by the Dedicated Host. For example, m5.
     */
    InstanceFamily?: String;
    /**
     * The number of sockets on the Dedicated Host.
     */
    Sockets?: Integer;
    /**
     * The total number of vCPUs on the Dedicated Host.
     */
    TotalVCpus?: Integer;
  }
  export type HostRecovery = "on"|"off"|string;
  export interface HostReservation {
    /**
     * The number of Dedicated Hosts the reservation is associated with.
     */
    Count?: Integer;
    /**
     * The currency in which the upfrontPrice and hourlyPrice amounts are specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The length of the reservation's term, specified in seconds. Can be 31536000 (1 year) | 94608000 (3 years).
     */
    Duration?: Integer;
    /**
     * The date and time that the reservation ends.
     */
    End?: DateTime;
    /**
     * The IDs of the Dedicated Hosts associated with the reservation.
     */
    HostIdSet?: ResponseHostIdSet;
    /**
     * The ID of the reservation that specifies the associated Dedicated Hosts.
     */
    HostReservationId?: HostReservationId;
    /**
     * The hourly price of the reservation.
     */
    HourlyPrice?: String;
    /**
     * The instance family of the Dedicated Host Reservation. The instance family on the Dedicated Host must be the same in order for it to benefit from the reservation.
     */
    InstanceFamily?: String;
    /**
     * The ID of the reservation. This remains the same regardless of which Dedicated Hosts are associated with it.
     */
    OfferingId?: OfferingId;
    /**
     * The payment option selected for this reservation.
     */
    PaymentOption?: PaymentOption;
    /**
     * The date and time that the reservation started.
     */
    Start?: DateTime;
    /**
     * The state of the reservation.
     */
    State?: ReservationState;
    /**
     * The upfront price of the reservation.
     */
    UpfrontPrice?: String;
    /**
     * Any tags assigned to the Dedicated Host Reservation.
     */
    Tags?: TagList;
  }
  export type HostReservationId = string;
  export type HostReservationIdSet = HostReservationId[];
  export type HostReservationSet = HostReservation[];
  export type HostTenancy = "dedicated"|"host"|string;
  export type HostnameType = "ip-name"|"resource-name"|string;
  export type Hour = number;
  export type HttpTokensState = "optional"|"required"|string;
  export type HypervisorType = "ovm"|"xen"|string;
  export type IKEVersionsList = IKEVersionsListValue[];
  export interface IKEVersionsListValue {
    /**
     * The IKE version.
     */
    Value?: String;
  }
  export type IKEVersionsRequestList = IKEVersionsRequestListValue[];
  export interface IKEVersionsRequestListValue {
    /**
     * The IKE version.
     */
    Value?: String;
  }
  export interface IamInstanceProfile {
    /**
     * The Amazon Resource Name (ARN) of the instance profile.
     */
    Arn?: String;
    /**
     * The ID of the instance profile.
     */
    Id?: String;
  }
  export interface IamInstanceProfileAssociation {
    /**
     * The ID of the association.
     */
    AssociationId?: String;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: IamInstanceProfile;
    /**
     * The state of the association.
     */
    State?: IamInstanceProfileAssociationState;
    /**
     * The time the IAM instance profile was associated with the instance.
     */
    Timestamp?: DateTime;
  }
  export type IamInstanceProfileAssociationId = string;
  export type IamInstanceProfileAssociationSet = IamInstanceProfileAssociation[];
  export type IamInstanceProfileAssociationState = "associating"|"associated"|"disassociating"|"disassociated"|string;
  export interface IamInstanceProfileSpecification {
    /**
     * The Amazon Resource Name (ARN) of the instance profile.
     */
    Arn?: String;
    /**
     * The name of the instance profile.
     */
    Name?: String;
  }
  export interface IcmpTypeCode {
    /**
     * The ICMP code. A value of -1 means all codes for the specified ICMP type.
     */
    Code?: Integer;
    /**
     * The ICMP type. A value of -1 means all types.
     */
    Type?: Integer;
  }
  export interface IdFormat {
    /**
     * The date in UTC at which you are permanently switched over to using longer IDs. If a deadline is not yet available for this resource type, this field is not returned.
     */
    Deadline?: DateTime;
    /**
     * The type of resource.
     */
    Resource?: String;
    /**
     * Indicates whether longer IDs (17-character IDs) are enabled for the resource.
     */
    UseLongIds?: Boolean;
  }
  export type IdFormatList = IdFormat[];
  export type Igmpv2SupportValue = "enable"|"disable"|string;
  export interface Image {
    /**
     * The architecture of the image.
     */
    Architecture?: ArchitectureValues;
    /**
     * The date and time the image was created.
     */
    CreationDate?: String;
    /**
     * The ID of the AMI.
     */
    ImageId?: String;
    /**
     * The location of the AMI.
     */
    ImageLocation?: String;
    /**
     * The type of image.
     */
    ImageType?: ImageTypeValues;
    /**
     * Indicates whether the image has public launch permissions. The value is true if this image has public launch permissions or false if it has only implicit and explicit launch permissions.
     */
    Public?: Boolean;
    /**
     * The kernel associated with the image, if any. Only applicable for machine images.
     */
    KernelId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the image.
     */
    OwnerId?: String;
    /**
     * This value is set to windows for Windows AMIs; otherwise, it is blank.
     */
    Platform?: PlatformValues;
    /**
     * The platform details associated with the billing code of the AMI. For more information, see Understand AMI billing information in the Amazon EC2 User Guide.
     */
    PlatformDetails?: String;
    /**
     * The operation of the Amazon EC2 instance and the billing code that is associated with the AMI. usageOperation corresponds to the lineitem/Operation column on your Amazon Web Services Cost and Usage Report and in the Amazon Web Services Price List API. You can view these fields on the Instances or AMIs pages in the Amazon EC2 console, or in the responses that are returned by the DescribeImages command in the Amazon EC2 API, or the describe-images command in the CLI.
     */
    UsageOperation?: String;
    /**
     * Any product codes associated with the AMI.
     */
    ProductCodes?: ProductCodeList;
    /**
     * The RAM disk associated with the image, if any. Only applicable for machine images.
     */
    RamdiskId?: String;
    /**
     * The current state of the AMI. If the state is available, the image is successfully registered and can be used to launch an instance.
     */
    State?: ImageState;
    /**
     * Any block device mapping entries.
     */
    BlockDeviceMappings?: BlockDeviceMappingList;
    /**
     * The description of the AMI that was provided during image creation.
     */
    Description?: String;
    /**
     * Specifies whether enhanced networking with ENA is enabled.
     */
    EnaSupport?: Boolean;
    /**
     * The hypervisor type of the image.
     */
    Hypervisor?: HypervisorType;
    /**
     * The Amazon Web Services account alias (for example, amazon, self) or the Amazon Web Services account ID of the AMI owner.
     */
    ImageOwnerAlias?: String;
    /**
     * The name of the AMI that was provided during image creation.
     */
    Name?: String;
    /**
     * The device name of the root device volume (for example, /dev/sda1).
     */
    RootDeviceName?: String;
    /**
     * The type of root device used by the AMI. The AMI can use an Amazon EBS volume or an instance store volume.
     */
    RootDeviceType?: DeviceType;
    /**
     * Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
     */
    SriovNetSupport?: String;
    /**
     * The reason for the state change.
     */
    StateReason?: StateReason;
    /**
     * Any tags assigned to the image.
     */
    Tags?: TagList;
    /**
     * The type of virtualization of the AMI.
     */
    VirtualizationType?: VirtualizationType;
    /**
     * The boot mode of the image. For more information, see Boot modes in the Amazon EC2 User Guide.
     */
    BootMode?: BootModeValues;
    /**
     * If the image is configured for NitroTPM support, the value is v2.0. For more information, see NitroTPM in the Amazon EC2 User Guide.
     */
    TpmSupport?: TpmSupportValues;
    /**
     * The date and time to deprecate the AMI, in UTC, in the following format: YYYY-MM-DDTHH:MM:SSZ. If you specified a value for seconds, Amazon EC2 rounds the seconds to the nearest minute.
     */
    DeprecationTime?: String;
    /**
     * If v2.0, it indicates that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.
     */
    ImdsSupport?: ImdsSupportValues;
  }
  export interface ImageAttribute {
    /**
     * The block device mapping entries.
     */
    BlockDeviceMappings?: BlockDeviceMappingList;
    /**
     * The ID of the AMI.
     */
    ImageId?: String;
    /**
     * The launch permissions.
     */
    LaunchPermissions?: LaunchPermissionList;
    /**
     * The product codes.
     */
    ProductCodes?: ProductCodeList;
    /**
     * A description for the AMI.
     */
    Description?: AttributeValue;
    /**
     * The kernel ID.
     */
    KernelId?: AttributeValue;
    /**
     * The RAM disk ID.
     */
    RamdiskId?: AttributeValue;
    /**
     * Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
     */
    SriovNetSupport?: AttributeValue;
    /**
     * The boot mode.
     */
    BootMode?: AttributeValue;
    /**
     * If the image is configured for NitroTPM support, the value is v2.0.
     */
    TpmSupport?: AttributeValue;
    /**
     * Base64 representation of the non-volatile UEFI variable store. To retrieve the UEFI data, use the GetInstanceUefiData command. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub. For more information, see UEFI Secure Boot in the Amazon EC2 User Guide.
     */
    UefiData?: AttributeValue;
    /**
     * The date and time, in ISO 8601 date-time format, when the AMI was last used to launch an EC2 instance. When the AMI is used to launch an instance, there is a 24-hour delay before that usage is reported.   lastLaunchedTime data is available starting April 2017. 
     */
    LastLaunchedTime?: AttributeValue;
    /**
     * If v2.0, it indicates that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.
     */
    ImdsSupport?: AttributeValue;
  }
  export type ImageAttributeName = "description"|"kernel"|"ramdisk"|"launchPermission"|"productCodes"|"blockDeviceMapping"|"sriovNetSupport"|"bootMode"|"tpmSupport"|"uefiData"|"lastLaunchedTime"|"imdsSupport"|string;
  export interface ImageDiskContainer {
    /**
     * The description of the disk image.
     */
    Description?: String;
    /**
     * The block device mapping for the disk.
     */
    DeviceName?: String;
    /**
     * The format of the disk image being imported. Valid values: OVA | VHD | VHDX | VMDK | RAW 
     */
    Format?: String;
    /**
     * The ID of the EBS snapshot to be used for importing the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The URL to the Amazon S3-based disk image being imported. The URL can either be a https URL (https://..) or an Amazon S3 URL (s3://..)
     */
    Url?: String;
    /**
     * The S3 bucket for the disk image.
     */
    UserBucket?: UserBucket;
  }
  export type ImageDiskContainerList = ImageDiskContainer[];
  export type ImageId = string;
  export type ImageIdList = ImageId[];
  export type ImageIdStringList = ImageId[];
  export type ImageList = Image[];
  export interface ImageRecycleBinInfo {
    /**
     * The ID of the AMI.
     */
    ImageId?: String;
    /**
     * The name of the AMI.
     */
    Name?: String;
    /**
     * The description of the AMI.
     */
    Description?: String;
    /**
     * The date and time when the AMI entered the Recycle Bin.
     */
    RecycleBinEnterTime?: MillisecondDateTime;
    /**
     * The date and time when the AMI is to be permanently deleted from the Recycle Bin.
     */
    RecycleBinExitTime?: MillisecondDateTime;
  }
  export type ImageRecycleBinInfoList = ImageRecycleBinInfo[];
  export type ImageState = "pending"|"available"|"invalid"|"deregistered"|"transient"|"failed"|"error"|string;
  export type ImageTypeValues = "machine"|"kernel"|"ramdisk"|string;
  export type ImdsSupportValues = "v2.0"|string;
  export interface ImportClientVpnClientCertificateRevocationListRequest {
    /**
     * The ID of the Client VPN endpoint to which the client certificate revocation list applies.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The client certificate revocation list file. For more information, see Generate a Client Certificate Revocation List in the Client VPN Administrator Guide.
     */
    CertificateRevocationList: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ImportClientVpnClientCertificateRevocationListResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ImportImageLicenseConfigurationRequest {
    /**
     * The ARN of a license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export interface ImportImageLicenseConfigurationResponse {
    /**
     * The ARN of a license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export type ImportImageLicenseSpecificationListRequest = ImportImageLicenseConfigurationRequest[];
  export type ImportImageLicenseSpecificationListResponse = ImportImageLicenseConfigurationResponse[];
  export interface ImportImageRequest {
    /**
     * The architecture of the virtual machine. Valid values: i386 | x86_64 
     */
    Architecture?: String;
    /**
     * The client-specific data.
     */
    ClientData?: ClientData;
    /**
     * The token to enable idempotency for VM import requests.
     */
    ClientToken?: String;
    /**
     * A description string for the import image task.
     */
    Description?: String;
    /**
     * Information about the disk containers.
     */
    DiskContainers?: ImageDiskContainerList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specifies whether the destination AMI of the imported image should be encrypted. The default KMS key for EBS is used unless you specify a non-default KMS key using KmsKeyId. For more information, see Amazon EBS Encryption in the Amazon Elastic Compute Cloud User Guide.
     */
    Encrypted?: Boolean;
    /**
     * The target hypervisor platform. Valid values: xen 
     */
    Hypervisor?: String;
    /**
     * An identifier for the symmetric KMS key to use when creating the encrypted AMI. This parameter is only required if you want to use a non-default KMS key; if this parameter is not specified, the default KMS key for EBS is used. If a KmsKeyId is specified, the Encrypted flag must also be set.  The KMS key identifier may be provided in any of the following formats:    Key ID   Key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the alias namespace, and then the key alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   ARN using key ID. The ID ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the key namespace, and then the key ID. For example, arn:aws:kms:us-east-1:012345678910:key/abcd1234-a123-456a-a12b-a123b4cd56ef.   ARN using key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the alias namespace, and then the key alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.    Amazon Web Services parses KmsKeyId asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.  The specified KMS key must exist in the Region that the AMI is being copied to. Amazon EBS does not support asymmetric KMS keys.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The license type to be used for the Amazon Machine Image (AMI) after importing. Specify AWS to replace the source-system license with an Amazon Web Services license or BYOL to retain the source-system license. Leaving this parameter undefined is the same as choosing AWS when importing a Windows Server operating system, and the same as choosing BYOL when importing a Windows client operating system (such as Windows 10) or a Linux operating system. To use BYOL, you must have existing licenses with rights to use these licenses in a third party cloud, such as Amazon Web Services. For more information, see Prerequisites in the VM Import/Export User Guide.
     */
    LicenseType?: String;
    /**
     * The operating system of the virtual machine. Valid values: Windows | Linux 
     */
    Platform?: String;
    /**
     * The name of the role to use when not using the default role, 'vmimport'.
     */
    RoleName?: String;
    /**
     * The ARNs of the license configurations.
     */
    LicenseSpecifications?: ImportImageLicenseSpecificationListRequest;
    /**
     * The tags to apply to the import image task during creation.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The usage operation value. For more information, see Licensing options in the VM Import/Export User Guide.
     */
    UsageOperation?: String;
    /**
     * The boot mode of the virtual machine.
     */
    BootMode?: BootModeValues;
  }
  export interface ImportImageResult {
    /**
     * The architecture of the virtual machine.
     */
    Architecture?: String;
    /**
     * A description of the import task.
     */
    Description?: String;
    /**
     * Indicates whether the AMI is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The target hypervisor of the import task.
     */
    Hypervisor?: String;
    /**
     * The ID of the Amazon Machine Image (AMI) created by the import task.
     */
    ImageId?: String;
    /**
     * The task ID of the import image task.
     */
    ImportTaskId?: ImportImageTaskId;
    /**
     * The identifier for the symmetric KMS key that was used to create the encrypted AMI.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The license type of the virtual machine.
     */
    LicenseType?: String;
    /**
     * The operating system of the virtual machine.
     */
    Platform?: String;
    /**
     * The progress of the task.
     */
    Progress?: String;
    /**
     * Information about the snapshots.
     */
    SnapshotDetails?: SnapshotDetailList;
    /**
     * A brief status of the task.
     */
    Status?: String;
    /**
     * A detailed status message of the import task.
     */
    StatusMessage?: String;
    /**
     * The ARNs of the license configurations.
     */
    LicenseSpecifications?: ImportImageLicenseSpecificationListResponse;
    /**
     * Any tags assigned to the import image task.
     */
    Tags?: TagList;
    /**
     * The usage operation value.
     */
    UsageOperation?: String;
  }
  export interface ImportImageTask {
    /**
     * The architecture of the virtual machine. Valid values: i386 | x86_64 | arm64 
     */
    Architecture?: String;
    /**
     * A description of the import task.
     */
    Description?: String;
    /**
     * Indicates whether the image is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The target hypervisor for the import task. Valid values: xen 
     */
    Hypervisor?: String;
    /**
     * The ID of the Amazon Machine Image (AMI) of the imported virtual machine.
     */
    ImageId?: String;
    /**
     * The ID of the import image task.
     */
    ImportTaskId?: String;
    /**
     * The identifier for the KMS key that was used to create the encrypted image.
     */
    KmsKeyId?: String;
    /**
     * The license type of the virtual machine.
     */
    LicenseType?: String;
    /**
     * The description string for the import image task.
     */
    Platform?: String;
    /**
     * The percentage of progress of the import image task.
     */
    Progress?: String;
    /**
     * Information about the snapshots.
     */
    SnapshotDetails?: SnapshotDetailList;
    /**
     * A brief status for the import image task.
     */
    Status?: String;
    /**
     * A descriptive status message for the import image task.
     */
    StatusMessage?: String;
    /**
     * The tags for the import image task.
     */
    Tags?: TagList;
    /**
     * The ARNs of the license configurations that are associated with the import image task.
     */
    LicenseSpecifications?: ImportImageLicenseSpecificationListResponse;
    /**
     * The usage operation value.
     */
    UsageOperation?: String;
    /**
     * The boot mode of the virtual machine.
     */
    BootMode?: BootModeValues;
  }
  export type ImportImageTaskId = string;
  export type ImportImageTaskList = ImportImageTask[];
  export interface ImportInstanceLaunchSpecification {
    /**
     * Reserved.
     */
    AdditionalInfo?: String;
    /**
     * The architecture of the instance.
     */
    Architecture?: ArchitectureValues;
    /**
     * The security group IDs.
     */
    GroupIds?: SecurityGroupIdStringList;
    /**
     * The security group names.
     */
    GroupNames?: SecurityGroupStringList;
    /**
     * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
     */
    InstanceInitiatedShutdownBehavior?: ShutdownBehavior;
    /**
     * The instance type. For more information about the instance types that you can import, see Instance Types in the VM Import/Export User Guide.
     */
    InstanceType?: InstanceType;
    /**
     * Indicates whether monitoring is enabled.
     */
    Monitoring?: Boolean;
    /**
     * The placement information for the instance.
     */
    Placement?: Placement;
    /**
     * [EC2-VPC] An available IP address from the IP address range of the subnet.
     */
    PrivateIpAddress?: String;
    /**
     * [EC2-VPC] The ID of the subnet in which to launch the instance.
     */
    SubnetId?: SubnetId;
    /**
     * The Base64-encoded user data to make available to the instance.
     */
    UserData?: UserData;
  }
  export interface ImportInstanceRequest {
    /**
     * A description for the instance being imported.
     */
    Description?: String;
    /**
     * The disk image.
     */
    DiskImages?: DiskImageList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The launch specification.
     */
    LaunchSpecification?: ImportInstanceLaunchSpecification;
    /**
     * The instance operating system.
     */
    Platform: PlatformValues;
  }
  export interface ImportInstanceResult {
    /**
     * Information about the conversion task.
     */
    ConversionTask?: ConversionTask;
  }
  export interface ImportInstanceTaskDetails {
    /**
     * A description of the task.
     */
    Description?: String;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The instance operating system.
     */
    Platform?: PlatformValues;
    /**
     * The volumes.
     */
    Volumes?: ImportInstanceVolumeDetailSet;
  }
  export interface ImportInstanceVolumeDetailItem {
    /**
     * The Availability Zone where the resulting instance will reside.
     */
    AvailabilityZone?: String;
    /**
     * The number of bytes converted so far.
     */
    BytesConverted?: Long;
    /**
     * A description of the task.
     */
    Description?: String;
    /**
     * The image.
     */
    Image?: DiskImageDescription;
    /**
     * The status of the import of this particular disk image.
     */
    Status?: String;
    /**
     * The status information or errors related to the disk image.
     */
    StatusMessage?: String;
    /**
     * The volume.
     */
    Volume?: DiskImageVolumeDescription;
  }
  export type ImportInstanceVolumeDetailSet = ImportInstanceVolumeDetailItem[];
  export interface ImportKeyPairRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique name for the key pair.
     */
    KeyName: String;
    /**
     * The public key. For API calls, the text must be base64-encoded. For command line tools, base64 encoding is performed for you.
     */
    PublicKeyMaterial: _Blob;
    /**
     * The tags to apply to the imported key pair.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface ImportKeyPairResult {
    /**
     *   For RSA key pairs, the key fingerprint is the MD5 public key fingerprint as specified in section 4 of RFC 4716.   For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.  
     */
    KeyFingerprint?: String;
    /**
     * The key pair name that you provided.
     */
    KeyName?: String;
    /**
     * The ID of the resulting key pair.
     */
    KeyPairId?: String;
    /**
     * The tags applied to the imported key pair.
     */
    Tags?: TagList;
  }
  export type ImportManifestUrl = string;
  export interface ImportSnapshotRequest {
    /**
     * The client-specific data.
     */
    ClientData?: ClientData;
    /**
     * Token to enable idempotency for VM import requests.
     */
    ClientToken?: String;
    /**
     * The description string for the import snapshot task.
     */
    Description?: String;
    /**
     * Information about the disk container.
     */
    DiskContainer?: SnapshotDiskContainer;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specifies whether the destination snapshot of the imported image should be encrypted. The default KMS key for EBS is used unless you specify a non-default KMS key using KmsKeyId. For more information, see Amazon EBS Encryption in the Amazon Elastic Compute Cloud User Guide.
     */
    Encrypted?: Boolean;
    /**
     * An identifier for the symmetric KMS key to use when creating the encrypted snapshot. This parameter is only required if you want to use a non-default KMS key; if this parameter is not specified, the default KMS key for EBS is used. If a KmsKeyId is specified, the Encrypted flag must also be set.  The KMS key identifier may be provided in any of the following formats:    Key ID   Key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the alias namespace, and then the key alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   ARN using key ID. The ID ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the key namespace, and then the key ID. For example, arn:aws:kms:us-east-1:012345678910:key/abcd1234-a123-456a-a12b-a123b4cd56ef.   ARN using key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the key, the Amazon Web Services account ID of the key owner, the alias namespace, and then the key alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.    Amazon Web Services parses KmsKeyId asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.  The specified KMS key must exist in the Region that the snapshot is being copied to. Amazon EBS does not support asymmetric KMS keys.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The name of the role to use when not using the default role, 'vmimport'.
     */
    RoleName?: String;
    /**
     * The tags to apply to the import snapshot task during creation.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface ImportSnapshotResult {
    /**
     * A description of the import snapshot task.
     */
    Description?: String;
    /**
     * The ID of the import snapshot task.
     */
    ImportTaskId?: String;
    /**
     * Information about the import snapshot task.
     */
    SnapshotTaskDetail?: SnapshotTaskDetail;
    /**
     * Any tags assigned to the import snapshot task.
     */
    Tags?: TagList;
  }
  export interface ImportSnapshotTask {
    /**
     * A description of the import snapshot task.
     */
    Description?: String;
    /**
     * The ID of the import snapshot task.
     */
    ImportTaskId?: String;
    /**
     * Describes an import snapshot task.
     */
    SnapshotTaskDetail?: SnapshotTaskDetail;
    /**
     * The tags for the import snapshot task.
     */
    Tags?: TagList;
  }
  export type ImportSnapshotTaskId = string;
  export type ImportSnapshotTaskIdList = ImportSnapshotTaskId[];
  export type ImportSnapshotTaskList = ImportSnapshotTask[];
  export type ImportTaskId = string;
  export type ImportTaskIdList = ImportImageTaskId[];
  export interface ImportVolumeRequest {
    /**
     * The Availability Zone for the resulting EBS volume.
     */
    AvailabilityZone: String;
    /**
     * A description of the volume.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The disk image.
     */
    Image: DiskImageDetail;
    /**
     * The volume size.
     */
    Volume: VolumeDetail;
  }
  export interface ImportVolumeResult {
    /**
     * Information about the conversion task.
     */
    ConversionTask?: ConversionTask;
  }
  export interface ImportVolumeTaskDetails {
    /**
     * The Availability Zone where the resulting volume will reside.
     */
    AvailabilityZone?: String;
    /**
     * The number of bytes converted so far.
     */
    BytesConverted?: Long;
    /**
     * The description you provided when starting the import volume task.
     */
    Description?: String;
    /**
     * The image.
     */
    Image?: DiskImageDescription;
    /**
     * The volume.
     */
    Volume?: DiskImageVolumeDescription;
  }
  export interface InferenceAcceleratorInfo {
    /**
     * Describes the Inference accelerators for the instance type.
     */
    Accelerators?: InferenceDeviceInfoList;
  }
  export type InferenceDeviceCount = number;
  export interface InferenceDeviceInfo {
    /**
     * The number of Inference accelerators for the instance type.
     */
    Count?: InferenceDeviceCount;
    /**
     * The name of the Inference accelerator.
     */
    Name?: InferenceDeviceName;
    /**
     * The manufacturer of the Inference accelerator.
     */
    Manufacturer?: InferenceDeviceManufacturerName;
  }
  export type InferenceDeviceInfoList = InferenceDeviceInfo[];
  export type InferenceDeviceManufacturerName = string;
  export type InferenceDeviceName = string;
  export type InsideCidrBlocksStringList = String[];
  export interface Instance {
    /**
     * The AMI launch index, which can be used to find this instance in the launch group.
     */
    AmiLaunchIndex?: Integer;
    /**
     * The ID of the AMI used to launch the instance.
     */
    ImageId?: String;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The kernel associated with this instance, if applicable.
     */
    KernelId?: String;
    /**
     * The name of the key pair, if this instance was launched with an associated key pair.
     */
    KeyName?: String;
    /**
     * The time the instance was launched.
     */
    LaunchTime?: DateTime;
    /**
     * The monitoring for the instance.
     */
    Monitoring?: Monitoring;
    /**
     * The location where the instance launched, if applicable.
     */
    Placement?: Placement;
    /**
     * The value is Windows for Windows instances; otherwise blank.
     */
    Platform?: PlatformValues;
    /**
     * (IPv4 only) The private DNS hostname name assigned to the instance. This DNS hostname can only be used inside the Amazon EC2 network. This name is not available until the instance enters the running state.  [EC2-VPC] The Amazon-provided DNS server resolves Amazon-provided private DNS hostnames if you've enabled DNS resolution and DNS hostnames in your VPC. If you are not using the Amazon-provided DNS server in your VPC, your custom domain name servers must resolve the hostname as appropriate.
     */
    PrivateDnsName?: String;
    /**
     * The private IPv4 address assigned to the instance.
     */
    PrivateIpAddress?: String;
    /**
     * The product codes attached to this instance, if applicable.
     */
    ProductCodes?: ProductCodeList;
    /**
     * (IPv4 only) The public DNS name assigned to the instance. This name is not available until the instance enters the running state. For EC2-VPC, this name is only available if you've enabled DNS hostnames for your VPC.
     */
    PublicDnsName?: String;
    /**
     * The public IPv4 address, or the Carrier IP address assigned to the instance, if applicable. A Carrier IP address only applies to an instance launched in a subnet associated with a Wavelength Zone.
     */
    PublicIpAddress?: String;
    /**
     * The RAM disk associated with this instance, if applicable.
     */
    RamdiskId?: String;
    /**
     * The current state of the instance.
     */
    State?: InstanceState;
    /**
     * The reason for the most recent state transition. This might be an empty string.
     */
    StateTransitionReason?: String;
    /**
     * [EC2-VPC] The ID of the subnet in which the instance is running.
     */
    SubnetId?: String;
    /**
     * [EC2-VPC] The ID of the VPC in which the instance is running.
     */
    VpcId?: String;
    /**
     * The architecture of the image.
     */
    Architecture?: ArchitectureValues;
    /**
     * Any block device mapping entries for the instance.
     */
    BlockDeviceMappings?: InstanceBlockDeviceMappingList;
    /**
     * The idempotency token you provided when you launched the instance, if applicable.
     */
    ClientToken?: String;
    /**
     * Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
     */
    EbsOptimized?: Boolean;
    /**
     * Specifies whether enhanced networking with ENA is enabled.
     */
    EnaSupport?: Boolean;
    /**
     * The hypervisor type of the instance. The value xen is used for both Xen and Nitro hypervisors.
     */
    Hypervisor?: HypervisorType;
    /**
     * The IAM instance profile associated with the instance, if applicable.
     */
    IamInstanceProfile?: IamInstanceProfile;
    /**
     * Indicates whether this is a Spot Instance or a Scheduled Instance.
     */
    InstanceLifecycle?: InstanceLifecycleType;
    /**
     * The Elastic GPU associated with the instance.
     */
    ElasticGpuAssociations?: ElasticGpuAssociationList;
    /**
     * The elastic inference accelerator associated with the instance.
     */
    ElasticInferenceAcceleratorAssociations?: ElasticInferenceAcceleratorAssociationList;
    /**
     * [EC2-VPC] The network interfaces for the instance.
     */
    NetworkInterfaces?: InstanceNetworkInterfaceList;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The device name of the root device volume (for example, /dev/sda1).
     */
    RootDeviceName?: String;
    /**
     * The root device type used by the AMI. The AMI can use an EBS volume or an instance store volume.
     */
    RootDeviceType?: DeviceType;
    /**
     * The security groups for the instance.
     */
    SecurityGroups?: GroupIdentifierList;
    /**
     * Indicates whether source/destination checking is enabled.
     */
    SourceDestCheck?: Boolean;
    /**
     * If the request is a Spot Instance request, the ID of the request.
     */
    SpotInstanceRequestId?: String;
    /**
     * Specifies whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
     */
    SriovNetSupport?: String;
    /**
     * The reason for the most recent state transition.
     */
    StateReason?: StateReason;
    /**
     * Any tags assigned to the instance.
     */
    Tags?: TagList;
    /**
     * The virtualization type of the instance.
     */
    VirtualizationType?: VirtualizationType;
    /**
     * The CPU options for the instance.
     */
    CpuOptions?: CpuOptions;
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId?: String;
    /**
     * Information about the Capacity Reservation targeting option.
     */
    CapacityReservationSpecification?: CapacityReservationSpecificationResponse;
    /**
     * Indicates whether the instance is enabled for hibernation.
     */
    HibernationOptions?: HibernationOptions;
    /**
     * The license configurations for the instance.
     */
    Licenses?: LicenseList;
    /**
     * The metadata options for the instance.
     */
    MetadataOptions?: InstanceMetadataOptionsResponse;
    /**
     * Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
     */
    EnclaveOptions?: EnclaveOptions;
    /**
     * The boot mode that was specified by the AMI. If the value is uefi-preferred, the AMI supports both UEFI and Legacy BIOS. The currentInstanceBootMode parameter is the boot mode that is used to boot the instance at launch or start.  The operating system contained in the AMI must be configured to support the specified boot mode.  For more information, see Boot modes in the Amazon EC2 User Guide.
     */
    BootMode?: BootModeValues;
    /**
     * The platform details value for the instance. For more information, see AMI billing information fields in the Amazon EC2 User Guide.
     */
    PlatformDetails?: String;
    /**
     * The usage operation value for the instance. For more information, see AMI billing information fields in the Amazon EC2 User Guide.
     */
    UsageOperation?: String;
    /**
     * The time that the usage operation was last updated.
     */
    UsageOperationUpdateTime?: MillisecondDateTime;
    /**
     * The options for the instance hostname.
     */
    PrivateDnsNameOptions?: PrivateDnsNameOptionsResponse;
    /**
     * The IPv6 address assigned to the instance.
     */
    Ipv6Address?: String;
    /**
     * If the instance is configured for NitroTPM support, the value is v2.0. For more information, see NitroTPM in the Amazon EC2 User Guide.
     */
    TpmSupport?: String;
    /**
     * Provides information on the recovery and maintenance options of your instance.
     */
    MaintenanceOptions?: InstanceMaintenanceOptions;
    /**
     * The boot mode that is used to boot the instance at launch or start. For more information, see Boot modes in the Amazon EC2 User Guide.
     */
    CurrentInstanceBootMode?: InstanceBootModeValues;
  }
  export interface InstanceAttribute {
    /**
     * The security groups associated with the instance.
     */
    Groups?: GroupIdentifierList;
    /**
     * The block device mapping of the instance.
     */
    BlockDeviceMappings?: InstanceBlockDeviceMappingList;
    /**
     * If the value is true, you can't terminate the instance through the Amazon EC2 console, CLI, or API; otherwise, you can.
     */
    DisableApiTermination?: AttributeBooleanValue;
    /**
     * Indicates whether enhanced networking with ENA is enabled.
     */
    EnaSupport?: AttributeBooleanValue;
    /**
     * To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to true; otherwise, set it to false.
     */
    EnclaveOptions?: EnclaveOptions;
    /**
     * Indicates whether the instance is optimized for Amazon EBS I/O.
     */
    EbsOptimized?: AttributeBooleanValue;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
     */
    InstanceInitiatedShutdownBehavior?: AttributeValue;
    /**
     * The instance type.
     */
    InstanceType?: AttributeValue;
    /**
     * The kernel ID.
     */
    KernelId?: AttributeValue;
    /**
     * A list of product codes.
     */
    ProductCodes?: ProductCodeList;
    /**
     * The RAM disk ID.
     */
    RamdiskId?: AttributeValue;
    /**
     * The device name of the root device volume (for example, /dev/sda1).
     */
    RootDeviceName?: AttributeValue;
    /**
     * Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is true, source/destination checks are enabled; otherwise, they are disabled. The default value is true. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls.
     */
    SourceDestCheck?: AttributeBooleanValue;
    /**
     * Indicates whether enhanced networking with the Intel 82599 Virtual Function interface is enabled.
     */
    SriovNetSupport?: AttributeValue;
    /**
     * The user data.
     */
    UserData?: AttributeValue;
    /**
     * To enable the instance for Amazon Web Services Stop Protection, set this parameter to true; otherwise, set it to false.
     */
    DisableApiStop?: AttributeBooleanValue;
  }
  export type InstanceAttributeName = "instanceType"|"kernel"|"ramdisk"|"userData"|"disableApiTermination"|"instanceInitiatedShutdownBehavior"|"rootDeviceName"|"blockDeviceMapping"|"productCodes"|"sourceDestCheck"|"groupSet"|"ebsOptimized"|"sriovNetSupport"|"enaSupport"|"enclaveOptions"|"disableApiStop"|string;
  export type InstanceAutoRecoveryState = "disabled"|"default"|string;
  export interface InstanceBlockDeviceMapping {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    DeviceName?: String;
    /**
     * Parameters used to automatically set up EBS volumes when the instance is launched.
     */
    Ebs?: EbsInstanceBlockDevice;
  }
  export type InstanceBlockDeviceMappingList = InstanceBlockDeviceMapping[];
  export interface InstanceBlockDeviceMappingSpecification {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    DeviceName?: String;
    /**
     * Parameters used to automatically set up EBS volumes when the instance is launched.
     */
    Ebs?: EbsInstanceBlockDeviceSpecification;
    /**
     * suppress the specified device included in the block device mapping.
     */
    NoDevice?: String;
    /**
     * The virtual device name.
     */
    VirtualName?: String;
  }
  export type InstanceBlockDeviceMappingSpecificationList = InstanceBlockDeviceMappingSpecification[];
  export type InstanceBootModeValues = "legacy-bios"|"uefi"|string;
  export interface InstanceCapacity {
    /**
     * The number of instances that can be launched onto the Dedicated Host based on the host's available capacity.
     */
    AvailableCapacity?: Integer;
    /**
     * The instance type supported by the Dedicated Host.
     */
    InstanceType?: String;
    /**
     * The total number of instances that can be launched onto the Dedicated Host if there are no instances running on it.
     */
    TotalCapacity?: Integer;
  }
  export interface InstanceCount {
    /**
     * The number of listed Reserved Instances in the state specified by the state.
     */
    InstanceCount?: Integer;
    /**
     * The states of the listed Reserved Instances.
     */
    State?: ListingState;
  }
  export type InstanceCountList = InstanceCount[];
  export interface InstanceCreditSpecification {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The credit option for CPU usage of the instance. Valid values: standard | unlimited 
     */
    CpuCredits?: String;
  }
  export type InstanceCreditSpecificationList = InstanceCreditSpecification[];
  export type InstanceCreditSpecificationListRequest = InstanceCreditSpecificationRequest[];
  export interface InstanceCreditSpecificationRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The credit option for CPU usage of the instance. Valid values: standard | unlimited  T3 instances with host tenancy do not support the unlimited CPU credit option.
     */
    CpuCredits?: String;
  }
  export type InstanceEventId = string;
  export interface InstanceEventWindow {
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId?: InstanceEventWindowId;
    /**
     * One or more time ranges defined for the event window.
     */
    TimeRanges?: InstanceEventWindowTimeRangeList;
    /**
     * The name of the event window.
     */
    Name?: String;
    /**
     * The cron expression defined for the event window.
     */
    CronExpression?: InstanceEventWindowCronExpression;
    /**
     * One or more targets associated with the event window.
     */
    AssociationTarget?: InstanceEventWindowAssociationTarget;
    /**
     * The current state of the event window.
     */
    State?: InstanceEventWindowState;
    /**
     * The instance tags associated with the event window.
     */
    Tags?: TagList;
  }
  export interface InstanceEventWindowAssociationRequest {
    /**
     * The IDs of the instances to associate with the event window. If the instance is on a Dedicated Host, you can't specify the Instance ID parameter; you must use the Dedicated Host ID parameter.
     */
    InstanceIds?: InstanceIdList;
    /**
     * The instance tags to associate with the event window. Any instances associated with the tags will be associated with the event window.
     */
    InstanceTags?: TagList;
    /**
     * The IDs of the Dedicated Hosts to associate with the event window.
     */
    DedicatedHostIds?: DedicatedHostIdList;
  }
  export interface InstanceEventWindowAssociationTarget {
    /**
     * The IDs of the instances associated with the event window.
     */
    InstanceIds?: InstanceIdList;
    /**
     * The instance tags associated with the event window. Any instances associated with the tags will be associated with the event window.
     */
    Tags?: TagList;
    /**
     * The IDs of the Dedicated Hosts associated with the event window.
     */
    DedicatedHostIds?: DedicatedHostIdList;
  }
  export type InstanceEventWindowCronExpression = string;
  export interface InstanceEventWindowDisassociationRequest {
    /**
     * The IDs of the instances to disassociate from the event window.
     */
    InstanceIds?: InstanceIdList;
    /**
     * The instance tags to disassociate from the event window. Any instances associated with the tags will be disassociated from the event window.
     */
    InstanceTags?: TagList;
    /**
     * The IDs of the Dedicated Hosts to disassociate from the event window.
     */
    DedicatedHostIds?: DedicatedHostIdList;
  }
  export type InstanceEventWindowId = string;
  export type InstanceEventWindowIdSet = InstanceEventWindowId[];
  export type InstanceEventWindowSet = InstanceEventWindow[];
  export type InstanceEventWindowState = "creating"|"deleting"|"active"|"deleted"|string;
  export interface InstanceEventWindowStateChange {
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId?: InstanceEventWindowId;
    /**
     * The current state of the event window.
     */
    State?: InstanceEventWindowState;
  }
  export interface InstanceEventWindowTimeRange {
    /**
     * The day on which the time range begins.
     */
    StartWeekDay?: WeekDay;
    /**
     * The hour when the time range begins.
     */
    StartHour?: Hour;
    /**
     * The day on which the time range ends.
     */
    EndWeekDay?: WeekDay;
    /**
     * The hour when the time range ends.
     */
    EndHour?: Hour;
  }
  export type InstanceEventWindowTimeRangeList = InstanceEventWindowTimeRange[];
  export interface InstanceEventWindowTimeRangeRequest {
    /**
     * The day on which the time range begins.
     */
    StartWeekDay?: WeekDay;
    /**
     * The hour when the time range begins.
     */
    StartHour?: Hour;
    /**
     * The day on which the time range ends.
     */
    EndWeekDay?: WeekDay;
    /**
     * The hour when the time range ends.
     */
    EndHour?: Hour;
  }
  export type InstanceEventWindowTimeRangeRequestSet = InstanceEventWindowTimeRangeRequest[];
  export interface InstanceExportDetails {
    /**
     * The ID of the resource being exported.
     */
    InstanceId?: String;
    /**
     * The target virtualization environment.
     */
    TargetEnvironment?: ExportEnvironment;
  }
  export interface InstanceFamilyCreditSpecification {
    /**
     * The instance family.
     */
    InstanceFamily?: UnlimitedSupportedInstanceFamily;
    /**
     * The default credit option for CPU usage of the instance family. Valid values are standard and unlimited.
     */
    CpuCredits?: String;
  }
  export type InstanceGeneration = "current"|"previous"|string;
  export type InstanceGenerationSet = InstanceGeneration[];
  export type InstanceHealthStatus = "healthy"|"unhealthy"|string;
  export type InstanceId = string;
  export type InstanceIdForResolver = string;
  export type InstanceIdList = InstanceId[];
  export type InstanceIdSet = InstanceId[];
  export type InstanceIdStringList = InstanceId[];
  export type InstanceIdWithVolumeResolver = string;
  export type InstanceIdsSet = InstanceId[];
  export type InstanceInterruptionBehavior = "hibernate"|"stop"|"terminate"|string;
  export interface InstanceIpv4Prefix {
    /**
     * One or more IPv4 prefixes assigned to the network interface.
     */
    Ipv4Prefix?: String;
  }
  export type InstanceIpv4PrefixList = InstanceIpv4Prefix[];
  export interface InstanceIpv6Address {
    /**
     * The IPv6 address.
     */
    Ipv6Address?: String;
  }
  export type InstanceIpv6AddressList = InstanceIpv6Address[];
  export type InstanceIpv6AddressListRequest = InstanceIpv6AddressRequest[];
  export interface InstanceIpv6AddressRequest {
    /**
     * The IPv6 address.
     */
    Ipv6Address?: String;
  }
  export interface InstanceIpv6Prefix {
    /**
     * One or more IPv6 prefixes assigned to the network interface.
     */
    Ipv6Prefix?: String;
  }
  export type InstanceIpv6PrefixList = InstanceIpv6Prefix[];
  export type InstanceLifecycle = "spot"|"on-demand"|string;
  export type InstanceLifecycleType = "spot"|"scheduled"|string;
  export type InstanceList = Instance[];
  export interface InstanceMaintenanceOptions {
    /**
     * Provides information on the current automatic recovery behavior of your instance.
     */
    AutoRecovery?: InstanceAutoRecoveryState;
  }
  export interface InstanceMaintenanceOptionsRequest {
    /**
     * Disables the automatic recovery behavior of your instance or sets it to default. For more information, see Simplified automatic recovery.
     */
    AutoRecovery?: InstanceAutoRecoveryState;
  }
  export interface InstanceMarketOptionsRequest {
    /**
     * The market type.
     */
    MarketType?: MarketType;
    /**
     * The options for Spot Instances.
     */
    SpotOptions?: SpotMarketOptions;
  }
  export type InstanceMatchCriteria = "open"|"targeted"|string;
  export type InstanceMetadataEndpointState = "disabled"|"enabled"|string;
  export interface InstanceMetadataOptionsRequest {
    /**
     * IMDSv2 uses token-backed sessions. Set the use of HTTP tokens to optional (in other words, set the use of IMDSv2 to optional) or required (in other words, set the use of IMDSv2 to required).    optional - When IMDSv2 is optional, you can choose to retrieve instance metadata with or without a session token in your request. If you retrieve the IAM role credentials without a token, the IMDSv1 role credentials are returned. If you retrieve the IAM role credentials using a valid session token, the IMDSv2 role credentials are returned.    required - When IMDSv2 is required, you must send a session token with any instance metadata retrieval requests. In this state, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available.   Default: optional 
     */
    HttpTokens?: HttpTokensState;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. Default: 1 Possible values: Integers from 1 to 64
     */
    HttpPutResponseHopLimit?: Integer;
    /**
     * Enables or disables the HTTP metadata endpoint on your instances. If you specify a value of disabled, you cannot access your instance metadata. Default: enabled 
     */
    HttpEndpoint?: InstanceMetadataEndpointState;
    /**
     * Enables or disables the IPv6 endpoint for the instance metadata service.
     */
    HttpProtocolIpv6?: InstanceMetadataProtocolState;
    /**
     * Set to enabled to allow access to instance tags from the instance metadata. Set to disabled to turn off access to instance tags from the instance metadata. For more information, see Work with instance tags using the instance metadata. Default: disabled 
     */
    InstanceMetadataTags?: InstanceMetadataTagsState;
  }
  export interface InstanceMetadataOptionsResponse {
    /**
     * The state of the metadata option changes.  pending - The metadata options are being updated and the instance is not ready to process metadata traffic with the new selection.  applied - The metadata options have been successfully applied on the instance.
     */
    State?: InstanceMetadataOptionsState;
    /**
     * IMDSv2 uses token-backed sessions. Indicates whether the use of HTTP tokens is optional (in other words, indicates whether the use of IMDSv2 is optional) or required (in other words, indicates whether the use of IMDSv2 is required).    optional - When IMDSv2 is optional, you can choose to retrieve instance metadata with or without a session token in your request. If you retrieve the IAM role credentials without a token, the IMDSv1 role credentials are returned. If you retrieve the IAM role credentials using a valid session token, the IMDSv2 role credentials are returned.    required - When IMDSv2 is required, you must send a session token with any instance metadata retrieval requests. In this state, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available.   Default: optional 
     */
    HttpTokens?: HttpTokensState;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. Default: 1 Possible values: Integers from 1 to 64
     */
    HttpPutResponseHopLimit?: Integer;
    /**
     * Indicates whether the HTTP metadata endpoint on your instances is enabled or disabled. If the value is disabled, you cannot access your instance metadata.
     */
    HttpEndpoint?: InstanceMetadataEndpointState;
    /**
     * Indicates whether the IPv6 endpoint for the instance metadata service is enabled or disabled.
     */
    HttpProtocolIpv6?: InstanceMetadataProtocolState;
    /**
     * Indicates whether access to instance tags from the instance metadata is enabled or disabled. For more information, see Work with instance tags using the instance metadata.
     */
    InstanceMetadataTags?: InstanceMetadataTagsState;
  }
  export type InstanceMetadataOptionsState = "pending"|"applied"|string;
  export type InstanceMetadataProtocolState = "disabled"|"enabled"|string;
  export type InstanceMetadataTagsState = "disabled"|"enabled"|string;
  export interface InstanceMonitoring {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The monitoring for the instance.
     */
    Monitoring?: Monitoring;
  }
  export type InstanceMonitoringList = InstanceMonitoring[];
  export interface InstanceNetworkInterface {
    /**
     * The association information for an Elastic IPv4 associated with the network interface.
     */
    Association?: InstanceNetworkInterfaceAssociation;
    /**
     * The network interface attachment.
     */
    Attachment?: InstanceNetworkInterfaceAttachment;
    /**
     * The description.
     */
    Description?: String;
    /**
     * The security groups.
     */
    Groups?: GroupIdentifierList;
    /**
     * The IPv6 addresses associated with the network interface.
     */
    Ipv6Addresses?: InstanceIpv6AddressList;
    /**
     * The MAC address.
     */
    MacAddress?: String;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The ID of the Amazon Web Services account that created the network interface.
     */
    OwnerId?: String;
    /**
     * The private DNS name.
     */
    PrivateDnsName?: String;
    /**
     * The IPv4 address of the network interface within the subnet.
     */
    PrivateIpAddress?: String;
    /**
     * The private IPv4 addresses associated with the network interface.
     */
    PrivateIpAddresses?: InstancePrivateIpAddressList;
    /**
     * Indicates whether source/destination checking is enabled.
     */
    SourceDestCheck?: Boolean;
    /**
     * The status of the network interface.
     */
    Status?: NetworkInterfaceStatus;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The type of network interface. Valid values: interface | efa | trunk 
     */
    InterfaceType?: String;
    /**
     * The IPv4 delegated prefixes that are assigned to the network interface.
     */
    Ipv4Prefixes?: InstanceIpv4PrefixList;
    /**
     * The IPv6 delegated prefixes that are assigned to the network interface.
     */
    Ipv6Prefixes?: InstanceIpv6PrefixList;
  }
  export interface InstanceNetworkInterfaceAssociation {
    /**
     * The carrier IP address associated with the network interface.
     */
    CarrierIp?: String;
    /**
     * The customer-owned IP address associated with the network interface.
     */
    CustomerOwnedIp?: String;
    /**
     * The ID of the owner of the Elastic IP address.
     */
    IpOwnerId?: String;
    /**
     * The public DNS name.
     */
    PublicDnsName?: String;
    /**
     * The public IP address or Elastic IP address bound to the network interface.
     */
    PublicIp?: String;
  }
  export interface InstanceNetworkInterfaceAttachment {
    /**
     * The time stamp when the attachment initiated.
     */
    AttachTime?: DateTime;
    /**
     * The ID of the network interface attachment.
     */
    AttachmentId?: String;
    /**
     * Indicates whether the network interface is deleted when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The index of the device on the instance for the network interface attachment.
     */
    DeviceIndex?: Integer;
    /**
     * The attachment state.
     */
    Status?: AttachmentStatus;
    /**
     * The index of the network card.
     */
    NetworkCardIndex?: Integer;
  }
  export type InstanceNetworkInterfaceList = InstanceNetworkInterface[];
  export interface InstanceNetworkInterfaceSpecification {
    /**
     * Indicates whether to assign a public IPv4 address to an instance you launch in a VPC. The public IP address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is true.
     */
    AssociatePublicIpAddress?: Boolean;
    /**
     * If set to true, the interface is deleted when the instance is terminated. You can specify true only if creating a new network interface when launching an instance.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The description of the network interface. Applies only if creating a network interface when launching an instance.
     */
    Description?: String;
    /**
     * The position of the network interface in the attachment order. A primary network interface has a device index of 0. If you specify a network interface when launching an instance, you must specify the device index.
     */
    DeviceIndex?: Integer;
    /**
     * The IDs of the security groups for the network interface. Applies only if creating a network interface when launching an instance.
     */
    Groups?: SecurityGroupIdStringList;
    /**
     * A number of IPv6 addresses to assign to the network interface. Amazon EC2 chooses the IPv6 addresses from the range of the subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch.
     */
    Ipv6AddressCount?: Integer;
    /**
     * The IPv6 addresses to assign to the network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch.
     */
    Ipv6Addresses?: InstanceIpv6AddressList;
    /**
     * The ID of the network interface. If you are creating a Spot Fleet, omit this parameter because you can’t specify a network interface ID in a launch specification.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The private IPv4 address of the network interface. Applies only if creating a network interface when launching an instance. You cannot specify this option if you're launching more than one instance in a RunInstances request.
     */
    PrivateIpAddress?: String;
    /**
     * The private IPv4 addresses to assign to the network interface. Only one private IPv4 address can be designated as primary. You cannot specify this option if you're launching more than one instance in a RunInstances request.
     */
    PrivateIpAddresses?: PrivateIpAddressSpecificationList;
    /**
     * The number of secondary private IPv4 addresses. You can't specify this option and specify more than one private IP address using the private IP addresses option. You cannot specify this option if you're launching more than one instance in a RunInstances request.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * The ID of the subnet associated with the network interface. Applies only if creating a network interface when launching an instance.
     */
    SubnetId?: String;
    /**
     * Indicates whether to assign a carrier IP address to the network interface. You can only assign a carrier IP address to a network interface that is in a subnet in a Wavelength Zone. For more information about carrier IP addresses, see Carrier IP address in the Amazon Web Services Wavelength Developer Guide.
     */
    AssociateCarrierIpAddress?: Boolean;
    /**
     * The type of network interface. Valid values: interface | efa 
     */
    InterfaceType?: String;
    /**
     * The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0. If you are using RequestSpotInstances to create Spot Instances, omit this parameter because you can’t specify the network card index when using this API. To specify the network card index, use RunInstances.
     */
    NetworkCardIndex?: Integer;
    /**
     * The IPv4 delegated prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option.
     */
    Ipv4Prefixes?: Ipv4PrefixList;
    /**
     * The number of IPv4 delegated prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv4Prefix option.
     */
    Ipv4PrefixCount?: Integer;
    /**
     * The IPv6 delegated prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option.
     */
    Ipv6Prefixes?: Ipv6PrefixList;
    /**
     * The number of IPv6 delegated prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv6Prefix option.
     */
    Ipv6PrefixCount?: Integer;
  }
  export type InstanceNetworkInterfaceSpecificationList = InstanceNetworkInterfaceSpecification[];
  export interface InstancePrivateIpAddress {
    /**
     * The association information for an Elastic IP address for the network interface.
     */
    Association?: InstanceNetworkInterfaceAssociation;
    /**
     * Indicates whether this IPv4 address is the primary private IP address of the network interface.
     */
    Primary?: Boolean;
    /**
     * The private IPv4 DNS name.
     */
    PrivateDnsName?: String;
    /**
     * The private IPv4 address of the network interface.
     */
    PrivateIpAddress?: String;
  }
  export type InstancePrivateIpAddressList = InstancePrivateIpAddress[];
  export interface InstanceRequirements {
    /**
     * The minimum and maximum number of vCPUs.
     */
    VCpuCount?: VCpuCountRange;
    /**
     * The minimum and maximum amount of memory, in MiB.
     */
    MemoryMiB?: MemoryMiB;
    /**
     * The CPU manufacturers to include.   For instance types with Intel CPUs, specify intel.   For instance types with AMD CPUs, specify amd.   For instance types with Amazon Web Services CPUs, specify amazon-web-services.    Don't confuse the CPU manufacturer with the CPU architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.  Default: Any manufacturer
     */
    CpuManufacturers?: CpuManufacturerSet;
    /**
     * The minimum and maximum amount of memory per vCPU, in GiB. Default: No minimum or maximum limits
     */
    MemoryGiBPerVCpu?: MemoryGiBPerVCpu;
    /**
     * The instance types to exclude. You can use strings with one or more wild cards, represented by an asterisk (*), to exclude an instance type, size, or generation. The following are examples: m5.8xlarge, c5*.*, m5a.*, r*, *3*. For example, if you specify c5*,Amazon EC2 will exclude the entire C5 instance family, which includes all C5a and C5n instance types. If you specify m5a.*, Amazon EC2 will exclude all the M5a instance types, but not the M5n instance types.  If you specify ExcludedInstanceTypes, you can't specify AllowedInstanceTypes.  Default: No excluded instance types
     */
    ExcludedInstanceTypes?: ExcludedInstanceTypeSet;
    /**
     * Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Current generation instance types are typically the latest two to three generations in each instance family. For more information, see Instance types in the Amazon EC2 User Guide. For current generation instance types, specify current. For previous generation instance types, specify previous. Default: Current and previous generation instance types
     */
    InstanceGenerations?: InstanceGenerationSet;
    /**
     * The price protection threshold for Spot Instances. This is the maximum you’ll pay for a Spot Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold. The parameter accepts an integer, which Amazon EC2 interprets as a percentage. To turn off price protection, specify a high value, such as 999999. This parameter is not supported for GetSpotPlacementScores and GetInstanceTypesFromInstanceRequirements.  If you set TargetCapacityUnitType to vcpu or memory-mib, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.  Default: 100 
     */
    SpotMaxPricePercentageOverLowestPrice?: Integer;
    /**
     * The price protection threshold for On-Demand Instances. This is the maximum you’ll pay for an On-Demand Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold. The parameter accepts an integer, which Amazon EC2 interprets as a percentage. To turn off price protection, specify a high value, such as 999999. This parameter is not supported for GetSpotPlacementScores and GetInstanceTypesFromInstanceRequirements.  If you set TargetCapacityUnitType to vcpu or memory-mib, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.  Default: 20 
     */
    OnDemandMaxPricePercentageOverLowestPrice?: Integer;
    /**
     * Indicates whether bare metal instance types must be included, excluded, or required.   To include bare metal instance types, specify included.   To require only bare metal instance types, specify required.   To exclude bare metal instance types, specify excluded.   Default: excluded 
     */
    BareMetal?: BareMetal;
    /**
     * Indicates whether burstable performance T instance types are included, excluded, or required. For more information, see Burstable performance instances.   To include burstable performance instance types, specify included.   To require only burstable performance instance types, specify required.   To exclude burstable performance instance types, specify excluded.   Default: excluded 
     */
    BurstablePerformance?: BurstablePerformance;
    /**
     * Indicates whether instance types must support hibernation for On-Demand Instances. This parameter is not supported for GetSpotPlacementScores. Default: false 
     */
    RequireHibernateSupport?: Boolean;
    /**
     * The minimum and maximum number of network interfaces. Default: No minimum or maximum limits
     */
    NetworkInterfaceCount?: NetworkInterfaceCount;
    /**
     * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, Amazon EC2 instance store in the Amazon EC2 User Guide.   To include instance types with instance store volumes, specify included.   To require only instance types with instance store volumes, specify required.   To exclude instance types with instance store volumes, specify excluded.   Default: included 
     */
    LocalStorage?: LocalStorage;
    /**
     * The type of local storage that is required.   For instance types with hard disk drive (HDD) storage, specify hdd.   For instance types with solid state drive (SSD) storage, specify ssd.   Default: hdd and ssd 
     */
    LocalStorageTypes?: LocalStorageTypeSet;
    /**
     * The minimum and maximum amount of total local storage, in GB. Default: No minimum or maximum limits
     */
    TotalLocalStorageGB?: TotalLocalStorageGB;
    /**
     * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see Amazon EBS–optimized instances in the Amazon EC2 User Guide. Default: No minimum or maximum limits
     */
    BaselineEbsBandwidthMbps?: BaselineEbsBandwidthMbps;
    /**
     * The accelerator types that must be on the instance type.   For instance types with GPU accelerators, specify gpu.   For instance types with FPGA accelerators, specify fpga.   For instance types with inference accelerators, specify inference.   Default: Any accelerator type
     */
    AcceleratorTypes?: AcceleratorTypeSet;
    /**
     * The minimum and maximum number of accelerators (GPUs, FPGAs, or Amazon Web Services Inferentia chips) on an instance. To exclude accelerator-enabled instance types, set Max to 0. Default: No minimum or maximum limits
     */
    AcceleratorCount?: AcceleratorCount;
    /**
     * Indicates whether instance types must have accelerators by specific manufacturers.   For instance types with NVIDIA devices, specify nvidia.   For instance types with AMD devices, specify amd.   For instance types with Amazon Web Services devices, specify amazon-web-services.   For instance types with Xilinx devices, specify xilinx.   Default: Any manufacturer
     */
    AcceleratorManufacturers?: AcceleratorManufacturerSet;
    /**
     * The accelerators that must be on the instance type.   For instance types with NVIDIA A100 GPUs, specify a100.   For instance types with NVIDIA V100 GPUs, specify v100.   For instance types with NVIDIA K80 GPUs, specify k80.   For instance types with NVIDIA T4 GPUs, specify t4.   For instance types with NVIDIA M60 GPUs, specify m60.   For instance types with AMD Radeon Pro V520 GPUs, specify radeon-pro-v520.   For instance types with Xilinx VU9P FPGAs, specify vu9p.   For instance types with Amazon Web Services Inferentia chips, specify inferentia.   For instance types with NVIDIA GRID K520 GPUs, specify k520.   Default: Any accelerator
     */
    AcceleratorNames?: AcceleratorNameSet;
    /**
     * The minimum and maximum amount of total accelerator memory, in MiB. Default: No minimum or maximum limits
     */
    AcceleratorTotalMemoryMiB?: AcceleratorTotalMemoryMiB;
    /**
     * The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps). Default: No minimum or maximum limits
     */
    NetworkBandwidthGbps?: NetworkBandwidthGbps;
    /**
     * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes. You can use strings with one or more wild cards, represented by an asterisk (*), to allow an instance type, size, or generation. The following are examples: m5.8xlarge, c5*.*, m5a.*, r*, *3*. For example, if you specify c5*,Amazon EC2 will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify m5a.*, Amazon EC2 will allow all the M5a instance types, but not the M5n instance types.  If you specify AllowedInstanceTypes, you can't specify ExcludedInstanceTypes.  Default: All instance types
     */
    AllowedInstanceTypes?: AllowedInstanceTypeSet;
  }
  export interface InstanceRequirementsRequest {
    /**
     * The minimum and maximum number of vCPUs.
     */
    VCpuCount: VCpuCountRangeRequest;
    /**
     * The minimum and maximum amount of memory, in MiB.
     */
    MemoryMiB: MemoryMiBRequest;
    /**
     * The CPU manufacturers to include.   For instance types with Intel CPUs, specify intel.   For instance types with AMD CPUs, specify amd.   For instance types with Amazon Web Services CPUs, specify amazon-web-services.    Don't confuse the CPU manufacturer with the CPU architecture. Instances will be launched with a compatible CPU architecture based on the Amazon Machine Image (AMI) that you specify in your launch template.  Default: Any manufacturer
     */
    CpuManufacturers?: CpuManufacturerSet;
    /**
     * The minimum and maximum amount of memory per vCPU, in GiB. Default: No minimum or maximum limits
     */
    MemoryGiBPerVCpu?: MemoryGiBPerVCpuRequest;
    /**
     * The instance types to exclude. You can use strings with one or more wild cards, represented by an asterisk (*), to exclude an instance family, type, size, or generation. The following are examples: m5.8xlarge, c5*.*, m5a.*, r*, *3*. For example, if you specify c5*,Amazon EC2 will exclude the entire C5 instance family, which includes all C5a and C5n instance types. If you specify m5a.*, Amazon EC2 will exclude all the M5a instance types, but not the M5n instance types.  If you specify ExcludedInstanceTypes, you can't specify AllowedInstanceTypes.  Default: No excluded instance types
     */
    ExcludedInstanceTypes?: ExcludedInstanceTypeSet;
    /**
     * Indicates whether current or previous generation instance types are included. The current generation instance types are recommended for use. Current generation instance types are typically the latest two to three generations in each instance family. For more information, see Instance types in the Amazon EC2 User Guide. For current generation instance types, specify current. For previous generation instance types, specify previous. Default: Current and previous generation instance types
     */
    InstanceGenerations?: InstanceGenerationSet;
    /**
     * The price protection threshold for Spot Instance. This is the maximum you’ll pay for an Spot Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold. The parameter accepts an integer, which Amazon EC2 interprets as a percentage. To turn off price protection, specify a high value, such as 999999. This parameter is not supported for GetSpotPlacementScores and GetInstanceTypesFromInstanceRequirements.  If you set TargetCapacityUnitType to vcpu or memory-mib, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.  Default: 100 
     */
    SpotMaxPricePercentageOverLowestPrice?: Integer;
    /**
     * The price protection threshold for On-Demand Instances. This is the maximum you’ll pay for an On-Demand Instance, expressed as a percentage above the least expensive current generation M, C, or R instance type with your specified attributes. When Amazon EC2 selects instance types with your attributes, it excludes instance types priced above your threshold. The parameter accepts an integer, which Amazon EC2 interprets as a percentage. To turn off price protection, specify a high value, such as 999999. This parameter is not supported for GetSpotPlacementScores and GetInstanceTypesFromInstanceRequirements.  If you set TargetCapacityUnitType to vcpu or memory-mib, the price protection threshold is applied based on the per-vCPU or per-memory price instead of the per-instance price.  Default: 20 
     */
    OnDemandMaxPricePercentageOverLowestPrice?: Integer;
    /**
     * Indicates whether bare metal instance types must be included, excluded, or required.   To include bare metal instance types, specify included.   To require only bare metal instance types, specify required.   To exclude bare metal instance types, specify excluded.   Default: excluded 
     */
    BareMetal?: BareMetal;
    /**
     * Indicates whether burstable performance T instance types are included, excluded, or required. For more information, see Burstable performance instances.   To include burstable performance instance types, specify included.   To require only burstable performance instance types, specify required.   To exclude burstable performance instance types, specify excluded.   Default: excluded 
     */
    BurstablePerformance?: BurstablePerformance;
    /**
     * Indicates whether instance types must support hibernation for On-Demand Instances. This parameter is not supported for GetSpotPlacementScores. Default: false 
     */
    RequireHibernateSupport?: Boolean;
    /**
     * The minimum and maximum number of network interfaces. Default: No minimum or maximum limits
     */
    NetworkInterfaceCount?: NetworkInterfaceCountRequest;
    /**
     * Indicates whether instance types with instance store volumes are included, excluded, or required. For more information, Amazon EC2 instance store in the Amazon EC2 User Guide.   To include instance types with instance store volumes, specify included.   To require only instance types with instance store volumes, specify required.   To exclude instance types with instance store volumes, specify excluded.   Default: included 
     */
    LocalStorage?: LocalStorage;
    /**
     * The type of local storage that is required.   For instance types with hard disk drive (HDD) storage, specify hdd.   For instance types with solid state drive (SSD) storage, specify ssd.   Default: hdd and ssd 
     */
    LocalStorageTypes?: LocalStorageTypeSet;
    /**
     * The minimum and maximum amount of total local storage, in GB. Default: No minimum or maximum limits
     */
    TotalLocalStorageGB?: TotalLocalStorageGBRequest;
    /**
     * The minimum and maximum baseline bandwidth to Amazon EBS, in Mbps. For more information, see Amazon EBS–optimized instances in the Amazon EC2 User Guide. Default: No minimum or maximum limits
     */
    BaselineEbsBandwidthMbps?: BaselineEbsBandwidthMbpsRequest;
    /**
     * The accelerator types that must be on the instance type.   To include instance types with GPU hardware, specify gpu.   To include instance types with FPGA hardware, specify fpga.   To include instance types with inference hardware, specify inference.   Default: Any accelerator type
     */
    AcceleratorTypes?: AcceleratorTypeSet;
    /**
     * The minimum and maximum number of accelerators (GPUs, FPGAs, or Amazon Web Services Inferentia chips) on an instance. To exclude accelerator-enabled instance types, set Max to 0. Default: No minimum or maximum limits
     */
    AcceleratorCount?: AcceleratorCountRequest;
    /**
     * Indicates whether instance types must have accelerators by specific manufacturers.   For instance types with NVIDIA devices, specify nvidia.   For instance types with AMD devices, specify amd.   For instance types with Amazon Web Services devices, specify amazon-web-services.   For instance types with Xilinx devices, specify xilinx.   Default: Any manufacturer
     */
    AcceleratorManufacturers?: AcceleratorManufacturerSet;
    /**
     * The accelerators that must be on the instance type.   For instance types with NVIDIA A100 GPUs, specify a100.   For instance types with NVIDIA V100 GPUs, specify v100.   For instance types with NVIDIA K80 GPUs, specify k80.   For instance types with NVIDIA T4 GPUs, specify t4.   For instance types with NVIDIA M60 GPUs, specify m60.   For instance types with AMD Radeon Pro V520 GPUs, specify radeon-pro-v520.   For instance types with Xilinx VU9P FPGAs, specify  vu9p.   For instance types with Amazon Web Services Inferentia chips, specify inferentia.   For instance types with NVIDIA GRID K520 GPUs, specify k520.   Default: Any accelerator
     */
    AcceleratorNames?: AcceleratorNameSet;
    /**
     * The minimum and maximum amount of total accelerator memory, in MiB. Default: No minimum or maximum limits
     */
    AcceleratorTotalMemoryMiB?: AcceleratorTotalMemoryMiBRequest;
    /**
     * The minimum and maximum amount of network bandwidth, in gigabits per second (Gbps). Default: No minimum or maximum limits
     */
    NetworkBandwidthGbps?: NetworkBandwidthGbpsRequest;
    /**
     * The instance types to apply your specified attributes against. All other instance types are ignored, even if they match your specified attributes. You can use strings with one or more wild cards, represented by an asterisk (*), to allow an instance type, size, or generation. The following are examples: m5.8xlarge, c5*.*, m5a.*, r*, *3*. For example, if you specify c5*,Amazon EC2 will allow the entire C5 instance family, which includes all C5a and C5n instance types. If you specify m5a.*, Amazon EC2 will allow all the M5a instance types, but not the M5n instance types.  If you specify AllowedInstanceTypes, you can't specify ExcludedInstanceTypes.  Default: All instance types
     */
    AllowedInstanceTypes?: AllowedInstanceTypeSet;
  }
  export interface InstanceRequirementsWithMetadataRequest {
    /**
     * The architecture type.
     */
    ArchitectureTypes?: ArchitectureTypeSet;
    /**
     * The virtualization type.
     */
    VirtualizationTypes?: VirtualizationTypeSet;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.
     */
    InstanceRequirements?: InstanceRequirementsRequest;
  }
  export interface InstanceSpecification {
    /**
     * The instance to specify which volumes should be snapshotted.
     */
    InstanceId: InstanceIdWithVolumeResolver;
    /**
     * Excludes the root volume from being snapshotted.
     */
    ExcludeBootVolume?: Boolean;
    /**
     * The IDs of the data (non-root) volumes to exclude from the multi-volume snapshot set. If you specify the ID of the root volume, the request fails. To exclude the root volume, use ExcludeBootVolume. You can specify up to 40 volume IDs per request.
     */
    ExcludeDataVolumeIds?: VolumeIdStringList;
  }
  export interface InstanceState {
    /**
     * The state of the instance as a 16-bit unsigned integer.  The high byte is all of the bits between 2^8 and (2^16)-1, which equals decimal values between 256 and 65,535. These numerical values are used for internal purposes and should be ignored. The low byte is all of the bits between 2^0 and (2^8)-1, which equals decimal values between 0 and 255.  The valid values for instance-state-code will all be in the range of the low byte and they are:    0 : pending     16 : running     32 : shutting-down     48 : terminated     64 : stopping     80 : stopped    You can ignore the high byte value by zeroing out all of the bits above 2^8 or 256 in decimal.
     */
    Code?: Integer;
    /**
     * The current state of the instance.
     */
    Name?: InstanceStateName;
  }
  export interface InstanceStateChange {
    /**
     * The current state of the instance.
     */
    CurrentState?: InstanceState;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The previous state of the instance.
     */
    PreviousState?: InstanceState;
  }
  export type InstanceStateChangeList = InstanceStateChange[];
  export type InstanceStateName = "pending"|"running"|"shutting-down"|"terminated"|"stopping"|"stopped"|string;
  export interface InstanceStatus {
    /**
     * The Availability Zone of the instance.
     */
    AvailabilityZone?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * Any scheduled events associated with the instance.
     */
    Events?: InstanceStatusEventList;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The intended state of the instance. DescribeInstanceStatus requires that an instance be in the running state.
     */
    InstanceState?: InstanceState;
    /**
     * Reports impaired functionality that stems from issues internal to the instance, such as impaired reachability.
     */
    InstanceStatus?: InstanceStatusSummary;
    /**
     * Reports impaired functionality that stems from issues related to the systems that support an instance, such as hardware failures and network connectivity problems.
     */
    SystemStatus?: InstanceStatusSummary;
  }
  export interface InstanceStatusDetails {
    /**
     * The time when a status check failed. For an instance that was launched and impaired, this is the time when the instance was launched.
     */
    ImpairedSince?: DateTime;
    /**
     * The type of instance status.
     */
    Name?: StatusName;
    /**
     * The status.
     */
    Status?: StatusType;
  }
  export type InstanceStatusDetailsList = InstanceStatusDetails[];
  export interface InstanceStatusEvent {
    /**
     * The ID of the event.
     */
    InstanceEventId?: InstanceEventId;
    /**
     * The event code.
     */
    Code?: EventCode;
    /**
     * A description of the event. After a scheduled event is completed, it can still be described for up to a week. If the event has been completed, this description starts with the following text: [Completed].
     */
    Description?: String;
    /**
     * The latest scheduled end time for the event.
     */
    NotAfter?: DateTime;
    /**
     * The earliest scheduled start time for the event.
     */
    NotBefore?: DateTime;
    /**
     * The deadline for starting the event.
     */
    NotBeforeDeadline?: DateTime;
  }
  export type InstanceStatusEventList = InstanceStatusEvent[];
  export type InstanceStatusList = InstanceStatus[];
  export interface InstanceStatusSummary {
    /**
     * The system instance health or application instance health.
     */
    Details?: InstanceStatusDetailsList;
    /**
     * The status.
     */
    Status?: SummaryStatus;
  }
  export type InstanceStorageEncryptionSupport = "unsupported"|"required"|string;
  export type InstanceStorageFlag = boolean;
  export interface InstanceStorageInfo {
    /**
     * The total size of the disks, in GB.
     */
    TotalSizeInGB?: DiskSize;
    /**
     * Describes the disks that are available for the instance type.
     */
    Disks?: DiskInfoList;
    /**
     * Indicates whether non-volatile memory express (NVMe) is supported.
     */
    NvmeSupport?: EphemeralNvmeSupport;
    /**
     * Indicates whether data is encrypted at rest.
     */
    EncryptionSupport?: InstanceStorageEncryptionSupport;
  }
  export type InstanceTagKeySet = String[];
  export interface InstanceTagNotificationAttribute {
    /**
     * The registered tag keys.
     */
    InstanceTagKeys?: InstanceTagKeySet;
    /**
     * Indicates wheter all tag keys in the current Region are registered to appear in scheduled event notifications. true indicates that all tag keys in the current Region are registered.
     */
    IncludeAllTagsOfInstance?: Boolean;
  }
  export type InstanceType = "a1.medium"|"a1.large"|"a1.xlarge"|"a1.2xlarge"|"a1.4xlarge"|"a1.metal"|"c1.medium"|"c1.xlarge"|"c3.large"|"c3.xlarge"|"c3.2xlarge"|"c3.4xlarge"|"c3.8xlarge"|"c4.large"|"c4.xlarge"|"c4.2xlarge"|"c4.4xlarge"|"c4.8xlarge"|"c5.large"|"c5.xlarge"|"c5.2xlarge"|"c5.4xlarge"|"c5.9xlarge"|"c5.12xlarge"|"c5.18xlarge"|"c5.24xlarge"|"c5.metal"|"c5a.large"|"c5a.xlarge"|"c5a.2xlarge"|"c5a.4xlarge"|"c5a.8xlarge"|"c5a.12xlarge"|"c5a.16xlarge"|"c5a.24xlarge"|"c5ad.large"|"c5ad.xlarge"|"c5ad.2xlarge"|"c5ad.4xlarge"|"c5ad.8xlarge"|"c5ad.12xlarge"|"c5ad.16xlarge"|"c5ad.24xlarge"|"c5d.large"|"c5d.xlarge"|"c5d.2xlarge"|"c5d.4xlarge"|"c5d.9xlarge"|"c5d.12xlarge"|"c5d.18xlarge"|"c5d.24xlarge"|"c5d.metal"|"c5n.large"|"c5n.xlarge"|"c5n.2xlarge"|"c5n.4xlarge"|"c5n.9xlarge"|"c5n.18xlarge"|"c5n.metal"|"c6g.medium"|"c6g.large"|"c6g.xlarge"|"c6g.2xlarge"|"c6g.4xlarge"|"c6g.8xlarge"|"c6g.12xlarge"|"c6g.16xlarge"|"c6g.metal"|"c6gd.medium"|"c6gd.large"|"c6gd.xlarge"|"c6gd.2xlarge"|"c6gd.4xlarge"|"c6gd.8xlarge"|"c6gd.12xlarge"|"c6gd.16xlarge"|"c6gd.metal"|"c6gn.medium"|"c6gn.large"|"c6gn.xlarge"|"c6gn.2xlarge"|"c6gn.4xlarge"|"c6gn.8xlarge"|"c6gn.12xlarge"|"c6gn.16xlarge"|"c6i.large"|"c6i.xlarge"|"c6i.2xlarge"|"c6i.4xlarge"|"c6i.8xlarge"|"c6i.12xlarge"|"c6i.16xlarge"|"c6i.24xlarge"|"c6i.32xlarge"|"c6i.metal"|"cc1.4xlarge"|"cc2.8xlarge"|"cg1.4xlarge"|"cr1.8xlarge"|"d2.xlarge"|"d2.2xlarge"|"d2.4xlarge"|"d2.8xlarge"|"d3.xlarge"|"d3.2xlarge"|"d3.4xlarge"|"d3.8xlarge"|"d3en.xlarge"|"d3en.2xlarge"|"d3en.4xlarge"|"d3en.6xlarge"|"d3en.8xlarge"|"d3en.12xlarge"|"dl1.24xlarge"|"f1.2xlarge"|"f1.4xlarge"|"f1.16xlarge"|"g2.2xlarge"|"g2.8xlarge"|"g3.4xlarge"|"g3.8xlarge"|"g3.16xlarge"|"g3s.xlarge"|"g4ad.xlarge"|"g4ad.2xlarge"|"g4ad.4xlarge"|"g4ad.8xlarge"|"g4ad.16xlarge"|"g4dn.xlarge"|"g4dn.2xlarge"|"g4dn.4xlarge"|"g4dn.8xlarge"|"g4dn.12xlarge"|"g4dn.16xlarge"|"g4dn.metal"|"g5.xlarge"|"g5.2xlarge"|"g5.4xlarge"|"g5.8xlarge"|"g5.12xlarge"|"g5.16xlarge"|"g5.24xlarge"|"g5.48xlarge"|"g5g.xlarge"|"g5g.2xlarge"|"g5g.4xlarge"|"g5g.8xlarge"|"g5g.16xlarge"|"g5g.metal"|"hi1.4xlarge"|"hpc6a.48xlarge"|"hs1.8xlarge"|"h1.2xlarge"|"h1.4xlarge"|"h1.8xlarge"|"h1.16xlarge"|"i2.xlarge"|"i2.2xlarge"|"i2.4xlarge"|"i2.8xlarge"|"i3.large"|"i3.xlarge"|"i3.2xlarge"|"i3.4xlarge"|"i3.8xlarge"|"i3.16xlarge"|"i3.metal"|"i3en.large"|"i3en.xlarge"|"i3en.2xlarge"|"i3en.3xlarge"|"i3en.6xlarge"|"i3en.12xlarge"|"i3en.24xlarge"|"i3en.metal"|"im4gn.large"|"im4gn.xlarge"|"im4gn.2xlarge"|"im4gn.4xlarge"|"im4gn.8xlarge"|"im4gn.16xlarge"|"inf1.xlarge"|"inf1.2xlarge"|"inf1.6xlarge"|"inf1.24xlarge"|"is4gen.medium"|"is4gen.large"|"is4gen.xlarge"|"is4gen.2xlarge"|"is4gen.4xlarge"|"is4gen.8xlarge"|"m1.small"|"m1.medium"|"m1.large"|"m1.xlarge"|"m2.xlarge"|"m2.2xlarge"|"m2.4xlarge"|"m3.medium"|"m3.large"|"m3.xlarge"|"m3.2xlarge"|"m4.large"|"m4.xlarge"|"m4.2xlarge"|"m4.4xlarge"|"m4.10xlarge"|"m4.16xlarge"|"m5.large"|"m5.xlarge"|"m5.2xlarge"|"m5.4xlarge"|"m5.8xlarge"|"m5.12xlarge"|"m5.16xlarge"|"m5.24xlarge"|"m5.metal"|"m5a.large"|"m5a.xlarge"|"m5a.2xlarge"|"m5a.4xlarge"|"m5a.8xlarge"|"m5a.12xlarge"|"m5a.16xlarge"|"m5a.24xlarge"|"m5ad.large"|"m5ad.xlarge"|"m5ad.2xlarge"|"m5ad.4xlarge"|"m5ad.8xlarge"|"m5ad.12xlarge"|"m5ad.16xlarge"|"m5ad.24xlarge"|"m5d.large"|"m5d.xlarge"|"m5d.2xlarge"|"m5d.4xlarge"|"m5d.8xlarge"|"m5d.12xlarge"|"m5d.16xlarge"|"m5d.24xlarge"|"m5d.metal"|"m5dn.large"|"m5dn.xlarge"|"m5dn.2xlarge"|"m5dn.4xlarge"|"m5dn.8xlarge"|"m5dn.12xlarge"|"m5dn.16xlarge"|"m5dn.24xlarge"|"m5dn.metal"|"m5n.large"|"m5n.xlarge"|"m5n.2xlarge"|"m5n.4xlarge"|"m5n.8xlarge"|"m5n.12xlarge"|"m5n.16xlarge"|"m5n.24xlarge"|"m5n.metal"|"m5zn.large"|"m5zn.xlarge"|"m5zn.2xlarge"|"m5zn.3xlarge"|"m5zn.6xlarge"|"m5zn.12xlarge"|"m5zn.metal"|"m6a.large"|"m6a.xlarge"|"m6a.2xlarge"|"m6a.4xlarge"|"m6a.8xlarge"|"m6a.12xlarge"|"m6a.16xlarge"|"m6a.24xlarge"|"m6a.32xlarge"|"m6a.48xlarge"|"m6g.metal"|"m6g.medium"|"m6g.large"|"m6g.xlarge"|"m6g.2xlarge"|"m6g.4xlarge"|"m6g.8xlarge"|"m6g.12xlarge"|"m6g.16xlarge"|"m6gd.metal"|"m6gd.medium"|"m6gd.large"|"m6gd.xlarge"|"m6gd.2xlarge"|"m6gd.4xlarge"|"m6gd.8xlarge"|"m6gd.12xlarge"|"m6gd.16xlarge"|"m6i.large"|"m6i.xlarge"|"m6i.2xlarge"|"m6i.4xlarge"|"m6i.8xlarge"|"m6i.12xlarge"|"m6i.16xlarge"|"m6i.24xlarge"|"m6i.32xlarge"|"m6i.metal"|"mac1.metal"|"p2.xlarge"|"p2.8xlarge"|"p2.16xlarge"|"p3.2xlarge"|"p3.8xlarge"|"p3.16xlarge"|"p3dn.24xlarge"|"p4d.24xlarge"|"r3.large"|"r3.xlarge"|"r3.2xlarge"|"r3.4xlarge"|"r3.8xlarge"|"r4.large"|"r4.xlarge"|"r4.2xlarge"|"r4.4xlarge"|"r4.8xlarge"|"r4.16xlarge"|"r5.large"|"r5.xlarge"|"r5.2xlarge"|"r5.4xlarge"|"r5.8xlarge"|"r5.12xlarge"|"r5.16xlarge"|"r5.24xlarge"|"r5.metal"|"r5a.large"|"r5a.xlarge"|"r5a.2xlarge"|"r5a.4xlarge"|"r5a.8xlarge"|"r5a.12xlarge"|"r5a.16xlarge"|"r5a.24xlarge"|"r5ad.large"|"r5ad.xlarge"|"r5ad.2xlarge"|"r5ad.4xlarge"|"r5ad.8xlarge"|"r5ad.12xlarge"|"r5ad.16xlarge"|"r5ad.24xlarge"|"r5b.large"|"r5b.xlarge"|"r5b.2xlarge"|"r5b.4xlarge"|"r5b.8xlarge"|"r5b.12xlarge"|"r5b.16xlarge"|"r5b.24xlarge"|"r5b.metal"|"r5d.large"|"r5d.xlarge"|"r5d.2xlarge"|"r5d.4xlarge"|"r5d.8xlarge"|"r5d.12xlarge"|"r5d.16xlarge"|"r5d.24xlarge"|"r5d.metal"|"r5dn.large"|"r5dn.xlarge"|"r5dn.2xlarge"|"r5dn.4xlarge"|"r5dn.8xlarge"|"r5dn.12xlarge"|"r5dn.16xlarge"|"r5dn.24xlarge"|"r5dn.metal"|"r5n.large"|"r5n.xlarge"|"r5n.2xlarge"|"r5n.4xlarge"|"r5n.8xlarge"|"r5n.12xlarge"|"r5n.16xlarge"|"r5n.24xlarge"|"r5n.metal"|"r6g.medium"|"r6g.large"|"r6g.xlarge"|"r6g.2xlarge"|"r6g.4xlarge"|"r6g.8xlarge"|"r6g.12xlarge"|"r6g.16xlarge"|"r6g.metal"|"r6gd.medium"|"r6gd.large"|"r6gd.xlarge"|"r6gd.2xlarge"|"r6gd.4xlarge"|"r6gd.8xlarge"|"r6gd.12xlarge"|"r6gd.16xlarge"|"r6gd.metal"|"r6i.large"|"r6i.xlarge"|"r6i.2xlarge"|"r6i.4xlarge"|"r6i.8xlarge"|"r6i.12xlarge"|"r6i.16xlarge"|"r6i.24xlarge"|"r6i.32xlarge"|"r6i.metal"|"t1.micro"|"t2.nano"|"t2.micro"|"t2.small"|"t2.medium"|"t2.large"|"t2.xlarge"|"t2.2xlarge"|"t3.nano"|"t3.micro"|"t3.small"|"t3.medium"|"t3.large"|"t3.xlarge"|"t3.2xlarge"|"t3a.nano"|"t3a.micro"|"t3a.small"|"t3a.medium"|"t3a.large"|"t3a.xlarge"|"t3a.2xlarge"|"t4g.nano"|"t4g.micro"|"t4g.small"|"t4g.medium"|"t4g.large"|"t4g.xlarge"|"t4g.2xlarge"|"u-6tb1.56xlarge"|"u-6tb1.112xlarge"|"u-9tb1.112xlarge"|"u-12tb1.112xlarge"|"u-6tb1.metal"|"u-9tb1.metal"|"u-12tb1.metal"|"u-18tb1.metal"|"u-24tb1.metal"|"vt1.3xlarge"|"vt1.6xlarge"|"vt1.24xlarge"|"x1.16xlarge"|"x1.32xlarge"|"x1e.xlarge"|"x1e.2xlarge"|"x1e.4xlarge"|"x1e.8xlarge"|"x1e.16xlarge"|"x1e.32xlarge"|"x2iezn.2xlarge"|"x2iezn.4xlarge"|"x2iezn.6xlarge"|"x2iezn.8xlarge"|"x2iezn.12xlarge"|"x2iezn.metal"|"x2gd.medium"|"x2gd.large"|"x2gd.xlarge"|"x2gd.2xlarge"|"x2gd.4xlarge"|"x2gd.8xlarge"|"x2gd.12xlarge"|"x2gd.16xlarge"|"x2gd.metal"|"z1d.large"|"z1d.xlarge"|"z1d.2xlarge"|"z1d.3xlarge"|"z1d.6xlarge"|"z1d.12xlarge"|"z1d.metal"|"x2idn.16xlarge"|"x2idn.24xlarge"|"x2idn.32xlarge"|"x2iedn.xlarge"|"x2iedn.2xlarge"|"x2iedn.4xlarge"|"x2iedn.8xlarge"|"x2iedn.16xlarge"|"x2iedn.24xlarge"|"x2iedn.32xlarge"|"c6a.large"|"c6a.xlarge"|"c6a.2xlarge"|"c6a.4xlarge"|"c6a.8xlarge"|"c6a.12xlarge"|"c6a.16xlarge"|"c6a.24xlarge"|"c6a.32xlarge"|"c6a.48xlarge"|"c6a.metal"|"m6a.metal"|"i4i.large"|"i4i.xlarge"|"i4i.2xlarge"|"i4i.4xlarge"|"i4i.8xlarge"|"i4i.16xlarge"|"i4i.32xlarge"|"i4i.metal"|"x2idn.metal"|"x2iedn.metal"|"c7g.medium"|"c7g.large"|"c7g.xlarge"|"c7g.2xlarge"|"c7g.4xlarge"|"c7g.8xlarge"|"c7g.12xlarge"|"c7g.16xlarge"|"mac2.metal"|"c6id.large"|"c6id.xlarge"|"c6id.2xlarge"|"c6id.4xlarge"|"c6id.8xlarge"|"c6id.12xlarge"|"c6id.16xlarge"|"c6id.24xlarge"|"c6id.32xlarge"|"c6id.metal"|"m6id.large"|"m6id.xlarge"|"m6id.2xlarge"|"m6id.4xlarge"|"m6id.8xlarge"|"m6id.12xlarge"|"m6id.16xlarge"|"m6id.24xlarge"|"m6id.32xlarge"|"m6id.metal"|"r6id.large"|"r6id.xlarge"|"r6id.2xlarge"|"r6id.4xlarge"|"r6id.8xlarge"|"r6id.12xlarge"|"r6id.16xlarge"|"r6id.24xlarge"|"r6id.32xlarge"|"r6id.metal"|"r6a.large"|"r6a.xlarge"|"r6a.2xlarge"|"r6a.4xlarge"|"r6a.8xlarge"|"r6a.12xlarge"|"r6a.16xlarge"|"r6a.24xlarge"|"r6a.32xlarge"|"r6a.48xlarge"|"r6a.metal"|"p4de.24xlarge"|"u-3tb1.56xlarge"|"u-18tb1.112xlarge"|"u-24tb1.112xlarge"|"trn1.2xlarge"|"trn1.32xlarge"|"hpc6id.32xlarge"|"c6in.large"|"c6in.xlarge"|"c6in.2xlarge"|"c6in.4xlarge"|"c6in.8xlarge"|"c6in.12xlarge"|"c6in.16xlarge"|"c6in.24xlarge"|"c6in.32xlarge"|"m6in.large"|"m6in.xlarge"|"m6in.2xlarge"|"m6in.4xlarge"|"m6in.8xlarge"|"m6in.12xlarge"|"m6in.16xlarge"|"m6in.24xlarge"|"m6in.32xlarge"|"m6idn.large"|"m6idn.xlarge"|"m6idn.2xlarge"|"m6idn.4xlarge"|"m6idn.8xlarge"|"m6idn.12xlarge"|"m6idn.16xlarge"|"m6idn.24xlarge"|"m6idn.32xlarge"|"r6in.large"|"r6in.xlarge"|"r6in.2xlarge"|"r6in.4xlarge"|"r6in.8xlarge"|"r6in.12xlarge"|"r6in.16xlarge"|"r6in.24xlarge"|"r6in.32xlarge"|"r6idn.large"|"r6idn.xlarge"|"r6idn.2xlarge"|"r6idn.4xlarge"|"r6idn.8xlarge"|"r6idn.12xlarge"|"r6idn.16xlarge"|"r6idn.24xlarge"|"r6idn.32xlarge"|"c7g.metal"|"m7g.medium"|"m7g.large"|"m7g.xlarge"|"m7g.2xlarge"|"m7g.4xlarge"|"m7g.8xlarge"|"m7g.12xlarge"|"m7g.16xlarge"|"m7g.metal"|"r7g.medium"|"r7g.large"|"r7g.xlarge"|"r7g.2xlarge"|"r7g.4xlarge"|"r7g.8xlarge"|"r7g.12xlarge"|"r7g.16xlarge"|"r7g.metal"|"c6in.metal"|"m6in.metal"|"m6idn.metal"|"r6in.metal"|"r6idn.metal"|string;
  export type InstanceTypeHypervisor = "nitro"|"xen"|string;
  export interface InstanceTypeInfo {
    /**
     * The instance type. For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceType?: InstanceType;
    /**
     * Indicates whether the instance type is current generation.
     */
    CurrentGeneration?: CurrentGenerationFlag;
    /**
     * Indicates whether the instance type is eligible for the free tier.
     */
    FreeTierEligible?: FreeTierEligibleFlag;
    /**
     * Indicates whether the instance type is offered for spot or On-Demand.
     */
    SupportedUsageClasses?: UsageClassTypeList;
    /**
     * The supported root device types.
     */
    SupportedRootDeviceTypes?: RootDeviceTypeList;
    /**
     * The supported virtualization types.
     */
    SupportedVirtualizationTypes?: VirtualizationTypeList;
    /**
     * Indicates whether the instance is a bare metal instance type.
     */
    BareMetal?: BareMetalFlag;
    /**
     * The hypervisor for the instance type.
     */
    Hypervisor?: InstanceTypeHypervisor;
    /**
     * Describes the processor.
     */
    ProcessorInfo?: ProcessorInfo;
    /**
     * Describes the vCPU configurations for the instance type.
     */
    VCpuInfo?: VCpuInfo;
    /**
     * Describes the memory for the instance type.
     */
    MemoryInfo?: MemoryInfo;
    /**
     * Indicates whether instance storage is supported.
     */
    InstanceStorageSupported?: InstanceStorageFlag;
    /**
     * Describes the instance storage for the instance type.
     */
    InstanceStorageInfo?: InstanceStorageInfo;
    /**
     * Describes the Amazon EBS settings for the instance type.
     */
    EbsInfo?: EbsInfo;
    /**
     * Describes the network settings for the instance type.
     */
    NetworkInfo?: NetworkInfo;
    /**
     * Describes the GPU accelerator settings for the instance type.
     */
    GpuInfo?: GpuInfo;
    /**
     * Describes the FPGA accelerator settings for the instance type.
     */
    FpgaInfo?: FpgaInfo;
    /**
     * Describes the placement group settings for the instance type.
     */
    PlacementGroupInfo?: PlacementGroupInfo;
    /**
     * Describes the Inference accelerator settings for the instance type.
     */
    InferenceAcceleratorInfo?: InferenceAcceleratorInfo;
    /**
     * Indicates whether On-Demand hibernation is supported.
     */
    HibernationSupported?: HibernationFlag;
    /**
     * Indicates whether the instance type is a burstable performance instance type.
     */
    BurstablePerformanceSupported?: BurstablePerformanceFlag;
    /**
     * Indicates whether Dedicated Hosts are supported on the instance type.
     */
    DedicatedHostsSupported?: DedicatedHostFlag;
    /**
     * Indicates whether auto recovery is supported.
     */
    AutoRecoverySupported?: AutoRecoveryFlag;
    /**
     * The supported boot modes. For more information, see Boot modes in the Amazon EC2 User Guide.
     */
    SupportedBootModes?: BootModeTypeList;
  }
  export interface InstanceTypeInfoFromInstanceRequirements {
    /**
     * The matching instance type.
     */
    InstanceType?: String;
  }
  export type InstanceTypeInfoFromInstanceRequirementsSet = InstanceTypeInfoFromInstanceRequirements[];
  export type InstanceTypeInfoList = InstanceTypeInfo[];
  export type InstanceTypeList = InstanceType[];
  export interface InstanceTypeOffering {
    /**
     * The instance type. For more information, see Instance types in the Amazon EC2 User Guide.
     */
    InstanceType?: InstanceType;
    /**
     * The location type.
     */
    LocationType?: LocationType;
    /**
     * The identifier for the location. This depends on the location type. For example, if the location type is region, the location is the Region code (for example, us-east-2.)
     */
    Location?: Location;
  }
  export type InstanceTypeOfferingsList = InstanceTypeOffering[];
  export type InstanceTypes = String[];
  export type InstanceTypesList = String[];
  export interface InstanceUsage {
    /**
     * The ID of the Amazon Web Services account that is making use of the Capacity Reservation.
     */
    AccountId?: String;
    /**
     * The number of instances the Amazon Web Services account currently has in the Capacity Reservation.
     */
    UsedInstanceCount?: Integer;
  }
  export type InstanceUsageSet = InstanceUsage[];
  export type Integer = number;
  export type IntegerWithConstraints = number;
  export interface IntegrateServices {
    /**
     * Information about the integration with Amazon Athena.
     */
    AthenaIntegrations?: AthenaIntegrationsSet;
  }
  export type InterfacePermissionType = "INSTANCE-ATTACH"|"EIP-ASSOCIATE"|string;
  export type InterfaceProtocolType = "VLAN"|"GRE"|string;
  export interface InternetGateway {
    /**
     * Any VPCs attached to the internet gateway.
     */
    Attachments?: InternetGatewayAttachmentList;
    /**
     * The ID of the internet gateway.
     */
    InternetGatewayId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the internet gateway.
     */
    OwnerId?: String;
    /**
     * Any tags assigned to the internet gateway.
     */
    Tags?: TagList;
  }
  export interface InternetGatewayAttachment {
    /**
     * The current state of the attachment. For an internet gateway, the state is available when attached to a VPC; otherwise, this value is not returned.
     */
    State?: AttachmentStatus;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type InternetGatewayAttachmentList = InternetGatewayAttachment[];
  export type InternetGatewayId = string;
  export type InternetGatewayIdList = InternetGatewayId[];
  export type InternetGatewayList = InternetGateway[];
  export type IpAddress = string;
  export type IpAddressList = IpAddress[];
  export type IpAddressType = "ipv4"|"dualstack"|"ipv6"|string;
  export type IpList = String[];
  export interface IpPermission {
    /**
     * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the type number. A value of -1 indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    FromPort?: Integer;
    /**
     * The IP protocol name (tcp, udp, icmp, icmpv6) or number (see Protocol Numbers). [VPC only] Use -1 to specify all protocols. When authorizing security group rules, specifying -1 or a protocol number other than tcp, udp, icmp, or icmpv6 allows traffic on all ports, regardless of any port range you specify. For tcp, udp, and icmp, you must specify a port range. For icmpv6, the port range is optional; if you omit the port range, traffic for all types and codes is allowed.
     */
    IpProtocol?: String;
    /**
     * The IPv4 ranges.
     */
    IpRanges?: IpRangeList;
    /**
     * [VPC only] The IPv6 ranges.
     */
    Ipv6Ranges?: Ipv6RangeList;
    /**
     * [VPC only] The prefix list IDs.
     */
    PrefixListIds?: PrefixListIdList;
    /**
     * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the code. A value of -1 indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    ToPort?: Integer;
    /**
     * The security group and Amazon Web Services account ID pairs.
     */
    UserIdGroupPairs?: UserIdGroupPairList;
  }
  export type IpPermissionList = IpPermission[];
  export type IpPrefixList = String[];
  export interface IpRange {
    /**
     * The IPv4 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv4 address, use the /32 prefix length.
     */
    CidrIp?: String;
    /**
     * A description for the security group rule that references this IPv4 address range. Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&amp;;{}!$*
     */
    Description?: String;
  }
  export type IpRangeList = IpRange[];
  export type IpRanges = String[];
  export interface Ipam {
    /**
     * The Amazon Web Services account ID of the owner of the IPAM.
     */
    OwnerId?: String;
    /**
     * The ID of the IPAM.
     */
    IpamId?: IpamId;
    /**
     * The Amazon Resource Name (ARN) of the IPAM.
     */
    IpamArn?: ResourceArn;
    /**
     * The Amazon Web Services Region of the IPAM.
     */
    IpamRegion?: String;
    /**
     * The ID of the IPAM's default public scope.
     */
    PublicDefaultScopeId?: IpamScopeId;
    /**
     * The ID of the IPAM's default private scope.
     */
    PrivateDefaultScopeId?: IpamScopeId;
    /**
     * The number of scopes in the IPAM. The scope quota is 5. For more information on quotas, see Quotas in IPAM in the Amazon VPC IPAM User Guide. 
     */
    ScopeCount?: Integer;
    /**
     * The description for the IPAM.
     */
    Description?: String;
    /**
     * The operating Regions for an IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions. For more information about operating Regions, see Create an IPAM in the Amazon VPC IPAM User Guide.
     */
    OperatingRegions?: IpamOperatingRegionSet;
    /**
     * The state of the IPAM.
     */
    State?: IpamState;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    Tags?: TagList;
    /**
     * The IPAM's default resource discovery ID.
     */
    DefaultResourceDiscoveryId?: IpamResourceDiscoveryId;
    /**
     * The IPAM's default resource discovery association ID.
     */
    DefaultResourceDiscoveryAssociationId?: IpamResourceDiscoveryAssociationId;
    /**
     * The IPAM's resource discovery association count.
     */
    ResourceDiscoveryAssociationCount?: Integer;
  }
  export type IpamAddressHistoryMaxResults = number;
  export interface IpamAddressHistoryRecord {
    /**
     * The ID of the resource owner.
     */
    ResourceOwnerId?: String;
    /**
     * The Amazon Web Services Region of the resource.
     */
    ResourceRegion?: String;
    /**
     * The type of the resource.
     */
    ResourceType?: IpamAddressHistoryResourceType;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The CIDR of the resource.
     */
    ResourceCidr?: String;
    /**
     * The name of the resource.
     */
    ResourceName?: String;
    /**
     * The compliance status of a resource. For more information on compliance statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.
     */
    ResourceComplianceStatus?: IpamComplianceStatus;
    /**
     * The overlap status of an IPAM resource. The overlap status tells you if the CIDR for a resource overlaps with another CIDR in the scope. For more information on overlap statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.
     */
    ResourceOverlapStatus?: IpamOverlapStatus;
    /**
     * The VPC ID of the resource.
     */
    VpcId?: String;
    /**
     * Sampled start time of the resource-to-CIDR association within the IPAM scope. Changes are picked up in periodic snapshots, so the start time may have occurred before this specific time.
     */
    SampledStartTime?: MillisecondDateTime;
    /**
     * Sampled end time of the resource-to-CIDR association within the IPAM scope. Changes are picked up in periodic snapshots, so the end time may have occurred before this specific time.
     */
    SampledEndTime?: MillisecondDateTime;
  }
  export type IpamAddressHistoryRecordSet = IpamAddressHistoryRecord[];
  export type IpamAddressHistoryResourceType = "eip"|"vpc"|"subnet"|"network-interface"|"instance"|string;
  export type IpamAssociatedResourceDiscoveryStatus = "active"|"not-found"|string;
  export interface IpamCidrAuthorizationContext {
    /**
     * The plain-text authorization message for the prefix and account.
     */
    Message?: String;
    /**
     * The signed authorization message for the prefix and account.
     */
    Signature?: String;
  }
  export type IpamComplianceStatus = "compliant"|"noncompliant"|"unmanaged"|"ignored"|string;
  export interface IpamDiscoveredAccount {
    /**
     * The account ID.
     */
    AccountId?: String;
    /**
     * The Amazon Web Services Region that the account information is returned from. An account can be discovered in multiple regions and will have a separate discovered account for each Region.
     */
    DiscoveryRegion?: String;
    /**
     * The resource discovery failure reason.
     */
    FailureReason?: IpamDiscoveryFailureReason;
    /**
     * The last attempted resource discovery time.
     */
    LastAttemptedDiscoveryTime?: MillisecondDateTime;
    /**
     * The last successful resource discovery time.
     */
    LastSuccessfulDiscoveryTime?: MillisecondDateTime;
  }
  export type IpamDiscoveredAccountSet = IpamDiscoveredAccount[];
  export interface IpamDiscoveredResourceCidr {
    /**
     * The resource discovery ID.
     */
    IpamResourceDiscoveryId?: IpamResourceDiscoveryId;
    /**
     * The resource Region.
     */
    ResourceRegion?: String;
    /**
     * The resource ID.
     */
    ResourceId?: String;
    /**
     * The resource owner ID.
     */
    ResourceOwnerId?: String;
    /**
     * The resource CIDR.
     */
    ResourceCidr?: String;
    /**
     * The resource type.
     */
    ResourceType?: IpamResourceType;
    /**
     * The resource tags.
     */
    ResourceTags?: IpamResourceTagList;
    /**
     * The percentage of IP address space in use. To convert the decimal to a percentage, multiply the decimal by 100. Note the following:   For resources that are VPCs, this is the percentage of IP address space in the VPC that's taken up by subnet CIDRs.    For resources that are subnets, if the subnet has an IPv4 CIDR provisioned to it, this is the percentage of IPv4 address space in the subnet that's in use. If the subnet has an IPv6 CIDR provisioned to it, the percentage of IPv6 address space in use is not represented. The percentage of IPv6 address space in use cannot currently be calculated.    For resources that are public IPv4 pools, this is the percentage of IP address space in the pool that's been allocated to Elastic IP addresses (EIPs).   
     */
    IpUsage?: BoxedDouble;
    /**
     * The VPC ID.
     */
    VpcId?: String;
    /**
     * The last successful resource discovery time.
     */
    SampleTime?: MillisecondDateTime;
  }
  export type IpamDiscoveredResourceCidrSet = IpamDiscoveredResourceCidr[];
  export type IpamDiscoveryFailureCode = "assume-role-failure"|"throttling-failure"|"unauthorized-failure"|string;
  export interface IpamDiscoveryFailureReason {
    /**
     * The discovery failure code.    assume-role-failure - IPAM could not assume the Amazon Web Services IAM service-linked role. This could be because of any of the following:   SLR has not been created yet and IPAM is still creating it.   You have opted-out of the IPAM home Region.   Account you are using as your IPAM account has been suspended.      throttling-failure - IPAM account is already using the allotted transactions per second and IPAM is receiving a throttling error when assuming the Amazon Web Services IAM SLR.    unauthorized-failure - Amazon Web Services account making the request is not authorized. For more information, see AuthFailure in the Amazon Elastic Compute Cloud API Reference.  
     */
    Code?: IpamDiscoveryFailureCode;
    /**
     * The discovery failure message.
     */
    Message?: String;
  }
  export type IpamId = string;
  export type IpamManagementState = "managed"|"unmanaged"|"ignored"|string;
  export type IpamMaxResults = number;
  export type IpamNetmaskLength = number;
  export interface IpamOperatingRegion {
    /**
     * The name of the operating Region.
     */
    RegionName?: String;
  }
  export type IpamOperatingRegionSet = IpamOperatingRegion[];
  export type IpamOverlapStatus = "overlapping"|"nonoverlapping"|"ignored"|string;
  export interface IpamPool {
    /**
     * The Amazon Web Services account ID of the owner of the IPAM pool.
     */
    OwnerId?: String;
    /**
     * The ID of the IPAM pool.
     */
    IpamPoolId?: IpamPoolId;
    /**
     * The ID of the source IPAM pool. You can use this option to create an IPAM pool within an existing source pool.
     */
    SourceIpamPoolId?: IpamPoolId;
    /**
     * The Amazon Resource Name (ARN) of the IPAM pool.
     */
    IpamPoolArn?: ResourceArn;
    /**
     * The ARN of the scope of the IPAM pool.
     */
    IpamScopeArn?: ResourceArn;
    /**
     * In IPAM, a scope is the highest-level container within IPAM. An IPAM contains two default scopes. Each scope represents the IP space for a single network. The private scope is intended for all private IP address space. The public scope is intended for all public IP address space. Scopes enable you to reuse IP addresses across multiple unconnected networks without causing IP address overlap or conflict.
     */
    IpamScopeType?: IpamScopeType;
    /**
     * The ARN of the IPAM.
     */
    IpamArn?: ResourceArn;
    /**
     * The Amazon Web Services Region of the IPAM pool.
     */
    IpamRegion?: String;
    /**
     * The locale of the IPAM pool. In IPAM, the locale is the Amazon Web Services Region where you want to make an IPAM pool available for allocations. Only resources in the same Region as the locale of the pool can get IP address allocations from the pool. You can only allocate a CIDR for a VPC, for example, from an IPAM pool that shares a locale with the VPC’s Region. Note that once you choose a Locale for a pool, you cannot modify it. If you choose an Amazon Web Services Region for locale that has not been configured as an operating Region for the IPAM, you'll get an error.
     */
    Locale?: String;
    /**
     * The depth of pools in your IPAM pool. The pool depth quota is 10. For more information, see Quotas in IPAM in the Amazon VPC IPAM User Guide. 
     */
    PoolDepth?: Integer;
    /**
     * The state of the IPAM pool.
     */
    State?: IpamPoolState;
    /**
     * A message related to the failed creation of an IPAM pool.
     */
    StateMessage?: String;
    /**
     * The description of the IPAM pool.
     */
    Description?: String;
    /**
     * If selected, IPAM will continuously look for resources within the CIDR range of this pool and automatically import them as allocations into your IPAM. The CIDRs that will be allocated for these resources must not already be allocated to other resources in order for the import to succeed. IPAM will import a CIDR regardless of its compliance with the pool's allocation rules, so a resource might be imported and subsequently marked as noncompliant. If IPAM discovers multiple CIDRs that overlap, IPAM will import the largest CIDR only. If IPAM discovers multiple CIDRs with matching CIDRs, IPAM will randomly import one of them only.  A locale must be set on the pool for this feature to work.
     */
    AutoImport?: Boolean;
    /**
     * Determines if a pool is publicly advertisable. This option is not available for pools with AddressFamily set to ipv4.
     */
    PubliclyAdvertisable?: Boolean;
    /**
     * The address family of the pool.
     */
    AddressFamily?: AddressFamily;
    /**
     * The minimum netmask length required for CIDR allocations in this IPAM pool to be compliant. The minimum netmask length must be less than the maximum netmask length. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.
     */
    AllocationMinNetmaskLength?: IpamNetmaskLength;
    /**
     * The maximum netmask length possible for CIDR allocations in this IPAM pool to be compliant. The maximum netmask length must be greater than the minimum netmask length. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.
     */
    AllocationMaxNetmaskLength?: IpamNetmaskLength;
    /**
     * The default netmask length for allocations added to this pool. If, for example, the CIDR assigned to this pool is 10.0.0.0/8 and you enter 16 here, new allocations will default to 10.0.0.0/16.
     */
    AllocationDefaultNetmaskLength?: IpamNetmaskLength;
    /**
     * Tags that are required for resources that use CIDRs from this IPAM pool. Resources that do not have these tags will not be allowed to allocate space from the pool. If the resources have their tags changed after they have allocated space or if the allocation tagging requirements are changed on the pool, the resource may be marked as noncompliant.
     */
    AllocationResourceTags?: IpamResourceTagList;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    Tags?: TagList;
    /**
     * Limits which service in Amazon Web Services that the pool can be used in. "ec2", for example, allows users to use space for Elastic IP addresses and VPCs.
     */
    AwsService?: IpamPoolAwsService;
    /**
     * The IP address source for pools in the public scope. Only used for provisioning IP address CIDRs to pools in the public scope. Default is BYOIP. For more information, see Create IPv6 pools in the Amazon VPC IPAM User Guide. By default, you can add only one Amazon-provided IPv6 CIDR block to a top-level IPv6 pool. For information on increasing the default limit, see  Quotas for your IPAM in the Amazon VPC IPAM User Guide.
     */
    PublicIpSource?: IpamPoolPublicIpSource;
  }
  export interface IpamPoolAllocation {
    /**
     * The CIDR for the allocation. A CIDR is a representation of an IP address and its associated network mask (or netmask) and refers to a range of IP addresses. An IPv4 CIDR example is 10.24.34.0/23. An IPv6 CIDR example is 2001:DB8::/32.
     */
    Cidr?: String;
    /**
     * The ID of an allocation.
     */
    IpamPoolAllocationId?: IpamPoolAllocationId;
    /**
     * A description of the pool allocation.
     */
    Description?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The type of the resource.
     */
    ResourceType?: IpamPoolAllocationResourceType;
    /**
     * The Amazon Web Services Region of the resource.
     */
    ResourceRegion?: String;
    /**
     * The owner of the resource.
     */
    ResourceOwner?: String;
  }
  export type IpamPoolAllocationDisallowedCidrs = String[];
  export type IpamPoolAllocationId = string;
  export type IpamPoolAllocationResourceType = "ipam-pool"|"vpc"|"ec2-public-ipv4-pool"|"custom"|string;
  export type IpamPoolAllocationSet = IpamPoolAllocation[];
  export type IpamPoolAwsService = "ec2"|string;
  export interface IpamPoolCidr {
    /**
     * The CIDR provisioned to the IPAM pool. A CIDR is a representation of an IP address and its associated network mask (or netmask) and refers to a range of IP addresses. An IPv4 CIDR example is 10.24.34.0/23. An IPv6 CIDR example is 2001:DB8::/32.
     */
    Cidr?: String;
    /**
     * The state of the CIDR.
     */
    State?: IpamPoolCidrState;
    /**
     * Details related to why an IPAM pool CIDR failed to be provisioned.
     */
    FailureReason?: IpamPoolCidrFailureReason;
    /**
     * The IPAM pool CIDR ID.
     */
    IpamPoolCidrId?: IpamPoolCidrId;
    /**
     * The netmask length of the CIDR you'd like to provision to a pool. Can be used for provisioning Amazon-provided IPv6 CIDRs to top-level pools and for provisioning CIDRs to pools with source pools. Cannot be used to provision BYOIP CIDRs to top-level pools. "NetmaskLength" or "Cidr" is required.
     */
    NetmaskLength?: Integer;
  }
  export type IpamPoolCidrFailureCode = "cidr-not-available"|"limit-exceeded"|string;
  export interface IpamPoolCidrFailureReason {
    /**
     * An error code related to why an IPAM pool CIDR failed to be provisioned.
     */
    Code?: IpamPoolCidrFailureCode;
    /**
     * A message related to why an IPAM pool CIDR failed to be provisioned.
     */
    Message?: String;
  }
  export type IpamPoolCidrId = string;
  export type IpamPoolCidrSet = IpamPoolCidr[];
  export type IpamPoolCidrState = "pending-provision"|"provisioned"|"failed-provision"|"pending-deprovision"|"deprovisioned"|"failed-deprovision"|"pending-import"|"failed-import"|string;
  export type IpamPoolId = string;
  export type IpamPoolPublicIpSource = "amazon"|"byoip"|string;
  export type IpamPoolSet = IpamPool[];
  export type IpamPoolState = "create-in-progress"|"create-complete"|"create-failed"|"modify-in-progress"|"modify-complete"|"modify-failed"|"delete-in-progress"|"delete-complete"|"delete-failed"|"isolate-in-progress"|"isolate-complete"|"restore-in-progress"|string;
  export interface IpamResourceCidr {
    /**
     * The IPAM ID for an IPAM resource.
     */
    IpamId?: IpamId;
    /**
     * The scope ID for an IPAM resource.
     */
    IpamScopeId?: IpamScopeId;
    /**
     * The pool ID for an IPAM resource.
     */
    IpamPoolId?: IpamPoolId;
    /**
     * The Amazon Web Services Region for an IPAM resource.
     */
    ResourceRegion?: String;
    /**
     * The Amazon Web Services account number of the owner of an IPAM resource.
     */
    ResourceOwnerId?: String;
    /**
     * The ID of an IPAM resource.
     */
    ResourceId?: String;
    /**
     * The name of an IPAM resource.
     */
    ResourceName?: String;
    /**
     * The CIDR for an IPAM resource.
     */
    ResourceCidr?: String;
    /**
     * The type of IPAM resource.
     */
    ResourceType?: IpamResourceType;
    /**
     * The tags for an IPAM resource.
     */
    ResourceTags?: IpamResourceTagList;
    /**
     * The percentage of IP address space in use. To convert the decimal to a percentage, multiply the decimal by 100. Note the following:   For resources that are VPCs, this is the percentage of IP address space in the VPC that's taken up by subnet CIDRs.    For resources that are subnets, if the subnet has an IPv4 CIDR provisioned to it, this is the percentage of IPv4 address space in the subnet that's in use. If the subnet has an IPv6 CIDR provisioned to it, the percentage of IPv6 address space in use is not represented. The percentage of IPv6 address space in use cannot currently be calculated.    For resources that are public IPv4 pools, this is the percentage of IP address space in the pool that's been allocated to Elastic IP addresses (EIPs).   
     */
    IpUsage?: BoxedDouble;
    /**
     * The compliance status of the IPAM resource. For more information on compliance statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.
     */
    ComplianceStatus?: IpamComplianceStatus;
    /**
     * The management state of the resource. For more information about management states, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.
     */
    ManagementState?: IpamManagementState;
    /**
     * The overlap status of an IPAM resource. The overlap status tells you if the CIDR for a resource overlaps with another CIDR in the scope. For more information on overlap statuses, see Monitor CIDR usage by resource in the Amazon VPC IPAM User Guide.
     */
    OverlapStatus?: IpamOverlapStatus;
    /**
     * The ID of a VPC.
     */
    VpcId?: String;
  }
  export type IpamResourceCidrSet = IpamResourceCidr[];
  export interface IpamResourceDiscovery {
    /**
     * The ID of the owner.
     */
    OwnerId?: String;
    /**
     * The resource discovery ID.
     */
    IpamResourceDiscoveryId?: IpamResourceDiscoveryId;
    /**
     * The resource discovery Amazon Resource Name (ARN).
     */
    IpamResourceDiscoveryArn?: String;
    /**
     * The resource discovery Region.
     */
    IpamResourceDiscoveryRegion?: String;
    /**
     * The resource discovery description.
     */
    Description?: String;
    /**
     * The operating Regions for the resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
     */
    OperatingRegions?: IpamOperatingRegionSet;
    /**
     * Defines if the resource discovery is the default. The default resource discovery is the resource discovery automatically created when you create an IPAM.
     */
    IsDefault?: Boolean;
    /**
     * The lifecycle state of the resource discovery.    create-in-progress - Resource discovery is being created.    create-complete - Resource discovery creation is complete.    create-failed - Resource discovery creation has failed.    modify-in-progress - Resource discovery is being modified.    modify-complete - Resource discovery modification is complete.    modify-failed - Resource discovery modification has failed.    delete-in-progress - Resource discovery is being deleted.    delete-complete - Resource discovery deletion is complete.    delete-failed - Resource discovery deletion has failed.    isolate-in-progress - Amazon Web Services account that created the resource discovery has been removed and the resource discovery is being isolated.    isolate-complete - Resource discovery isolation is complete.    restore-in-progress - Amazon Web Services account that created the resource discovery and was isolated has been restored.  
     */
    State?: IpamResourceDiscoveryState;
    /**
     * A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.
     */
    Tags?: TagList;
  }
  export interface IpamResourceDiscoveryAssociation {
    /**
     * The Amazon Web Services account ID of the resource discovery owner.
     */
    OwnerId?: String;
    /**
     * The resource discovery association ID.
     */
    IpamResourceDiscoveryAssociationId?: IpamResourceDiscoveryAssociationId;
    /**
     * The resource discovery association Amazon Resource Name (ARN).
     */
    IpamResourceDiscoveryAssociationArn?: String;
    /**
     * The resource discovery ID.
     */
    IpamResourceDiscoveryId?: IpamResourceDiscoveryId;
    /**
     * The IPAM ID.
     */
    IpamId?: IpamId;
    /**
     * The IPAM ARN.
     */
    IpamArn?: ResourceArn;
    /**
     * The IPAM home Region.
     */
    IpamRegion?: String;
    /**
     * Defines if the resource discovery is the default. When you create an IPAM, a default resource discovery is created for your IPAM and it's associated with your IPAM.
     */
    IsDefault?: Boolean;
    /**
     * The resource discovery status.    active - Connection or permissions required to read the results of the resource discovery are intact.    not-found - Connection or permissions required to read the results of the resource discovery are broken. This may happen if the owner of the resource discovery stopped sharing it or deleted the resource discovery. Verify the resource discovery still exists and the Amazon Web Services RAM resource share is still intact.  
     */
    ResourceDiscoveryStatus?: IpamAssociatedResourceDiscoveryStatus;
    /**
     * The lifecycle state of the association when you associate or disassociate a resource discovery.    associate-in-progress - Resource discovery is being associated.    associate-complete - Resource discovery association is complete.    associate-failed - Resource discovery association has failed.    disassociate-in-progress - Resource discovery is being disassociated.    disassociate-complete - Resource discovery disassociation is complete.    disassociate-failed  - Resource discovery disassociation has failed.    isolate-in-progress - Amazon Web Services account that created the resource discovery association has been removed and the resource discovery associatation is being isolated.    isolate-complete - Resource discovery isolation is complete..    restore-in-progress - Resource discovery is being restored.  
     */
    State?: IpamResourceDiscoveryAssociationState;
    /**
     * A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value. You can use tags to search and filter your resources or track your Amazon Web Services costs.
     */
    Tags?: TagList;
  }
  export type IpamResourceDiscoveryAssociationId = string;
  export type IpamResourceDiscoveryAssociationSet = IpamResourceDiscoveryAssociation[];
  export type IpamResourceDiscoveryAssociationState = "associate-in-progress"|"associate-complete"|"associate-failed"|"disassociate-in-progress"|"disassociate-complete"|"disassociate-failed"|"isolate-in-progress"|"isolate-complete"|"restore-in-progress"|string;
  export type IpamResourceDiscoveryId = string;
  export type IpamResourceDiscoverySet = IpamResourceDiscovery[];
  export type IpamResourceDiscoveryState = "create-in-progress"|"create-complete"|"create-failed"|"modify-in-progress"|"modify-complete"|"modify-failed"|"delete-in-progress"|"delete-complete"|"delete-failed"|"isolate-in-progress"|"isolate-complete"|"restore-in-progress"|string;
  export interface IpamResourceTag {
    /**
     * The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
     */
    Key?: String;
    /**
     * The value of the tag.
     */
    Value?: String;
  }
  export type IpamResourceTagList = IpamResourceTag[];
  export type IpamResourceType = "vpc"|"subnet"|"eip"|"public-ipv4-pool"|"ipv6-pool"|string;
  export interface IpamScope {
    /**
     * The Amazon Web Services account ID of the owner of the scope.
     */
    OwnerId?: String;
    /**
     * The ID of the scope.
     */
    IpamScopeId?: IpamScopeId;
    /**
     * The Amazon Resource Name (ARN) of the scope.
     */
    IpamScopeArn?: ResourceArn;
    /**
     * The ARN of the IPAM.
     */
    IpamArn?: ResourceArn;
    /**
     * The Amazon Web Services Region of the IPAM scope.
     */
    IpamRegion?: String;
    /**
     * The type of the scope.
     */
    IpamScopeType?: IpamScopeType;
    /**
     * Defines if the scope is the default scope or not.
     */
    IsDefault?: Boolean;
    /**
     * The description of the scope.
     */
    Description?: String;
    /**
     * The number of pools in the scope.
     */
    PoolCount?: Integer;
    /**
     * The state of the IPAM scope.
     */
    State?: IpamScopeState;
    /**
     * The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.
     */
    Tags?: TagList;
  }
  export type IpamScopeId = string;
  export type IpamScopeSet = IpamScope[];
  export type IpamScopeState = "create-in-progress"|"create-complete"|"create-failed"|"modify-in-progress"|"modify-complete"|"modify-failed"|"delete-in-progress"|"delete-complete"|"delete-failed"|"isolate-in-progress"|"isolate-complete"|"restore-in-progress"|string;
  export type IpamScopeType = "public"|"private"|string;
  export type IpamSet = Ipam[];
  export type IpamState = "create-in-progress"|"create-complete"|"create-failed"|"modify-in-progress"|"modify-complete"|"modify-failed"|"delete-in-progress"|"delete-complete"|"delete-failed"|"isolate-in-progress"|"isolate-complete"|"restore-in-progress"|string;
  export type Ipv4PoolCoipId = string;
  export type Ipv4PoolEc2Id = string;
  export type Ipv4PrefixList = Ipv4PrefixSpecificationRequest[];
  export type Ipv4PrefixListResponse = Ipv4PrefixSpecificationResponse[];
  export interface Ipv4PrefixSpecification {
    /**
     * The IPv4 prefix. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
     */
    Ipv4Prefix?: String;
  }
  export interface Ipv4PrefixSpecificationRequest {
    /**
     * The IPv4 prefix. For information, see  Assigning prefixes to Amazon EC2 network interfaces in the Amazon Elastic Compute Cloud User Guide.
     */
    Ipv4Prefix?: String;
  }
  export interface Ipv4PrefixSpecificationResponse {
    /**
     * The IPv4 delegated prefixes assigned to the network interface.
     */
    Ipv4Prefix?: String;
  }
  export type Ipv4PrefixesList = Ipv4PrefixSpecification[];
  export type Ipv6Address = string;
  export type Ipv6AddressList = String[];
  export interface Ipv6CidrAssociation {
    /**
     * The IPv6 CIDR block.
     */
    Ipv6Cidr?: String;
    /**
     * The resource that's associated with the IPv6 CIDR block.
     */
    AssociatedResource?: String;
  }
  export type Ipv6CidrAssociationSet = Ipv6CidrAssociation[];
  export interface Ipv6CidrBlock {
    /**
     * The IPv6 CIDR block.
     */
    Ipv6CidrBlock?: String;
  }
  export type Ipv6CidrBlockSet = Ipv6CidrBlock[];
  export type Ipv6Flag = boolean;
  export interface Ipv6Pool {
    /**
     * The ID of the address pool.
     */
    PoolId?: String;
    /**
     * The description for the address pool.
     */
    Description?: String;
    /**
     * The CIDR blocks for the address pool.
     */
    PoolCidrBlocks?: PoolCidrBlocksSet;
    /**
     * Any tags for the address pool.
     */
    Tags?: TagList;
  }
  export type Ipv6PoolEc2Id = string;
  export type Ipv6PoolIdList = Ipv6PoolEc2Id[];
  export type Ipv6PoolMaxResults = number;
  export type Ipv6PoolSet = Ipv6Pool[];
  export type Ipv6PrefixList = Ipv6PrefixSpecificationRequest[];
  export type Ipv6PrefixListResponse = Ipv6PrefixSpecificationResponse[];
  export interface Ipv6PrefixSpecification {
    /**
     * The IPv6 prefix.
     */
    Ipv6Prefix?: String;
  }
  export interface Ipv6PrefixSpecificationRequest {
    /**
     * The IPv6 prefix.
     */
    Ipv6Prefix?: String;
  }
  export interface Ipv6PrefixSpecificationResponse {
    /**
     * The IPv6 delegated prefixes assigned to the network interface.
     */
    Ipv6Prefix?: String;
  }
  export type Ipv6PrefixesList = Ipv6PrefixSpecification[];
  export interface Ipv6Range {
    /**
     * The IPv6 CIDR range. You can either specify a CIDR range or a source security group, not both. To specify a single IPv6 address, use the /128 prefix length.
     */
    CidrIpv6?: String;
    /**
     * A description for the security group rule that references this IPv6 address range. Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=&amp;;{}!$*
     */
    Description?: String;
  }
  export type Ipv6RangeList = Ipv6Range[];
  export type Ipv6SupportValue = "enable"|"disable"|string;
  export type KernelId = string;
  export type KeyFormat = "pem"|"ppk"|string;
  export type KeyNameStringList = KeyPairName[];
  export interface KeyPair {
    /**
     *   For RSA key pairs, the key fingerprint is the SHA-1 digest of the DER encoded private key.   For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.  
     */
    KeyFingerprint?: String;
    /**
     * An unencrypted PEM encoded RSA or ED25519 private key.
     */
    KeyMaterial?: SensitiveUserData;
    /**
     * The name of the key pair.
     */
    KeyName?: String;
    /**
     * The ID of the key pair.
     */
    KeyPairId?: String;
    /**
     * Any tags applied to the key pair.
     */
    Tags?: TagList;
  }
  export type KeyPairId = string;
  export type KeyPairIdStringList = KeyPairId[];
  export interface KeyPairInfo {
    /**
     * The ID of the key pair.
     */
    KeyPairId?: String;
    /**
     * If you used CreateKeyPair to create the key pair:   For RSA key pairs, the key fingerprint is the SHA-1 digest of the DER encoded private key.   For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.   If you used ImportKeyPair to provide Amazon Web Services the public key:   For RSA key pairs, the key fingerprint is the MD5 public key fingerprint as specified in section 4 of RFC4716.   For ED25519 key pairs, the key fingerprint is the base64-encoded SHA-256 digest, which is the default for OpenSSH, starting with OpenSSH 6.8.  
     */
    KeyFingerprint?: String;
    /**
     * The name of the key pair.
     */
    KeyName?: String;
    /**
     * The type of key pair.
     */
    KeyType?: KeyType;
    /**
     * Any tags applied to the key pair.
     */
    Tags?: TagList;
    /**
     * The public key material.
     */
    PublicKey?: String;
    /**
     * If you used Amazon EC2 to create the key pair, this is the date and time when the key was created, in ISO 8601 date-time format, in the UTC time zone. If you imported an existing key pair to Amazon EC2, this is the date and time the key was imported, in ISO 8601 date-time format, in the UTC time zone.
     */
    CreateTime?: MillisecondDateTime;
  }
  export type KeyPairList = KeyPairInfo[];
  export type KeyPairName = string;
  export type KeyType = "rsa"|"ed25519"|string;
  export type KmsKeyId = string;
  export interface LastError {
    /**
     * The error message for the VPC endpoint error.
     */
    Message?: String;
    /**
     * The error code for the VPC endpoint error.
     */
    Code?: String;
  }
  export interface LaunchPermission {
    /**
     * The name of the group.
     */
    Group?: PermissionGroup;
    /**
     * The Amazon Web Services account ID. Constraints: Up to 10 000 account IDs can be specified in a single request.
     */
    UserId?: String;
    /**
     * The Amazon Resource Name (ARN) of an organization.
     */
    OrganizationArn?: String;
    /**
     * The Amazon Resource Name (ARN) of an organizational unit (OU).
     */
    OrganizationalUnitArn?: String;
  }
  export type LaunchPermissionList = LaunchPermission[];
  export interface LaunchPermissionModifications {
    /**
     * The Amazon Web Services account ID, organization ARN, or OU ARN to add to the list of launch permissions for the AMI.
     */
    Add?: LaunchPermissionList;
    /**
     * The Amazon Web Services account ID, organization ARN, or OU ARN to remove from the list of launch permissions for the AMI.
     */
    Remove?: LaunchPermissionList;
  }
  export interface LaunchSpecification {
    /**
     * The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
     */
    UserData?: SensitiveUserData;
    /**
     * One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
     */
    SecurityGroups?: GroupIdentifierList;
    /**
     * Deprecated.
     */
    AddressingType?: String;
    /**
     * One or more block device mapping entries.
     */
    BlockDeviceMappings?: BlockDeviceMappingList;
    /**
     * Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance. Default: false 
     */
    EbsOptimized?: Boolean;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: IamInstanceProfileSpecification;
    /**
     * The ID of the AMI.
     */
    ImageId?: String;
    /**
     * The instance type. Only one instance type can be specified.
     */
    InstanceType?: InstanceType;
    /**
     * The ID of the kernel.
     */
    KernelId?: String;
    /**
     * The name of the key pair.
     */
    KeyName?: String;
    /**
     * One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
     */
    NetworkInterfaces?: InstanceNetworkInterfaceSpecificationList;
    /**
     * The placement information for the instance.
     */
    Placement?: SpotPlacement;
    /**
     * The ID of the RAM disk.
     */
    RamdiskId?: String;
    /**
     * The ID of the subnet in which to launch the instance.
     */
    SubnetId?: String;
    Monitoring?: RunInstancesMonitoringEnabled;
  }
  export type LaunchSpecsList = SpotFleetLaunchSpecification[];
  export interface LaunchTemplate {
    /**
     * The ID of the launch template.
     */
    LaunchTemplateId?: String;
    /**
     * The name of the launch template.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The time launch template was created.
     */
    CreateTime?: DateTime;
    /**
     * The principal that created the launch template. 
     */
    CreatedBy?: String;
    /**
     * The version number of the default version of the launch template.
     */
    DefaultVersionNumber?: Long;
    /**
     * The version number of the latest version of the launch template.
     */
    LatestVersionNumber?: Long;
    /**
     * The tags for the launch template.
     */
    Tags?: TagList;
  }
  export interface LaunchTemplateAndOverridesResponse {
    /**
     * The launch template.
     */
    LaunchTemplateSpecification?: FleetLaunchTemplateSpecification;
    /**
     * Any parameters that you specify override the same parameters in the launch template.
     */
    Overrides?: FleetLaunchTemplateOverrides;
  }
  export type LaunchTemplateAutoRecoveryState = "default"|"disabled"|string;
  export interface LaunchTemplateBlockDeviceMapping {
    /**
     * The device name.
     */
    DeviceName?: String;
    /**
     * The virtual device name (ephemeralN).
     */
    VirtualName?: String;
    /**
     * Information about the block device for an EBS volume.
     */
    Ebs?: LaunchTemplateEbsBlockDevice;
    /**
     * To omit the device from the block device mapping, specify an empty string.
     */
    NoDevice?: String;
  }
  export type LaunchTemplateBlockDeviceMappingList = LaunchTemplateBlockDeviceMapping[];
  export interface LaunchTemplateBlockDeviceMappingRequest {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    DeviceName?: String;
    /**
     * The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with 2 available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume.
     */
    VirtualName?: String;
    /**
     * Parameters used to automatically set up EBS volumes when the instance is launched.
     */
    Ebs?: LaunchTemplateEbsBlockDeviceRequest;
    /**
     * To omit the device from the block device mapping, specify an empty string.
     */
    NoDevice?: String;
  }
  export type LaunchTemplateBlockDeviceMappingRequestList = LaunchTemplateBlockDeviceMappingRequest[];
  export interface LaunchTemplateCapacityReservationSpecificationRequest {
    /**
     * Indicates the instance's Capacity Reservation preferences. Possible preferences include:    open - The instance can run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).    none - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.  
     */
    CapacityReservationPreference?: CapacityReservationPreference;
    /**
     * Information about the target Capacity Reservation or Capacity Reservation group.
     */
    CapacityReservationTarget?: CapacityReservationTarget;
  }
  export interface LaunchTemplateCapacityReservationSpecificationResponse {
    /**
     * Indicates the instance's Capacity Reservation preferences. Possible preferences include:    open - The instance can run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).    none - The instance avoids running in a Capacity Reservation even if one is available. The instance runs in On-Demand capacity.  
     */
    CapacityReservationPreference?: CapacityReservationPreference;
    /**
     * Information about the target Capacity Reservation or Capacity Reservation group.
     */
    CapacityReservationTarget?: CapacityReservationTargetResponse;
  }
  export interface LaunchTemplateConfig {
    /**
     * The launch template.
     */
    LaunchTemplateSpecification?: FleetLaunchTemplateSpecification;
    /**
     * Any parameters that you specify override the same parameters in the launch template.
     */
    Overrides?: LaunchTemplateOverridesList;
  }
  export type LaunchTemplateConfigList = LaunchTemplateConfig[];
  export interface LaunchTemplateCpuOptions {
    /**
     * The number of CPU cores for the instance.
     */
    CoreCount?: Integer;
    /**
     * The number of threads per CPU core.
     */
    ThreadsPerCore?: Integer;
  }
  export interface LaunchTemplateCpuOptionsRequest {
    /**
     * The number of CPU cores for the instance.
     */
    CoreCount?: Integer;
    /**
     * The number of threads per CPU core. To disable multithreading for the instance, specify a value of 1. Otherwise, specify the default value of 2.
     */
    ThreadsPerCore?: Integer;
  }
  export interface LaunchTemplateEbsBlockDevice {
    /**
     * Indicates whether the EBS volume is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * Indicates whether the EBS volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The number of I/O operations per second (IOPS) that the volume supports. 
     */
    Iops?: Integer;
    /**
     * The ARN of the Key Management Service (KMS) CMK used for encryption.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The size of the volume, in GiB.
     */
    VolumeSize?: Integer;
    /**
     * The volume type.
     */
    VolumeType?: VolumeType;
    /**
     * The throughput that the volume supports, in MiB/s.
     */
    Throughput?: Integer;
  }
  export interface LaunchTemplateEbsBlockDeviceRequest {
    /**
     * Indicates whether the EBS volume is encrypted. Encrypted volumes can only be attached to instances that support Amazon EBS encryption. If you are creating a volume from a snapshot, you can't specify an encryption value.
     */
    Encrypted?: Boolean;
    /**
     * Indicates whether the EBS volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting. The following are the supported values for each volume type:    gp3: 3,000-16,000 IOPS    io1: 100-64,000 IOPS    io2: 100-64,000 IOPS   For io1 and io2 volumes, we guarantee 64,000 IOPS only for Instances built on the Nitro System. Other instance families guarantee performance up to 32,000 IOPS. This parameter is supported for io1, io2, and gp3 volumes only. This parameter is not supported for gp2, st1, sc1, or standard volumes.
     */
    Iops?: Integer;
    /**
     * The ARN of the symmetric Key Management Service (KMS) CMK used for encryption.
     */
    KmsKeyId?: KmsKeyId;
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The size of the volume, in GiBs. You must specify either a snapshot ID or a volume size. The following are the supported volumes sizes for each volume type:    gp2 and gp3: 1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384    standard: 1-1,024  
     */
    VolumeSize?: Integer;
    /**
     * The volume type. For more information, see Amazon EBS volume types in the Amazon Elastic Compute Cloud User Guide.
     */
    VolumeType?: VolumeType;
    /**
     * The throughput to provision for a gp3 volume, with a maximum of 1,000 MiB/s. Valid Range: Minimum value of 125. Maximum value of 1000.
     */
    Throughput?: Integer;
  }
  export interface LaunchTemplateElasticInferenceAccelerator {
    /**
     *  The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge. 
     */
    Type: String;
    /**
     *  The number of elastic inference accelerators to attach to the instance.  Default: 1
     */
    Count?: LaunchTemplateElasticInferenceAcceleratorCount;
  }
  export type LaunchTemplateElasticInferenceAcceleratorCount = number;
  export type LaunchTemplateElasticInferenceAcceleratorList = LaunchTemplateElasticInferenceAccelerator[];
  export interface LaunchTemplateElasticInferenceAcceleratorResponse {
    /**
     *  The type of elastic inference accelerator. The possible values are eia1.medium, eia1.large, and eia1.xlarge. 
     */
    Type?: String;
    /**
     *  The number of elastic inference accelerators to attach to the instance.  Default: 1
     */
    Count?: Integer;
  }
  export type LaunchTemplateElasticInferenceAcceleratorResponseList = LaunchTemplateElasticInferenceAcceleratorResponse[];
  export interface LaunchTemplateEnclaveOptions {
    /**
     * If this parameter is set to true, the instance is enabled for Amazon Web Services Nitro Enclaves; otherwise, it is not enabled for Amazon Web Services Nitro Enclaves.
     */
    Enabled?: Boolean;
  }
  export interface LaunchTemplateEnclaveOptionsRequest {
    /**
     * To enable the instance for Amazon Web Services Nitro Enclaves, set this parameter to true.
     */
    Enabled?: Boolean;
  }
  export type LaunchTemplateErrorCode = "launchTemplateIdDoesNotExist"|"launchTemplateIdMalformed"|"launchTemplateNameDoesNotExist"|"launchTemplateNameMalformed"|"launchTemplateVersionDoesNotExist"|"unexpectedError"|string;
  export interface LaunchTemplateHibernationOptions {
    /**
     * If this parameter is set to true, the instance is enabled for hibernation; otherwise, it is not enabled for hibernation.
     */
    Configured?: Boolean;
  }
  export interface LaunchTemplateHibernationOptionsRequest {
    /**
     * If you set this parameter to true, the instance is enabled for hibernation. Default: false 
     */
    Configured?: Boolean;
  }
  export type LaunchTemplateHttpTokensState = "optional"|"required"|string;
  export interface LaunchTemplateIamInstanceProfileSpecification {
    /**
     * The Amazon Resource Name (ARN) of the instance profile.
     */
    Arn?: String;
    /**
     * The name of the instance profile.
     */
    Name?: String;
  }
  export interface LaunchTemplateIamInstanceProfileSpecificationRequest {
    /**
     * The Amazon Resource Name (ARN) of the instance profile.
     */
    Arn?: String;
    /**
     * The name of the instance profile.
     */
    Name?: String;
  }
  export type LaunchTemplateId = string;
  export type LaunchTemplateIdStringList = LaunchTemplateId[];
  export interface LaunchTemplateInstanceMaintenanceOptions {
    /**
     * Disables the automatic recovery behavior of your instance or sets it to default.
     */
    AutoRecovery?: LaunchTemplateAutoRecoveryState;
  }
  export interface LaunchTemplateInstanceMaintenanceOptionsRequest {
    /**
     * Disables the automatic recovery behavior of your instance or sets it to default. For more information, see Simplified automatic recovery.
     */
    AutoRecovery?: LaunchTemplateAutoRecoveryState;
  }
  export interface LaunchTemplateInstanceMarketOptions {
    /**
     * The market type.
     */
    MarketType?: MarketType;
    /**
     * The options for Spot Instances.
     */
    SpotOptions?: LaunchTemplateSpotMarketOptions;
  }
  export interface LaunchTemplateInstanceMarketOptionsRequest {
    /**
     * The market type.
     */
    MarketType?: MarketType;
    /**
     * The options for Spot Instances.
     */
    SpotOptions?: LaunchTemplateSpotMarketOptionsRequest;
  }
  export type LaunchTemplateInstanceMetadataEndpointState = "disabled"|"enabled"|string;
  export interface LaunchTemplateInstanceMetadataOptions {
    /**
     * The state of the metadata option changes.  pending - The metadata options are being updated and the instance is not ready to process metadata traffic with the new selection.  applied - The metadata options have been successfully applied on the instance.
     */
    State?: LaunchTemplateInstanceMetadataOptionsState;
    /**
     * Indicates whether IMDSv2 is optional or required.  optional - When IMDSv2 is optional, you can choose to retrieve instance metadata with or without a session token in your request. If you retrieve the IAM role credentials without a token, the IMDSv1 role credentials are returned. If you retrieve the IAM role credentials using a valid session token, the IMDSv2 role credentials are returned.  required - When IMDSv2 is required, you must send a session token with any instance metadata retrieval requests. In this state, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available. Default: optional 
     */
    HttpTokens?: LaunchTemplateHttpTokensState;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. Default: 1 Possible values: Integers from 1 to 64
     */
    HttpPutResponseHopLimit?: Integer;
    /**
     * Enables or disables the HTTP metadata endpoint on your instances. If the parameter is not specified, the default state is enabled.  If you specify a value of disabled, you will not be able to access your instance metadata.  
     */
    HttpEndpoint?: LaunchTemplateInstanceMetadataEndpointState;
    /**
     * Enables or disables the IPv6 endpoint for the instance metadata service. Default: disabled 
     */
    HttpProtocolIpv6?: LaunchTemplateInstanceMetadataProtocolIpv6;
    /**
     * Set to enabled to allow access to instance tags from the instance metadata. Set to disabled to turn off access to instance tags from the instance metadata. For more information, see Work with instance tags using the instance metadata. Default: disabled 
     */
    InstanceMetadataTags?: LaunchTemplateInstanceMetadataTagsState;
  }
  export interface LaunchTemplateInstanceMetadataOptionsRequest {
    /**
     * IMDSv2 uses token-backed sessions. Set the use of HTTP tokens to optional (in other words, set the use of IMDSv2 to optional) or required (in other words, set the use of IMDSv2 to required).    optional - When IMDSv2 is optional, you can choose to retrieve instance metadata with or without a session token in your request. If you retrieve the IAM role credentials without a token, the IMDSv1 role credentials are returned. If you retrieve the IAM role credentials using a valid session token, the IMDSv2 role credentials are returned.    required - When IMDSv2 is required, you must send a session token with any instance metadata retrieval requests. In this state, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available.   Default: optional 
     */
    HttpTokens?: LaunchTemplateHttpTokensState;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. Default: 1  Possible values: Integers from 1 to 64
     */
    HttpPutResponseHopLimit?: Integer;
    /**
     * Enables or disables the HTTP metadata endpoint on your instances. If the parameter is not specified, the default state is enabled.  If you specify a value of disabled, you will not be able to access your instance metadata.  
     */
    HttpEndpoint?: LaunchTemplateInstanceMetadataEndpointState;
    /**
     * Enables or disables the IPv6 endpoint for the instance metadata service. Default: disabled 
     */
    HttpProtocolIpv6?: LaunchTemplateInstanceMetadataProtocolIpv6;
    /**
     * Set to enabled to allow access to instance tags from the instance metadata. Set to disabled to turn off access to instance tags from the instance metadata. For more information, see Work with instance tags using the instance metadata. Default: disabled 
     */
    InstanceMetadataTags?: LaunchTemplateInstanceMetadataTagsState;
  }
  export type LaunchTemplateInstanceMetadataOptionsState = "pending"|"applied"|string;
  export type LaunchTemplateInstanceMetadataProtocolIpv6 = "disabled"|"enabled"|string;
  export type LaunchTemplateInstanceMetadataTagsState = "disabled"|"enabled"|string;
  export interface LaunchTemplateInstanceNetworkInterfaceSpecification {
    /**
     * Indicates whether to associate a Carrier IP address with eth0 for a new network interface. Use this option when you launch an instance in a Wavelength Zone and want to associate a Carrier IP address with the network interface. For more information about Carrier IP addresses, see Carrier IP addresses in the Wavelength Developer Guide.
     */
    AssociateCarrierIpAddress?: Boolean;
    /**
     * Indicates whether to associate a public IPv4 address with eth0 for a new network interface.
     */
    AssociatePublicIpAddress?: Boolean;
    /**
     * Indicates whether the network interface is deleted when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
    /**
     * A description for the network interface.
     */
    Description?: String;
    /**
     * The device index for the network interface attachment.
     */
    DeviceIndex?: Integer;
    /**
     * The IDs of one or more security groups.
     */
    Groups?: GroupIdStringList;
    /**
     * The type of network interface.
     */
    InterfaceType?: String;
    /**
     * The number of IPv6 addresses for the network interface.
     */
    Ipv6AddressCount?: Integer;
    /**
     * The IPv6 addresses for the network interface.
     */
    Ipv6Addresses?: InstanceIpv6AddressList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The primary private IPv4 address of the network interface.
     */
    PrivateIpAddress?: String;
    /**
     * One or more private IPv4 addresses.
     */
    PrivateIpAddresses?: PrivateIpAddressSpecificationList;
    /**
     * The number of secondary private IPv4 addresses for the network interface.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * The ID of the subnet for the network interface.
     */
    SubnetId?: SubnetId;
    /**
     * The index of the network card.
     */
    NetworkCardIndex?: Integer;
    /**
     * One or more IPv4 prefixes assigned to the network interface.
     */
    Ipv4Prefixes?: Ipv4PrefixListResponse;
    /**
     * The number of IPv4 prefixes that Amazon Web Services automatically assigned to the network interface.
     */
    Ipv4PrefixCount?: Integer;
    /**
     * One or more IPv6 prefixes assigned to the network interface.
     */
    Ipv6Prefixes?: Ipv6PrefixListResponse;
    /**
     * The number of IPv6 prefixes that Amazon Web Services automatically assigned to the network interface.
     */
    Ipv6PrefixCount?: Integer;
  }
  export type LaunchTemplateInstanceNetworkInterfaceSpecificationList = LaunchTemplateInstanceNetworkInterfaceSpecification[];
  export interface LaunchTemplateInstanceNetworkInterfaceSpecificationRequest {
    /**
     * Associates a Carrier IP address with eth0 for a new network interface. Use this option when you launch an instance in a Wavelength Zone and want to associate a Carrier IP address with the network interface. For more information about Carrier IP addresses, see Carrier IP addresses in the Wavelength Developer Guide.
     */
    AssociateCarrierIpAddress?: Boolean;
    /**
     * Associates a public IPv4 address with eth0 for a new network interface.
     */
    AssociatePublicIpAddress?: Boolean;
    /**
     * Indicates whether the network interface is deleted when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
    /**
     * A description for the network interface.
     */
    Description?: String;
    /**
     * The device index for the network interface attachment.
     */
    DeviceIndex?: Integer;
    /**
     * The IDs of one or more security groups.
     */
    Groups?: SecurityGroupIdStringList;
    /**
     * The type of network interface. To create an Elastic Fabric Adapter (EFA), specify efa. For more information, see Elastic Fabric Adapter in the Amazon Elastic Compute Cloud User Guide. If you are not creating an EFA, specify interface or omit this parameter. Valid values: interface | efa 
     */
    InterfaceType?: String;
    /**
     * The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses.
     */
    Ipv6AddressCount?: Integer;
    /**
     * One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't use this option if you're specifying a number of IPv6 addresses.
     */
    Ipv6Addresses?: InstanceIpv6AddressListRequest;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The primary private IPv4 address of the network interface.
     */
    PrivateIpAddress?: String;
    /**
     * One or more private IPv4 addresses.
     */
    PrivateIpAddresses?: PrivateIpAddressSpecificationList;
    /**
     * The number of secondary private IPv4 addresses to assign to a network interface.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * The ID of the subnet for the network interface.
     */
    SubnetId?: SubnetId;
    /**
     * The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0.
     */
    NetworkCardIndex?: Integer;
    /**
     * One or more IPv4 prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option.
     */
    Ipv4Prefixes?: Ipv4PrefixList;
    /**
     * The number of IPv4 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv4Prefix option.
     */
    Ipv4PrefixCount?: Integer;
    /**
     * One or more IPv6 prefixes to be assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option.
     */
    Ipv6Prefixes?: Ipv6PrefixList;
    /**
     * The number of IPv6 prefixes to be automatically assigned to the network interface. You cannot use this option if you use the Ipv6Prefix option.
     */
    Ipv6PrefixCount?: Integer;
  }
  export type LaunchTemplateInstanceNetworkInterfaceSpecificationRequestList = LaunchTemplateInstanceNetworkInterfaceSpecificationRequest[];
  export interface LaunchTemplateLicenseConfiguration {
    /**
     * The Amazon Resource Name (ARN) of the license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export interface LaunchTemplateLicenseConfigurationRequest {
    /**
     * The Amazon Resource Name (ARN) of the license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export type LaunchTemplateLicenseList = LaunchTemplateLicenseConfiguration[];
  export type LaunchTemplateLicenseSpecificationListRequest = LaunchTemplateLicenseConfigurationRequest[];
  export type LaunchTemplateName = string;
  export type LaunchTemplateNameStringList = LaunchTemplateName[];
  export interface LaunchTemplateOverrides {
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The ID of the subnet in which to launch the instances.
     */
    SubnetId?: SubnetId;
    /**
     * The Availability Zone in which to launch the instances.
     */
    AvailabilityZone?: String;
    /**
     * The number of units provided by the specified instance type.
     */
    WeightedCapacity?: Double;
    /**
     * The priority for the launch template override. The highest priority is launched first. If OnDemandAllocationStrategy is set to prioritized, Spot Fleet uses priority to determine which launch template override to use first in fulfilling On-Demand capacity. If the Spot AllocationStrategy is set to capacityOptimizedPrioritized, Spot Fleet uses priority on a best-effort basis to determine which launch template override to use in fulfilling Spot capacity, but optimizes for capacity first. Valid values are whole numbers starting at 0. The lower the number, the higher the priority. If no number is set, the launch template override has the lowest priority. You can set the same priority for different launch template overrides.
     */
    Priority?: Double;
    /**
     * The instance requirements. When you specify instance requirements, Amazon EC2 will identify instance types with the provided requirements, and then use your On-Demand and Spot allocation strategies to launch instances from these instance types, in the same way as when you specify a list of instance types.  If you specify InstanceRequirements, you can't specify InstanceType. 
     */
    InstanceRequirements?: InstanceRequirements;
  }
  export type LaunchTemplateOverridesList = LaunchTemplateOverrides[];
  export interface LaunchTemplatePlacement {
    /**
     * The Availability Zone of the instance.
     */
    AvailabilityZone?: String;
    /**
     * The affinity setting for the instance on the Dedicated Host.
     */
    Affinity?: String;
    /**
     * The name of the placement group for the instance.
     */
    GroupName?: String;
    /**
     * The ID of the Dedicated Host for the instance.
     */
    HostId?: String;
    /**
     * The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. 
     */
    Tenancy?: Tenancy;
    /**
     * Reserved for future use.
     */
    SpreadDomain?: String;
    /**
     * The ARN of the host resource group in which to launch the instances. 
     */
    HostResourceGroupArn?: String;
    /**
     * The number of the partition the instance should launch in. Valid only if the placement group strategy is set to partition.
     */
    PartitionNumber?: Integer;
    /**
     * The Group ID of the placement group. You must specify the Placement Group Group ID to launch an instance in a shared placement group.
     */
    GroupId?: PlacementGroupId;
  }
  export interface LaunchTemplatePlacementRequest {
    /**
     * The Availability Zone for the instance.
     */
    AvailabilityZone?: String;
    /**
     * The affinity setting for an instance on a Dedicated Host.
     */
    Affinity?: String;
    /**
     * The name of the placement group for the instance.
     */
    GroupName?: PlacementGroupName;
    /**
     * The ID of the Dedicated Host for the instance.
     */
    HostId?: DedicatedHostId;
    /**
     * The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware.
     */
    Tenancy?: Tenancy;
    /**
     * Reserved for future use.
     */
    SpreadDomain?: String;
    /**
     * The ARN of the host resource group in which to launch the instances. If you specify a host resource group ARN, omit the Tenancy parameter or set it to host.
     */
    HostResourceGroupArn?: String;
    /**
     * The number of the partition the instance should launch in. Valid only if the placement group strategy is set to partition.
     */
    PartitionNumber?: Integer;
    /**
     * The Group Id of a placement group. You must specify the Placement Group Group Id to launch an instance in a shared placement group.
     */
    GroupId?: PlacementGroupId;
  }
  export interface LaunchTemplatePrivateDnsNameOptions {
    /**
     * The type of hostname to assign to an instance.
     */
    HostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export interface LaunchTemplatePrivateDnsNameOptionsRequest {
    /**
     * The type of hostname for Amazon EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 native subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
     */
    HostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export type LaunchTemplateSet = LaunchTemplate[];
  export interface LaunchTemplateSpecification {
    /**
     * The ID of the launch template. You must specify the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: String;
    /**
     * The launch template version number, $Latest, or $Default. If the value is $Latest, Amazon EC2 uses the latest version of the launch template. If the value is $Default, Amazon EC2 uses the default version of the launch template. Default: The default version of the launch template.
     */
    Version?: String;
  }
  export interface LaunchTemplateSpotMarketOptions {
    /**
     * The maximum hourly price you're willing to pay for the Spot Instances. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxPrice?: String;
    /**
     * The Spot Instance request type.
     */
    SpotInstanceType?: SpotInstanceType;
    /**
     * The required duration for the Spot Instances (also known as Spot blocks), in minutes. This value must be a multiple of 60 (60, 120, 180, 240, 300, or 360).
     */
    BlockDurationMinutes?: Integer;
    /**
     * The end date of the request. For a one-time request, the request remains active until all instances launch, the request is canceled, or this date is reached. If the request is persistent, it remains active until it is canceled or this date and time is reached.
     */
    ValidUntil?: DateTime;
    /**
     * The behavior when a Spot Instance is interrupted.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
  }
  export interface LaunchTemplateSpotMarketOptionsRequest {
    /**
     * The maximum hourly price you're willing to pay for the Spot Instances. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxPrice?: String;
    /**
     * The Spot Instance request type.
     */
    SpotInstanceType?: SpotInstanceType;
    /**
     * Deprecated.
     */
    BlockDurationMinutes?: Integer;
    /**
     * The end date of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ). Supported only for persistent requests.   For a persistent request, the request remains active until the ValidUntil date and time is reached. Otherwise, the request remains active until you cancel it.   For a one-time request, ValidUntil is not supported. The request remains active until all instances launch or you cancel the request.   Default: 7 days from the current date
     */
    ValidUntil?: DateTime;
    /**
     * The behavior when a Spot Instance is interrupted. The default is terminate.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
  }
  export interface LaunchTemplateTagSpecification {
    /**
     * The type of resource to tag.
     */
    ResourceType?: ResourceType;
    /**
     * The tags for the resource.
     */
    Tags?: TagList;
  }
  export type LaunchTemplateTagSpecificationList = LaunchTemplateTagSpecification[];
  export interface LaunchTemplateTagSpecificationRequest {
    /**
     * The type of resource to tag. The Valid Values are all the resource types that can be tagged. However, when creating a launch template, you can specify tags for the following resource types only: instance | volume | elastic-gpu | network-interface | spot-instances-request  To tag a resource after it has been created, see CreateTags.
     */
    ResourceType?: ResourceType;
    /**
     * The tags to apply to the resource.
     */
    Tags?: TagList;
  }
  export type LaunchTemplateTagSpecificationRequestList = LaunchTemplateTagSpecificationRequest[];
  export interface LaunchTemplateVersion {
    /**
     * The ID of the launch template.
     */
    LaunchTemplateId?: String;
    /**
     * The name of the launch template.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The version number.
     */
    VersionNumber?: Long;
    /**
     * The description for the version.
     */
    VersionDescription?: VersionDescription;
    /**
     * The time the version was created.
     */
    CreateTime?: DateTime;
    /**
     * The principal that created the version.
     */
    CreatedBy?: String;
    /**
     * Indicates whether the version is the default version.
     */
    DefaultVersion?: Boolean;
    /**
     * Information about the launch template.
     */
    LaunchTemplateData?: ResponseLaunchTemplateData;
  }
  export type LaunchTemplateVersionSet = LaunchTemplateVersion[];
  export interface LaunchTemplatesMonitoring {
    /**
     * Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
     */
    Enabled?: Boolean;
  }
  export interface LaunchTemplatesMonitoringRequest {
    /**
     * Specify true to enable detailed monitoring. Otherwise, basic monitoring is enabled.
     */
    Enabled?: Boolean;
  }
  export interface LicenseConfiguration {
    /**
     * The Amazon Resource Name (ARN) of the license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export interface LicenseConfigurationRequest {
    /**
     * The Amazon Resource Name (ARN) of the license configuration.
     */
    LicenseConfigurationArn?: String;
  }
  export type LicenseList = LicenseConfiguration[];
  export type LicenseSpecificationListRequest = LicenseConfigurationRequest[];
  export type ListImagesInRecycleBinMaxResults = number;
  export interface ListImagesInRecycleBinRequest {
    /**
     * The IDs of the AMIs to list. Omit this parameter to list all of the AMIs that are in the Recycle Bin. You can specify up to 20 IDs in a single request.
     */
    ImageIds?: ImageIdStringList;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: ListImagesInRecycleBinMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ListImagesInRecycleBinResult {
    /**
     * Information about the AMIs.
     */
    Images?: ImageRecycleBinInfoList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type ListSnapshotsInRecycleBinMaxResults = number;
  export interface ListSnapshotsInRecycleBinRequest {
    /**
     * The maximum number of items to return for this request. To get the next page of items, make another request with the token returned in the output. For more information, see Pagination.
     */
    MaxResults?: ListSnapshotsInRecycleBinMaxResults;
    /**
     * The token returned from a previous paginated request. Pagination continues from the end of the items returned by the previous request.
     */
    NextToken?: String;
    /**
     * The IDs of the snapshots to list. Omit this parameter to list all of the snapshots that are in the Recycle Bin.
     */
    SnapshotIds?: SnapshotIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ListSnapshotsInRecycleBinResult {
    /**
     * Information about the snapshots.
     */
    Snapshots?: SnapshotRecycleBinInfoList;
    /**
     * The token to include in another request to get the next page of items. This value is null when there are no more items to return.
     */
    NextToken?: String;
  }
  export type ListingState = "available"|"sold"|"cancelled"|"pending"|string;
  export type ListingStatus = "active"|"pending"|"cancelled"|"closed"|string;
  export type LoadBalancerArn = string;
  export interface LoadBalancersConfig {
    /**
     * The Classic Load Balancers.
     */
    ClassicLoadBalancersConfig?: ClassicLoadBalancersConfig;
    /**
     * The target groups.
     */
    TargetGroupsConfig?: TargetGroupsConfig;
  }
  export interface LoadPermission {
    /**
     * The Amazon Web Services account ID.
     */
    UserId?: String;
    /**
     * The name of the group.
     */
    Group?: PermissionGroup;
  }
  export type LoadPermissionList = LoadPermission[];
  export type LoadPermissionListRequest = LoadPermissionRequest[];
  export interface LoadPermissionModifications {
    /**
     * The load permissions to add.
     */
    Add?: LoadPermissionListRequest;
    /**
     * The load permissions to remove.
     */
    Remove?: LoadPermissionListRequest;
  }
  export interface LoadPermissionRequest {
    /**
     * The name of the group.
     */
    Group?: PermissionGroup;
    /**
     * The Amazon Web Services account ID.
     */
    UserId?: String;
  }
  export interface LocalGateway {
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: LocalGatewayId;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway.
     */
    OwnerId?: String;
    /**
     * The state of the local gateway.
     */
    State?: String;
    /**
     * The tags assigned to the local gateway.
     */
    Tags?: TagList;
  }
  export type LocalGatewayId = string;
  export type LocalGatewayIdSet = LocalGatewayId[];
  export type LocalGatewayMaxResults = number;
  export interface LocalGatewayRoute {
    /**
     * The CIDR block used for destination matches.
     */
    DestinationCidrBlock?: String;
    /**
     * The ID of the virtual interface group.
     */
    LocalGatewayVirtualInterfaceGroupId?: LocalGatewayVirtualInterfaceGroupId;
    /**
     * The route type.
     */
    Type?: LocalGatewayRouteType;
    /**
     * The state of the route.
     */
    State?: LocalGatewayRouteState;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: LocalGatewayRoutetableId;
    /**
     * The Amazon Resource Name (ARN) of the local gateway route table.
     */
    LocalGatewayRouteTableArn?: ResourceArn;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway route.
     */
    OwnerId?: String;
    /**
     * The ID of the subnet.
     */
    SubnetId?: SubnetId;
    /**
     * The ID of the customer-owned address pool.
     */
    CoipPoolId?: CoipPoolId;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     *  The ID of the prefix list. 
     */
    DestinationPrefixListId?: PrefixListResourceId;
  }
  export type LocalGatewayRouteList = LocalGatewayRoute[];
  export type LocalGatewayRouteState = "pending"|"active"|"blackhole"|"deleting"|"deleted"|string;
  export interface LocalGatewayRouteTable {
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: String;
    /**
     * The Amazon Resource Name (ARN) of the local gateway route table.
     */
    LocalGatewayRouteTableArn?: ResourceArn;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: LocalGatewayId;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway route table.
     */
    OwnerId?: String;
    /**
     * The state of the local gateway route table.
     */
    State?: String;
    /**
     * The tags assigned to the local gateway route table.
     */
    Tags?: TagList;
    /**
     * The mode of the local gateway route table.
     */
    Mode?: LocalGatewayRouteTableMode;
    /**
     * Information about the state change.
     */
    StateReason?: StateReason;
  }
  export type LocalGatewayRouteTableIdSet = LocalGatewayRoutetableId[];
  export type LocalGatewayRouteTableMode = "direct-vpc-routing"|"coip"|string;
  export type LocalGatewayRouteTableSet = LocalGatewayRouteTable[];
  export interface LocalGatewayRouteTableVirtualInterfaceGroupAssociation {
    /**
     * The ID of the association.
     */
    LocalGatewayRouteTableVirtualInterfaceGroupAssociationId?: LocalGatewayRouteTableVirtualInterfaceGroupAssociationId;
    /**
     * The ID of the virtual interface group.
     */
    LocalGatewayVirtualInterfaceGroupId?: LocalGatewayVirtualInterfaceGroupId;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: String;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: LocalGatewayId;
    /**
     * The Amazon Resource Name (ARN) of the local gateway route table for the virtual interface group.
     */
    LocalGatewayRouteTableArn?: ResourceArn;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway virtual interface group association.
     */
    OwnerId?: String;
    /**
     * The state of the association.
     */
    State?: String;
    /**
     * The tags assigned to the association.
     */
    Tags?: TagList;
  }
  export type LocalGatewayRouteTableVirtualInterfaceGroupAssociationId = string;
  export type LocalGatewayRouteTableVirtualInterfaceGroupAssociationIdSet = LocalGatewayRouteTableVirtualInterfaceGroupAssociationId[];
  export type LocalGatewayRouteTableVirtualInterfaceGroupAssociationSet = LocalGatewayRouteTableVirtualInterfaceGroupAssociation[];
  export interface LocalGatewayRouteTableVpcAssociation {
    /**
     * The ID of the association.
     */
    LocalGatewayRouteTableVpcAssociationId?: LocalGatewayRouteTableVpcAssociationId;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId?: String;
    /**
     * The Amazon Resource Name (ARN) of the local gateway route table for the association.
     */
    LocalGatewayRouteTableArn?: ResourceArn;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: String;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway route table for the association.
     */
    OwnerId?: String;
    /**
     * The state of the association.
     */
    State?: String;
    /**
     * The tags assigned to the association.
     */
    Tags?: TagList;
  }
  export type LocalGatewayRouteTableVpcAssociationId = string;
  export type LocalGatewayRouteTableVpcAssociationIdSet = LocalGatewayRouteTableVpcAssociationId[];
  export type LocalGatewayRouteTableVpcAssociationSet = LocalGatewayRouteTableVpcAssociation[];
  export type LocalGatewayRouteType = "static"|"propagated"|string;
  export type LocalGatewayRoutetableId = string;
  export type LocalGatewaySet = LocalGateway[];
  export interface LocalGatewayVirtualInterface {
    /**
     * The ID of the virtual interface.
     */
    LocalGatewayVirtualInterfaceId?: LocalGatewayVirtualInterfaceId;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: String;
    /**
     * The ID of the VLAN.
     */
    Vlan?: Integer;
    /**
     * The local address.
     */
    LocalAddress?: String;
    /**
     * The peer address.
     */
    PeerAddress?: String;
    /**
     * The Border Gateway Protocol (BGP) Autonomous System Number (ASN) of the local gateway.
     */
    LocalBgpAsn?: Integer;
    /**
     * The peer BGP ASN.
     */
    PeerBgpAsn?: Integer;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway virtual interface.
     */
    OwnerId?: String;
    /**
     * The tags assigned to the virtual interface.
     */
    Tags?: TagList;
  }
  export interface LocalGatewayVirtualInterfaceGroup {
    /**
     * The ID of the virtual interface group.
     */
    LocalGatewayVirtualInterfaceGroupId?: LocalGatewayVirtualInterfaceGroupId;
    /**
     * The IDs of the virtual interfaces.
     */
    LocalGatewayVirtualInterfaceIds?: LocalGatewayVirtualInterfaceIdSet;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the local gateway virtual interface group.
     */
    OwnerId?: String;
    /**
     * The tags assigned to the virtual interface group.
     */
    Tags?: TagList;
  }
  export type LocalGatewayVirtualInterfaceGroupId = string;
  export type LocalGatewayVirtualInterfaceGroupIdSet = LocalGatewayVirtualInterfaceGroupId[];
  export type LocalGatewayVirtualInterfaceGroupSet = LocalGatewayVirtualInterfaceGroup[];
  export type LocalGatewayVirtualInterfaceId = string;
  export type LocalGatewayVirtualInterfaceIdSet = LocalGatewayVirtualInterfaceId[];
  export type LocalGatewayVirtualInterfaceSet = LocalGatewayVirtualInterface[];
  export type LocalStorage = "included"|"required"|"excluded"|string;
  export type LocalStorageType = "hdd"|"ssd"|string;
  export type LocalStorageTypeSet = LocalStorageType[];
  export type Location = string;
  export type LocationType = "region"|"availability-zone"|"availability-zone-id"|string;
  export type LogDestinationType = "cloud-watch-logs"|"s3"|"kinesis-data-firehose"|string;
  export type Long = number;
  export interface MaintenanceDetails {
    /**
     * Verify existence of a pending maintenance.
     */
    PendingMaintenance?: String;
    /**
     * The timestamp after which Amazon Web Services will automatically apply maintenance.
     */
    MaintenanceAutoAppliedAfter?: MillisecondDateTime;
    /**
     * Timestamp of last applied maintenance.
     */
    LastMaintenanceApplied?: MillisecondDateTime;
  }
  export interface ManagedPrefixList {
    /**
     * The ID of the prefix list.
     */
    PrefixListId?: PrefixListResourceId;
    /**
     * The IP address version.
     */
    AddressFamily?: String;
    /**
     * The current state of the prefix list.
     */
    State?: PrefixListState;
    /**
     * The state message.
     */
    StateMessage?: String;
    /**
     * The Amazon Resource Name (ARN) for the prefix list.
     */
    PrefixListArn?: ResourceArn;
    /**
     * The name of the prefix list.
     */
    PrefixListName?: String;
    /**
     * The maximum number of entries for the prefix list.
     */
    MaxEntries?: Integer;
    /**
     * The version of the prefix list.
     */
    Version?: Long;
    /**
     * The tags for the prefix list.
     */
    Tags?: TagList;
    /**
     * The ID of the owner of the prefix list.
     */
    OwnerId?: String;
  }
  export type ManagedPrefixListSet = ManagedPrefixList[];
  export type MarketType = "spot"|string;
  export type MaxIpv4AddrPerInterface = number;
  export type MaxIpv6AddrPerInterface = number;
  export type MaxNetworkInterfaces = number;
  export type MaxResults = number;
  export type MaxResultsParam = number;
  export type MaximumBandwidthInMbps = number;
  export type MaximumEfaInterfaces = number;
  export type MaximumIops = number;
  export type MaximumNetworkCards = number;
  export type MaximumThroughputInMBps = number;
  export type MembershipType = "static"|"igmp"|string;
  export interface MemoryGiBPerVCpu {
    /**
     * The minimum amount of memory per vCPU, in GiB. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Double;
    /**
     * The maximum amount of memory per vCPU, in GiB. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Double;
  }
  export interface MemoryGiBPerVCpuRequest {
    /**
     * The minimum amount of memory per vCPU, in GiB. To specify no minimum limit, omit this parameter.
     */
    Min?: Double;
    /**
     * The maximum amount of memory per vCPU, in GiB. To specify no maximum limit, omit this parameter.
     */
    Max?: Double;
  }
  export interface MemoryInfo {
    /**
     * The size of the memory, in MiB.
     */
    SizeInMiB?: MemorySize;
  }
  export interface MemoryMiB {
    /**
     * The minimum amount of memory, in MiB. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum amount of memory, in MiB. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface MemoryMiBRequest {
    /**
     * The minimum amount of memory, in MiB. To specify no minimum limit, specify 0.
     */
    Min: Integer;
    /**
     * The maximum amount of memory, in MiB. To specify no maximum limit, omit this parameter.
     */
    Max?: Integer;
  }
  export type MemorySize = number;
  export interface MetricPoint {
    /**
     * The start date for the metric point. The starting date for the metric point. The starting time must be formatted as yyyy-mm-ddThh:mm:ss. For example, 2022-06-10T12:00:00.000Z.
     */
    StartDate?: MillisecondDateTime;
    /**
     * The end date for the metric point. The ending time must be formatted as yyyy-mm-ddThh:mm:ss. For example, 2022-06-12T12:00:00.000Z.
     */
    EndDate?: MillisecondDateTime;
    Value?: Float;
    /**
     * The status of the metric point.
     */
    Status?: String;
  }
  export type MetricPoints = MetricPoint[];
  export type MetricType = "aggregate-latency"|string;
  export type MillisecondDateTime = Date;
  export interface ModifyAddressAttributeRequest {
    /**
     * [EC2-VPC] The allocation ID.
     */
    AllocationId: AllocationId;
    /**
     * The domain name to modify for the IP address.
     */
    DomainName?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyAddressAttributeResult {
    /**
     * Information about the Elastic IP address.
     */
    Address?: AddressAttribute;
  }
  export interface ModifyAvailabilityZoneGroupRequest {
    /**
     * The name of the Availability Zone group, Local Zone group, or Wavelength Zone group.
     */
    GroupName: String;
    /**
     * Indicates whether you are opted in to the Local Zone group or Wavelength Zone group. The only valid value is opted-in. You must contact Amazon Web Services Support to opt out of a Local Zone or Wavelength Zone group.
     */
    OptInStatus: ModifyAvailabilityZoneOptInStatus;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyAvailabilityZoneGroupResult {
    /**
     * Is true if the request succeeds, and an error otherwise.
     */
    Return?: Boolean;
  }
  export type ModifyAvailabilityZoneOptInStatus = "opted-in"|"not-opted-in"|string;
  export interface ModifyCapacityReservationFleetRequest {
    /**
     * The ID of the Capacity Reservation Fleet to modify.
     */
    CapacityReservationFleetId: CapacityReservationFleetId;
    /**
     * The total number of capacity units to be reserved by the Capacity Reservation Fleet. This value, together with the instance type weights that you assign to each instance type used by the Fleet determine the number of instances for which the Fleet reserves capacity. Both values are based on units that make sense for your workload. For more information, see Total target capacity in the Amazon EC2 User Guide.
     */
    TotalTargetCapacity?: Integer;
    /**
     * The date and time at which the Capacity Reservation Fleet expires. When the Capacity Reservation Fleet expires, its state changes to expired and all of the Capacity Reservations in the Fleet expire. The Capacity Reservation Fleet expires within an hour after the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation Fleet is guaranteed to expire between 13:30:55 and 14:30:55 on 5/31/2019. You can't specify EndDate and  RemoveEndDate in the same request.
     */
    EndDate?: MillisecondDateTime;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to remove the end date from the Capacity Reservation Fleet. If you remove the end date, the Capacity Reservation Fleet does not expire and it remains active until you explicitly cancel it using the CancelCapacityReservationFleet action. You can't specify RemoveEndDate and  EndDate in the same request.
     */
    RemoveEndDate?: Boolean;
  }
  export interface ModifyCapacityReservationFleetResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyCapacityReservationRequest {
    /**
     * The ID of the Capacity Reservation.
     */
    CapacityReservationId: CapacityReservationId;
    /**
     * The number of instances for which to reserve capacity. The number of instances can't be increased or decreased by more than 1000 in a single request.
     */
    InstanceCount?: Integer;
    /**
     * The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to expired when it reaches its end date and time. The Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019. You must provide an EndDate value if EndDateType is limited. Omit EndDate if EndDateType is unlimited.
     */
    EndDate?: DateTime;
    /**
     * Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:    unlimited - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an EndDate value if EndDateType is unlimited.    limited - The Capacity Reservation expires automatically at a specified date and time. You must provide an EndDate value if EndDateType is limited.  
     */
    EndDateType?: EndDateType;
    /**
     * Reserved. Capacity Reservations you have created are accepted by default.
     */
    Accept?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Reserved for future use.
     */
    AdditionalInfo?: String;
  }
  export interface ModifyCapacityReservationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyClientVpnEndpointRequest {
    /**
     * The ID of the Client VPN endpoint to modify.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ARN of the server certificate to be used. The server certificate must be provisioned in Certificate Manager (ACM).
     */
    ServerCertificateArn?: String;
    /**
     * Information about the client connection logging options. If you enable client connection logging, data about client connections is sent to a Cloudwatch Logs log stream. The following information is logged:   Client connection requests   Client connection results (successful and unsuccessful)   Reasons for unsuccessful client connection requests   Client connection termination time  
     */
    ConnectionLogOptions?: ConnectionLogOptions;
    /**
     * Information about the DNS servers to be used by Client VPN connections. A Client VPN endpoint can have up to two DNS servers.
     */
    DnsServers?: DnsServersOptionsModifyStructure;
    /**
     * The port number to assign to the Client VPN endpoint for TCP and UDP traffic. Valid Values: 443 | 1194  Default Value: 443 
     */
    VpnPort?: Integer;
    /**
     * A brief description of the Client VPN endpoint.
     */
    Description?: String;
    /**
     * Indicates whether the VPN is split-tunnel. For information about split-tunnel VPN endpoints, see Split-tunnel Client VPN endpoint in the Client VPN Administrator Guide.
     */
    SplitTunnel?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of one or more security groups to apply to the target network.
     */
    SecurityGroupIds?: ClientVpnSecurityGroupIdSet;
    /**
     * The ID of the VPC to associate with the Client VPN endpoint.
     */
    VpcId?: VpcId;
    /**
     * Specify whether to enable the self-service portal for the Client VPN endpoint.
     */
    SelfServicePortal?: SelfServicePortal;
    /**
     * The options for managing connection authorization for new client connections.
     */
    ClientConnectOptions?: ClientConnectOptions;
    /**
     * The maximum VPN session duration time in hours. Valid values: 8 | 10 | 12 | 24  Default value: 24 
     */
    SessionTimeoutHours?: Integer;
    /**
     * Options for enabling a customizable text banner that will be displayed on Amazon Web Services provided clients when a VPN session is established.
     */
    ClientLoginBannerOptions?: ClientLoginBannerOptions;
  }
  export interface ModifyClientVpnEndpointResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyDefaultCreditSpecificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The instance family.
     */
    InstanceFamily: UnlimitedSupportedInstanceFamily;
    /**
     * The credit option for CPU usage of the instance family. Valid Values: standard | unlimited 
     */
    CpuCredits: String;
  }
  export interface ModifyDefaultCreditSpecificationResult {
    /**
     * The default credit option for CPU usage of the instance family.
     */
    InstanceFamilyCreditSpecification?: InstanceFamilyCreditSpecification;
  }
  export interface ModifyEbsDefaultKmsKeyIdRequest {
    /**
     * The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified, the encrypted state must be true. You can specify the KMS key using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the action can appear to complete, but eventually fails. Amazon EBS does not support asymmetric KMS keys.
     */
    KmsKeyId: KmsKeyId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyEbsDefaultKmsKeyIdResult {
    /**
     * The Amazon Resource Name (ARN) of the default KMS key for encryption by default.
     */
    KmsKeyId?: String;
  }
  export interface ModifyFleetRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether running instances should be terminated if the total target capacity of the EC2 Fleet is decreased below the current size of the EC2 Fleet. Supported only for fleets of type maintain.
     */
    ExcessCapacityTerminationPolicy?: FleetExcessCapacityTerminationPolicy;
    /**
     * The launch template and overrides.
     */
    LaunchTemplateConfigs?: FleetLaunchTemplateConfigListRequest;
    /**
     * The ID of the EC2 Fleet.
     */
    FleetId: FleetId;
    /**
     * The size of the EC2 Fleet.
     */
    TargetCapacitySpecification?: TargetCapacitySpecificationRequest;
    /**
     * Reserved.
     */
    Context?: String;
  }
  export interface ModifyFleetResult {
    /**
     * If the request succeeds, the response returns true. If the request fails, no response is returned, and instead an error message is returned.
     */
    Return?: Boolean;
  }
  export interface ModifyFpgaImageAttributeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the AFI.
     */
    FpgaImageId: FpgaImageId;
    /**
     * The name of the attribute.
     */
    Attribute?: FpgaImageAttributeName;
    /**
     * The operation type.
     */
    OperationType?: OperationType;
    /**
     * The Amazon Web Services account IDs. This parameter is valid only when modifying the loadPermission attribute.
     */
    UserIds?: UserIdStringList;
    /**
     * The user groups. This parameter is valid only when modifying the loadPermission attribute.
     */
    UserGroups?: UserGroupStringList;
    /**
     * The product codes. After you add a product code to an AFI, it can't be removed. This parameter is valid only when modifying the productCodes attribute.
     */
    ProductCodes?: ProductCodeStringList;
    /**
     * The load permission for the AFI.
     */
    LoadPermission?: LoadPermissionModifications;
    /**
     * A description for the AFI.
     */
    Description?: String;
    /**
     * A name for the AFI.
     */
    Name?: String;
  }
  export interface ModifyFpgaImageAttributeResult {
    /**
     * Information about the attribute.
     */
    FpgaImageAttribute?: FpgaImageAttribute;
  }
  export interface ModifyHostsRequest {
    /**
     * Specify whether to enable or disable auto-placement.
     */
    AutoPlacement?: AutoPlacement;
    /**
     * The IDs of the Dedicated Hosts to modify.
     */
    HostIds: RequestHostIdList;
    /**
     * Indicates whether to enable or disable host recovery for the Dedicated Host. For more information, see  Host recovery in the Amazon EC2 User Guide.
     */
    HostRecovery?: HostRecovery;
    /**
     * Specifies the instance type to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support only a specific instance type. If you want to modify a Dedicated Host to support multiple instance types in its current instance family, omit this parameter and specify InstanceFamily instead. You cannot specify InstanceType and InstanceFamily in the same request.
     */
    InstanceType?: String;
    /**
     * Specifies the instance family to be supported by the Dedicated Host. Specify this parameter to modify a Dedicated Host to support multiple instance types within its current instance family. If you want to modify a Dedicated Host to support a specific instance type only, omit this parameter and specify InstanceType instead. You cannot specify InstanceFamily and InstanceType in the same request.
     */
    InstanceFamily?: String;
    /**
     * Indicates whether to enable or disable host maintenance for the Dedicated Host. For more information, see  Host maintenance in the Amazon EC2 User Guide.
     */
    HostMaintenance?: HostMaintenance;
  }
  export interface ModifyHostsResult {
    /**
     * The IDs of the Dedicated Hosts that were successfully modified.
     */
    Successful?: ResponseHostIdList;
    /**
     * The IDs of the Dedicated Hosts that could not be modified. Check whether the setting you requested can be used.
     */
    Unsuccessful?: UnsuccessfulItemList;
  }
  export interface ModifyIdFormatRequest {
    /**
     * The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. Alternatively, use the all-current option to include all resource types that are currently within their opt-in period for longer IDs.
     */
    Resource: String;
    /**
     * Indicate whether the resource should use longer IDs (17-character IDs).
     */
    UseLongIds: Boolean;
  }
  export interface ModifyIdentityIdFormatRequest {
    /**
     * The ARN of the principal, which can be an IAM user, IAM role, or the root user. Specify all to modify the ID format for all IAM users, IAM roles, and the root user of the account.
     */
    PrincipalArn: String;
    /**
     * The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. Alternatively, use the all-current option to include all resource types that are currently within their opt-in period for longer IDs.
     */
    Resource: String;
    /**
     * Indicates whether the resource should use longer IDs (17-character IDs)
     */
    UseLongIds: Boolean;
  }
  export interface ModifyImageAttributeRequest {
    /**
     * The name of the attribute to modify. Valid values: description | imdsSupport | launchPermission 
     */
    Attribute?: String;
    /**
     * A new description for the AMI.
     */
    Description?: AttributeValue;
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * A new launch permission for the AMI.
     */
    LaunchPermission?: LaunchPermissionModifications;
    /**
     * The operation type. This parameter can be used only when the Attribute parameter is launchPermission.
     */
    OperationType?: OperationType;
    /**
     * Not supported.
     */
    ProductCodes?: ProductCodeStringList;
    /**
     * The user groups. This parameter can be used only when the Attribute parameter is launchPermission.
     */
    UserGroups?: UserGroupStringList;
    /**
     * The Amazon Web Services account IDs. This parameter can be used only when the Attribute parameter is launchPermission.
     */
    UserIds?: UserIdStringList;
    /**
     * The value of the attribute being modified. This parameter can be used only when the Attribute parameter is description or imdsSupport.
     */
    Value?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of an organization. This parameter can be used only when the Attribute parameter is launchPermission.
     */
    OrganizationArns?: OrganizationArnStringList;
    /**
     * The Amazon Resource Name (ARN) of an organizational unit (OU). This parameter can be used only when the Attribute parameter is launchPermission.
     */
    OrganizationalUnitArns?: OrganizationalUnitArnStringList;
    /**
     * Set to v2.0 to indicate that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.  Do not use this parameter unless your AMI software supports IMDSv2. After you set the value to v2.0, you can't undo it. The only way to “reset” your AMI is to create a new AMI from the underlying snapshot. 
     */
    ImdsSupport?: AttributeValue;
  }
  export interface ModifyInstanceAttributeRequest {
    /**
     * Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is true, source/destination checks are enabled; otherwise, they are disabled. The default value is true. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls.
     */
    SourceDestCheck?: AttributeBooleanValue;
    /**
     * The name of the attribute to modify.  You can modify the following attributes only: disableApiTermination | instanceType | kernel | ramdisk | instanceInitiatedShutdownBehavior | blockDeviceMapping | userData | sourceDestCheck | groupSet | ebsOptimized | sriovNetSupport | enaSupport | nvmeSupport | disableApiStop | enclaveOptions  
     */
    Attribute?: InstanceAttributeName;
    /**
     * Modifies the DeleteOnTermination attribute for volumes that are currently attached. The volume must be owned by the caller. If no value is specified for DeleteOnTermination, the default is true and the volume is deleted when the instance is terminated. To add instance store volumes to an Amazon EBS-backed instance, you must add them when you launch the instance. For more information, see Update the block device mapping when launching an instance in the Amazon EC2 User Guide.
     */
    BlockDeviceMappings?: InstanceBlockDeviceMappingSpecificationList;
    /**
     * If the value is true, you can't terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. You cannot use this parameter for Spot Instances.
     */
    DisableApiTermination?: AttributeBooleanValue;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specifies whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance.
     */
    EbsOptimized?: AttributeBooleanValue;
    /**
     * Set to true to enable enhanced networking with ENA for the instance. This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable.
     */
    EnaSupport?: AttributeBooleanValue;
    /**
     * [EC2-VPC] Replaces the security groups of the instance with the specified security groups. You must specify at least one security group, even if it's just the default security group for the VPC. You must specify the security group ID, not the security group name.
     */
    Groups?: GroupIdStringList;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * Specifies whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
     */
    InstanceInitiatedShutdownBehavior?: AttributeValue;
    /**
     * Changes the instance type to the specified value. For more information, see Instance types in the Amazon EC2 User Guide. If the instance type is not valid, the error returned is InvalidInstanceAttributeValue.
     */
    InstanceType?: AttributeValue;
    /**
     * Changes the instance's kernel to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB.
     */
    Kernel?: AttributeValue;
    /**
     * Changes the instance's RAM disk to the specified value. We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB.
     */
    Ramdisk?: AttributeValue;
    /**
     * Set to simple to enable enhanced networking with the Intel 82599 Virtual Function interface for the instance. There is no way to disable enhanced networking with the Intel 82599 Virtual Function interface at this time. This option is supported only for HVM instances. Specifying this option with a PV instance can make it unreachable.
     */
    SriovNetSupport?: AttributeValue;
    /**
     * Changes the instance's user data to the specified value. If you are using an Amazon Web Services SDK or command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text.
     */
    UserData?: BlobAttributeValue;
    /**
     * A new value for the attribute. Use only with the kernel, ramdisk, userData, disableApiTermination, or instanceInitiatedShutdownBehavior attribute.
     */
    Value?: String;
    /**
     * Indicates whether an instance is enabled for stop protection. For more information, see Stop Protection. 
     */
    DisableApiStop?: AttributeBooleanValue;
  }
  export interface ModifyInstanceCapacityReservationAttributesRequest {
    /**
     * The ID of the instance to be modified.
     */
    InstanceId: InstanceId;
    /**
     * Information about the Capacity Reservation targeting option.
     */
    CapacityReservationSpecification: CapacityReservationSpecification;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyInstanceCapacityReservationAttributesResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyInstanceCreditSpecificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Information about the credit option for CPU usage.
     */
    InstanceCreditSpecifications: InstanceCreditSpecificationListRequest;
  }
  export interface ModifyInstanceCreditSpecificationResult {
    /**
     * Information about the instances whose credit option for CPU usage was successfully modified.
     */
    SuccessfulInstanceCreditSpecifications?: SuccessfulInstanceCreditSpecificationSet;
    /**
     * Information about the instances whose credit option for CPU usage was not modified.
     */
    UnsuccessfulInstanceCreditSpecifications?: UnsuccessfulInstanceCreditSpecificationSet;
  }
  export interface ModifyInstanceEventStartTimeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance with the scheduled event.
     */
    InstanceId: InstanceId;
    /**
     * The ID of the event whose date and time you are modifying.
     */
    InstanceEventId: String;
    /**
     * The new date and time when the event will take place.
     */
    NotBefore: DateTime;
  }
  export interface ModifyInstanceEventStartTimeResult {
    /**
     * Information about the event.
     */
    Event?: InstanceStatusEvent;
  }
  export interface ModifyInstanceEventWindowRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The name of the event window.
     */
    Name?: String;
    /**
     * The ID of the event window.
     */
    InstanceEventWindowId: InstanceEventWindowId;
    /**
     * The time ranges of the event window.
     */
    TimeRanges?: InstanceEventWindowTimeRangeRequestSet;
    /**
     * The cron expression of the event window, for example, * 0-4,20-23 * * 1,5. Constraints:   Only hour and day of the week values are supported.   For day of the week values, you can specify either integers 0 through 6, or alternative single values SUN through SAT.   The minute, month, and year must be specified by *.   The hour value must be one or a multiple range, for example, 0-4 or 0-4,20-23.   Each hour range must be &gt;= 2 hours, for example, 0-2 or 20-23.   The event window must be &gt;= 4 hours. The combined total time ranges in the event window must be &gt;= 4 hours.   For more information about cron expressions, see cron on the Wikipedia website.
     */
    CronExpression?: InstanceEventWindowCronExpression;
  }
  export interface ModifyInstanceEventWindowResult {
    /**
     * Information about the event window.
     */
    InstanceEventWindow?: InstanceEventWindow;
  }
  export interface ModifyInstanceMaintenanceOptionsRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * Disables the automatic recovery behavior of your instance or sets it to default.
     */
    AutoRecovery?: InstanceAutoRecoveryState;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyInstanceMaintenanceOptionsResult {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * Provides information on the current automatic recovery behavior of your instance.
     */
    AutoRecovery?: InstanceAutoRecoveryState;
  }
  export interface ModifyInstanceMetadataOptionsRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * IMDSv2 uses token-backed sessions. Set the use of HTTP tokens to optional (in other words, set the use of IMDSv2 to optional) or required (in other words, set the use of IMDSv2 to required).    optional - When IMDSv2 is optional, you can choose to retrieve instance metadata with or without a session token in your request. If you retrieve the IAM role credentials without a token, the IMDSv1 role credentials are returned. If you retrieve the IAM role credentials using a valid session token, the IMDSv2 role credentials are returned.    required - When IMDSv2 is required, you must send a session token with any instance metadata retrieval requests. In this state, retrieving the IAM role credentials always returns IMDSv2 credentials; IMDSv1 credentials are not available.   Default: optional 
     */
    HttpTokens?: HttpTokensState;
    /**
     * The desired HTTP PUT response hop limit for instance metadata requests. The larger the number, the further instance metadata requests can travel. If no parameter is specified, the existing state is maintained. Possible values: Integers from 1 to 64
     */
    HttpPutResponseHopLimit?: Integer;
    /**
     * Enables or disables the HTTP metadata endpoint on your instances. If this parameter is not specified, the existing state is maintained. If you specify a value of disabled, you cannot access your instance metadata.
     */
    HttpEndpoint?: InstanceMetadataEndpointState;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Enables or disables the IPv6 endpoint for the instance metadata service. This setting applies only if you have enabled the HTTP metadata endpoint.
     */
    HttpProtocolIpv6?: InstanceMetadataProtocolState;
    /**
     * Set to enabled to allow access to instance tags from the instance metadata. Set to disabled to turn off access to instance tags from the instance metadata. For more information, see Work with instance tags using the instance metadata. Default: disabled 
     */
    InstanceMetadataTags?: InstanceMetadataTagsState;
  }
  export interface ModifyInstanceMetadataOptionsResult {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The metadata options for the instance.
     */
    InstanceMetadataOptions?: InstanceMetadataOptionsResponse;
  }
  export interface ModifyInstancePlacementRequest {
    /**
     * The affinity setting for the instance.
     */
    Affinity?: Affinity;
    /**
     * The name of the placement group in which to place the instance. For spread placement groups, the instance must have a tenancy of default. For cluster and partition placement groups, the instance must have a tenancy of default or dedicated. To remove an instance from a placement group, specify an empty string ("").
     */
    GroupName?: PlacementGroupName;
    /**
     * The ID of the Dedicated Host with which to associate the instance.
     */
    HostId?: DedicatedHostId;
    /**
     * The ID of the instance that you are modifying.
     */
    InstanceId: InstanceId;
    /**
     * The tenancy for the instance.  For T3 instances, you can't change the tenancy from dedicated to host, or from host to dedicated. Attempting to make one of these unsupported tenancy changes results in the InvalidTenancy error code. 
     */
    Tenancy?: HostTenancy;
    /**
     * The number of the partition in which to place the instance. Valid only if the placement group strategy is set to partition.
     */
    PartitionNumber?: Integer;
    /**
     * The ARN of the host resource group in which to place the instance.
     */
    HostResourceGroupArn?: String;
    /**
     * The Group Id of a placement group. You must specify the Placement Group Group Id to launch an instance in a shared placement group.
     */
    GroupId?: PlacementGroupId;
  }
  export interface ModifyInstancePlacementResult {
    /**
     * Is true if the request succeeds, and an error otherwise.
     */
    Return?: Boolean;
  }
  export interface ModifyIpamPoolRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool you want to modify.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The description of the IPAM pool you want to modify.
     */
    Description?: String;
    /**
     * If true, IPAM will continuously look for resources within the CIDR range of this pool and automatically import them as allocations into your IPAM. The CIDRs that will be allocated for these resources must not already be allocated to other resources in order for the import to succeed. IPAM will import a CIDR regardless of its compliance with the pool's allocation rules, so a resource might be imported and subsequently marked as noncompliant. If IPAM discovers multiple CIDRs that overlap, IPAM will import the largest CIDR only. If IPAM discovers multiple CIDRs with matching CIDRs, IPAM will randomly import one of them only.  A locale must be set on the pool for this feature to work.
     */
    AutoImport?: Boolean;
    /**
     * The minimum netmask length required for CIDR allocations in this IPAM pool to be compliant. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128. The minimum netmask length must be less than the maximum netmask length.
     */
    AllocationMinNetmaskLength?: IpamNetmaskLength;
    /**
     * The maximum netmask length possible for CIDR allocations in this IPAM pool to be compliant. Possible netmask lengths for IPv4 addresses are 0 - 32. Possible netmask lengths for IPv6 addresses are 0 - 128.The maximum netmask length must be greater than the minimum netmask length.
     */
    AllocationMaxNetmaskLength?: IpamNetmaskLength;
    /**
     * The default netmask length for allocations added to this pool. If, for example, the CIDR assigned to this pool is 10.0.0.0/8 and you enter 16 here, new allocations will default to 10.0.0.0/16.
     */
    AllocationDefaultNetmaskLength?: IpamNetmaskLength;
    /**
     * Clear the default netmask length allocation rule for this pool.
     */
    ClearAllocationDefaultNetmaskLength?: Boolean;
    /**
     * Add tag allocation rules to a pool. For more information about allocation rules, see Create a top-level pool in the Amazon VPC IPAM User Guide.
     */
    AddAllocationResourceTags?: RequestIpamResourceTagList;
    /**
     * Remove tag allocation rules from a pool.
     */
    RemoveAllocationResourceTags?: RequestIpamResourceTagList;
  }
  export interface ModifyIpamPoolResult {
    /**
     * The results of the modification.
     */
    IpamPool?: IpamPool;
  }
  export interface ModifyIpamRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM you want to modify.
     */
    IpamId: IpamId;
    /**
     * The description of the IPAM you want to modify.
     */
    Description?: String;
    /**
     * Choose the operating Regions for the IPAM. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions. For more information about operating Regions, see Create an IPAM in the Amazon VPC IPAM User Guide.
     */
    AddOperatingRegions?: AddIpamOperatingRegionSet;
    /**
     * The operating Regions to remove.
     */
    RemoveOperatingRegions?: RemoveIpamOperatingRegionSet;
  }
  export interface ModifyIpamResourceCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the resource you want to modify.
     */
    ResourceId: String;
    /**
     * The CIDR of the resource you want to modify.
     */
    ResourceCidr: String;
    /**
     * The Amazon Web Services Region of the resource you want to modify.
     */
    ResourceRegion: String;
    /**
     * The ID of the current scope that the resource CIDR is in.
     */
    CurrentIpamScopeId: IpamScopeId;
    /**
     * The ID of the scope you want to transfer the resource CIDR to.
     */
    DestinationIpamScopeId?: IpamScopeId;
    /**
     * Determines if the resource is monitored by IPAM. If a resource is monitored, the resource is discovered by IPAM and you can view details about the resource’s CIDR.
     */
    Monitored: Boolean;
  }
  export interface ModifyIpamResourceCidrResult {
    /**
     * The CIDR of the resource.
     */
    IpamResourceCidr?: IpamResourceCidr;
  }
  export interface ModifyIpamResourceDiscoveryRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A resource discovery ID.
     */
    IpamResourceDiscoveryId: IpamResourceDiscoveryId;
    /**
     * A resource discovery description.
     */
    Description?: String;
    /**
     * Add operating Regions to the resource discovery. Operating Regions are Amazon Web Services Regions where the IPAM is allowed to manage IP address CIDRs. IPAM only discovers and monitors resources in the Amazon Web Services Regions you select as operating Regions.
     */
    AddOperatingRegions?: AddIpamOperatingRegionSet;
    /**
     * Remove operating Regions.
     */
    RemoveOperatingRegions?: RemoveIpamOperatingRegionSet;
  }
  export interface ModifyIpamResourceDiscoveryResult {
    /**
     * A resource discovery.
     */
    IpamResourceDiscovery?: IpamResourceDiscovery;
  }
  export interface ModifyIpamResult {
    /**
     * The results of the modification.
     */
    Ipam?: Ipam;
  }
  export interface ModifyIpamScopeRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the scope you want to modify.
     */
    IpamScopeId: IpamScopeId;
    /**
     * The description of the scope you want to modify.
     */
    Description?: String;
  }
  export interface ModifyIpamScopeResult {
    /**
     * The results of the modification.
     */
    IpamScope?: IpamScope;
  }
  export interface ModifyLaunchTemplateRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. For more information, see Ensuring idempotency. Constraint: Maximum 128 ASCII characters.
     */
    ClientToken?: String;
    /**
     * The ID of the launch template. You must specify either the LaunchTemplateId or the LaunchTemplateName, but not both.
     */
    LaunchTemplateId?: LaunchTemplateId;
    /**
     * The name of the launch template. You must specify either the LaunchTemplateName or the LaunchTemplateId, but not both.
     */
    LaunchTemplateName?: LaunchTemplateName;
    /**
     * The version number of the launch template to set as the default version.
     */
    DefaultVersion?: String;
  }
  export interface ModifyLaunchTemplateResult {
    /**
     * Information about the launch template.
     */
    LaunchTemplate?: LaunchTemplate;
  }
  export interface ModifyLocalGatewayRouteRequest {
    /**
     * The CIDR block used for destination matches. The value that you provide must match the CIDR of an existing route in the table.
     */
    DestinationCidrBlock?: String;
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     *  The ID of the virtual interface group. 
     */
    LocalGatewayVirtualInterfaceGroupId?: LocalGatewayVirtualInterfaceGroupId;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     *  The ID of the prefix list. Use a prefix list in place of DestinationCidrBlock. You cannot use DestinationPrefixListId and DestinationCidrBlock in the same request. 
     */
    DestinationPrefixListId?: PrefixListResourceId;
  }
  export interface ModifyLocalGatewayRouteResult {
    /**
     * Information about the local gateway route table.
     */
    Route?: LocalGatewayRoute;
  }
  export interface ModifyManagedPrefixListRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The current version of the prefix list.
     */
    CurrentVersion?: Long;
    /**
     * A name for the prefix list.
     */
    PrefixListName?: String;
    /**
     * One or more entries to add to the prefix list.
     */
    AddEntries?: AddPrefixListEntries;
    /**
     * One or more entries to remove from the prefix list.
     */
    RemoveEntries?: RemovePrefixListEntries;
    /**
     * The maximum number of entries for the prefix list. You cannot modify the entries of a prefix list and modify the size of a prefix list at the same time. If any of the resources that reference the prefix list cannot support the new maximum size, the modify operation fails. Check the state message for the IDs of the first ten resources that do not support the new maximum size.
     */
    MaxEntries?: Integer;
  }
  export interface ModifyManagedPrefixListResult {
    /**
     * Information about the prefix list.
     */
    PrefixList?: ManagedPrefixList;
  }
  export interface ModifyNetworkInterfaceAttributeRequest {
    /**
     * Information about the interface attachment. If modifying the delete on termination attribute, you must specify the ID of the interface attachment.
     */
    Attachment?: NetworkInterfaceAttachmentChanges;
    /**
     * A description for the network interface.
     */
    Description?: AttributeValue;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Changes the security groups for the network interface. The new set of groups you specify replaces the current set. You must specify at least one group, even if it's just the default security group in the VPC. You must specify the ID of the security group, not the name.
     */
    Groups?: SecurityGroupIdStringList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * Enable or disable source/destination checks, which ensure that the instance is either the source or the destination of any traffic that it receives. If the value is true, source/destination checks are enabled; otherwise, they are disabled. The default value is true. You must disable source/destination checks if the instance runs services such as network address translation, routing, or firewalls.
     */
    SourceDestCheck?: AttributeBooleanValue;
    /**
     * Updates the ENA Express configuration for the network interface that’s attached to the instance.
     */
    EnaSrdSpecification?: EnaSrdSpecification;
  }
  export interface ModifyPrivateDnsNameOptionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
     */
    PrivateDnsHostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export interface ModifyPrivateDnsNameOptionsResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyReservedInstancesRequest {
    /**
     * The IDs of the Reserved Instances to modify.
     */
    ReservedInstancesIds: ReservedInstancesIdStringList;
    /**
     * A unique, case-sensitive token you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The configuration settings for the Reserved Instances to modify.
     */
    TargetConfigurations: ReservedInstancesConfigurationList;
  }
  export interface ModifyReservedInstancesResult {
    /**
     * The ID for the modification.
     */
    ReservedInstancesModificationId?: String;
  }
  export interface ModifySecurityGroupRulesRequest {
    /**
     * The ID of the security group.
     */
    GroupId: SecurityGroupId;
    /**
     * Information about the security group properties to update.
     */
    SecurityGroupRules: SecurityGroupRuleUpdateList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifySecurityGroupRulesResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifySnapshotAttributeRequest {
    /**
     * The snapshot attribute to modify. Only volume creation permissions can be modified.
     */
    Attribute?: SnapshotAttributeName;
    /**
     * A JSON representation of the snapshot attribute modification.
     */
    CreateVolumePermission?: CreateVolumePermissionModifications;
    /**
     * The group to modify for the snapshot.
     */
    GroupNames?: GroupNameStringList;
    /**
     * The type of operation to perform to the attribute.
     */
    OperationType?: OperationType;
    /**
     * The ID of the snapshot.
     */
    SnapshotId: SnapshotId;
    /**
     * The account ID to modify for the snapshot.
     */
    UserIds?: UserIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifySnapshotTierRequest {
    /**
     * The ID of the snapshot.
     */
    SnapshotId: SnapshotId;
    /**
     * The name of the storage tier. You must specify archive.
     */
    StorageTier?: TargetStorageTier;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifySnapshotTierResult {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The date and time when the archive process was started.
     */
    TieringStartTime?: MillisecondDateTime;
  }
  export interface ModifySpotFleetRequestRequest {
    /**
     * Indicates whether running instances should be terminated if the target capacity of the Spot Fleet request is decreased below the current size of the Spot Fleet. Supported only for fleets of type maintain.
     */
    ExcessCapacityTerminationPolicy?: ExcessCapacityTerminationPolicy;
    /**
     * The launch template and overrides. You can only use this parameter if you specified a launch template (LaunchTemplateConfigs) in your Spot Fleet request. If you specified LaunchSpecifications in your Spot Fleet request, then omit this parameter.
     */
    LaunchTemplateConfigs?: LaunchTemplateConfigList;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId: SpotFleetRequestId;
    /**
     * The size of the fleet.
     */
    TargetCapacity?: Integer;
    /**
     * The number of On-Demand Instances in the fleet.
     */
    OnDemandTargetCapacity?: Integer;
    /**
     * Reserved.
     */
    Context?: String;
  }
  export interface ModifySpotFleetRequestResponse {
    /**
     * If the request succeeds, the response returns true. If the request fails, no response is returned, and instead an error message is returned.
     */
    Return?: Boolean;
  }
  export interface ModifySubnetAttributeRequest {
    /**
     * Specify true to indicate that network interfaces created in the specified subnet should be assigned an IPv6 address. This includes a network interface that's created when launching an instance into the subnet (the instance therefore receives an IPv6 address).  If you enable the IPv6 addressing feature for your subnet, your network interface or instance only receives an IPv6 address if it's created using version 2016-11-15 or later of the Amazon EC2 API.
     */
    AssignIpv6AddressOnCreation?: AttributeBooleanValue;
    /**
     * Specify true to indicate that network interfaces attached to instances created in the specified subnet should be assigned a public IPv4 address.
     */
    MapPublicIpOnLaunch?: AttributeBooleanValue;
    /**
     * The ID of the subnet.
     */
    SubnetId: SubnetId;
    /**
     * Specify true to indicate that network interfaces attached to instances created in the specified subnet should be assigned a customer-owned IPv4 address. When this value is true, you must specify the customer-owned IP pool using CustomerOwnedIpv4Pool.
     */
    MapCustomerOwnedIpOnLaunch?: AttributeBooleanValue;
    /**
     * The customer-owned IPv4 address pool associated with the subnet. You must set this value when you specify true for MapCustomerOwnedIpOnLaunch.
     */
    CustomerOwnedIpv4Pool?: CoipPoolId;
    /**
     * Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.
     */
    EnableDns64?: AttributeBooleanValue;
    /**
     * The type of hostname to assign to instances in the subnet at launch. For IPv4-only and dual-stack (IPv4 and IPv6) subnets, an instance DNS name can be based on the instance IPv4 address (ip-name) or the instance ID (resource-name). For IPv6 only subnets, an instance DNS name must be based on the instance ID (resource-name).
     */
    PrivateDnsHostnameTypeOnLaunch?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecordOnLaunch?: AttributeBooleanValue;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecordOnLaunch?: AttributeBooleanValue;
    /**
     *  Indicates the device position for local network interfaces in this subnet. For example, 1 indicates local network interfaces in this subnet are the secondary network interface (eth1). A local network interface cannot be the primary network interface (eth0). 
     */
    EnableLniAtDeviceIndex?: Integer;
    /**
     *  Specify true to indicate that local network interfaces at the current position should be disabled. 
     */
    DisableLniAtDeviceIndex?: AttributeBooleanValue;
  }
  export interface ModifyTrafficMirrorFilterNetworkServicesRequest {
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId: TrafficMirrorFilterId;
    /**
     * The network service, for example Amazon DNS, that you want to mirror.
     */
    AddNetworkServices?: TrafficMirrorNetworkServiceList;
    /**
     * The network service, for example Amazon DNS, that you no longer want to mirror.
     */
    RemoveNetworkServices?: TrafficMirrorNetworkServiceList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTrafficMirrorFilterNetworkServicesResult {
    /**
     * The Traffic Mirror filter that the network service is associated with.
     */
    TrafficMirrorFilter?: TrafficMirrorFilter;
  }
  export interface ModifyTrafficMirrorFilterRuleRequest {
    /**
     * The ID of the Traffic Mirror rule.
     */
    TrafficMirrorFilterRuleId: TrafficMirrorFilterRuleIdWithResolver;
    /**
     * The type of traffic to assign to the rule.
     */
    TrafficDirection?: TrafficDirection;
    /**
     * The number of the Traffic Mirror rule. This number must be unique for each Traffic Mirror rule in a given direction. The rules are processed in ascending order by rule number.
     */
    RuleNumber?: Integer;
    /**
     * The action to assign to the rule.
     */
    RuleAction?: TrafficMirrorRuleAction;
    /**
     * The destination ports that are associated with the Traffic Mirror rule.
     */
    DestinationPortRange?: TrafficMirrorPortRangeRequest;
    /**
     * The port range to assign to the Traffic Mirror rule.
     */
    SourcePortRange?: TrafficMirrorPortRangeRequest;
    /**
     * The protocol, for example TCP, to assign to the Traffic Mirror rule.
     */
    Protocol?: Integer;
    /**
     * The destination CIDR block to assign to the Traffic Mirror rule.
     */
    DestinationCidrBlock?: String;
    /**
     * The source CIDR block to assign to the Traffic Mirror rule.
     */
    SourceCidrBlock?: String;
    /**
     * The description to assign to the Traffic Mirror rule.
     */
    Description?: String;
    /**
     * The properties that you want to remove from the Traffic Mirror filter rule. When you remove a property from a Traffic Mirror filter rule, the property is set to the default.
     */
    RemoveFields?: TrafficMirrorFilterRuleFieldList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTrafficMirrorFilterRuleResult {
    /**
     * Modifies a Traffic Mirror rule.
     */
    TrafficMirrorFilterRule?: TrafficMirrorFilterRule;
  }
  export interface ModifyTrafficMirrorSessionRequest {
    /**
     * The ID of the Traffic Mirror session.
     */
    TrafficMirrorSessionId: TrafficMirrorSessionId;
    /**
     * The Traffic Mirror target. The target must be in the same VPC as the source, or have a VPC peering connection with the source.
     */
    TrafficMirrorTargetId?: TrafficMirrorTargetId;
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId?: TrafficMirrorFilterId;
    /**
     * The number of bytes in each packet to mirror. These are bytes after the VXLAN header. To mirror a subset, set this to the length (in bytes) to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. Do not specify this parameter when you want to mirror the entire packet.
     */
    PacketLength?: Integer;
    /**
     * The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets. Valid values are 1-32766.
     */
    SessionNumber?: Integer;
    /**
     * The virtual network ID of the Traffic Mirror session.
     */
    VirtualNetworkId?: Integer;
    /**
     * The description to assign to the Traffic Mirror session.
     */
    Description?: String;
    /**
     * The properties that you want to remove from the Traffic Mirror session. When you remove a property from a Traffic Mirror session, the property is set to the default.
     */
    RemoveFields?: TrafficMirrorSessionFieldList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTrafficMirrorSessionResult {
    /**
     * Information about the Traffic Mirror session.
     */
    TrafficMirrorSession?: TrafficMirrorSession;
  }
  export interface ModifyTransitGatewayOptions {
    /**
     * Adds IPv4 or IPv6 CIDR blocks for the transit gateway. Must be a size /24 CIDR block or larger for IPv4, or a size /64 CIDR block or larger for IPv6.
     */
    AddTransitGatewayCidrBlocks?: TransitGatewayCidrBlockStringList;
    /**
     * Removes CIDR blocks for the transit gateway.
     */
    RemoveTransitGatewayCidrBlocks?: TransitGatewayCidrBlockStringList;
    /**
     * Enable or disable Equal Cost Multipath Protocol support.
     */
    VpnEcmpSupport?: VpnEcmpSupportValue;
    /**
     * Enable or disable DNS support.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Enable or disable automatic acceptance of attachment requests.
     */
    AutoAcceptSharedAttachments?: AutoAcceptSharedAttachmentsValue;
    /**
     * Enable or disable automatic association with the default association route table.
     */
    DefaultRouteTableAssociation?: DefaultRouteTableAssociationValue;
    /**
     * The ID of the default association route table.
     */
    AssociationDefaultRouteTableId?: TransitGatewayRouteTableId;
    /**
     * Enable or disable automatic propagation of routes to the default propagation route table.
     */
    DefaultRouteTablePropagation?: DefaultRouteTablePropagationValue;
    /**
     * The ID of the default propagation route table.
     */
    PropagationDefaultRouteTableId?: TransitGatewayRouteTableId;
    /**
     * A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs. The modify ASN operation is not allowed on a transit gateway with active BGP sessions. You must first delete all transit gateway attachments that have BGP configured prior to modifying the ASN on the transit gateway.
     */
    AmazonSideAsn?: Long;
  }
  export interface ModifyTransitGatewayPrefixListReferenceRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The ID of the attachment to which traffic is routed.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Indicates whether to drop traffic that matches this route.
     */
    Blackhole?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTransitGatewayPrefixListReferenceResult {
    /**
     * Information about the prefix list reference.
     */
    TransitGatewayPrefixListReference?: TransitGatewayPrefixListReference;
  }
  export interface ModifyTransitGatewayRequest {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId: TransitGatewayId;
    /**
     * The description for the transit gateway.
     */
    Description?: String;
    /**
     * The options to modify.
     */
    Options?: ModifyTransitGatewayOptions;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTransitGatewayResult {
    /**
     * Information about the transit gateway.
     */
    TransitGateway?: TransitGateway;
  }
  export interface ModifyTransitGatewayVpcAttachmentRequest {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * The IDs of one or more subnets to add. You can specify at most one subnet per Availability Zone.
     */
    AddSubnetIds?: TransitGatewaySubnetIdList;
    /**
     * The IDs of one or more subnets to remove.
     */
    RemoveSubnetIds?: TransitGatewaySubnetIdList;
    /**
     * The new VPC attachment options.
     */
    Options?: ModifyTransitGatewayVpcAttachmentRequestOptions;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyTransitGatewayVpcAttachmentRequestOptions {
    /**
     * Enable or disable DNS support. The default is enable.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Enable or disable IPv6 support. The default is enable.
     */
    Ipv6Support?: Ipv6SupportValue;
    /**
     * Enable or disable support for appliance mode. If enabled, a traffic flow between a source and destination uses the same Availability Zone for the VPC attachment for the lifetime of that flow. The default is disable.
     */
    ApplianceModeSupport?: ApplianceModeSupportValue;
  }
  export interface ModifyTransitGatewayVpcAttachmentResult {
    /**
     * Information about the modified attachment.
     */
    TransitGatewayVpcAttachment?: TransitGatewayVpcAttachment;
  }
  export interface ModifyVerifiedAccessEndpointEniOptions {
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
  }
  export interface ModifyVerifiedAccessEndpointLoadBalancerOptions {
    /**
     * The IDs of the subnets.
     */
    SubnetIds?: ModifyVerifiedAccessEndpointSubnetIdList;
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
  }
  export interface ModifyVerifiedAccessEndpointPolicyRequest {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointId: VerifiedAccessEndpointId;
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVerifiedAccessEndpointPolicyResult {
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled?: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
  }
  export interface ModifyVerifiedAccessEndpointRequest {
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointId: VerifiedAccessEndpointId;
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId?: VerifiedAccessGroupId;
    /**
     * The load balancer details if creating the Amazon Web Services Verified Access endpoint as load-balancertype.
     */
    LoadBalancerOptions?: ModifyVerifiedAccessEndpointLoadBalancerOptions;
    /**
     * The network interface options.
     */
    NetworkInterfaceOptions?: ModifyVerifiedAccessEndpointEniOptions;
    /**
     * A description for the Amazon Web Services Verified Access endpoint.
     */
    Description?: String;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVerifiedAccessEndpointResult {
    /**
     * The Amazon Web Services Verified Access endpoint details.
     */
    VerifiedAccessEndpoint?: VerifiedAccessEndpoint;
  }
  export type ModifyVerifiedAccessEndpointSubnetIdList = SubnetId[];
  export interface ModifyVerifiedAccessGroupPolicyRequest {
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId: VerifiedAccessGroupId;
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVerifiedAccessGroupPolicyResult {
    /**
     * The status of the Verified Access policy.
     */
    PolicyEnabled?: Boolean;
    /**
     * The Amazon Web Services Verified Access policy document.
     */
    PolicyDocument?: String;
  }
  export interface ModifyVerifiedAccessGroupRequest {
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId: VerifiedAccessGroupId;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: VerifiedAccessInstanceId;
    /**
     * A description for the Amazon Web Services Verified Access group.
     */
    Description?: String;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVerifiedAccessGroupResult {
    /**
     * Details of Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroup?: VerifiedAccessGroup;
  }
  export interface ModifyVerifiedAccessInstanceLoggingConfigurationRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * The configuration options for Amazon Web Services Verified Access instances.
     */
    AccessLogs: VerifiedAccessLogOptions;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface ModifyVerifiedAccessInstanceLoggingConfigurationResult {
    /**
     * The logging configuration for Amazon Web Services Verified Access instance.
     */
    LoggingConfiguration?: VerifiedAccessInstanceLoggingConfiguration;
  }
  export interface ModifyVerifiedAccessInstanceRequest {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId: VerifiedAccessInstanceId;
    /**
     * A description for the Amazon Web Services Verified Access instance.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface ModifyVerifiedAccessInstanceResult {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstance?: VerifiedAccessInstance;
  }
  export interface ModifyVerifiedAccessTrustProviderOidcOptions {
    /**
     * OpenID Connect (OIDC) scopes are used by an application during authentication to authorize access to a user's details. Each scope returns a specific set of user attributes.
     */
    Scope?: String;
  }
  export interface ModifyVerifiedAccessTrustProviderRequest {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProviderId: VerifiedAccessTrustProviderId;
    /**
     * The OpenID Connect details for an oidc-type, user-identity based trust provider.
     */
    OidcOptions?: ModifyVerifiedAccessTrustProviderOidcOptions;
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * A unique, case-sensitive token that you provide to ensure idempotency of your modification request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface ModifyVerifiedAccessTrustProviderResult {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProvider?: VerifiedAccessTrustProvider;
  }
  export interface ModifyVolumeAttributeRequest {
    /**
     * Indicates whether the volume should be auto-enabled for I/O operations.
     */
    AutoEnableIO?: AttributeBooleanValue;
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVolumeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the volume.
     */
    VolumeId: VolumeId;
    /**
     * The target size of the volume, in GiB. The target volume size must be greater than or equal to the existing size of the volume. The following are the supported volumes sizes for each volume type:    gp2 and gp3: 1-16,384    io1 and io2: 4-16,384    st1 and sc1: 125-16,384    standard: 1-1,024   Default: The existing size is retained.
     */
    Size?: Integer;
    /**
     * The target EBS volume type of the volume. For more information, see Amazon EBS volume types in the Amazon Elastic Compute Cloud User Guide. Default: The existing type is retained.
     */
    VolumeType?: VolumeType;
    /**
     * The target IOPS rate of the volume. This parameter is valid only for gp3, io1, and io2 volumes. The following are the supported values for each volume type:    gp3: 3,000-16,000 IOPS    io1: 100-64,000 IOPS    io2: 100-64,000 IOPS   Default: The existing value is retained if you keep the same volume type. If you change the volume type to io1, io2, or gp3, the default is 3,000.
     */
    Iops?: Integer;
    /**
     * The target throughput of the volume, in MiB/s. This parameter is valid only for gp3 volumes. The maximum value is 1,000. Default: The existing value is retained if the source and target volume type is gp3. Otherwise, the default value is 125. Valid Range: Minimum value of 125. Maximum value of 1000.
     */
    Throughput?: Integer;
    /**
     * Specifies whether to enable Amazon EBS Multi-Attach. If you enable Multi-Attach, you can attach the volume to up to 16  Nitro-based instances in the same Availability Zone. This parameter is supported with io1 and io2 volumes only. For more information, see  Amazon EBS Multi-Attach in the Amazon Elastic Compute Cloud User Guide.
     */
    MultiAttachEnabled?: Boolean;
  }
  export interface ModifyVolumeResult {
    /**
     * Information about the volume modification.
     */
    VolumeModification?: VolumeModification;
  }
  export interface ModifyVpcAttributeRequest {
    /**
     * Indicates whether the instances launched in the VPC get DNS hostnames. If enabled, instances in the VPC get DNS hostnames; otherwise, they do not. You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute. You can only enable DNS hostnames if you've enabled DNS support.
     */
    EnableDnsHostnames?: AttributeBooleanValue;
    /**
     * Indicates whether the DNS resolution is supported for the VPC. If enabled, queries to the Amazon provided DNS server at the 169.254.169.253 IP address, or the reserved IP address at the base of the VPC network range "plus two" succeed. If disabled, the Amazon provided DNS service in the VPC that resolves public DNS hostnames to IP addresses is not enabled. You cannot modify the DNS resolution and DNS hostnames attributes in the same request. Use separate requests for each attribute.
     */
    EnableDnsSupport?: AttributeBooleanValue;
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * Indicates whether Network Address Usage metrics are enabled for your VPC.
     */
    EnableNetworkAddressUsageMetrics?: AttributeBooleanValue;
  }
  export interface ModifyVpcEndpointConnectionNotificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the notification.
     */
    ConnectionNotificationId: ConnectionNotificationId;
    /**
     * The ARN for the SNS topic for the notification.
     */
    ConnectionNotificationArn?: String;
    /**
     * The events for the endpoint. Valid values are Accept, Connect, Delete, and Reject.
     */
    ConnectionEvents?: ValueStringList;
  }
  export interface ModifyVpcEndpointConnectionNotificationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    ReturnValue?: Boolean;
  }
  export interface ModifyVpcEndpointRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the endpoint.
     */
    VpcEndpointId: VpcEndpointId;
    /**
     * (Gateway endpoint) Specify true to reset the policy document to the default policy. The default policy allows full access to the service.
     */
    ResetPolicy?: Boolean;
    /**
     * (Interface and gateway endpoints) A policy to attach to the endpoint that controls access to the service. The policy must be in valid JSON format.
     */
    PolicyDocument?: String;
    /**
     * (Gateway endpoint) The IDs of the route tables to associate with the endpoint.
     */
    AddRouteTableIds?: VpcEndpointRouteTableIdList;
    /**
     * (Gateway endpoint) The IDs of the route tables to disassociate from the endpoint.
     */
    RemoveRouteTableIds?: VpcEndpointRouteTableIdList;
    /**
     * (Interface and Gateway Load Balancer endpoints) The IDs of the subnets in which to serve the endpoint. For a Gateway Load Balancer endpoint, you can specify only one subnet.
     */
    AddSubnetIds?: VpcEndpointSubnetIdList;
    /**
     * (Interface endpoint) The IDs of the subnets from which to remove the endpoint.
     */
    RemoveSubnetIds?: VpcEndpointSubnetIdList;
    /**
     * (Interface endpoint) The IDs of the security groups to associate with the network interface.
     */
    AddSecurityGroupIds?: VpcEndpointSecurityGroupIdList;
    /**
     * (Interface endpoint) The IDs of the security groups to disassociate from the network interface.
     */
    RemoveSecurityGroupIds?: VpcEndpointSecurityGroupIdList;
    /**
     * The IP address type for the endpoint.
     */
    IpAddressType?: IpAddressType;
    /**
     * The DNS options for the endpoint.
     */
    DnsOptions?: DnsOptionsSpecification;
    /**
     * (Interface endpoint) Indicates whether a private hosted zone is associated with the VPC.
     */
    PrivateDnsEnabled?: Boolean;
  }
  export interface ModifyVpcEndpointResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyVpcEndpointServiceConfigurationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * (Interface endpoint configuration) The private DNS name to assign to the endpoint service.
     */
    PrivateDnsName?: String;
    /**
     * (Interface endpoint configuration) Removes the private DNS name of the endpoint service.
     */
    RemovePrivateDnsName?: Boolean;
    /**
     * Indicates whether requests to create an endpoint to your service must be accepted.
     */
    AcceptanceRequired?: Boolean;
    /**
     * The Amazon Resource Names (ARNs) of Network Load Balancers to add to your service configuration.
     */
    AddNetworkLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of Network Load Balancers to remove from your service configuration.
     */
    RemoveNetworkLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of Gateway Load Balancers to add to your service configuration.
     */
    AddGatewayLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of Gateway Load Balancers to remove from your service configuration.
     */
    RemoveGatewayLoadBalancerArns?: ValueStringList;
    /**
     * The IP address types to add to your service configuration.
     */
    AddSupportedIpAddressTypes?: ValueStringList;
    /**
     * The IP address types to remove from your service configuration.
     */
    RemoveSupportedIpAddressTypes?: ValueStringList;
  }
  export interface ModifyVpcEndpointServiceConfigurationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ModifyVpcEndpointServicePayerResponsibilityRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * The entity that is responsible for the endpoint costs. The default is the endpoint owner. If you set the payer responsibility to the service owner, you cannot set it back to the endpoint owner.
     */
    PayerResponsibility: PayerResponsibility;
  }
  export interface ModifyVpcEndpointServicePayerResponsibilityResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    ReturnValue?: Boolean;
  }
  export interface ModifyVpcEndpointServicePermissionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * The Amazon Resource Names (ARN) of the principals. Permissions are granted to the principals in this list. To grant permissions to all principals, specify an asterisk (*).
     */
    AddAllowedPrincipals?: ValueStringList;
    /**
     * The Amazon Resource Names (ARN) of the principals. Permissions are revoked for principals in this list.
     */
    RemoveAllowedPrincipals?: ValueStringList;
  }
  export interface ModifyVpcEndpointServicePermissionsResult {
    /**
     * Information about the added principals.
     */
    AddedPrincipals?: AddedPrincipalSet;
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    ReturnValue?: Boolean;
  }
  export interface ModifyVpcPeeringConnectionOptionsRequest {
    /**
     * The VPC peering connection options for the accepter VPC.
     */
    AccepterPeeringConnectionOptions?: PeeringConnectionOptionsRequest;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The VPC peering connection options for the requester VPC.
     */
    RequesterPeeringConnectionOptions?: PeeringConnectionOptionsRequest;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId: VpcPeeringConnectionId;
  }
  export interface ModifyVpcPeeringConnectionOptionsResult {
    /**
     * Information about the VPC peering connection options for the accepter VPC.
     */
    AccepterPeeringConnectionOptions?: PeeringConnectionOptions;
    /**
     * Information about the VPC peering connection options for the requester VPC.
     */
    RequesterPeeringConnectionOptions?: PeeringConnectionOptions;
  }
  export interface ModifyVpcTenancyRequest {
    /**
     * The ID of the VPC.
     */
    VpcId: VpcId;
    /**
     * The instance tenancy attribute for the VPC. 
     */
    InstanceTenancy: VpcTenancy;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVpcTenancyResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    ReturnValue?: Boolean;
  }
  export interface ModifyVpnConnectionOptionsRequest {
    /**
     * The ID of the Site-to-Site VPN connection. 
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: 0.0.0.0/0 
     */
    LocalIpv4NetworkCidr?: String;
    /**
     * The IPv4 CIDR on the Amazon Web Services side of the VPN connection. Default: 0.0.0.0/0 
     */
    RemoteIpv4NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: ::/0 
     */
    LocalIpv6NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the Amazon Web Services side of the VPN connection. Default: ::/0 
     */
    RemoteIpv6NetworkCidr?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVpnConnectionOptionsResult {
    /**
     * Information about the VPN connection.
     */
    VpnConnection?: VpnConnection;
  }
  export interface ModifyVpnConnectionRequest {
    /**
     * The ID of the VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the customer gateway at your end of the VPN connection.
     */
    CustomerGatewayId?: CustomerGatewayId;
    /**
     * The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
     */
    VpnGatewayId?: VpnGatewayId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVpnConnectionResult {
    /**
     * Information about the VPN connection.
     */
    VpnConnection?: VpnConnection;
  }
  export interface ModifyVpnTunnelCertificateRequest {
    /**
     * The ID of the Amazon Web Services Site-to-Site VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The external IP address of the VPN tunnel.
     */
    VpnTunnelOutsideIpAddress: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ModifyVpnTunnelCertificateResult {
    /**
     * Information about the VPN connection.
     */
    VpnConnection?: VpnConnection;
  }
  export interface ModifyVpnTunnelOptionsRequest {
    /**
     * The ID of the Amazon Web Services Site-to-Site VPN connection.
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The external IP address of the VPN tunnel.
     */
    VpnTunnelOutsideIpAddress: String;
    /**
     * The tunnel options to modify.
     */
    TunnelOptions: ModifyVpnTunnelOptionsSpecification;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Choose whether or not to trigger immediate tunnel replacement. Valid values: True | False 
     */
    SkipTunnelReplacement?: Boolean;
  }
  export interface ModifyVpnTunnelOptionsResult {
    /**
     * Information about the VPN connection.
     */
    VpnConnection?: VpnConnection;
  }
  export interface ModifyVpnTunnelOptionsSpecification {
    /**
     * The range of inside IPv4 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same virtual private gateway.  Constraints: A size /30 CIDR block from the 169.254.0.0/16 range. The following CIDR blocks are reserved and cannot be used:    169.254.0.0/30     169.254.1.0/30     169.254.2.0/30     169.254.3.0/30     169.254.4.0/30     169.254.5.0/30     169.254.169.252/30   
     */
    TunnelInsideCidr?: String;
    /**
     * The range of inside IPv6 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same transit gateway. Constraints: A size /126 CIDR block from the local fd00::/8 range.
     */
    TunnelInsideIpv6Cidr?: String;
    /**
     * The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and the customer gateway. Constraints: Allowed characters are alphanumeric characters, periods (.), and underscores (_). Must be between 8 and 64 characters in length and cannot start with zero (0).
     */
    PreSharedKey?: String;
    /**
     * The lifetime for phase 1 of the IKE negotiation, in seconds. Constraints: A value between 900 and 28,800. Default: 28800 
     */
    Phase1LifetimeSeconds?: Integer;
    /**
     * The lifetime for phase 2 of the IKE negotiation, in seconds. Constraints: A value between 900 and 3,600. The value must be less than the value for Phase1LifetimeSeconds. Default: 3600 
     */
    Phase2LifetimeSeconds?: Integer;
    /**
     * The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey. The exact time of the rekey is randomly selected based on the value for RekeyFuzzPercentage. Constraints: A value between 60 and half of Phase2LifetimeSeconds. Default: 540 
     */
    RekeyMarginTimeSeconds?: Integer;
    /**
     * The percentage of the rekey window (determined by RekeyMarginTimeSeconds) during which the rekey time is randomly selected. Constraints: A value between 0 and 100. Default: 100 
     */
    RekeyFuzzPercentage?: Integer;
    /**
     * The number of packets in an IKE replay window. Constraints: A value between 64 and 2048. Default: 1024 
     */
    ReplayWindowSize?: Integer;
    /**
     * The number of seconds after which a DPD timeout occurs. Constraints: A value greater than or equal to 30. Default: 30 
     */
    DPDTimeoutSeconds?: Integer;
    /**
     * The action to take after DPD timeout occurs. Specify restart to restart the IKE initiation. Specify clear to end the IKE session. Valid Values: clear | none | restart  Default: clear 
     */
    DPDTimeoutAction?: String;
    /**
     * One or more encryption algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: AES128 | AES256 | AES128-GCM-16 | AES256-GCM-16 
     */
    Phase1EncryptionAlgorithms?: Phase1EncryptionAlgorithmsRequestList;
    /**
     * One or more encryption algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: AES128 | AES256 | AES128-GCM-16 | AES256-GCM-16 
     */
    Phase2EncryptionAlgorithms?: Phase2EncryptionAlgorithmsRequestList;
    /**
     * One or more integrity algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: SHA1 | SHA2-256 | SHA2-384 | SHA2-512 
     */
    Phase1IntegrityAlgorithms?: Phase1IntegrityAlgorithmsRequestList;
    /**
     * One or more integrity algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: SHA1 | SHA2-256 | SHA2-384 | SHA2-512 
     */
    Phase2IntegrityAlgorithms?: Phase2IntegrityAlgorithmsRequestList;
    /**
     * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: 2 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 | 24 
     */
    Phase1DHGroupNumbers?: Phase1DHGroupNumbersRequestList;
    /**
     * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: 2 | 5 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 | 24 
     */
    Phase2DHGroupNumbers?: Phase2DHGroupNumbersRequestList;
    /**
     * The IKE versions that are permitted for the VPN tunnel. Valid values: ikev1 | ikev2 
     */
    IKEVersions?: IKEVersionsRequestList;
    /**
     * The action to take when the establishing the tunnel for the VPN connection. By default, your customer gateway device must initiate the IKE negotiation and bring up the tunnel. Specify start for Amazon Web Services to initiate the IKE negotiation. Valid Values: add | start  Default: add 
     */
    StartupAction?: String;
    /**
     * Options for logging VPN tunnel activity.
     */
    LogOptions?: VpnTunnelLogOptionsSpecification;
    /**
     * Turn on or off tunnel endpoint lifecycle control feature.
     */
    EnableTunnelLifecycleControl?: Boolean;
  }
  export interface MonitorInstancesRequest {
    /**
     * The IDs of the instances.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface MonitorInstancesResult {
    /**
     * The monitoring information.
     */
    InstanceMonitorings?: InstanceMonitoringList;
  }
  export interface Monitoring {
    /**
     * Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
     */
    State?: MonitoringState;
  }
  export type MonitoringState = "disabled"|"disabling"|"enabled"|"pending"|string;
  export interface MoveAddressToVpcRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Elastic IP address.
     */
    PublicIp: String;
  }
  export interface MoveAddressToVpcResult {
    /**
     * The allocation ID for the Elastic IP address.
     */
    AllocationId?: String;
    /**
     * The status of the move of the IP address.
     */
    Status?: Status;
  }
  export interface MoveByoipCidrToIpamRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The BYOIP CIDR.
     */
    Cidr: String;
    /**
     * The IPAM pool ID.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The Amazon Web Services account ID of the owner of the IPAM pool.
     */
    IpamPoolOwner: String;
  }
  export interface MoveByoipCidrToIpamResult {
    /**
     * The BYOIP CIDR.
     */
    ByoipCidr?: ByoipCidr;
  }
  export type MoveStatus = "movingToVpc"|"restoringToClassic"|string;
  export interface MovingAddressStatus {
    /**
     * The status of the Elastic IP address that's being moved to the EC2-VPC platform, or restored to the EC2-Classic platform.
     */
    MoveStatus?: MoveStatus;
    /**
     * The Elastic IP address.
     */
    PublicIp?: String;
  }
  export type MovingAddressStatusSet = MovingAddressStatus[];
  export type MulticastSupportValue = "enable"|"disable"|string;
  export interface NatGateway {
    /**
     * The date and time the NAT gateway was created.
     */
    CreateTime?: DateTime;
    /**
     * The date and time the NAT gateway was deleted, if applicable.
     */
    DeleteTime?: DateTime;
    /**
     * If the NAT gateway could not be created, specifies the error code for the failure. (InsufficientFreeAddressesInSubnet | Gateway.NotAttached | InvalidAllocationID.NotFound | Resource.AlreadyAssociated | InternalError | InvalidSubnetID.NotFound)
     */
    FailureCode?: String;
    /**
     * If the NAT gateway could not be created, specifies the error message for the failure, that corresponds to the error code.   For InsufficientFreeAddressesInSubnet: "Subnet has insufficient free addresses to create this NAT gateway"   For Gateway.NotAttached: "Network vpc-xxxxxxxx has no Internet gateway attached"   For InvalidAllocationID.NotFound: "Elastic IP address eipalloc-xxxxxxxx could not be associated with this NAT gateway"   For Resource.AlreadyAssociated: "Elastic IP address eipalloc-xxxxxxxx is already associated"   For InternalError: "Network interface eni-xxxxxxxx, created and used internally by this NAT gateway is in an invalid state. Please try again."   For InvalidSubnetID.NotFound: "The specified subnet subnet-xxxxxxxx does not exist or could not be found."  
     */
    FailureMessage?: String;
    /**
     * Information about the IP addresses and network interface associated with the NAT gateway.
     */
    NatGatewayAddresses?: NatGatewayAddressList;
    /**
     * The ID of the NAT gateway.
     */
    NatGatewayId?: String;
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    ProvisionedBandwidth?: ProvisionedBandwidth;
    /**
     * The state of the NAT gateway.    pending: The NAT gateway is being created and is not ready to process traffic.    failed: The NAT gateway could not be created. Check the failureCode and failureMessage fields for the reason.    available: The NAT gateway is able to process traffic. This status remains until you delete the NAT gateway, and does not indicate the health of the NAT gateway.    deleting: The NAT gateway is in the process of being terminated and may still be processing traffic.    deleted: The NAT gateway has been terminated and is no longer processing traffic.  
     */
    State?: NatGatewayState;
    /**
     * The ID of the subnet in which the NAT gateway is located.
     */
    SubnetId?: String;
    /**
     * The ID of the VPC in which the NAT gateway is located.
     */
    VpcId?: String;
    /**
     * The tags for the NAT gateway.
     */
    Tags?: TagList;
    /**
     * Indicates whether the NAT gateway supports public or private connectivity.
     */
    ConnectivityType?: ConnectivityType;
  }
  export interface NatGatewayAddress {
    /**
     * [Public NAT gateway only] The allocation ID of the Elastic IP address that's associated with the NAT gateway.
     */
    AllocationId?: String;
    /**
     * The ID of the network interface associated with the NAT gateway.
     */
    NetworkInterfaceId?: String;
    /**
     * The private IP address associated with the NAT gateway.
     */
    PrivateIp?: String;
    /**
     * [Public NAT gateway only] The Elastic IP address associated with the NAT gateway.
     */
    PublicIp?: String;
    /**
     * [Public NAT gateway only] The association ID of the Elastic IP address that's associated with the NAT gateway.
     */
    AssociationId?: String;
    /**
     * Defines if the IP address is the primary address.
     */
    IsPrimary?: Boolean;
    /**
     * The address failure message.
     */
    FailureMessage?: String;
    /**
     * The address status.
     */
    Status?: NatGatewayAddressStatus;
  }
  export type NatGatewayAddressList = NatGatewayAddress[];
  export type NatGatewayAddressStatus = "assigning"|"unassigning"|"associating"|"disassociating"|"succeeded"|"failed"|string;
  export type NatGatewayId = string;
  export type NatGatewayIdStringList = NatGatewayId[];
  export type NatGatewayList = NatGateway[];
  export type NatGatewayState = "pending"|"failed"|"available"|"deleting"|"deleted"|string;
  export type NetmaskLength = number;
  export interface NetworkAcl {
    /**
     * Any associations between the network ACL and one or more subnets
     */
    Associations?: NetworkAclAssociationList;
    /**
     * One or more entries (rules) in the network ACL.
     */
    Entries?: NetworkAclEntryList;
    /**
     * Indicates whether this is the default network ACL for the VPC.
     */
    IsDefault?: Boolean;
    /**
     * The ID of the network ACL.
     */
    NetworkAclId?: String;
    /**
     * Any tags assigned to the network ACL.
     */
    Tags?: TagList;
    /**
     * The ID of the VPC for the network ACL.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the network ACL.
     */
    OwnerId?: String;
  }
  export interface NetworkAclAssociation {
    /**
     * The ID of the association between a network ACL and a subnet.
     */
    NetworkAclAssociationId?: String;
    /**
     * The ID of the network ACL.
     */
    NetworkAclId?: String;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
  }
  export type NetworkAclAssociationId = string;
  export type NetworkAclAssociationList = NetworkAclAssociation[];
  export interface NetworkAclEntry {
    /**
     * The IPv4 network range to allow or deny, in CIDR notation.
     */
    CidrBlock?: String;
    /**
     * Indicates whether the rule is an egress rule (applied to traffic leaving the subnet).
     */
    Egress?: Boolean;
    /**
     * ICMP protocol: The ICMP type and code.
     */
    IcmpTypeCode?: IcmpTypeCode;
    /**
     * The IPv6 network range to allow or deny, in CIDR notation.
     */
    Ipv6CidrBlock?: String;
    /**
     * TCP or UDP protocols: The range of ports the rule applies to.
     */
    PortRange?: PortRange;
    /**
     * The protocol number. A value of "-1" means all protocols.
     */
    Protocol?: String;
    /**
     * Indicates whether to allow or deny the traffic that matches the rule.
     */
    RuleAction?: RuleAction;
    /**
     * The rule number for the entry. ACL entries are processed in ascending order by rule number.
     */
    RuleNumber?: Integer;
  }
  export type NetworkAclEntryList = NetworkAclEntry[];
  export type NetworkAclId = string;
  export type NetworkAclIdStringList = NetworkAclId[];
  export type NetworkAclList = NetworkAcl[];
  export interface NetworkBandwidthGbps {
    /**
     * The minimum amount of network bandwidth, in Gbps. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Double;
    /**
     * The maximum amount of network bandwidth, in Gbps. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Double;
  }
  export interface NetworkBandwidthGbpsRequest {
    /**
     * The minimum amount of network bandwidth, in Gbps. To specify no minimum limit, omit this parameter.
     */
    Min?: Double;
    /**
     * The maximum amount of network bandwidth, in Gbps. To specify no maximum limit, omit this parameter.
     */
    Max?: Double;
  }
  export type NetworkCardIndex = number;
  export interface NetworkCardInfo {
    /**
     * The index of the network card.
     */
    NetworkCardIndex?: NetworkCardIndex;
    /**
     * The network performance of the network card.
     */
    NetworkPerformance?: NetworkPerformance;
    /**
     * The maximum number of network interfaces for the network card.
     */
    MaximumNetworkInterfaces?: MaxNetworkInterfaces;
  }
  export type NetworkCardInfoList = NetworkCardInfo[];
  export interface NetworkInfo {
    /**
     * The network performance.
     */
    NetworkPerformance?: NetworkPerformance;
    /**
     * The maximum number of network interfaces for the instance type.
     */
    MaximumNetworkInterfaces?: MaxNetworkInterfaces;
    /**
     * The maximum number of physical network cards that can be allocated to the instance.
     */
    MaximumNetworkCards?: MaximumNetworkCards;
    /**
     * The index of the default network card, starting at 0.
     */
    DefaultNetworkCardIndex?: DefaultNetworkCardIndex;
    /**
     * Describes the network cards for the instance type.
     */
    NetworkCards?: NetworkCardInfoList;
    /**
     * The maximum number of IPv4 addresses per network interface.
     */
    Ipv4AddressesPerInterface?: MaxIpv4AddrPerInterface;
    /**
     * The maximum number of IPv6 addresses per network interface.
     */
    Ipv6AddressesPerInterface?: MaxIpv6AddrPerInterface;
    /**
     * Indicates whether IPv6 is supported.
     */
    Ipv6Supported?: Ipv6Flag;
    /**
     * Indicates whether Elastic Network Adapter (ENA) is supported.
     */
    EnaSupport?: EnaSupport;
    /**
     * Indicates whether Elastic Fabric Adapter (EFA) is supported.
     */
    EfaSupported?: EfaSupportedFlag;
    /**
     * Describes the Elastic Fabric Adapters for the instance type.
     */
    EfaInfo?: EfaInfo;
    /**
     * Indicates whether the instance type automatically encrypts in-transit traffic between instances.
     */
    EncryptionInTransitSupported?: EncryptionInTransitSupported;
    /**
     * Indicates whether the instance type supports ENA Express. ENA Express uses Amazon Web Services Scalable Reliable Datagram (SRD) technology to increase the maximum bandwidth used per stream and minimize tail latency of network traffic between EC2 instances.
     */
    EnaSrdSupported?: EnaSrdSupported;
  }
  export interface NetworkInsightsAccessScope {
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
    /**
     * The Amazon Resource Name (ARN) of the Network Access Scope.
     */
    NetworkInsightsAccessScopeArn?: ResourceArn;
    /**
     * The creation date.
     */
    CreatedDate?: MillisecondDateTime;
    /**
     * The last updated date.
     */
    UpdatedDate?: MillisecondDateTime;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export interface NetworkInsightsAccessScopeAnalysis {
    /**
     * The ID of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisId?: NetworkInsightsAccessScopeAnalysisId;
    /**
     * The Amazon Resource Name (ARN) of the Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysisArn?: ResourceArn;
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
    /**
     * The status.
     */
    Status?: AnalysisStatus;
    /**
     * The status message.
     */
    StatusMessage?: String;
    /**
     * The warning message.
     */
    WarningMessage?: String;
    /**
     * The analysis start date.
     */
    StartDate?: MillisecondDateTime;
    /**
     * The analysis end date.
     */
    EndDate?: MillisecondDateTime;
    /**
     * Indicates whether there are findings.
     */
    FindingsFound?: FindingsFound;
    /**
     * The number of network interfaces analyzed.
     */
    AnalyzedEniCount?: Integer;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type NetworkInsightsAccessScopeAnalysisId = string;
  export type NetworkInsightsAccessScopeAnalysisIdList = NetworkInsightsAccessScopeAnalysisId[];
  export type NetworkInsightsAccessScopeAnalysisList = NetworkInsightsAccessScopeAnalysis[];
  export interface NetworkInsightsAccessScopeContent {
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId?: NetworkInsightsAccessScopeId;
    /**
     * The paths to match.
     */
    MatchPaths?: AccessScopePathList;
    /**
     * The paths to exclude.
     */
    ExcludePaths?: AccessScopePathList;
  }
  export type NetworkInsightsAccessScopeId = string;
  export type NetworkInsightsAccessScopeIdList = NetworkInsightsAccessScopeId[];
  export type NetworkInsightsAccessScopeList = NetworkInsightsAccessScope[];
  export interface NetworkInsightsAnalysis {
    /**
     * The ID of the network insights analysis.
     */
    NetworkInsightsAnalysisId?: NetworkInsightsAnalysisId;
    /**
     * The Amazon Resource Name (ARN) of the network insights analysis.
     */
    NetworkInsightsAnalysisArn?: ResourceArn;
    /**
     * The ID of the path.
     */
    NetworkInsightsPathId?: NetworkInsightsPathId;
    /**
     * The member accounts that contain resources that the path can traverse.
     */
    AdditionalAccounts?: ValueStringList;
    /**
     * The Amazon Resource Names (ARN) of the resources that the path must traverse.
     */
    FilterInArns?: ArnList;
    /**
     * The time the analysis started.
     */
    StartDate?: MillisecondDateTime;
    /**
     * The status of the network insights analysis.
     */
    Status?: AnalysisStatus;
    /**
     * The status message, if the status is failed.
     */
    StatusMessage?: String;
    /**
     * The warning message.
     */
    WarningMessage?: String;
    /**
     * Indicates whether the destination is reachable from the source.
     */
    NetworkPathFound?: Boolean;
    /**
     * The components in the path from source to destination.
     */
    ForwardPathComponents?: PathComponentList;
    /**
     * The components in the path from destination to source.
     */
    ReturnPathComponents?: PathComponentList;
    /**
     * The explanations. For more information, see Reachability Analyzer explanation codes.
     */
    Explanations?: ExplanationList;
    /**
     * Potential intermediate components.
     */
    AlternatePathHints?: AlternatePathHintList;
    /**
     * Potential intermediate accounts.
     */
    SuggestedAccounts?: ValueStringList;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type NetworkInsightsAnalysisId = string;
  export type NetworkInsightsAnalysisIdList = NetworkInsightsAnalysisId[];
  export type NetworkInsightsAnalysisList = NetworkInsightsAnalysis[];
  export type NetworkInsightsMaxResults = number;
  export interface NetworkInsightsPath {
    /**
     * The ID of the path.
     */
    NetworkInsightsPathId?: NetworkInsightsPathId;
    /**
     * The Amazon Resource Name (ARN) of the path.
     */
    NetworkInsightsPathArn?: ResourceArn;
    /**
     * The time stamp when the path was created.
     */
    CreatedDate?: MillisecondDateTime;
    /**
     * The ID of the source.
     */
    Source?: String;
    /**
     * The ID of the destination.
     */
    Destination?: String;
    /**
     * The Amazon Resource Name (ARN) of the source.
     */
    SourceArn?: ResourceArn;
    /**
     * The Amazon Resource Name (ARN) of the destination.
     */
    DestinationArn?: ResourceArn;
    /**
     * The IP address of the source.
     */
    SourceIp?: IpAddress;
    /**
     * The IP address of the destination.
     */
    DestinationIp?: IpAddress;
    /**
     * The protocol.
     */
    Protocol?: Protocol;
    /**
     * The destination port.
     */
    DestinationPort?: Integer;
    /**
     * The tags associated with the path.
     */
    Tags?: TagList;
    /**
     * Scopes the analysis to network paths that match specific filters at the source.
     */
    FilterAtSource?: PathFilter;
    /**
     * Scopes the analysis to network paths that match specific filters at the destination.
     */
    FilterAtDestination?: PathFilter;
  }
  export type NetworkInsightsPathId = string;
  export type NetworkInsightsPathIdList = NetworkInsightsPathId[];
  export type NetworkInsightsPathList = NetworkInsightsPath[];
  export type NetworkInsightsResourceId = string;
  export interface NetworkInterface {
    /**
     * The association information for an Elastic IP address (IPv4) associated with the network interface.
     */
    Association?: NetworkInterfaceAssociation;
    /**
     * The network interface attachment.
     */
    Attachment?: NetworkInterfaceAttachment;
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * A description.
     */
    Description?: String;
    /**
     * Any security groups for the network interface.
     */
    Groups?: GroupIdentifierList;
    /**
     * The type of network interface.
     */
    InterfaceType?: NetworkInterfaceType;
    /**
     * The IPv6 addresses associated with the network interface.
     */
    Ipv6Addresses?: NetworkInterfaceIpv6AddressesList;
    /**
     * The MAC address.
     */
    MacAddress?: String;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The Amazon Web Services account ID of the owner of the network interface.
     */
    OwnerId?: String;
    /**
     * The private DNS name.
     */
    PrivateDnsName?: String;
    /**
     * The IPv4 address of the network interface within the subnet.
     */
    PrivateIpAddress?: String;
    /**
     * The private IPv4 addresses associated with the network interface.
     */
    PrivateIpAddresses?: NetworkInterfacePrivateIpAddressList;
    /**
     * The IPv4 prefixes that are assigned to the network interface.
     */
    Ipv4Prefixes?: Ipv4PrefixesList;
    /**
     * The IPv6 prefixes that are assigned to the network interface.
     */
    Ipv6Prefixes?: Ipv6PrefixesList;
    /**
     * The alias or Amazon Web Services account ID of the principal or service that created the network interface.
     */
    RequesterId?: String;
    /**
     * Indicates whether the network interface is being managed by Amazon Web Services.
     */
    RequesterManaged?: Boolean;
    /**
     * Indicates whether source/destination checking is enabled.
     */
    SourceDestCheck?: Boolean;
    /**
     * The status of the network interface.
     */
    Status?: NetworkInterfaceStatus;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
    /**
     * Any tags assigned to the network interface.
     */
    TagSet?: TagList;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * Indicates whether a network interface with an IPv6 address is unreachable from the public internet. If the value is true, inbound traffic from the internet is dropped and you cannot assign an elastic IP address to the network interface. The network interface is reachable from peered VPCs and resources connected through a transit gateway, including on-premises networks.
     */
    DenyAllIgwTraffic?: Boolean;
    /**
     * Indicates whether this is an IPv6 only network interface.
     */
    Ipv6Native?: Boolean;
    /**
     * The IPv6 globally unique address associated with the network interface.
     */
    Ipv6Address?: String;
  }
  export interface NetworkInterfaceAssociation {
    /**
     * The allocation ID.
     */
    AllocationId?: String;
    /**
     * The association ID.
     */
    AssociationId?: String;
    /**
     * The ID of the Elastic IP address owner.
     */
    IpOwnerId?: String;
    /**
     * The public DNS name.
     */
    PublicDnsName?: String;
    /**
     * The address of the Elastic IP address bound to the network interface.
     */
    PublicIp?: String;
    /**
     * The customer-owned IP address associated with the network interface.
     */
    CustomerOwnedIp?: String;
    /**
     * The carrier IP address associated with the network interface. This option is only available when the network interface is in a subnet which is associated with a Wavelength Zone.
     */
    CarrierIp?: String;
  }
  export interface NetworkInterfaceAttachment {
    /**
     * The timestamp indicating when the attachment initiated.
     */
    AttachTime?: DateTime;
    /**
     * The ID of the network interface attachment.
     */
    AttachmentId?: String;
    /**
     * Indicates whether the network interface is deleted when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The device index of the network interface attachment on the instance.
     */
    DeviceIndex?: Integer;
    /**
     * The index of the network card.
     */
    NetworkCardIndex?: Integer;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The Amazon Web Services account ID of the owner of the instance.
     */
    InstanceOwnerId?: String;
    /**
     * The attachment state.
     */
    Status?: AttachmentStatus;
    /**
     * Configures ENA Express for the network interface that this action attaches to the instance.
     */
    EnaSrdSpecification?: AttachmentEnaSrdSpecification;
  }
  export interface NetworkInterfaceAttachmentChanges {
    /**
     * The ID of the network interface attachment.
     */
    AttachmentId?: NetworkInterfaceAttachmentId;
    /**
     * Indicates whether the network interface is deleted when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
  }
  export type NetworkInterfaceAttachmentId = string;
  export type NetworkInterfaceAttribute = "description"|"groupSet"|"sourceDestCheck"|"attachment"|string;
  export interface NetworkInterfaceCount {
    /**
     * The minimum number of network interfaces. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum number of network interfaces. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface NetworkInterfaceCountRequest {
    /**
     * The minimum number of network interfaces. To specify no minimum limit, omit this parameter.
     */
    Min?: Integer;
    /**
     * The maximum number of network interfaces. To specify no maximum limit, omit this parameter.
     */
    Max?: Integer;
  }
  export type NetworkInterfaceCreationType = "efa"|"branch"|"trunk"|string;
  export type NetworkInterfaceId = string;
  export type NetworkInterfaceIdList = NetworkInterfaceId[];
  export interface NetworkInterfaceIpv6Address {
    /**
     * The IPv6 address.
     */
    Ipv6Address?: String;
  }
  export type NetworkInterfaceIpv6AddressesList = NetworkInterfaceIpv6Address[];
  export type NetworkInterfaceList = NetworkInterface[];
  export interface NetworkInterfacePermission {
    /**
     * The ID of the network interface permission.
     */
    NetworkInterfacePermissionId?: String;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The Amazon Web Services account ID.
     */
    AwsAccountId?: String;
    /**
     * The Amazon Web Service.
     */
    AwsService?: String;
    /**
     * The type of permission.
     */
    Permission?: InterfacePermissionType;
    /**
     * Information about the state of the permission.
     */
    PermissionState?: NetworkInterfacePermissionState;
  }
  export type NetworkInterfacePermissionId = string;
  export type NetworkInterfacePermissionIdList = NetworkInterfacePermissionId[];
  export type NetworkInterfacePermissionList = NetworkInterfacePermission[];
  export interface NetworkInterfacePermissionState {
    /**
     * The state of the permission.
     */
    State?: NetworkInterfacePermissionStateCode;
    /**
     * A status message, if applicable.
     */
    StatusMessage?: String;
  }
  export type NetworkInterfacePermissionStateCode = "pending"|"granted"|"revoking"|"revoked"|string;
  export interface NetworkInterfacePrivateIpAddress {
    /**
     * The association information for an Elastic IP address (IPv4) associated with the network interface.
     */
    Association?: NetworkInterfaceAssociation;
    /**
     * Indicates whether this IPv4 address is the primary private IPv4 address of the network interface.
     */
    Primary?: Boolean;
    /**
     * The private DNS name.
     */
    PrivateDnsName?: String;
    /**
     * The private IPv4 address.
     */
    PrivateIpAddress?: String;
  }
  export type NetworkInterfacePrivateIpAddressList = NetworkInterfacePrivateIpAddress[];
  export type NetworkInterfaceStatus = "available"|"associated"|"attaching"|"in-use"|"detaching"|string;
  export type NetworkInterfaceType = "interface"|"natGateway"|"efa"|"trunk"|"load_balancer"|"network_load_balancer"|"vpc_endpoint"|"branch"|"transit_gateway"|"lambda"|"quicksight"|"global_accelerator_managed"|"api_gateway_managed"|"gateway_load_balancer"|"gateway_load_balancer_endpoint"|"iot_rules_managed"|"aws_codestar_connections_managed"|string;
  export type NetworkPerformance = string;
  export interface NewDhcpConfiguration {
    Key?: String;
    Values?: ValueStringList;
  }
  export type NewDhcpConfigurationList = NewDhcpConfiguration[];
  export type NextToken = string;
  export type OccurrenceDayRequestSet = Integer[];
  export type OccurrenceDaySet = Integer[];
  export type OfferingClassType = "standard"|"convertible"|string;
  export type OfferingId = string;
  export type OfferingTypeValues = "Heavy Utilization"|"Medium Utilization"|"Light Utilization"|"No Upfront"|"Partial Upfront"|"All Upfront"|string;
  export interface OidcOptions {
    /**
     * The OIDC issuer.
     */
    Issuer?: String;
    /**
     * The OIDC authorization endpoint.
     */
    AuthorizationEndpoint?: String;
    /**
     * The OIDC token endpoint.
     */
    TokenEndpoint?: String;
    /**
     * The OIDC user info endpoint.
     */
    UserInfoEndpoint?: String;
    /**
     * The client identifier.
     */
    ClientId?: String;
    /**
     * The client secret.
     */
    ClientSecret?: String;
    /**
     * The OpenID Connect (OIDC) scope specified.
     */
    Scope?: String;
  }
  export type OnDemandAllocationStrategy = "lowestPrice"|"prioritized"|string;
  export interface OnDemandOptions {
    /**
     * The strategy that determines the order of the launch template overrides to use in fulfilling On-Demand capacity.  lowest-price - EC2 Fleet uses price to determine the order, launching the lowest price first.  prioritized - EC2 Fleet uses the priority that you assigned to each launch template override, launching the highest priority first. Default: lowest-price 
     */
    AllocationStrategy?: FleetOnDemandAllocationStrategy;
    /**
     * The strategy for using unused Capacity Reservations for fulfilling On-Demand capacity. Supported only for fleets of type instant.
     */
    CapacityReservationOptions?: CapacityReservationOptions;
    /**
     * Indicates that the fleet uses a single instance type to launch all On-Demand Instances in the fleet. Supported only for fleets of type instant.
     */
    SingleInstanceType?: Boolean;
    /**
     * Indicates that the fleet launches all On-Demand Instances into a single Availability Zone. Supported only for fleets of type instant.
     */
    SingleAvailabilityZone?: Boolean;
    /**
     * The minimum target capacity for On-Demand Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances. Supported only for fleets of type instant. At least one of the following must be specified: SingleAvailabilityZone | SingleInstanceType 
     */
    MinTargetCapacity?: Integer;
    /**
     * The maximum amount per hour for On-Demand Instances that you're willing to pay.
     */
    MaxTotalPrice?: String;
  }
  export interface OnDemandOptionsRequest {
    /**
     * The strategy that determines the order of the launch template overrides to use in fulfilling On-Demand capacity.  lowest-price - EC2 Fleet uses price to determine the order, launching the lowest price first.  prioritized - EC2 Fleet uses the priority that you assigned to each launch template override, launching the highest priority first. Default: lowest-price 
     */
    AllocationStrategy?: FleetOnDemandAllocationStrategy;
    /**
     * The strategy for using unused Capacity Reservations for fulfilling On-Demand capacity. Supported only for fleets of type instant.
     */
    CapacityReservationOptions?: CapacityReservationOptionsRequest;
    /**
     * Indicates that the fleet uses a single instance type to launch all On-Demand Instances in the fleet. Supported only for fleets of type instant.
     */
    SingleInstanceType?: Boolean;
    /**
     * Indicates that the fleet launches all On-Demand Instances into a single Availability Zone. Supported only for fleets of type instant.
     */
    SingleAvailabilityZone?: Boolean;
    /**
     * The minimum target capacity for On-Demand Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances. Supported only for fleets of type instant. At least one of the following must be specified: SingleAvailabilityZone | SingleInstanceType 
     */
    MinTargetCapacity?: Integer;
    /**
     * The maximum amount per hour for On-Demand Instances that you're willing to pay.
     */
    MaxTotalPrice?: String;
  }
  export type OperationType = "add"|"remove"|string;
  export type OrganizationArnStringList = String[];
  export type OrganizationalUnitArnStringList = String[];
  export type OutpostArn = string;
  export type OwnerStringList = String[];
  export interface PacketHeaderStatement {
    /**
     * The source addresses.
     */
    SourceAddresses?: ValueStringList;
    /**
     * The destination addresses.
     */
    DestinationAddresses?: ValueStringList;
    /**
     * The source ports.
     */
    SourcePorts?: ValueStringList;
    /**
     * The destination ports.
     */
    DestinationPorts?: ValueStringList;
    /**
     * The source prefix lists.
     */
    SourcePrefixLists?: ValueStringList;
    /**
     * The destination prefix lists.
     */
    DestinationPrefixLists?: ValueStringList;
    /**
     * The protocols.
     */
    Protocols?: ProtocolList;
  }
  export interface PacketHeaderStatementRequest {
    /**
     * The source addresses.
     */
    SourceAddresses?: ValueStringList;
    /**
     * The destination addresses.
     */
    DestinationAddresses?: ValueStringList;
    /**
     * The source ports.
     */
    SourcePorts?: ValueStringList;
    /**
     * The destination ports.
     */
    DestinationPorts?: ValueStringList;
    /**
     * The source prefix lists.
     */
    SourcePrefixLists?: ValueStringList;
    /**
     * The destination prefix lists.
     */
    DestinationPrefixLists?: ValueStringList;
    /**
     * The protocols.
     */
    Protocols?: ProtocolList;
  }
  export type PartitionLoadFrequency = "none"|"daily"|"weekly"|"monthly"|string;
  export interface PathComponent {
    /**
     * The sequence number.
     */
    SequenceNumber?: Integer;
    /**
     * The network ACL rule.
     */
    AclRule?: AnalysisAclRule;
    /**
     * The resource to which the path component is attached.
     */
    AttachedTo?: AnalysisComponent;
    /**
     * The component.
     */
    Component?: AnalysisComponent;
    /**
     * The destination VPC.
     */
    DestinationVpc?: AnalysisComponent;
    /**
     * The outbound header.
     */
    OutboundHeader?: AnalysisPacketHeader;
    /**
     * The inbound header.
     */
    InboundHeader?: AnalysisPacketHeader;
    /**
     * The route table route.
     */
    RouteTableRoute?: AnalysisRouteTableRoute;
    /**
     * The security group rule.
     */
    SecurityGroupRule?: AnalysisSecurityGroupRule;
    /**
     * The source VPC.
     */
    SourceVpc?: AnalysisComponent;
    /**
     * The subnet.
     */
    Subnet?: AnalysisComponent;
    /**
     * The component VPC.
     */
    Vpc?: AnalysisComponent;
    /**
     * The additional details.
     */
    AdditionalDetails?: AdditionalDetailList;
    /**
     * The transit gateway.
     */
    TransitGateway?: AnalysisComponent;
    /**
     * The route in a transit gateway route table.
     */
    TransitGatewayRouteTableRoute?: TransitGatewayRouteTableRoute;
    /**
     * The explanation codes.
     */
    Explanations?: ExplanationList;
    /**
     * The load balancer listener.
     */
    ElasticLoadBalancerListener?: AnalysisComponent;
    /**
     * The Network Firewall stateless rule.
     */
    FirewallStatelessRule?: FirewallStatelessRule;
    /**
     * The Network Firewall stateful rule.
     */
    FirewallStatefulRule?: FirewallStatefulRule;
    /**
     * The name of the VPC endpoint service.
     */
    ServiceName?: String;
  }
  export type PathComponentList = PathComponent[];
  export interface PathFilter {
    /**
     * The source IPv4 address.
     */
    SourceAddress?: IpAddress;
    /**
     * The source port range.
     */
    SourcePortRange?: FilterPortRange;
    /**
     * The destination IPv4 address.
     */
    DestinationAddress?: IpAddress;
    /**
     * The destination port range.
     */
    DestinationPortRange?: FilterPortRange;
  }
  export interface PathRequestFilter {
    /**
     * The source IPv4 address.
     */
    SourceAddress?: IpAddress;
    /**
     * The source port range.
     */
    SourcePortRange?: RequestFilterPortRange;
    /**
     * The destination IPv4 address.
     */
    DestinationAddress?: IpAddress;
    /**
     * The destination port range.
     */
    DestinationPortRange?: RequestFilterPortRange;
  }
  export interface PathStatement {
    /**
     * The packet header statement.
     */
    PacketHeaderStatement?: PacketHeaderStatement;
    /**
     * The resource statement.
     */
    ResourceStatement?: ResourceStatement;
  }
  export interface PathStatementRequest {
    /**
     * The packet header statement.
     */
    PacketHeaderStatement?: PacketHeaderStatementRequest;
    /**
     * The resource statement.
     */
    ResourceStatement?: ResourceStatementRequest;
  }
  export type PayerResponsibility = "ServiceOwner"|string;
  export type PaymentOption = "AllUpfront"|"PartialUpfront"|"NoUpfront"|string;
  export interface PciId {
    /**
     * The ID of the device.
     */
    DeviceId?: String;
    /**
     * The ID of the vendor.
     */
    VendorId?: String;
    /**
     * The ID of the subsystem.
     */
    SubsystemId?: String;
    /**
     * The ID of the vendor for the subsystem.
     */
    SubsystemVendorId?: String;
  }
  export interface PeeringAttachmentStatus {
    /**
     * The status code.
     */
    Code?: String;
    /**
     * The status message, if applicable.
     */
    Message?: String;
  }
  export interface PeeringConnectionOptions {
    /**
     * If true, the public DNS hostnames of instances in the specified VPC resolve to private IP addresses when queried from instances in the peer VPC.
     */
    AllowDnsResolutionFromRemoteVpc?: Boolean;
    /**
     * If true, enables outbound communication from an EC2-Classic instance that's linked to a local VPC using ClassicLink to instances in a peer VPC.
     */
    AllowEgressFromLocalClassicLinkToRemoteVpc?: Boolean;
    /**
     * If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that's linked to a peer VPC using ClassicLink.
     */
    AllowEgressFromLocalVpcToRemoteClassicLink?: Boolean;
  }
  export interface PeeringConnectionOptionsRequest {
    /**
     * If true, enables a local VPC to resolve public DNS hostnames to private IP addresses when queried from instances in the peer VPC.
     */
    AllowDnsResolutionFromRemoteVpc?: Boolean;
    /**
     * If true, enables outbound communication from an EC2-Classic instance that's linked to a local VPC using ClassicLink to instances in a peer VPC.
     */
    AllowEgressFromLocalClassicLinkToRemoteVpc?: Boolean;
    /**
     * If true, enables outbound communication from instances in a local VPC to an EC2-Classic instance that's linked to a peer VPC using ClassicLink.
     */
    AllowEgressFromLocalVpcToRemoteClassicLink?: Boolean;
  }
  export interface PeeringTgwInfo {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The ID of the core network where the transit gateway peer is located.
     */
    CoreNetworkId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the transit gateway.
     */
    OwnerId?: String;
    /**
     * The Region of the transit gateway.
     */
    Region?: String;
  }
  export type PeriodType = "five-minutes"|"fifteen-minutes"|"one-hour"|"three-hours"|"one-day"|"one-week"|string;
  export type PermissionGroup = "all"|string;
  export type Phase1DHGroupNumbersList = Phase1DHGroupNumbersListValue[];
  export interface Phase1DHGroupNumbersListValue {
    /**
     * The Diffie-Hellmann group number.
     */
    Value?: Integer;
  }
  export type Phase1DHGroupNumbersRequestList = Phase1DHGroupNumbersRequestListValue[];
  export interface Phase1DHGroupNumbersRequestListValue {
    /**
     * The Diffie-Hellmann group number.
     */
    Value?: Integer;
  }
  export type Phase1EncryptionAlgorithmsList = Phase1EncryptionAlgorithmsListValue[];
  export interface Phase1EncryptionAlgorithmsListValue {
    /**
     * The value for the encryption algorithm.
     */
    Value?: String;
  }
  export type Phase1EncryptionAlgorithmsRequestList = Phase1EncryptionAlgorithmsRequestListValue[];
  export interface Phase1EncryptionAlgorithmsRequestListValue {
    /**
     * The value for the encryption algorithm.
     */
    Value?: String;
  }
  export type Phase1IntegrityAlgorithmsList = Phase1IntegrityAlgorithmsListValue[];
  export interface Phase1IntegrityAlgorithmsListValue {
    /**
     * The value for the integrity algorithm.
     */
    Value?: String;
  }
  export type Phase1IntegrityAlgorithmsRequestList = Phase1IntegrityAlgorithmsRequestListValue[];
  export interface Phase1IntegrityAlgorithmsRequestListValue {
    /**
     * The value for the integrity algorithm.
     */
    Value?: String;
  }
  export type Phase2DHGroupNumbersList = Phase2DHGroupNumbersListValue[];
  export interface Phase2DHGroupNumbersListValue {
    /**
     * The Diffie-Hellmann group number.
     */
    Value?: Integer;
  }
  export type Phase2DHGroupNumbersRequestList = Phase2DHGroupNumbersRequestListValue[];
  export interface Phase2DHGroupNumbersRequestListValue {
    /**
     * The Diffie-Hellmann group number.
     */
    Value?: Integer;
  }
  export type Phase2EncryptionAlgorithmsList = Phase2EncryptionAlgorithmsListValue[];
  export interface Phase2EncryptionAlgorithmsListValue {
    /**
     * The encryption algorithm.
     */
    Value?: String;
  }
  export type Phase2EncryptionAlgorithmsRequestList = Phase2EncryptionAlgorithmsRequestListValue[];
  export interface Phase2EncryptionAlgorithmsRequestListValue {
    /**
     * The encryption algorithm.
     */
    Value?: String;
  }
  export type Phase2IntegrityAlgorithmsList = Phase2IntegrityAlgorithmsListValue[];
  export interface Phase2IntegrityAlgorithmsListValue {
    /**
     * The integrity algorithm.
     */
    Value?: String;
  }
  export type Phase2IntegrityAlgorithmsRequestList = Phase2IntegrityAlgorithmsRequestListValue[];
  export interface Phase2IntegrityAlgorithmsRequestListValue {
    /**
     * The integrity algorithm.
     */
    Value?: String;
  }
  export interface Placement {
    /**
     * The Availability Zone of the instance. If not specified, an Availability Zone will be automatically chosen for you based on the load balancing criteria for the Region. This parameter is not supported for CreateFleet.
     */
    AvailabilityZone?: String;
    /**
     * The affinity setting for the instance on the Dedicated Host. This parameter is not supported for CreateFleet or ImportInstance.
     */
    Affinity?: String;
    /**
     * The name of the placement group that the instance is in. If you specify GroupName, you can't specify GroupId.
     */
    GroupName?: PlacementGroupName;
    /**
     * The number of the partition that the instance is in. Valid only if the placement group strategy is set to partition. This parameter is not supported for CreateFleet.
     */
    PartitionNumber?: Integer;
    /**
     * The ID of the Dedicated Host on which the instance resides. This parameter is not supported for CreateFleet or ImportInstance.
     */
    HostId?: String;
    /**
     * The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. This parameter is not supported for CreateFleet. The host tenancy is not supported for ImportInstance or for T3 instances that are configured for the unlimited CPU credit option.
     */
    Tenancy?: Tenancy;
    /**
     * Reserved for future use.
     */
    SpreadDomain?: String;
    /**
     * The ARN of the host resource group in which to launch the instances. If you specify this parameter, either omit the Tenancy parameter or set it to host. This parameter is not supported for CreateFleet.
     */
    HostResourceGroupArn?: String;
    /**
     * The ID of the placement group that the instance is in. If you specify GroupId, you can't specify GroupName.
     */
    GroupId?: PlacementGroupId;
  }
  export interface PlacementGroup {
    /**
     * The name of the placement group.
     */
    GroupName?: String;
    /**
     * The state of the placement group.
     */
    State?: PlacementGroupState;
    /**
     * The placement strategy.
     */
    Strategy?: PlacementStrategy;
    /**
     * The number of partitions. Valid only if strategy is set to partition.
     */
    PartitionCount?: Integer;
    /**
     * The ID of the placement group.
     */
    GroupId?: String;
    /**
     * Any tags applied to the placement group.
     */
    Tags?: TagList;
    /**
     * The Amazon Resource Name (ARN) of the placement group.
     */
    GroupArn?: String;
    /**
     * The spread level for the placement group. Only Outpost placement groups can be spread across hosts.
     */
    SpreadLevel?: SpreadLevel;
  }
  export type PlacementGroupArn = string;
  export type PlacementGroupId = string;
  export type PlacementGroupIdStringList = PlacementGroupId[];
  export interface PlacementGroupInfo {
    /**
     * The supported placement group types.
     */
    SupportedStrategies?: PlacementGroupStrategyList;
  }
  export type PlacementGroupList = PlacementGroup[];
  export type PlacementGroupName = string;
  export type PlacementGroupState = "pending"|"available"|"deleting"|"deleted"|string;
  export type PlacementGroupStrategy = "cluster"|"partition"|"spread"|string;
  export type PlacementGroupStrategyList = PlacementGroupStrategy[];
  export type PlacementGroupStringList = PlacementGroupName[];
  export interface PlacementResponse {
    /**
     * The name of the placement group that the instance is in.
     */
    GroupName?: PlacementGroupName;
  }
  export type PlacementStrategy = "cluster"|"spread"|"partition"|string;
  export type PlatformValues = "Windows"|string;
  export interface PoolCidrBlock {
    /**
     * The CIDR block.
     */
    Cidr?: String;
  }
  export type PoolCidrBlocksSet = PoolCidrBlock[];
  export type PoolMaxResults = number;
  export type Port = number;
  export interface PortRange {
    /**
     * The first port in the range.
     */
    From?: Integer;
    /**
     * The last port in the range.
     */
    To?: Integer;
  }
  export type PortRangeList = PortRange[];
  export interface PrefixList {
    /**
     * The IP address range of the Amazon Web Service.
     */
    Cidrs?: ValueStringList;
    /**
     * The ID of the prefix.
     */
    PrefixListId?: String;
    /**
     * The name of the prefix.
     */
    PrefixListName?: String;
  }
  export interface PrefixListAssociation {
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The owner of the resource.
     */
    ResourceOwner?: String;
  }
  export type PrefixListAssociationSet = PrefixListAssociation[];
  export interface PrefixListEntry {
    /**
     * The CIDR block.
     */
    Cidr?: String;
    /**
     * The description.
     */
    Description?: String;
  }
  export type PrefixListEntrySet = PrefixListEntry[];
  export interface PrefixListId {
    /**
     * A description for the security group rule that references this prefix list ID. Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
     */
    Description?: String;
    /**
     * The ID of the prefix.
     */
    PrefixListId?: String;
  }
  export type PrefixListIdList = PrefixListId[];
  export type PrefixListIdSet = String[];
  export type PrefixListMaxResults = number;
  export type PrefixListResourceId = string;
  export type PrefixListResourceIdStringList = PrefixListResourceId[];
  export type PrefixListSet = PrefixList[];
  export type PrefixListState = "create-in-progress"|"create-complete"|"create-failed"|"modify-in-progress"|"modify-complete"|"modify-failed"|"restore-in-progress"|"restore-complete"|"restore-failed"|"delete-in-progress"|"delete-complete"|"delete-failed"|string;
  export interface PriceSchedule {
    /**
     * The current price schedule, as determined by the term remaining for the Reserved Instance in the listing. A specific price schedule is always in effect, but only one price schedule can be active at any time. Take, for example, a Reserved Instance listing that has five months remaining in its term. When you specify price schedules for five months and two months, this means that schedule 1, covering the first three months of the remaining term, will be active during months 5, 4, and 3. Then schedule 2, covering the last two months of the term, will be active for months 2 and 1.
     */
    Active?: Boolean;
    /**
     * The currency for transacting the Reserved Instance resale. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The fixed price for the term.
     */
    Price?: Double;
    /**
     * The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
     */
    Term?: Long;
  }
  export type PriceScheduleList = PriceSchedule[];
  export interface PriceScheduleSpecification {
    /**
     * The currency for transacting the Reserved Instance resale. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The fixed price for the term.
     */
    Price?: Double;
    /**
     * The number of months remaining in the reservation. For example, 2 is the second to the last month before the capacity reservation expires.
     */
    Term?: Long;
  }
  export type PriceScheduleSpecificationList = PriceScheduleSpecification[];
  export interface PricingDetail {
    /**
     * The number of reservations available for the price.
     */
    Count?: Integer;
    /**
     * The price per instance.
     */
    Price?: Double;
  }
  export type PricingDetailsList = PricingDetail[];
  export interface PrincipalIdFormat {
    /**
     * PrincipalIdFormatARN description
     */
    Arn?: String;
    /**
     * PrincipalIdFormatStatuses description
     */
    Statuses?: IdFormatList;
  }
  export type PrincipalIdFormatList = PrincipalIdFormat[];
  export type PrincipalType = "All"|"Service"|"OrganizationUnit"|"Account"|"User"|"Role"|string;
  export type Priority = number;
  export interface PrivateDnsDetails {
    /**
     * The private DNS name assigned to the VPC endpoint service.
     */
    PrivateDnsName?: String;
  }
  export type PrivateDnsDetailsSet = PrivateDnsDetails[];
  export interface PrivateDnsNameConfiguration {
    /**
     * The verification state of the VPC endpoint service. &gt;Consumers of the endpoint service can use the private name only when the state is verified.
     */
    State?: DnsNameState;
    /**
     * The endpoint service verification type, for example TXT.
     */
    Type?: String;
    /**
     * The value the service provider adds to the private DNS name domain record before verification.
     */
    Value?: String;
    /**
     * The name of the record subdomain the service provider needs to create. The service provider adds the value text to the name.
     */
    Name?: String;
  }
  export interface PrivateDnsNameOptionsOnLaunch {
    /**
     * The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
     */
    HostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostname with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export interface PrivateDnsNameOptionsRequest {
    /**
     * The type of hostname for EC2 instances. For IPv4 only subnets, an instance DNS name must be based on the instance IPv4 address. For IPv6 only subnets, an instance DNS name must be based on the instance ID. For dual-stack subnets, you can specify whether DNS names use the instance IPv4 address or the instance ID.
     */
    HostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export interface PrivateDnsNameOptionsResponse {
    /**
     * The type of hostname to assign to an instance.
     */
    HostnameType?: HostnameType;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS A records.
     */
    EnableResourceNameDnsARecord?: Boolean;
    /**
     * Indicates whether to respond to DNS queries for instance hostnames with DNS AAAA records.
     */
    EnableResourceNameDnsAAAARecord?: Boolean;
  }
  export type PrivateIpAddressConfigSet = ScheduledInstancesPrivateIpAddressConfig[];
  export type PrivateIpAddressCount = number;
  export interface PrivateIpAddressSpecification {
    /**
     * Indicates whether the private IPv4 address is the primary private IPv4 address. Only one IPv4 address can be designated as primary.
     */
    Primary?: Boolean;
    /**
     * The private IPv4 address.
     */
    PrivateIpAddress?: String;
  }
  export type PrivateIpAddressSpecificationList = PrivateIpAddressSpecification[];
  export type PrivateIpAddressStringList = String[];
  export interface ProcessorInfo {
    /**
     * The architectures supported by the instance type.
     */
    SupportedArchitectures?: ArchitectureTypeList;
    /**
     * The speed of the processor, in GHz.
     */
    SustainedClockSpeedInGhz?: ProcessorSustainedClockSpeed;
  }
  export type ProcessorSustainedClockSpeed = number;
  export interface ProductCode {
    /**
     * The product code.
     */
    ProductCodeId?: String;
    /**
     * The type of product code.
     */
    ProductCodeType?: ProductCodeValues;
  }
  export type ProductCodeList = ProductCode[];
  export type ProductCodeStringList = String[];
  export type ProductCodeValues = "devpay"|"marketplace"|string;
  export type ProductDescriptionList = String[];
  export interface PropagatingVgw {
    /**
     * The ID of the virtual private gateway.
     */
    GatewayId?: String;
  }
  export type PropagatingVgwList = PropagatingVgw[];
  export type Protocol = "tcp"|"udp"|string;
  export type ProtocolInt = number;
  export type ProtocolIntList = ProtocolInt[];
  export type ProtocolList = Protocol[];
  export type ProtocolValue = "gre"|string;
  export interface ProvisionByoipCidrRequest {
    /**
     * The public IPv4 or IPv6 address range, in CIDR notation. The most specific IPv4 prefix that you can specify is /24. The most specific IPv6 prefix you can specify is /56. The address range cannot overlap with another address range that you've brought to this or another Region.
     */
    Cidr: String;
    /**
     * A signed document that proves that you are authorized to bring the specified IP address range to Amazon using BYOIP.
     */
    CidrAuthorizationContext?: CidrAuthorizationContext;
    /**
     * (IPv6 only) Indicate whether the address range will be publicly advertised to the internet. Default: true
     */
    PubliclyAdvertisable?: Boolean;
    /**
     * A description for the address range and the address pool.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to apply to the address pool.
     */
    PoolTagSpecifications?: TagSpecificationList;
    /**
     * Reserved.
     */
    MultiRegion?: Boolean;
  }
  export interface ProvisionByoipCidrResult {
    /**
     * Information about the address range.
     */
    ByoipCidr?: ByoipCidr;
  }
  export interface ProvisionIpamPoolCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool to which you want to assign a CIDR.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The CIDR you want to assign to the IPAM pool. Either "NetmaskLength" or "Cidr" is required. This value will be null if you specify "NetmaskLength" and will be filled in during the provisioning process.
     */
    Cidr?: String;
    /**
     * A signed document that proves that you are authorized to bring a specified IP address range to Amazon using BYOIP. This option applies to public pools only.
     */
    CidrAuthorizationContext?: IpamCidrAuthorizationContext;
    /**
     * The netmask length of the CIDR you'd like to provision to a pool. Can be used for provisioning Amazon-provided IPv6 CIDRs to top-level pools and for provisioning CIDRs to pools with source pools. Cannot be used to provision BYOIP CIDRs to top-level pools. Either "NetmaskLength" or "Cidr" is required.
     */
    NetmaskLength?: Integer;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
  }
  export interface ProvisionIpamPoolCidrResult {
    /**
     * Information about the provisioned CIDR.
     */
    IpamPoolCidr?: IpamPoolCidr;
  }
  export interface ProvisionPublicIpv4PoolCidrRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool you would like to use to allocate this CIDR.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The ID of the public IPv4 pool you would like to use for this CIDR.
     */
    PoolId: Ipv4PoolEc2Id;
    /**
     * The netmask length of the CIDR you would like to allocate to the public IPv4 pool.
     */
    NetmaskLength: Integer;
  }
  export interface ProvisionPublicIpv4PoolCidrResult {
    /**
     * The ID of the pool that you want to provision the CIDR to.
     */
    PoolId?: Ipv4PoolEc2Id;
    /**
     * Information about the address range of the public IPv4 pool.
     */
    PoolAddressRange?: PublicIpv4PoolRange;
  }
  export interface ProvisionedBandwidth {
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    ProvisionTime?: DateTime;
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    Provisioned?: String;
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    RequestTime?: DateTime;
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    Requested?: String;
    /**
     * Reserved. If you need to sustain traffic greater than the documented limits, contact us through the Support Center.
     */
    Status?: String;
  }
  export interface PtrUpdateStatus {
    /**
     * The value for the PTR record update.
     */
    Value?: String;
    /**
     * The status of the PTR record update.
     */
    Status?: String;
    /**
     * The reason for the PTR record update.
     */
    Reason?: String;
  }
  export type PublicIpAddress = string;
  export type PublicIpStringList = String[];
  export interface PublicIpv4Pool {
    /**
     * The ID of the address pool.
     */
    PoolId?: String;
    /**
     * A description of the address pool.
     */
    Description?: String;
    /**
     * The address ranges.
     */
    PoolAddressRanges?: PublicIpv4PoolRangeSet;
    /**
     * The total number of addresses.
     */
    TotalAddressCount?: Integer;
    /**
     * The total number of available addresses.
     */
    TotalAvailableAddressCount?: Integer;
    /**
     * The name of the location from which the address pool is advertised. A network border group is a unique set of Availability Zones or Local Zones from where Amazon Web Services advertises public IP addresses.
     */
    NetworkBorderGroup?: String;
    /**
     * Any tags for the address pool.
     */
    Tags?: TagList;
  }
  export type PublicIpv4PoolIdStringList = Ipv4PoolEc2Id[];
  export interface PublicIpv4PoolRange {
    /**
     * The first IP address in the range.
     */
    FirstAddress?: String;
    /**
     * The last IP address in the range.
     */
    LastAddress?: String;
    /**
     * The number of addresses in the range.
     */
    AddressCount?: Integer;
    /**
     * The number of available addresses in the range.
     */
    AvailableAddressCount?: Integer;
  }
  export type PublicIpv4PoolRangeSet = PublicIpv4PoolRange[];
  export type PublicIpv4PoolSet = PublicIpv4Pool[];
  export interface Purchase {
    /**
     * The currency in which the UpfrontPrice and HourlyPrice amounts are specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The duration of the reservation's term in seconds.
     */
    Duration?: Integer;
    /**
     * The IDs of the Dedicated Hosts associated with the reservation.
     */
    HostIdSet?: ResponseHostIdSet;
    /**
     * The ID of the reservation.
     */
    HostReservationId?: HostReservationId;
    /**
     * The hourly price of the reservation per hour.
     */
    HourlyPrice?: String;
    /**
     * The instance family on the Dedicated Host that the reservation can be associated with.
     */
    InstanceFamily?: String;
    /**
     * The payment option for the reservation.
     */
    PaymentOption?: PaymentOption;
    /**
     * The upfront price of the reservation.
     */
    UpfrontPrice?: String;
  }
  export interface PurchaseHostReservationRequest {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The currency in which the totalUpfrontPrice, LimitPrice, and totalHourlyPrice amounts are specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The IDs of the Dedicated Hosts with which the reservation will be associated.
     */
    HostIdSet: RequestHostIdSet;
    /**
     * The specified limit is checked against the total upfront cost of the reservation (calculated as the offering's upfront cost multiplied by the host count). If the total upfront cost is greater than the specified price limit, the request fails. This is used to ensure that the purchase does not exceed the expected upfront cost of the purchase. At this time, the only supported currency is USD. For example, to indicate a limit price of USD 100, specify 100.00.
     */
    LimitPrice?: String;
    /**
     * The ID of the offering.
     */
    OfferingId: OfferingId;
    /**
     * The tags to apply to the Dedicated Host Reservation during purchase.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export interface PurchaseHostReservationResult {
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The currency in which the totalUpfrontPrice and totalHourlyPrice amounts are specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * Describes the details of the purchase.
     */
    Purchase?: PurchaseSet;
    /**
     * The total hourly price of the reservation calculated per hour.
     */
    TotalHourlyPrice?: String;
    /**
     * The total amount charged to your account when you purchase the reservation.
     */
    TotalUpfrontPrice?: String;
  }
  export interface PurchaseRequest {
    /**
     * The number of instances.
     */
    InstanceCount: Integer;
    /**
     * The purchase token.
     */
    PurchaseToken: String;
  }
  export type PurchaseRequestSet = PurchaseRequest[];
  export interface PurchaseReservedInstancesOfferingRequest {
    /**
     * The number of Reserved Instances to purchase.
     */
    InstanceCount: Integer;
    /**
     * The ID of the Reserved Instance offering to purchase.
     */
    ReservedInstancesOfferingId: ReservedInstancesOfferingId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Specified for Reserved Instance Marketplace offerings to limit the total order and ensure that the Reserved Instances are not purchased at unexpected prices.
     */
    LimitPrice?: ReservedInstanceLimitPrice;
    /**
     * The time at which to purchase the Reserved Instance, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    PurchaseTime?: DateTime;
  }
  export interface PurchaseReservedInstancesOfferingResult {
    /**
     * The IDs of the purchased Reserved Instances. If your purchase crosses into a discounted pricing tier, the final Reserved Instances IDs might change. For more information, see Crossing pricing tiers in the Amazon Elastic Compute Cloud User Guide.
     */
    ReservedInstancesId?: String;
  }
  export interface PurchaseScheduledInstancesRequest {
    /**
     * Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The purchase requests.
     */
    PurchaseRequests: PurchaseRequestSet;
  }
  export interface PurchaseScheduledInstancesResult {
    /**
     * Information about the Scheduled Instances.
     */
    ScheduledInstanceSet?: PurchasedScheduledInstanceSet;
  }
  export type PurchaseSet = Purchase[];
  export type PurchasedScheduledInstanceSet = ScheduledInstance[];
  export type RIProductDescription = "Linux/UNIX"|"Linux/UNIX (Amazon VPC)"|"Windows"|"Windows (Amazon VPC)"|string;
  export type RamdiskId = string;
  export type ReasonCodesList = ReportInstanceReasonCodes[];
  export interface RebootInstancesRequest {
    /**
     * The instance IDs.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RecurringCharge {
    /**
     * The amount of the recurring charge.
     */
    Amount?: Double;
    /**
     * The frequency of the recurring charge.
     */
    Frequency?: RecurringChargeFrequency;
  }
  export type RecurringChargeFrequency = "Hourly"|string;
  export type RecurringChargesList = RecurringCharge[];
  export interface ReferencedSecurityGroup {
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * The status of a VPC peering connection, if applicable.
     */
    PeeringStatus?: String;
    /**
     * The Amazon Web Services account ID.
     */
    UserId?: String;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId?: String;
  }
  export interface Region {
    /**
     * The Region service endpoint.
     */
    Endpoint?: String;
    /**
     * The name of the Region.
     */
    RegionName?: String;
    /**
     * The Region opt-in status. The possible values are opt-in-not-required, opted-in, and not-opted-in.
     */
    OptInStatus?: String;
  }
  export type RegionList = Region[];
  export type RegionNameStringList = String[];
  export type RegionNames = String[];
  export interface RegisterImageRequest {
    /**
     * The full path to your AMI manifest in Amazon S3 storage. The specified bucket must have the aws-exec-read canned access control list (ACL) to ensure that it can be accessed by Amazon EC2. For more information, see Canned ACLs in the Amazon S3 Service Developer Guide.
     */
    ImageLocation?: String;
    /**
     * The architecture of the AMI. Default: For Amazon EBS-backed AMIs, i386. For instance store-backed AMIs, the architecture specified in the manifest file.
     */
    Architecture?: ArchitectureValues;
    /**
     * The block device mapping entries. If you specify an Amazon EBS volume using the ID of an Amazon EBS snapshot, you can't specify the encryption state of the volume. If you create an AMI on an Outpost, then all backing snapshots must be on the same Outpost or in the Region of that Outpost. AMIs on an Outpost that include local snapshots can be used to launch instances on the same Outpost only. For more information, Amazon EBS local snapshots on Outposts in the Amazon EC2 User Guide.
     */
    BlockDeviceMappings?: BlockDeviceMappingRequestList;
    /**
     * A description for your AMI.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Set to true to enable enhanced networking with ENA for the AMI and any instances that you launch from the AMI. This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
     */
    EnaSupport?: Boolean;
    /**
     * The ID of the kernel.
     */
    KernelId?: KernelId;
    /**
     * A name for your AMI. Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_)
     */
    Name: String;
    /**
     * The billing product codes. Your account must be authorized to specify billing product codes. If your account is not authorized to specify billing product codes, you can publish AMIs that include billable software and list them on the Amazon Web Services Marketplace. You must first register as a seller on the Amazon Web Services Marketplace. For more information, see Getting started as a seller and AMI-based products in the Amazon Web Services Marketplace Seller Guide.
     */
    BillingProducts?: BillingProductList;
    /**
     * The ID of the RAM disk.
     */
    RamdiskId?: RamdiskId;
    /**
     * The device name of the root device volume (for example, /dev/sda1).
     */
    RootDeviceName?: String;
    /**
     * Set to simple to enable enhanced networking with the Intel 82599 Virtual Function interface for the AMI and any instances that you launch from the AMI. There is no way to disable sriovNetSupport at this time. This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable.
     */
    SriovNetSupport?: String;
    /**
     * The type of virtualization (hvm | paravirtual). Default: paravirtual 
     */
    VirtualizationType?: String;
    /**
     * The boot mode of the AMI. A value of uefi-preferred indicates that the AMI supports both UEFI and Legacy BIOS.  The operating system contained in the AMI must be configured to support the specified boot mode.  For more information, see Boot modes in the Amazon EC2 User Guide.
     */
    BootMode?: BootModeValues;
    /**
     * Set to v2.0 to enable Trusted Platform Module (TPM) support. For more information, see NitroTPM in the Amazon EC2 User Guide.
     */
    TpmSupport?: TpmSupportValues;
    /**
     * Base64 representation of the non-volatile UEFI variable store. To retrieve the UEFI data, use the GetInstanceUefiData command. You can inspect and modify the UEFI data by using the python-uefivars tool on GitHub. For more information, see UEFI Secure Boot in the Amazon EC2 User Guide.
     */
    UefiData?: StringType;
    /**
     * Set to v2.0 to indicate that IMDSv2 is specified in the AMI. Instances launched from this AMI will have HttpTokens automatically set to required so that, by default, the instance requires that IMDSv2 is used when requesting instance metadata. In addition, HttpPutResponseHopLimit is set to 2. For more information, see Configure the AMI in the Amazon EC2 User Guide.  If you set the value to v2.0, make sure that your AMI software can support IMDSv2. 
     */
    ImdsSupport?: ImdsSupportValues;
  }
  export interface RegisterImageResult {
    /**
     * The ID of the newly registered AMI.
     */
    ImageId?: String;
  }
  export interface RegisterInstanceEventNotificationAttributesRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Information about the tag keys to register.
     */
    InstanceTagAttribute?: RegisterInstanceTagAttributeRequest;
  }
  export interface RegisterInstanceEventNotificationAttributesResult {
    /**
     * The resulting set of tag keys.
     */
    InstanceTagAttribute?: InstanceTagNotificationAttribute;
  }
  export interface RegisterInstanceTagAttributeRequest {
    /**
     * Indicates whether to register all tag keys in the current Region. Specify true to register all tag keys.
     */
    IncludeAllTagsOfInstance?: Boolean;
    /**
     * The tag keys to register.
     */
    InstanceTagKeys?: InstanceTagKeySet;
  }
  export interface RegisterTransitGatewayMulticastGroupMembersRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
    /**
     * The group members' network interface IDs to register with the transit gateway multicast group.
     */
    NetworkInterfaceIds: TransitGatewayNetworkInterfaceIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RegisterTransitGatewayMulticastGroupMembersResult {
    /**
     * Information about the registered transit gateway multicast group members.
     */
    RegisteredMulticastGroupMembers?: TransitGatewayMulticastRegisteredGroupMembers;
  }
  export interface RegisterTransitGatewayMulticastGroupSourcesRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
    /**
     * The group sources' network interface IDs to register with the transit gateway multicast group.
     */
    NetworkInterfaceIds: TransitGatewayNetworkInterfaceIdList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RegisterTransitGatewayMulticastGroupSourcesResult {
    /**
     * Information about the transit gateway multicast group sources.
     */
    RegisteredMulticastGroupSources?: TransitGatewayMulticastRegisteredGroupSources;
  }
  export interface RejectTransitGatewayMulticastDomainAssociationsRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: TransitGatewayMulticastDomainId;
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The IDs of the subnets to associate with the transit gateway multicast domain.
     */
    SubnetIds?: ValueStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RejectTransitGatewayMulticastDomainAssociationsResult {
    /**
     * Information about the multicast domain associations.
     */
    Associations?: TransitGatewayMulticastDomainAssociations;
  }
  export interface RejectTransitGatewayPeeringAttachmentRequest {
    /**
     * The ID of the transit gateway peering attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RejectTransitGatewayPeeringAttachmentResult {
    /**
     * The transit gateway peering attachment.
     */
    TransitGatewayPeeringAttachment?: TransitGatewayPeeringAttachment;
  }
  export interface RejectTransitGatewayVpcAttachmentRequest {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId: TransitGatewayAttachmentId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RejectTransitGatewayVpcAttachmentResult {
    /**
     * Information about the attachment.
     */
    TransitGatewayVpcAttachment?: TransitGatewayVpcAttachment;
  }
  export interface RejectVpcEndpointConnectionsRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the service.
     */
    ServiceId: VpcEndpointServiceId;
    /**
     * The IDs of the VPC endpoints.
     */
    VpcEndpointIds: VpcEndpointIdList;
  }
  export interface RejectVpcEndpointConnectionsResult {
    /**
     * Information about the endpoints that were not rejected, if applicable.
     */
    Unsuccessful?: UnsuccessfulItemSet;
  }
  export interface RejectVpcPeeringConnectionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId: VpcPeeringConnectionId;
  }
  export interface RejectVpcPeeringConnectionResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface ReleaseAddressRequest {
    /**
     * [EC2-VPC] The allocation ID. Required for EC2-VPC.
     */
    AllocationId?: AllocationId;
    /**
     * [EC2-Classic] The Elastic IP address. Required for EC2-Classic.
     */
    PublicIp?: String;
    /**
     * The set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses. If you provide an incorrect network border group, you receive an InvalidAddress.NotFound error. You cannot use a network border group with EC2 Classic. If you attempt this operation on EC2 classic, you receive an InvalidParameterCombination error.
     */
    NetworkBorderGroup?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ReleaseHostsRequest {
    /**
     * The IDs of the Dedicated Hosts to release.
     */
    HostIds: RequestHostIdList;
  }
  export interface ReleaseHostsResult {
    /**
     * The IDs of the Dedicated Hosts that were successfully released.
     */
    Successful?: ResponseHostIdList;
    /**
     * The IDs of the Dedicated Hosts that could not be released, including an error message.
     */
    Unsuccessful?: UnsuccessfulItemList;
  }
  export interface ReleaseIpamPoolAllocationRequest {
    /**
     * A check for whether you have the required permissions for the action without actually making the request and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the IPAM pool which contains the allocation you want to release.
     */
    IpamPoolId: IpamPoolId;
    /**
     * The CIDR of the allocation you want to release.
     */
    Cidr: String;
    /**
     * The ID of the allocation.
     */
    IpamPoolAllocationId: IpamPoolAllocationId;
  }
  export interface ReleaseIpamPoolAllocationResult {
    /**
     * Indicates if the release was successful.
     */
    Success?: Boolean;
  }
  export interface RemoveIpamOperatingRegion {
    /**
     * The name of the operating Region you want to remove.
     */
    RegionName?: String;
  }
  export type RemoveIpamOperatingRegionSet = RemoveIpamOperatingRegion[];
  export type RemovePrefixListEntries = RemovePrefixListEntry[];
  export interface RemovePrefixListEntry {
    /**
     * The CIDR block.
     */
    Cidr: String;
  }
  export interface ReplaceIamInstanceProfileAssociationRequest {
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile: IamInstanceProfileSpecification;
    /**
     * The ID of the existing IAM instance profile association.
     */
    AssociationId: IamInstanceProfileAssociationId;
  }
  export interface ReplaceIamInstanceProfileAssociationResult {
    /**
     * Information about the IAM instance profile association.
     */
    IamInstanceProfileAssociation?: IamInstanceProfileAssociation;
  }
  export interface ReplaceNetworkAclAssociationRequest {
    /**
     * The ID of the current association between the original network ACL and the subnet.
     */
    AssociationId: NetworkAclAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the new network ACL to associate with the subnet.
     */
    NetworkAclId: NetworkAclId;
  }
  export interface ReplaceNetworkAclAssociationResult {
    /**
     * The ID of the new association.
     */
    NewAssociationId?: String;
  }
  export interface ReplaceNetworkAclEntryRequest {
    /**
     * The IPv4 network range to allow or deny, in CIDR notation (for example 172.16.0.0/24).
     */
    CidrBlock?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether to replace the egress rule. Default: If no value is specified, we replace the ingress rule.
     */
    Egress: Boolean;
    /**
     * ICMP protocol: The ICMP or ICMPv6 type and code. Required if specifying protocol 1 (ICMP) or protocol 58 (ICMPv6) with an IPv6 CIDR block.
     */
    IcmpTypeCode?: IcmpTypeCode;
    /**
     * The IPv6 network range to allow or deny, in CIDR notation (for example 2001:bd8:1234:1a00::/64).
     */
    Ipv6CidrBlock?: String;
    /**
     * The ID of the ACL.
     */
    NetworkAclId: NetworkAclId;
    /**
     * TCP or UDP protocols: The range of ports the rule applies to. Required if specifying protocol 6 (TCP) or 17 (UDP).
     */
    PortRange?: PortRange;
    /**
     * The protocol number. A value of "-1" means all protocols. If you specify "-1" or a protocol number other than "6" (TCP), "17" (UDP), or "1" (ICMP), traffic on all ports is allowed, regardless of any ports or ICMP types or codes that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv4 CIDR block, traffic for all ICMP types and codes allowed, regardless of any that you specify. If you specify protocol "58" (ICMPv6) and specify an IPv6 CIDR block, you must specify an ICMP type and code.
     */
    Protocol: String;
    /**
     * Indicates whether to allow or deny the traffic that matches the rule.
     */
    RuleAction: RuleAction;
    /**
     * The rule number of the entry to replace.
     */
    RuleNumber: Integer;
  }
  export interface ReplaceRootVolumeTask {
    /**
     * The ID of the root volume replacement task.
     */
    ReplaceRootVolumeTaskId?: ReplaceRootVolumeTaskId;
    /**
     * The ID of the instance for which the root volume replacement task was created.
     */
    InstanceId?: String;
    /**
     * The state of the task. The task can be in one of the following states:    pending - the replacement volume is being created.    in-progress - the original volume is being detached and the replacement volume is being attached.    succeeded - the replacement volume has been successfully attached to the instance and the instance is available.    failing - the replacement task is in the process of failing.    failed - the replacement task has failed but the original root volume is still attached.    failing-detached - the replacement task is in the process of failing. The instance might have no root volume attached.    failed-detached - the replacement task has failed and the instance has no root volume attached.  
     */
    TaskState?: ReplaceRootVolumeTaskState;
    /**
     * The time the task was started.
     */
    StartTime?: String;
    /**
     * The time the task completed.
     */
    CompleteTime?: String;
    /**
     * The tags assigned to the task.
     */
    Tags?: TagList;
    /**
     * The ID of the AMI used to create the replacement root volume.
     */
    ImageId?: ImageId;
    /**
     * The ID of the snapshot used to create the replacement root volume.
     */
    SnapshotId?: SnapshotId;
    /**
     * Indicates whether the original root volume is to be deleted after the root volume replacement task completes.
     */
    DeleteReplacedRootVolume?: Boolean;
  }
  export type ReplaceRootVolumeTaskId = string;
  export type ReplaceRootVolumeTaskIds = ReplaceRootVolumeTaskId[];
  export type ReplaceRootVolumeTaskState = "pending"|"in-progress"|"failing"|"succeeded"|"failed"|"failed-detached"|string;
  export type ReplaceRootVolumeTasks = ReplaceRootVolumeTask[];
  export interface ReplaceRouteRequest {
    /**
     * The IPv4 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
     */
    DestinationCidrBlock?: String;
    /**
     * The IPv6 CIDR address block used for the destination match. The value that you provide must match the CIDR of an existing route in the table.
     */
    DestinationIpv6CidrBlock?: String;
    /**
     * The ID of the prefix list for the route.
     */
    DestinationPrefixListId?: PrefixListResourceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of a VPC endpoint. Supported for Gateway Load Balancer endpoints only.
     */
    VpcEndpointId?: VpcEndpointId;
    /**
     * [IPv6 traffic only] The ID of an egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId?: EgressOnlyInternetGatewayId;
    /**
     * The ID of an internet gateway or virtual private gateway.
     */
    GatewayId?: RouteGatewayId;
    /**
     * The ID of a NAT instance in your VPC.
     */
    InstanceId?: InstanceId;
    /**
     * Specifies whether to reset the local route to its default target (local).
     */
    LocalTarget?: Boolean;
    /**
     * [IPv4 traffic only] The ID of a NAT gateway.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * The ID of a transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: LocalGatewayId;
    /**
     * [IPv4 traffic only] The ID of a carrier gateway.
     */
    CarrierGatewayId?: CarrierGatewayId;
    /**
     * The ID of a network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The ID of the route table.
     */
    RouteTableId: RouteTableId;
    /**
     * The ID of a VPC peering connection.
     */
    VpcPeeringConnectionId?: VpcPeeringConnectionId;
    /**
     * The Amazon Resource Name (ARN) of the core network.
     */
    CoreNetworkArn?: CoreNetworkArn;
  }
  export interface ReplaceRouteTableAssociationRequest {
    /**
     * The association ID.
     */
    AssociationId: RouteTableAssociationId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the new route table to associate with the subnet.
     */
    RouteTableId: RouteTableId;
  }
  export interface ReplaceRouteTableAssociationResult {
    /**
     * The ID of the new association.
     */
    NewAssociationId?: String;
    /**
     * The state of the association.
     */
    AssociationState?: RouteTableAssociationState;
  }
  export interface ReplaceTransitGatewayRouteRequest {
    /**
     * The CIDR range used for the destination match. Routing decisions are based on the most specific match.
     */
    DestinationCidrBlock: String;
    /**
     * The ID of the route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * Indicates whether traffic matching this route is to be dropped.
     */
    Blackhole?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ReplaceTransitGatewayRouteResult {
    /**
     * Information about the modified route.
     */
    Route?: TransitGatewayRoute;
  }
  export interface ReplaceVpnTunnelRequest {
    /**
     * The ID of the Site-to-Site VPN connection. 
     */
    VpnConnectionId: VpnConnectionId;
    /**
     * The external IP address of the VPN tunnel.
     */
    VpnTunnelOutsideIpAddress: String;
    /**
     * Trigger pending tunnel endpoint maintenance.
     */
    ApplyPendingMaintenance?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ReplaceVpnTunnelResult {
    /**
     * Confirmation of replace tunnel operation.
     */
    Return?: Boolean;
  }
  export type ReplacementStrategy = "launch"|"launch-before-terminate"|string;
  export type ReportInstanceReasonCodes = "instance-stuck-in-state"|"unresponsive"|"not-accepting-credentials"|"password-not-available"|"performance-network"|"performance-instance-store"|"performance-ebs-volume"|"performance-other"|"other"|string;
  export interface ReportInstanceStatusRequest {
    /**
     * Descriptive text about the health state of your instance.
     */
    Description?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The time at which the reported instance health state ended.
     */
    EndTime?: DateTime;
    /**
     * The instances.
     */
    Instances: InstanceIdStringList;
    /**
     * The reason codes that describe the health state of your instance.    instance-stuck-in-state: My instance is stuck in a state.    unresponsive: My instance is unresponsive.    not-accepting-credentials: My instance is not accepting my credentials.    password-not-available: A password is not available for my instance.    performance-network: My instance is experiencing performance problems that I believe are network related.    performance-instance-store: My instance is experiencing performance problems that I believe are related to the instance stores.    performance-ebs-volume: My instance is experiencing performance problems that I believe are related to an EBS volume.    performance-other: My instance is experiencing performance problems.    other: [explain using the description parameter]  
     */
    ReasonCodes: ReasonCodesList;
    /**
     * The time at which the reported instance health state began.
     */
    StartTime?: DateTime;
    /**
     * The status of all instances listed.
     */
    Status: ReportStatusType;
  }
  export type ReportStatusType = "ok"|"impaired"|string;
  export interface RequestFilterPortRange {
    /**
     * The first port in the range.
     */
    FromPort?: Port;
    /**
     * The last port in the range.
     */
    ToPort?: Port;
  }
  export type RequestHostIdList = DedicatedHostId[];
  export type RequestHostIdSet = DedicatedHostId[];
  export type RequestInstanceTypeList = InstanceType[];
  export interface RequestIpamResourceTag {
    /**
     * The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.
     */
    Key?: String;
    /**
     * The value for the tag.
     */
    Value?: String;
  }
  export type RequestIpamResourceTagList = RequestIpamResourceTag[];
  export interface RequestLaunchTemplateData {
    /**
     * The ID of the kernel.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see User provided kernels in the Amazon Elastic Compute Cloud User Guide. 
     */
    KernelId?: KernelId;
    /**
     * Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS-optimized instance.
     */
    EbsOptimized?: Boolean;
    /**
     * The name or Amazon Resource Name (ARN) of an IAM instance profile.
     */
    IamInstanceProfile?: LaunchTemplateIamInstanceProfileSpecificationRequest;
    /**
     * The block device mapping.
     */
    BlockDeviceMappings?: LaunchTemplateBlockDeviceMappingRequestList;
    /**
     * One or more network interfaces. If you specify a network interface, you must specify any security groups and subnets as part of the network interface.
     */
    NetworkInterfaces?: LaunchTemplateInstanceNetworkInterfaceSpecificationRequestList;
    /**
     * The ID of the AMI. Alternatively, you can specify a Systems Manager parameter, which will resolve to an AMI ID on launch. Valid formats:    ami-17characters00000     resolve:ssm:parameter-name     resolve:ssm:parameter-name:version-number     resolve:ssm:parameter-name:label    For more information, see Use a Systems Manager parameter to find an AMI in the Amazon Elastic Compute Cloud User Guide.
     */
    ImageId?: ImageId;
    /**
     * The instance type. For more information, see Instance types in the Amazon Elastic Compute Cloud User Guide. If you specify InstanceType, you can't specify InstanceRequirements.
     */
    InstanceType?: InstanceType;
    /**
     * The name of the key pair. You can create a key pair using CreateKeyPair or ImportKeyPair.  If you do not specify a key pair, you can't connect to the instance unless you choose an AMI that is configured to allow users another way to log in. 
     */
    KeyName?: KeyPairName;
    /**
     * The monitoring for the instance.
     */
    Monitoring?: LaunchTemplatesMonitoringRequest;
    /**
     * The placement for the instance.
     */
    Placement?: LaunchTemplatePlacementRequest;
    /**
     * The ID of the RAM disk.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see User provided kernels in the Amazon Elastic Compute Cloud User Guide. 
     */
    RamDiskId?: RamdiskId;
    /**
     * If you set this parameter to true, you can't terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. To change this attribute after launch, use ModifyInstanceAttribute. Alternatively, if you set InstanceInitiatedShutdownBehavior to terminate, you can terminate the instance by running the shutdown command from the instance.
     */
    DisableApiTermination?: Boolean;
    /**
     * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown). Default: stop 
     */
    InstanceInitiatedShutdownBehavior?: ShutdownBehavior;
    /**
     * The user data to make available to the instance. You must provide base64-encoded text. User data is limited to 16 KB. For more information, see Run commands on your Linux instance at launch (Linux) or Work with instance user data (Windows) in the Amazon Elastic Compute Cloud User Guide. If you are creating the launch template for use with Batch, the user data must be provided in the  MIME multi-part archive format. For more information, see Amazon EC2 user data in launch templates in the Batch User Guide.
     */
    UserData?: String;
    /**
     * The tags to apply to the resources that are created during instance launch. You can specify tags for the following resources only:   Instances   Volumes   Elastic graphics   Spot Instance requests   Network interfaces   To tag a resource after it has been created, see CreateTags.  To tag the launch template itself, you must use the TagSpecification parameter. 
     */
    TagSpecifications?: LaunchTemplateTagSpecificationRequestList;
    /**
     * An elastic GPU to associate with the instance.
     */
    ElasticGpuSpecifications?: ElasticGpuSpecificationList;
    /**
     *  The elastic inference accelerator for the instance. 
     */
    ElasticInferenceAccelerators?: LaunchTemplateElasticInferenceAcceleratorList;
    /**
     * One or more security group IDs. You can create a security group using CreateSecurityGroup. You cannot specify both a security group ID and security name in the same request.
     */
    SecurityGroupIds?: SecurityGroupIdStringList;
    /**
     * One or more security group names. For a nondefault VPC, you must use security group IDs instead. You cannot specify both a security group ID and security name in the same request.
     */
    SecurityGroups?: SecurityGroupStringList;
    /**
     * The market (purchasing) option for the instances.
     */
    InstanceMarketOptions?: LaunchTemplateInstanceMarketOptionsRequest;
    /**
     * The credit option for CPU usage of the instance. Valid only for T instances.
     */
    CreditSpecification?: CreditSpecificationRequest;
    /**
     * The CPU options for the instance. For more information, see Optimizing CPU Options in the Amazon Elastic Compute Cloud User Guide.
     */
    CpuOptions?: LaunchTemplateCpuOptionsRequest;
    /**
     * The Capacity Reservation targeting option. If you do not specify this parameter, the instance's Capacity Reservation preference defaults to open, which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
     */
    CapacityReservationSpecification?: LaunchTemplateCapacityReservationSpecificationRequest;
    /**
     * The license configurations.
     */
    LicenseSpecifications?: LaunchTemplateLicenseSpecificationListRequest;
    /**
     * Indicates whether an instance is enabled for hibernation. This parameter is valid only if the instance meets the hibernation prerequisites. For more information, see Hibernate your instance in the Amazon Elastic Compute Cloud User Guide.
     */
    HibernationOptions?: LaunchTemplateHibernationOptionsRequest;
    /**
     * The metadata options for the instance. For more information, see Instance metadata and user data in the Amazon Elastic Compute Cloud User Guide.
     */
    MetadataOptions?: LaunchTemplateInstanceMetadataOptionsRequest;
    /**
     * Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see  What is Amazon Web Services Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide. You can't enable Amazon Web Services Nitro Enclaves and hibernation on the same instance.
     */
    EnclaveOptions?: LaunchTemplateEnclaveOptionsRequest;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with these attributes. If you specify InstanceRequirements, you can't specify InstanceType.
     */
    InstanceRequirements?: InstanceRequirementsRequest;
    /**
     * The options for the instance hostname. The default values are inherited from the subnet.
     */
    PrivateDnsNameOptions?: LaunchTemplatePrivateDnsNameOptionsRequest;
    /**
     * The maintenance options for the instance.
     */
    MaintenanceOptions?: LaunchTemplateInstanceMaintenanceOptionsRequest;
    /**
     * Indicates whether to enable the instance for stop protection. For more information, see Stop protection in the Amazon Elastic Compute Cloud User Guide.
     */
    DisableApiStop?: Boolean;
  }
  export interface RequestSpotFleetRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The configuration for the Spot Fleet request.
     */
    SpotFleetRequestConfig: SpotFleetRequestConfigData;
  }
  export interface RequestSpotFleetResponse {
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
  }
  export interface RequestSpotInstancesRequest {
    /**
     * The user-specified name for a logical grouping of requests. When you specify an Availability Zone group in a Spot Instance request, all Spot Instances in the request are launched in the same Availability Zone. Instance proximity is maintained with this parameter, but the choice of Availability Zone is not. The group applies only to requests for Spot Instances of the same instance type. Any additional Spot Instance requests that are specified with the same Availability Zone group name are launched in that same Availability Zone, as long as at least one instance from the group is still active. If there is no active instance running in the Availability Zone group that you specify for a new Spot Instance request (all instances are terminated, the request is expired, or the maximum price you specified falls below current Spot price), then Amazon EC2 launches the instance in any Availability Zone where the constraint can be met. Consequently, the subsequent set of Spot Instances could be placed in a different zone from the original request, even if you specified the same Availability Zone group. Default: Instances are launched in any available Availability Zone.
     */
    AvailabilityZoneGroup?: String;
    /**
     * Deprecated.
     */
    BlockDurationMinutes?: Integer;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to Ensure Idempotency in the Amazon EC2 User Guide for Linux Instances.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The maximum number of Spot Instances to launch. Default: 1
     */
    InstanceCount?: Integer;
    /**
     * The instance launch group. Launch groups are Spot Instances that launch together and terminate together. Default: Instances are launched and terminated individually
     */
    LaunchGroup?: String;
    /**
     * The launch specification.
     */
    LaunchSpecification?: RequestSpotLaunchSpecification;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The Spot Instance request type. Default: one-time 
     */
    Type?: SpotInstanceType;
    /**
     * The start date of the request. If this is a one-time request, the request becomes active at this date and time and remains active until all instances launch, the request expires, or the request is canceled. If the request is persistent, the request becomes active at this date and time and remains active until it expires or is canceled. The specified start date and time cannot be equal to the current date and time. You must specify a start date and time that occurs after the current date and time.
     */
    ValidFrom?: DateTime;
    /**
     * The end date of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ).   For a persistent request, the request remains active until the ValidUntil date and time is reached. Otherwise, the request remains active until you cancel it.    For a one-time request, the request remains active until all instances launch, the request is canceled, or the ValidUntil date and time is reached. By default, the request is valid for 7 days from the date the request was created.  
     */
    ValidUntil?: DateTime;
    /**
     * The key-value pair for tagging the Spot Instance request on creation. The value for ResourceType must be spot-instances-request, otherwise the Spot Instance request fails. To tag the Spot Instance request after it has been created, see CreateTags. 
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The behavior when a Spot Instance is interrupted. The default is terminate.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
  }
  export interface RequestSpotInstancesResult {
    /**
     * One or more Spot Instance requests.
     */
    SpotInstanceRequests?: SpotInstanceRequestList;
  }
  export interface RequestSpotLaunchSpecification {
    /**
     * One or more security group IDs.
     */
    SecurityGroupIds?: RequestSpotLaunchSpecificationSecurityGroupIdList;
    /**
     * One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
     */
    SecurityGroups?: RequestSpotLaunchSpecificationSecurityGroupList;
    /**
     * Deprecated.
     */
    AddressingType?: String;
    /**
     * One or more block device mapping entries. You can't specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
     */
    BlockDeviceMappings?: BlockDeviceMappingList;
    /**
     * Indicates whether the instance is optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance. Default: false 
     */
    EbsOptimized?: Boolean;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: IamInstanceProfileSpecification;
    /**
     * The ID of the AMI.
     */
    ImageId?: ImageId;
    /**
     * The instance type. Only one instance type can be specified.
     */
    InstanceType?: InstanceType;
    /**
     * The ID of the kernel.
     */
    KernelId?: KernelId;
    /**
     * The name of the key pair.
     */
    KeyName?: KeyPairName;
    /**
     * Indicates whether basic or detailed monitoring is enabled for the instance. Default: Disabled
     */
    Monitoring?: RunInstancesMonitoringEnabled;
    /**
     * One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.
     */
    NetworkInterfaces?: InstanceNetworkInterfaceSpecificationList;
    /**
     * The placement information for the instance.
     */
    Placement?: SpotPlacement;
    /**
     * The ID of the RAM disk.
     */
    RamdiskId?: RamdiskId;
    /**
     * The ID of the subnet in which to launch the instance.
     */
    SubnetId?: SubnetId;
    /**
     * The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
     */
    UserData?: SensitiveUserData;
  }
  export type RequestSpotLaunchSpecificationSecurityGroupIdList = SecurityGroupId[];
  export type RequestSpotLaunchSpecificationSecurityGroupList = String[];
  export interface Reservation {
    /**
     * [EC2-Classic only] The security groups.
     */
    Groups?: GroupIdentifierList;
    /**
     * The instances.
     */
    Instances?: InstanceList;
    /**
     * The ID of the Amazon Web Services account that owns the reservation.
     */
    OwnerId?: String;
    /**
     * The ID of the requester that launched the instances on your behalf (for example, Amazon Web Services Management Console or Auto Scaling).
     */
    RequesterId?: String;
    /**
     * The ID of the reservation.
     */
    ReservationId?: String;
  }
  export interface ReservationFleetInstanceSpecification {
    /**
     * The instance type for which the Capacity Reservation Fleet reserves capacity.
     */
    InstanceType?: InstanceType;
    /**
     * The type of operating system for which the Capacity Reservation Fleet reserves capacity.
     */
    InstancePlatform?: CapacityReservationInstancePlatform;
    /**
     * The number of capacity units provided by the specified instance type. This value, together with the total target capacity that you specify for the Fleet determine the number of instances for which the Fleet reserves capacity. Both values are based on units that make sense for your workload. For more information, see Total target capacity in the Amazon EC2 User Guide.
     */
    Weight?: DoubleWithConstraints;
    /**
     * The Availability Zone in which the Capacity Reservation Fleet reserves the capacity. A Capacity Reservation Fleet can't span Availability Zones. All instance type specifications that you specify for the Fleet must use the same Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The ID of the Availability Zone in which the Capacity Reservation Fleet reserves the capacity. A Capacity Reservation Fleet can't span Availability Zones. All instance type specifications that you specify for the Fleet must use the same Availability Zone.
     */
    AvailabilityZoneId?: String;
    /**
     * Indicates whether the Capacity Reservation Fleet supports EBS-optimized instances types. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using EBS-optimized instance types.
     */
    EbsOptimized?: Boolean;
    /**
     * The priority to assign to the instance type. This value is used to determine which of the instance types specified for the Fleet should be prioritized for use. A lower value indicates a high priority. For more information, see Instance type priority in the Amazon EC2 User Guide.
     */
    Priority?: IntegerWithConstraints;
  }
  export type ReservationFleetInstanceSpecificationList = ReservationFleetInstanceSpecification[];
  export type ReservationId = string;
  export type ReservationList = Reservation[];
  export type ReservationState = "payment-pending"|"payment-failed"|"active"|"retired"|string;
  export interface ReservationValue {
    /**
     * The hourly rate of the reservation.
     */
    HourlyPrice?: String;
    /**
     * The balance of the total value (the sum of remainingUpfrontValue + hourlyPrice * number of hours remaining).
     */
    RemainingTotalValue?: String;
    /**
     * The remaining upfront cost of the reservation.
     */
    RemainingUpfrontValue?: String;
  }
  export type ReservedInstanceIdSet = ReservationId[];
  export interface ReservedInstanceLimitPrice {
    /**
     * Used for Reserved Instance Marketplace offerings. Specifies the limit price on the total order (instanceCount * price).
     */
    Amount?: Double;
    /**
     * The currency in which the limitPrice amount is specified. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
  }
  export interface ReservedInstanceReservationValue {
    /**
     * The total value of the Convertible Reserved Instance that you are exchanging.
     */
    ReservationValue?: ReservationValue;
    /**
     * The ID of the Convertible Reserved Instance that you are exchanging.
     */
    ReservedInstanceId?: String;
  }
  export type ReservedInstanceReservationValueSet = ReservedInstanceReservationValue[];
  export type ReservedInstanceState = "payment-pending"|"active"|"payment-failed"|"retired"|"queued"|"queued-deleted"|string;
  export interface ReservedInstances {
    /**
     * The Availability Zone in which the Reserved Instance can be used.
     */
    AvailabilityZone?: String;
    /**
     * The duration of the Reserved Instance, in seconds.
     */
    Duration?: Long;
    /**
     * The time when the Reserved Instance expires.
     */
    End?: DateTime;
    /**
     * The purchase price of the Reserved Instance.
     */
    FixedPrice?: Float;
    /**
     * The number of reservations purchased.
     */
    InstanceCount?: Integer;
    /**
     * The instance type on which the Reserved Instance can be used.
     */
    InstanceType?: InstanceType;
    /**
     * The Reserved Instance product platform description.
     */
    ProductDescription?: RIProductDescription;
    /**
     * The ID of the Reserved Instance.
     */
    ReservedInstancesId?: String;
    /**
     * The date and time the Reserved Instance started.
     */
    Start?: DateTime;
    /**
     * The state of the Reserved Instance purchase.
     */
    State?: ReservedInstanceState;
    /**
     * The usage price of the Reserved Instance, per hour.
     */
    UsagePrice?: Float;
    /**
     * The currency of the Reserved Instance. It's specified using ISO 4217 standard currency codes. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The tenancy of the instance.
     */
    InstanceTenancy?: Tenancy;
    /**
     * The offering class of the Reserved Instance.
     */
    OfferingClass?: OfferingClassType;
    /**
     * The Reserved Instance offering type.
     */
    OfferingType?: OfferingTypeValues;
    /**
     * The recurring charge tag assigned to the resource.
     */
    RecurringCharges?: RecurringChargesList;
    /**
     * The scope of the Reserved Instance.
     */
    Scope?: scope;
    /**
     * Any tags assigned to the resource.
     */
    Tags?: TagList;
  }
  export interface ReservedInstancesConfiguration {
    /**
     * The Availability Zone for the modified Reserved Instances.
     */
    AvailabilityZone?: String;
    /**
     * The number of modified Reserved Instances.  This is a required field for a request. 
     */
    InstanceCount?: Integer;
    /**
     * The instance type for the modified Reserved Instances.
     */
    InstanceType?: InstanceType;
    /**
     * The network platform of the modified Reserved Instances, which is either EC2-Classic or EC2-VPC.
     */
    Platform?: String;
    /**
     * Whether the Reserved Instance is applied to instances in a Region or instances in a specific Availability Zone.
     */
    Scope?: scope;
  }
  export type ReservedInstancesConfigurationList = ReservedInstancesConfiguration[];
  export interface ReservedInstancesId {
    /**
     * The ID of the Reserved Instance.
     */
    ReservedInstancesId?: String;
  }
  export type ReservedInstancesIdStringList = ReservationId[];
  export type ReservedInstancesList = ReservedInstances[];
  export interface ReservedInstancesListing {
    /**
     * A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The time the listing was created.
     */
    CreateDate?: DateTime;
    /**
     * The number of instances in this state.
     */
    InstanceCounts?: InstanceCountList;
    /**
     * The price of the Reserved Instance listing.
     */
    PriceSchedules?: PriceScheduleList;
    /**
     * The ID of the Reserved Instance.
     */
    ReservedInstancesId?: String;
    /**
     * The ID of the Reserved Instance listing.
     */
    ReservedInstancesListingId?: String;
    /**
     * The status of the Reserved Instance listing.
     */
    Status?: ListingStatus;
    /**
     * The reason for the current status of the Reserved Instance listing. The response can be blank.
     */
    StatusMessage?: String;
    /**
     * Any tags assigned to the resource.
     */
    Tags?: TagList;
    /**
     * The last modified timestamp of the listing.
     */
    UpdateDate?: DateTime;
  }
  export type ReservedInstancesListingId = string;
  export type ReservedInstancesListingList = ReservedInstancesListing[];
  export interface ReservedInstancesModification {
    /**
     * A unique, case-sensitive key supplied by the client to ensure that the request is idempotent. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * The time when the modification request was created.
     */
    CreateDate?: DateTime;
    /**
     * The time for the modification to become effective.
     */
    EffectiveDate?: DateTime;
    /**
     * Contains target configurations along with their corresponding new Reserved Instance IDs.
     */
    ModificationResults?: ReservedInstancesModificationResultList;
    /**
     * The IDs of one or more Reserved Instances.
     */
    ReservedInstancesIds?: ReservedIntancesIds;
    /**
     * A unique ID for the Reserved Instance modification.
     */
    ReservedInstancesModificationId?: String;
    /**
     * The status of the Reserved Instances modification request.
     */
    Status?: String;
    /**
     * The reason for the status.
     */
    StatusMessage?: String;
    /**
     * The time when the modification request was last updated.
     */
    UpdateDate?: DateTime;
  }
  export type ReservedInstancesModificationId = string;
  export type ReservedInstancesModificationIdStringList = ReservedInstancesModificationId[];
  export type ReservedInstancesModificationList = ReservedInstancesModification[];
  export interface ReservedInstancesModificationResult {
    /**
     * The ID for the Reserved Instances that were created as part of the modification request. This field is only available when the modification is fulfilled.
     */
    ReservedInstancesId?: String;
    /**
     * The target Reserved Instances configurations supplied as part of the modification request.
     */
    TargetConfiguration?: ReservedInstancesConfiguration;
  }
  export type ReservedInstancesModificationResultList = ReservedInstancesModificationResult[];
  export interface ReservedInstancesOffering {
    /**
     * The Availability Zone in which the Reserved Instance can be used.
     */
    AvailabilityZone?: String;
    /**
     * The duration of the Reserved Instance, in seconds.
     */
    Duration?: Long;
    /**
     * The purchase price of the Reserved Instance.
     */
    FixedPrice?: Float;
    /**
     * The instance type on which the Reserved Instance can be used.
     */
    InstanceType?: InstanceType;
    /**
     * The Reserved Instance product platform description.
     */
    ProductDescription?: RIProductDescription;
    /**
     * The ID of the Reserved Instance offering. This is the offering ID used in GetReservedInstancesExchangeQuote to confirm that an exchange can be made.
     */
    ReservedInstancesOfferingId?: String;
    /**
     * The usage price of the Reserved Instance, per hour.
     */
    UsagePrice?: Float;
    /**
     * The currency of the Reserved Instance offering you are purchasing. It's specified using ISO 4217 standard currency codes. At this time, the only supported currency is USD.
     */
    CurrencyCode?: CurrencyCodeValues;
    /**
     * The tenancy of the instance.
     */
    InstanceTenancy?: Tenancy;
    /**
     * Indicates whether the offering is available through the Reserved Instance Marketplace (resale) or Amazon Web Services. If it's a Reserved Instance Marketplace offering, this is true.
     */
    Marketplace?: Boolean;
    /**
     * If convertible it can be exchanged for Reserved Instances of the same or higher monetary value, with different configurations. If standard, it is not possible to perform an exchange.
     */
    OfferingClass?: OfferingClassType;
    /**
     * The Reserved Instance offering type.
     */
    OfferingType?: OfferingTypeValues;
    /**
     * The pricing details of the Reserved Instance offering.
     */
    PricingDetails?: PricingDetailsList;
    /**
     * The recurring charge tag assigned to the resource.
     */
    RecurringCharges?: RecurringChargesList;
    /**
     * Whether the Reserved Instance is applied to instances in a Region or an Availability Zone.
     */
    Scope?: scope;
  }
  export type ReservedInstancesOfferingId = string;
  export type ReservedInstancesOfferingIdStringList = ReservedInstancesOfferingId[];
  export type ReservedInstancesOfferingList = ReservedInstancesOffering[];
  export type ReservedIntancesIds = ReservedInstancesId[];
  export interface ResetAddressAttributeRequest {
    /**
     * [EC2-VPC] The allocation ID.
     */
    AllocationId: AllocationId;
    /**
     * The attribute of the IP address.
     */
    Attribute: AddressAttributeName;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ResetAddressAttributeResult {
    /**
     * Information about the IP address.
     */
    Address?: AddressAttribute;
  }
  export interface ResetEbsDefaultKmsKeyIdRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ResetEbsDefaultKmsKeyIdResult {
    /**
     * The Amazon Resource Name (ARN) of the default KMS key for EBS encryption by default.
     */
    KmsKeyId?: String;
  }
  export type ResetFpgaImageAttributeName = "loadPermission"|string;
  export interface ResetFpgaImageAttributeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the AFI.
     */
    FpgaImageId: FpgaImageId;
    /**
     * The attribute.
     */
    Attribute?: ResetFpgaImageAttributeName;
  }
  export interface ResetFpgaImageAttributeResult {
    /**
     * Is true if the request succeeds, and an error otherwise.
     */
    Return?: Boolean;
  }
  export type ResetImageAttributeName = "launchPermission"|string;
  export interface ResetImageAttributeRequest {
    /**
     * The attribute to reset (currently you can only reset the launch permission attribute).
     */
    Attribute: ResetImageAttributeName;
    /**
     * The ID of the AMI.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface ResetInstanceAttributeRequest {
    /**
     * The attribute to reset.  You can only reset the following attributes: kernel | ramdisk | sourceDestCheck. 
     */
    Attribute: InstanceAttributeName;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
  }
  export interface ResetNetworkInterfaceAttributeRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The source/destination checking attribute. Resets the value to true.
     */
    SourceDestCheck?: String;
  }
  export interface ResetSnapshotAttributeRequest {
    /**
     * The attribute to reset. Currently, only the attribute for permission to create volumes can be reset.
     */
    Attribute: SnapshotAttributeName;
    /**
     * The ID of the snapshot.
     */
    SnapshotId: SnapshotId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type ResourceArn = string;
  export type ResourceIdList = TaggableResourceId[];
  export type ResourceList = String[];
  export interface ResourceStatement {
    /**
     * The resources.
     */
    Resources?: ValueStringList;
    /**
     * The resource types.
     */
    ResourceTypes?: ValueStringList;
  }
  export interface ResourceStatementRequest {
    /**
     * The resources.
     */
    Resources?: ValueStringList;
    /**
     * The resource types.
     */
    ResourceTypes?: ValueStringList;
  }
  export type ResourceType = "capacity-reservation"|"client-vpn-endpoint"|"customer-gateway"|"carrier-gateway"|"coip-pool"|"dedicated-host"|"dhcp-options"|"egress-only-internet-gateway"|"elastic-ip"|"elastic-gpu"|"export-image-task"|"export-instance-task"|"fleet"|"fpga-image"|"host-reservation"|"image"|"import-image-task"|"import-snapshot-task"|"instance"|"instance-event-window"|"internet-gateway"|"ipam"|"ipam-pool"|"ipam-scope"|"ipv4pool-ec2"|"ipv6pool-ec2"|"key-pair"|"launch-template"|"local-gateway"|"local-gateway-route-table"|"local-gateway-virtual-interface"|"local-gateway-virtual-interface-group"|"local-gateway-route-table-vpc-association"|"local-gateway-route-table-virtual-interface-group-association"|"natgateway"|"network-acl"|"network-interface"|"network-insights-analysis"|"network-insights-path"|"network-insights-access-scope"|"network-insights-access-scope-analysis"|"placement-group"|"prefix-list"|"replace-root-volume-task"|"reserved-instances"|"route-table"|"security-group"|"security-group-rule"|"snapshot"|"spot-fleet-request"|"spot-instances-request"|"subnet"|"subnet-cidr-reservation"|"traffic-mirror-filter"|"traffic-mirror-session"|"traffic-mirror-target"|"transit-gateway"|"transit-gateway-attachment"|"transit-gateway-connect-peer"|"transit-gateway-multicast-domain"|"transit-gateway-policy-table"|"transit-gateway-route-table"|"transit-gateway-route-table-announcement"|"volume"|"vpc"|"vpc-endpoint"|"vpc-endpoint-connection"|"vpc-endpoint-service"|"vpc-endpoint-service-permission"|"vpc-peering-connection"|"vpn-connection"|"vpn-gateway"|"vpc-flow-log"|"capacity-reservation-fleet"|"traffic-mirror-filter-rule"|"vpc-endpoint-connection-device-type"|"verified-access-instance"|"verified-access-group"|"verified-access-endpoint"|"verified-access-policy"|"verified-access-trust-provider"|"vpn-connection-device-type"|"vpc-block-public-access-exclusion"|"ipam-resource-discovery"|"ipam-resource-discovery-association"|string;
  export interface ResponseError {
    /**
     * The error code.
     */
    Code?: LaunchTemplateErrorCode;
    /**
     * The error message, if applicable.
     */
    Message?: String;
  }
  export type ResponseHostIdList = String[];
  export type ResponseHostIdSet = String[];
  export interface ResponseLaunchTemplateData {
    /**
     * The ID of the kernel, if applicable.
     */
    KernelId?: String;
    /**
     * Indicates whether the instance is optimized for Amazon EBS I/O. 
     */
    EbsOptimized?: Boolean;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: LaunchTemplateIamInstanceProfileSpecification;
    /**
     * The block device mappings.
     */
    BlockDeviceMappings?: LaunchTemplateBlockDeviceMappingList;
    /**
     * The network interfaces.
     */
    NetworkInterfaces?: LaunchTemplateInstanceNetworkInterfaceSpecificationList;
    /**
     * The ID of the AMI or a Systems Manager parameter. The Systems Manager parameter will resolve to the ID of the AMI at instance launch. The value depends on what you specified in the request. The possible values are:   If an AMI ID was specified in the request, then this is the AMI ID.   If a Systems Manager parameter was specified in the request, and ResolveAlias was configured as true, then this is the AMI ID that the parameter is mapped to in the Parameter Store.   If a Systems Manager parameter was specified in the request, and ResolveAlias was configured as false, then this is the parameter value.   For more information, see Use a Systems Manager parameter instead of an AMI ID in the Amazon Elastic Compute Cloud User Guide.
     */
    ImageId?: String;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The name of the key pair.
     */
    KeyName?: String;
    /**
     * The monitoring for the instance.
     */
    Monitoring?: LaunchTemplatesMonitoring;
    /**
     * The placement of the instance.
     */
    Placement?: LaunchTemplatePlacement;
    /**
     * The ID of the RAM disk, if applicable.
     */
    RamDiskId?: String;
    /**
     * If set to true, indicates that the instance cannot be terminated using the Amazon EC2 console, command line tool, or API.
     */
    DisableApiTermination?: Boolean;
    /**
     * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown).
     */
    InstanceInitiatedShutdownBehavior?: ShutdownBehavior;
    /**
     * The user data for the instance. 
     */
    UserData?: SensitiveUserData;
    /**
     * The tags that are applied to the resources that are created during instance launch.
     */
    TagSpecifications?: LaunchTemplateTagSpecificationList;
    /**
     * The elastic GPU specification.
     */
    ElasticGpuSpecifications?: ElasticGpuSpecificationResponseList;
    /**
     *  The elastic inference accelerator for the instance. 
     */
    ElasticInferenceAccelerators?: LaunchTemplateElasticInferenceAcceleratorResponseList;
    /**
     * The security group IDs.
     */
    SecurityGroupIds?: ValueStringList;
    /**
     * The security group names.
     */
    SecurityGroups?: ValueStringList;
    /**
     * The market (purchasing) option for the instances.
     */
    InstanceMarketOptions?: LaunchTemplateInstanceMarketOptions;
    /**
     * The credit option for CPU usage of the instance.
     */
    CreditSpecification?: CreditSpecification;
    /**
     * The CPU options for the instance. For more information, see Optimizing CPU options in the Amazon Elastic Compute Cloud User Guide.
     */
    CpuOptions?: LaunchTemplateCpuOptions;
    /**
     * Information about the Capacity Reservation targeting option.
     */
    CapacityReservationSpecification?: LaunchTemplateCapacityReservationSpecificationResponse;
    /**
     * The license configurations.
     */
    LicenseSpecifications?: LaunchTemplateLicenseList;
    /**
     * Indicates whether an instance is configured for hibernation. For more information, see Hibernate your instance in the Amazon Elastic Compute Cloud User Guide.
     */
    HibernationOptions?: LaunchTemplateHibernationOptions;
    /**
     * The metadata options for the instance. For more information, see Instance metadata and user data in the Amazon Elastic Compute Cloud User Guide.
     */
    MetadataOptions?: LaunchTemplateInstanceMetadataOptions;
    /**
     * Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves.
     */
    EnclaveOptions?: LaunchTemplateEnclaveOptions;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with these attributes. If you specify InstanceRequirements, you can't specify InstanceTypes.
     */
    InstanceRequirements?: InstanceRequirements;
    /**
     * The options for the instance hostname.
     */
    PrivateDnsNameOptions?: LaunchTemplatePrivateDnsNameOptions;
    /**
     * The maintenance options for your instance.
     */
    MaintenanceOptions?: LaunchTemplateInstanceMaintenanceOptions;
    /**
     * Indicates whether the instance is enabled for stop protection. For more information, see Stop protection in the Amazon Elastic Compute Cloud User Guide.
     */
    DisableApiStop?: Boolean;
  }
  export type RestorableByStringList = String[];
  export interface RestoreAddressToClassicRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The Elastic IP address.
     */
    PublicIp: String;
  }
  export interface RestoreAddressToClassicResult {
    /**
     * The Elastic IP address.
     */
    PublicIp?: String;
    /**
     * The move status for the IP address.
     */
    Status?: Status;
  }
  export interface RestoreImageFromRecycleBinRequest {
    /**
     * The ID of the AMI to restore.
     */
    ImageId: ImageId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RestoreImageFromRecycleBinResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    Return?: Boolean;
  }
  export interface RestoreManagedPrefixListVersionRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the prefix list.
     */
    PrefixListId: PrefixListResourceId;
    /**
     * The version to restore.
     */
    PreviousVersion: Long;
    /**
     * The current version number for the prefix list.
     */
    CurrentVersion: Long;
  }
  export interface RestoreManagedPrefixListVersionResult {
    /**
     * Information about the prefix list.
     */
    PrefixList?: ManagedPrefixList;
  }
  export interface RestoreSnapshotFromRecycleBinRequest {
    /**
     * The ID of the snapshot to restore.
     */
    SnapshotId: SnapshotId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RestoreSnapshotFromRecycleBinResult {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide.
     */
    OutpostArn?: String;
    /**
     * The description for the snapshot.
     */
    Description?: String;
    /**
     * Indicates whether the snapshot is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The ID of the Amazon Web Services account that owns the EBS snapshot.
     */
    OwnerId?: String;
    /**
     * The progress of the snapshot, as a percentage.
     */
    Progress?: String;
    /**
     * The time stamp when the snapshot was initiated.
     */
    StartTime?: MillisecondDateTime;
    /**
     * The state of the snapshot.
     */
    State?: SnapshotState;
    /**
     * The ID of the volume that was used to create the snapshot.
     */
    VolumeId?: String;
    /**
     * The size of the volume, in GiB.
     */
    VolumeSize?: Integer;
  }
  export interface RestoreSnapshotTierRequest {
    /**
     * The ID of the snapshot to restore.
     */
    SnapshotId: SnapshotId;
    /**
     * Specifies the number of days for which to temporarily restore an archived snapshot. Required for temporary restores only. The snapshot will be automatically re-archived after this period. To temporarily restore an archived snapshot, specify the number of days and omit the PermanentRestore parameter or set it to false.
     */
    TemporaryRestoreDays?: RestoreSnapshotTierRequestTemporaryRestoreDays;
    /**
     * Indicates whether to permanently restore an archived snapshot. To permanently restore an archived snapshot, specify true and omit the RestoreSnapshotTierRequest$TemporaryRestoreDays parameter.
     */
    PermanentRestore?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type RestoreSnapshotTierRequestTemporaryRestoreDays = number;
  export interface RestoreSnapshotTierResult {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The date and time when the snapshot restore process started.
     */
    RestoreStartTime?: MillisecondDateTime;
    /**
     * For temporary restores only. The number of days for which the archived snapshot is temporarily restored.
     */
    RestoreDuration?: Integer;
    /**
     * Indicates whether the snapshot is permanently restored. true indicates a permanent restore. false indicates a temporary restore.
     */
    IsPermanentRestore?: Boolean;
  }
  export type ResultRange = number;
  export interface RevokeClientVpnIngressRequest {
    /**
     * The ID of the Client VPN endpoint with which the authorization rule is associated.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The IPv4 address range, in CIDR notation, of the network for which access is being removed.
     */
    TargetNetworkCidr: String;
    /**
     * The ID of the Active Directory group for which to revoke access. 
     */
    AccessGroupId?: String;
    /**
     * Indicates whether access should be revoked for all clients.
     */
    RevokeAllGroups?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface RevokeClientVpnIngressResult {
    /**
     * The current state of the authorization rule.
     */
    Status?: ClientVpnAuthorizationRuleStatus;
  }
  export interface RevokeSecurityGroupEgressRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the security group.
     */
    GroupId: SecurityGroupId;
    /**
     * The sets of IP permissions. You can't specify a destination security group and a CIDR IP address range in the same set of permissions.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The IDs of the security group rules.
     */
    SecurityGroupRuleIds?: SecurityGroupRuleIdList;
    /**
     * Not supported. Use a set of IP permissions to specify the CIDR.
     */
    CidrIp?: String;
    /**
     * Not supported. Use a set of IP permissions to specify the port.
     */
    FromPort?: Integer;
    /**
     * Not supported. Use a set of IP permissions to specify the protocol name or number.
     */
    IpProtocol?: String;
    /**
     * Not supported. Use a set of IP permissions to specify the port.
     */
    ToPort?: Integer;
    /**
     * Not supported. Use a set of IP permissions to specify a destination security group.
     */
    SourceSecurityGroupName?: String;
    /**
     * Not supported. Use a set of IP permissions to specify a destination security group.
     */
    SourceSecurityGroupOwnerId?: String;
  }
  export interface RevokeSecurityGroupEgressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
    /**
     * The outbound rules that were unknown to the service. In some cases, unknownIpPermissionSet might be in a different format from the request parameter. 
     */
    UnknownIpPermissions?: IpPermissionList;
  }
  export interface RevokeSecurityGroupIngressRequest {
    /**
     * The CIDR IP address range. You can't specify this parameter when specifying a source security group.
     */
    CidrIp?: String;
    /**
     * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP, this is the type number. A value of -1 indicates all ICMP types.
     */
    FromPort?: Integer;
    /**
     * The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupId?: SecurityGroupId;
    /**
     * [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupName?: SecurityGroupName;
    /**
     * The sets of IP permissions. You can't specify a source security group and a CIDR IP address range in the same set of permissions.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The IP protocol name (tcp, udp, icmp) or number (see Protocol Numbers). Use -1 to specify all.
     */
    IpProtocol?: String;
    /**
     * [EC2-Classic, default VPC] The name of the source security group. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the start of the port range, the IP protocol, and the end of the port range. For EC2-VPC, the source security group must be in the same VPC. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.
     */
    SourceSecurityGroupName?: String;
    /**
     * [EC2-Classic] The Amazon Web Services account ID of the source security group, if the source security group is in a different account. You can't specify this parameter in combination with the following parameters: the CIDR IP address range, the IP protocol, the start of the port range, and the end of the port range. To revoke a specific rule for an IP protocol and port range, use a set of IP permissions instead.
     */
    SourceSecurityGroupOwnerId?: String;
    /**
     * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP, this is the code. A value of -1 indicates all ICMP codes.
     */
    ToPort?: Integer;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The IDs of the security group rules.
     */
    SecurityGroupRuleIds?: SecurityGroupRuleIdList;
  }
  export interface RevokeSecurityGroupIngressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
    /**
     * The inbound rules that were unknown to the service. In some cases, unknownIpPermissionSet might be in a different format from the request parameter. 
     */
    UnknownIpPermissions?: IpPermissionList;
  }
  export type RoleId = string;
  export type RootDeviceType = "ebs"|"instance-store"|string;
  export type RootDeviceTypeList = RootDeviceType[];
  export interface Route {
    /**
     * The IPv4 CIDR block used for the destination match.
     */
    DestinationCidrBlock?: String;
    /**
     * The IPv6 CIDR block used for the destination match.
     */
    DestinationIpv6CidrBlock?: String;
    /**
     * The prefix of the Amazon Web Service.
     */
    DestinationPrefixListId?: String;
    /**
     * The ID of the egress-only internet gateway.
     */
    EgressOnlyInternetGatewayId?: String;
    /**
     * The ID of a gateway attached to your VPC.
     */
    GatewayId?: String;
    /**
     * The ID of a NAT instance in your VPC.
     */
    InstanceId?: String;
    /**
     * The ID of Amazon Web Services account that owns the instance.
     */
    InstanceOwnerId?: String;
    /**
     * The ID of a NAT gateway.
     */
    NatGatewayId?: String;
    /**
     * The ID of a transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The ID of the local gateway.
     */
    LocalGatewayId?: String;
    /**
     * The ID of the carrier gateway.
     */
    CarrierGatewayId?: CarrierGatewayId;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * Describes how the route was created.    CreateRouteTable - The route was automatically created when the route table was created.    CreateRoute - The route was manually added to the route table.    EnableVgwRoutePropagation - The route was propagated by route propagation.  
     */
    Origin?: RouteOrigin;
    /**
     * The state of the route. The blackhole state indicates that the route's target isn't available (for example, the specified gateway isn't attached to the VPC, or the specified NAT instance has been terminated).
     */
    State?: RouteState;
    /**
     * The ID of a VPC peering connection.
     */
    VpcPeeringConnectionId?: String;
    /**
     * The Amazon Resource Name (ARN) of the core network.
     */
    CoreNetworkArn?: CoreNetworkArn;
  }
  export type RouteGatewayId = string;
  export type RouteList = Route[];
  export type RouteOrigin = "CreateRouteTable"|"CreateRoute"|"EnableVgwRoutePropagation"|string;
  export type RouteState = "active"|"blackhole"|string;
  export interface RouteTable {
    /**
     * The associations between the route table and one or more subnets or a gateway.
     */
    Associations?: RouteTableAssociationList;
    /**
     * Any virtual private gateway (VGW) propagating routes.
     */
    PropagatingVgws?: PropagatingVgwList;
    /**
     * The ID of the route table.
     */
    RouteTableId?: String;
    /**
     * The routes in the route table.
     */
    Routes?: RouteList;
    /**
     * Any tags assigned to the route table.
     */
    Tags?: TagList;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the route table.
     */
    OwnerId?: String;
  }
  export interface RouteTableAssociation {
    /**
     * Indicates whether this is the main route table.
     */
    Main?: Boolean;
    /**
     * The ID of the association.
     */
    RouteTableAssociationId?: String;
    /**
     * The ID of the route table.
     */
    RouteTableId?: String;
    /**
     * The ID of the subnet. A subnet ID is not returned for an implicit association.
     */
    SubnetId?: String;
    /**
     * The ID of the internet gateway or virtual private gateway.
     */
    GatewayId?: String;
    /**
     * The state of the association.
     */
    AssociationState?: RouteTableAssociationState;
  }
  export type RouteTableAssociationId = string;
  export type RouteTableAssociationList = RouteTableAssociation[];
  export interface RouteTableAssociationState {
    /**
     * The state of the association.
     */
    State?: RouteTableAssociationStateCode;
    /**
     * The status message, if applicable.
     */
    StatusMessage?: String;
  }
  export type RouteTableAssociationStateCode = "associating"|"associated"|"disassociating"|"disassociated"|"failed"|string;
  export type RouteTableId = string;
  export type RouteTableIdStringList = RouteTableId[];
  export type RouteTableList = RouteTable[];
  export type RuleAction = "allow"|"deny"|string;
  export interface RuleGroupRuleOptionsPair {
    /**
     * The ARN of the rule group.
     */
    RuleGroupArn?: ResourceArn;
    /**
     * The rule options.
     */
    RuleOptions?: RuleOptionList;
  }
  export type RuleGroupRuleOptionsPairList = RuleGroupRuleOptionsPair[];
  export interface RuleGroupTypePair {
    /**
     * The ARN of the rule group.
     */
    RuleGroupArn?: ResourceArn;
    /**
     * The rule group type. The possible values are Domain List and Suricata.
     */
    RuleGroupType?: String;
  }
  export type RuleGroupTypePairList = RuleGroupTypePair[];
  export interface RuleOption {
    /**
     * The Suricata keyword.
     */
    Keyword?: String;
    /**
     * The settings for the keyword.
     */
    Settings?: StringList;
  }
  export type RuleOptionList = RuleOption[];
  export interface RunInstancesMonitoringEnabled {
    /**
     * Indicates whether detailed monitoring is enabled. Otherwise, basic monitoring is enabled.
     */
    Enabled: Boolean;
  }
  export interface RunInstancesRequest {
    /**
     * The block device mapping, which defines the EBS volumes and instance store volumes to attach to the instance at launch. For more information, see Block device mappings in the Amazon EC2 User Guide.
     */
    BlockDeviceMappings?: BlockDeviceMappingRequestList;
    /**
     * The ID of the AMI. An AMI ID is required to launch an instance and must be specified here or in a launch template.
     */
    ImageId?: ImageId;
    /**
     * The instance type. For more information, see Instance types in the Amazon EC2 User Guide. Default: m1.small 
     */
    InstanceType?: InstanceType;
    /**
     * [EC2-VPC] The number of IPv6 addresses to associate with the primary network interface. Amazon EC2 chooses the IPv6 addresses from the range of your subnet. You cannot specify this option and the option to assign specific IPv6 addresses in the same request. You can specify this option if you've specified a minimum number of instances to launch. You cannot specify this option and the network interfaces option in the same request.
     */
    Ipv6AddressCount?: Integer;
    /**
     * [EC2-VPC] The IPv6 addresses from the range of the subnet to associate with the primary network interface. You cannot specify this option and the option to assign a number of IPv6 addresses in the same request. You cannot specify this option if you've specified a minimum number of instances to launch. You cannot specify this option and the network interfaces option in the same request.
     */
    Ipv6Addresses?: InstanceIpv6AddressList;
    /**
     * The ID of the kernel.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB in the Amazon EC2 User Guide. 
     */
    KernelId?: KernelId;
    /**
     * The name of the key pair. You can create a key pair using CreateKeyPair or ImportKeyPair.  If you do not specify a key pair, you can't connect to the instance unless you choose an AMI that is configured to allow users another way to log in. 
     */
    KeyName?: KeyPairName;
    /**
     * The maximum number of instances to launch. If you specify more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches the largest possible number of instances above MinCount. Constraints: Between 1 and the maximum number you're allowed for the specified instance type. For more information about the default limits, and how to request an increase, see How many instances can I run in Amazon EC2 in the Amazon EC2 FAQ.
     */
    MaxCount: Integer;
    /**
     * The minimum number of instances to launch. If you specify a minimum that is more instances than Amazon EC2 can launch in the target Availability Zone, Amazon EC2 launches no instances. Constraints: Between 1 and the maximum number you're allowed for the specified instance type. For more information about the default limits, and how to request an increase, see How many instances can I run in Amazon EC2 in the Amazon EC2 General FAQ.
     */
    MinCount: Integer;
    /**
     * Specifies whether detailed monitoring is enabled for the instance.
     */
    Monitoring?: RunInstancesMonitoringEnabled;
    /**
     * The placement for the instance.
     */
    Placement?: Placement;
    /**
     * The ID of the RAM disk to select. Some kernels require additional drivers at launch. Check the kernel requirements for information about whether you need to specify a RAM disk. To find kernel requirements, go to the Amazon Web Services Resource Center and search for the kernel ID.  We recommend that you use PV-GRUB instead of kernels and RAM disks. For more information, see PV-GRUB in the Amazon EC2 User Guide. 
     */
    RamdiskId?: RamdiskId;
    /**
     * The IDs of the security groups. You can create a security group using CreateSecurityGroup. If you specify a network interface, you must specify any security groups as part of the network interface.
     */
    SecurityGroupIds?: SecurityGroupIdStringList;
    /**
     * [EC2-Classic, default VPC] The names of the security groups. If you specify a network interface, you must specify any security groups as part of the network interface. Default: Amazon EC2 uses the default security group.
     */
    SecurityGroups?: SecurityGroupStringList;
    /**
     * [EC2-VPC] The ID of the subnet to launch the instance into. If you specify a network interface, you must specify any subnets as part of the network interface.
     */
    SubnetId?: SubnetId;
    /**
     * The user data script to make available to the instance. For more information, see Run commands on your Linux instance at launch and Run commands on your Windows instance at launch. If you are using a command line tool, base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide base64-encoded text. User data is limited to 16 KB.
     */
    UserData?: RunInstancesUserData;
    /**
     * Reserved.
     */
    AdditionalInfo?: String;
    /**
     * Unique, case-sensitive identifier you provide to ensure the idempotency of the request. If you do not specify a client token, a randomly generated token is used for the request to ensure idempotency. For more information, see Ensuring Idempotency. Constraints: Maximum 64 ASCII characters
     */
    ClientToken?: String;
    /**
     * If you set this parameter to true, you can't terminate the instance using the Amazon EC2 console, CLI, or API; otherwise, you can. To change this attribute after launch, use ModifyInstanceAttribute. Alternatively, if you set InstanceInitiatedShutdownBehavior to terminate, you can terminate the instance by running the shutdown command from the instance. Default: false 
     */
    DisableApiTermination?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Indicates whether the instance is optimized for Amazon EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal Amazon EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS-optimized instance. Default: false 
     */
    EbsOptimized?: Boolean;
    /**
     * The name or Amazon Resource Name (ARN) of an IAM instance profile.
     */
    IamInstanceProfile?: IamInstanceProfileSpecification;
    /**
     * Indicates whether an instance stops or terminates when you initiate shutdown from the instance (using the operating system command for system shutdown). Default: stop 
     */
    InstanceInitiatedShutdownBehavior?: ShutdownBehavior;
    /**
     * The network interfaces to associate with the instance. If you specify a network interface, you must specify any security groups and subnets as part of the network interface.
     */
    NetworkInterfaces?: InstanceNetworkInterfaceSpecificationList;
    /**
     * [EC2-VPC] The primary IPv4 address. You must specify a value from the IPv4 address range of the subnet. Only one private IP address can be designated as primary. You can't specify this option if you've specified the option to designate a private IP address as the primary IP address in a network interface specification. You cannot specify this option if you're launching more than one instance in the request. You cannot specify this option and the network interfaces option in the same request.
     */
    PrivateIpAddress?: String;
    /**
     * An elastic GPU to associate with the instance. An Elastic GPU is a GPU resource that you can attach to your Windows instance to accelerate the graphics performance of your applications. For more information, see Amazon EC2 Elastic GPUs in the Amazon EC2 User Guide.
     */
    ElasticGpuSpecification?: ElasticGpuSpecifications;
    /**
     * An elastic inference accelerator to associate with the instance. Elastic inference accelerators are a resource you can attach to your Amazon EC2 instances to accelerate your Deep Learning (DL) inference workloads. You cannot specify accelerators from different generations in the same request.  Starting April 15, 2023, Amazon Web Services will not onboard new customers to Amazon Elastic Inference (EI), and will help current customers migrate their workloads to options that offer better price and performance. After April 15, 2023, new customers will not be able to launch instances with Amazon EI accelerators in Amazon SageMaker, Amazon ECS, or Amazon EC2. However, customers who have used Amazon EI at least once during the past 30-day period are considered current customers and will be able to continue using the service. 
     */
    ElasticInferenceAccelerators?: ElasticInferenceAccelerators;
    /**
     * The tags to apply to the resources that are created during instance launch. You can specify tags for the following resources only:   Instances   Volumes   Elastic graphics   Spot Instance requests   Network interfaces   To tag a resource after it has been created, see CreateTags.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * The launch template to use to launch the instances. Any parameters that you specify in RunInstances override the same parameters in the launch template. You can specify either the name or ID of a launch template, but not both.
     */
    LaunchTemplate?: LaunchTemplateSpecification;
    /**
     * The market (purchasing) option for the instances. For RunInstances, persistent Spot Instance requests are only supported when InstanceInterruptionBehavior is set to either hibernate or stop.
     */
    InstanceMarketOptions?: InstanceMarketOptionsRequest;
    /**
     * The credit option for CPU usage of the burstable performance instance. Valid values are standard and unlimited. To change this attribute after launch, use  ModifyInstanceCreditSpecification. For more information, see Burstable performance instances in the Amazon EC2 User Guide. Default: standard (T2 instances) or unlimited (T3/T3a/T4g instances) For T3 instances with host tenancy, only standard is supported.
     */
    CreditSpecification?: CreditSpecificationRequest;
    /**
     * The CPU options for the instance. For more information, see Optimize CPU options in the Amazon EC2 User Guide.
     */
    CpuOptions?: CpuOptionsRequest;
    /**
     * Information about the Capacity Reservation targeting option. If you do not specify this parameter, the instance's Capacity Reservation preference defaults to open, which enables it to run in any open Capacity Reservation that has matching attributes (instance type, platform, Availability Zone).
     */
    CapacityReservationSpecification?: CapacityReservationSpecification;
    /**
     * Indicates whether an instance is enabled for hibernation. For more information, see Hibernate your instance in the Amazon EC2 User Guide. You can't enable hibernation and Amazon Web Services Nitro Enclaves on the same instance.
     */
    HibernationOptions?: HibernationOptionsRequest;
    /**
     * The license configurations.
     */
    LicenseSpecifications?: LicenseSpecificationListRequest;
    /**
     * The metadata options for the instance. For more information, see Instance metadata and user data.
     */
    MetadataOptions?: InstanceMetadataOptionsRequest;
    /**
     * Indicates whether the instance is enabled for Amazon Web Services Nitro Enclaves. For more information, see  What is Amazon Web Services Nitro Enclaves? in the Amazon Web Services Nitro Enclaves User Guide. You can't enable Amazon Web Services Nitro Enclaves and hibernation on the same instance.
     */
    EnclaveOptions?: EnclaveOptionsRequest;
    /**
     * The options for the instance hostname. The default values are inherited from the subnet.
     */
    PrivateDnsNameOptions?: PrivateDnsNameOptionsRequest;
    /**
     * The maintenance and recovery options for the instance.
     */
    MaintenanceOptions?: InstanceMaintenanceOptionsRequest;
    /**
     * Indicates whether an instance is enabled for stop protection. For more information, see Stop protection. 
     */
    DisableApiStop?: Boolean;
  }
  export type RunInstancesUserData = string;
  export interface RunScheduledInstancesRequest {
    /**
     * Unique, case-sensitive identifier that ensures the idempotency of the request. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The number of instances. Default: 1
     */
    InstanceCount?: Integer;
    /**
     * The launch specification. You must match the instance type, Availability Zone, network, and platform of the schedule that you purchased.
     */
    LaunchSpecification: ScheduledInstancesLaunchSpecification;
    /**
     * The Scheduled Instance ID.
     */
    ScheduledInstanceId: ScheduledInstanceId;
  }
  export interface RunScheduledInstancesResult {
    /**
     * The IDs of the newly launched instances.
     */
    InstanceIdSet?: InstanceIdSet;
  }
  export interface S3ObjectTag {
    /**
     * The key of the tag. Constraints: Tag keys are case-sensitive and can be up to 128 Unicode characters in length. May not begin with aws:.
     */
    Key?: String;
    /**
     * The value of the tag. Constraints: Tag values are case-sensitive and can be up to 256 Unicode characters in length.
     */
    Value?: String;
  }
  export type S3ObjectTagList = S3ObjectTag[];
  export interface S3Storage {
    /**
     * The access key ID of the owner of the bucket. Before you specify a value for your access key ID, review and follow the guidance in Best Practices for Amazon Web Services accounts in the Account ManagementReference Guide.
     */
    AWSAccessKeyId?: String;
    /**
     * The bucket in which to store the AMI. You can specify a bucket that you already own or a new bucket that Amazon EC2 creates on your behalf. If you specify a bucket that belongs to someone else, Amazon EC2 returns an error.
     */
    Bucket?: String;
    /**
     * The beginning of the file name of the AMI.
     */
    Prefix?: String;
    /**
     * An Amazon S3 upload policy that gives Amazon EC2 permission to upload items into Amazon S3 on your behalf.
     */
    UploadPolicy?: _Blob;
    /**
     * The signature of the JSON document.
     */
    UploadPolicySignature?: String;
  }
  export interface ScheduledInstance {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The date when the Scheduled Instance was purchased.
     */
    CreateDate?: DateTime;
    /**
     * The hourly price for a single instance.
     */
    HourlyPrice?: String;
    /**
     * The number of instances.
     */
    InstanceCount?: Integer;
    /**
     * The instance type.
     */
    InstanceType?: String;
    /**
     * The network platform (EC2-Classic or EC2-VPC).
     */
    NetworkPlatform?: String;
    /**
     * The time for the next schedule to start.
     */
    NextSlotStartTime?: DateTime;
    /**
     * The platform (Linux/UNIX or Windows).
     */
    Platform?: String;
    /**
     * The time that the previous schedule ended or will end.
     */
    PreviousSlotEndTime?: DateTime;
    /**
     * The schedule recurrence.
     */
    Recurrence?: ScheduledInstanceRecurrence;
    /**
     * The Scheduled Instance ID.
     */
    ScheduledInstanceId?: String;
    /**
     * The number of hours in the schedule.
     */
    SlotDurationInHours?: Integer;
    /**
     * The end date for the Scheduled Instance.
     */
    TermEndDate?: DateTime;
    /**
     * The start date for the Scheduled Instance.
     */
    TermStartDate?: DateTime;
    /**
     * The total number of hours for a single instance for the entire term.
     */
    TotalScheduledInstanceHours?: Integer;
  }
  export interface ScheduledInstanceAvailability {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The number of available instances.
     */
    AvailableInstanceCount?: Integer;
    /**
     * The time period for the first schedule to start.
     */
    FirstSlotStartTime?: DateTime;
    /**
     * The hourly price for a single instance.
     */
    HourlyPrice?: String;
    /**
     * The instance type. You can specify one of the C3, C4, M4, or R3 instance types.
     */
    InstanceType?: String;
    /**
     * The maximum term. The only possible value is 365 days.
     */
    MaxTermDurationInDays?: Integer;
    /**
     * The minimum term. The only possible value is 365 days.
     */
    MinTermDurationInDays?: Integer;
    /**
     * The network platform (EC2-Classic or EC2-VPC).
     */
    NetworkPlatform?: String;
    /**
     * The platform (Linux/UNIX or Windows).
     */
    Platform?: String;
    /**
     * The purchase token. This token expires in two hours.
     */
    PurchaseToken?: String;
    /**
     * The schedule recurrence.
     */
    Recurrence?: ScheduledInstanceRecurrence;
    /**
     * The number of hours in the schedule.
     */
    SlotDurationInHours?: Integer;
    /**
     * The total number of hours for a single instance for the entire term.
     */
    TotalScheduledInstanceHours?: Integer;
  }
  export type ScheduledInstanceAvailabilitySet = ScheduledInstanceAvailability[];
  export type ScheduledInstanceId = string;
  export type ScheduledInstanceIdRequestSet = ScheduledInstanceId[];
  export interface ScheduledInstanceRecurrence {
    /**
     * The frequency (Daily, Weekly, or Monthly).
     */
    Frequency?: String;
    /**
     * The interval quantity. The interval unit depends on the value of frequency. For example, every 2 weeks or every 2 months.
     */
    Interval?: Integer;
    /**
     * The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday).
     */
    OccurrenceDaySet?: OccurrenceDaySet;
    /**
     * Indicates whether the occurrence is relative to the end of the specified week or month.
     */
    OccurrenceRelativeToEnd?: Boolean;
    /**
     * The unit for occurrenceDaySet (DayOfWeek or DayOfMonth).
     */
    OccurrenceUnit?: String;
  }
  export interface ScheduledInstanceRecurrenceRequest {
    /**
     * The frequency (Daily, Weekly, or Monthly).
     */
    Frequency?: String;
    /**
     * The interval quantity. The interval unit depends on the value of Frequency. For example, every 2 weeks or every 2 months.
     */
    Interval?: Integer;
    /**
     * The days. For a monthly schedule, this is one or more days of the month (1-31). For a weekly schedule, this is one or more days of the week (1-7, where 1 is Sunday). You can't specify this value with a daily schedule. If the occurrence is relative to the end of the month, you can specify only a single day.
     */
    OccurrenceDays?: OccurrenceDayRequestSet;
    /**
     * Indicates whether the occurrence is relative to the end of the specified week or month. You can't specify this value with a daily schedule.
     */
    OccurrenceRelativeToEnd?: Boolean;
    /**
     * The unit for OccurrenceDays (DayOfWeek or DayOfMonth). This value is required for a monthly schedule. You can't specify DayOfWeek with a weekly schedule. You can't specify this value with a daily schedule.
     */
    OccurrenceUnit?: String;
  }
  export type ScheduledInstanceSet = ScheduledInstance[];
  export interface ScheduledInstancesBlockDeviceMapping {
    /**
     * The device name (for example, /dev/sdh or xvdh).
     */
    DeviceName?: String;
    /**
     * Parameters used to set up EBS volumes automatically when the instance is launched.
     */
    Ebs?: ScheduledInstancesEbs;
    /**
     * To omit the device from the block device mapping, specify an empty string.
     */
    NoDevice?: String;
    /**
     * The virtual device name (ephemeralN). Instance store volumes are numbered starting from 0. An instance type with two available instance store volumes can specify mappings for ephemeral0 and ephemeral1. The number of available instance store volumes depends on the instance type. After you connect to the instance, you must mount the volume. Constraints: For M3 instances, you must specify instance store volumes in the block device mapping for the instance. When you launch an M3 instance, we ignore any instance store volumes specified in the block device mapping for the AMI.
     */
    VirtualName?: String;
  }
  export type ScheduledInstancesBlockDeviceMappingSet = ScheduledInstancesBlockDeviceMapping[];
  export interface ScheduledInstancesEbs {
    /**
     * Indicates whether the volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
    /**
     * Indicates whether the volume is encrypted. You can attached encrypted volumes only to instances that support them.
     */
    Encrypted?: Boolean;
    /**
     * The number of I/O operations per second (IOPS) to provision for an io1 or io2 volume, with a maximum ratio of 50 IOPS/GiB for io1, and 500 IOPS/GiB for io2. Range is 100 to 64,000 IOPS for volumes in most Regions. Maximum IOPS of 64,000 is guaranteed only on instances built on the Nitro System. Other instance families guarantee performance up to 32,000 IOPS. For more information, see Amazon EBS volume types in the Amazon EC2 User Guide. This parameter is valid only for Provisioned IOPS SSD (io1 and io2) volumes.
     */
    Iops?: Integer;
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The size of the volume, in GiB. Default: If you're creating the volume from a snapshot and don't specify a volume size, the default is the snapshot size.
     */
    VolumeSize?: Integer;
    /**
     * The volume type. gp2 for General Purpose SSD, io1 or  io2 for Provisioned IOPS SSD, Throughput Optimized HDD for st1, Cold HDD for sc1, or standard for Magnetic. Default: gp2 
     */
    VolumeType?: String;
  }
  export interface ScheduledInstancesIamInstanceProfile {
    /**
     * The Amazon Resource Name (ARN).
     */
    Arn?: String;
    /**
     * The name.
     */
    Name?: String;
  }
  export interface ScheduledInstancesIpv6Address {
    /**
     * The IPv6 address.
     */
    Ipv6Address?: Ipv6Address;
  }
  export type ScheduledInstancesIpv6AddressList = ScheduledInstancesIpv6Address[];
  export interface ScheduledInstancesLaunchSpecification {
    /**
     * The block device mapping entries.
     */
    BlockDeviceMappings?: ScheduledInstancesBlockDeviceMappingSet;
    /**
     * Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS-optimized instance. Default: false 
     */
    EbsOptimized?: Boolean;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: ScheduledInstancesIamInstanceProfile;
    /**
     * The ID of the Amazon Machine Image (AMI).
     */
    ImageId: ImageId;
    /**
     * The instance type.
     */
    InstanceType?: String;
    /**
     * The ID of the kernel.
     */
    KernelId?: KernelId;
    /**
     * The name of the key pair.
     */
    KeyName?: KeyPairName;
    /**
     * Enable or disable monitoring for the instances.
     */
    Monitoring?: ScheduledInstancesMonitoring;
    /**
     * The network interfaces.
     */
    NetworkInterfaces?: ScheduledInstancesNetworkInterfaceSet;
    /**
     * The placement information.
     */
    Placement?: ScheduledInstancesPlacement;
    /**
     * The ID of the RAM disk.
     */
    RamdiskId?: RamdiskId;
    /**
     * The IDs of the security groups.
     */
    SecurityGroupIds?: ScheduledInstancesSecurityGroupIdSet;
    /**
     * The ID of the subnet in which to launch the instances.
     */
    SubnetId?: SubnetId;
    /**
     * The base64-encoded MIME user data.
     */
    UserData?: String;
  }
  export interface ScheduledInstancesMonitoring {
    /**
     * Indicates whether monitoring is enabled.
     */
    Enabled?: Boolean;
  }
  export interface ScheduledInstancesNetworkInterface {
    /**
     * Indicates whether to assign a public IPv4 address to instances launched in a VPC. The public IPv4 address can only be assigned to a network interface for eth0, and can only be assigned to a new network interface, not an existing one. You cannot specify more than one network interface in the request. If launching into a default subnet, the default value is true.
     */
    AssociatePublicIpAddress?: Boolean;
    /**
     * Indicates whether to delete the interface when the instance is terminated.
     */
    DeleteOnTermination?: Boolean;
    /**
     * The description.
     */
    Description?: String;
    /**
     * The index of the device for the network interface attachment.
     */
    DeviceIndex?: Integer;
    /**
     * The IDs of the security groups.
     */
    Groups?: ScheduledInstancesSecurityGroupIdSet;
    /**
     * The number of IPv6 addresses to assign to the network interface. The IPv6 addresses are automatically selected from the subnet range.
     */
    Ipv6AddressCount?: Integer;
    /**
     * The specific IPv6 addresses from the subnet range.
     */
    Ipv6Addresses?: ScheduledInstancesIpv6AddressList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The IPv4 address of the network interface within the subnet.
     */
    PrivateIpAddress?: String;
    /**
     * The private IPv4 addresses.
     */
    PrivateIpAddressConfigs?: PrivateIpAddressConfigSet;
    /**
     * The number of secondary private IPv4 addresses.
     */
    SecondaryPrivateIpAddressCount?: Integer;
    /**
     * The ID of the subnet.
     */
    SubnetId?: SubnetId;
  }
  export type ScheduledInstancesNetworkInterfaceSet = ScheduledInstancesNetworkInterface[];
  export interface ScheduledInstancesPlacement {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The name of the placement group.
     */
    GroupName?: PlacementGroupName;
  }
  export interface ScheduledInstancesPrivateIpAddressConfig {
    /**
     * Indicates whether this is a primary IPv4 address. Otherwise, this is a secondary IPv4 address.
     */
    Primary?: Boolean;
    /**
     * The IPv4 address.
     */
    PrivateIpAddress?: String;
  }
  export type ScheduledInstancesSecurityGroupIdSet = SecurityGroupId[];
  export interface SearchLocalGatewayRoutesRequest {
    /**
     * The ID of the local gateway route table.
     */
    LocalGatewayRouteTableId: LocalGatewayRoutetableId;
    /**
     * One or more filters.    prefix-list-id - The ID of the prefix list.    route-search.exact-match - The exact match of the specified filter.    route-search.longest-prefix-match - The longest prefix that matches the route.    route-search.subnet-of-match - The routes with a subnet that match the specified CIDR filter.    route-search.supernet-of-match - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.    state - The state of the route.    type - The route type.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: MaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface SearchLocalGatewayRoutesResult {
    /**
     * Information about the routes.
     */
    Routes?: LocalGatewayRouteList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface SearchTransitGatewayMulticastGroupsRequest {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId: TransitGatewayMulticastDomainId;
    /**
     * One or more filters. The possible values are:    group-ip-address - The IP address of the transit gateway multicast group.    is-group-member - The resource is a group member. Valid values are true | false.    is-group-source - The resource is a group source. Valid values are true | false.    member-type - The member type. Valid values are igmp | static.    resource-id - The ID of the resource.    resource-type - The type of resource. Valid values are vpc | vpn | direct-connect-gateway | tgw-peering.    source-type - The source type. Valid values are igmp | static.    subnet-id - The ID of the subnet.    transit-gateway-attachment-id - The id of the transit gateway attachment.  
     */
    Filters?: FilterList;
    /**
     * The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * The token for the next page of results.
     */
    NextToken?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface SearchTransitGatewayMulticastGroupsResult {
    /**
     * Information about the transit gateway multicast group.
     */
    MulticastGroups?: TransitGatewayMulticastGroupList;
    /**
     * The token to use to retrieve the next page of results. This value is null when there are no more results to return.
     */
    NextToken?: String;
  }
  export interface SearchTransitGatewayRoutesRequest {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId: TransitGatewayRouteTableId;
    /**
     * One or more filters. The possible values are:    attachment.transit-gateway-attachment-id- The id of the transit gateway attachment.    attachment.resource-id - The resource id of the transit gateway attachment.    attachment.resource-type - The attachment resource type. Valid values are vpc | vpn | direct-connect-gateway | peering | connect.    prefix-list-id - The ID of the prefix list.    route-search.exact-match - The exact match of the specified filter.    route-search.longest-prefix-match - The longest prefix that matches the route.    route-search.subnet-of-match - The routes with a subnet that match the specified CIDR filter.    route-search.supernet-of-match - The routes with a CIDR that encompass the CIDR filter. For example, if you have 10.0.1.0/29 and 10.0.1.0/31 routes in your route table and you specify supernet-of-match as 10.0.1.0/30, then the result returns 10.0.1.0/29.    state - The state of the route (active | blackhole).    type - The type of route (propagated | static).  
     */
    Filters: FilterList;
    /**
     * The maximum number of routes to return.
     */
    MaxResults?: TransitGatewayMaxResults;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface SearchTransitGatewayRoutesResult {
    /**
     * Information about the routes.
     */
    Routes?: TransitGatewayRouteList;
    /**
     * Indicates whether there are additional routes available.
     */
    AdditionalRoutesAvailable?: Boolean;
  }
  export interface SecurityGroup {
    /**
     * A description of the security group.
     */
    Description?: String;
    /**
     * The name of the security group.
     */
    GroupName?: String;
    /**
     * The inbound rules associated with the security group.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The Amazon Web Services account ID of the owner of the security group.
     */
    OwnerId?: String;
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * [VPC only] The outbound rules associated with the security group.
     */
    IpPermissionsEgress?: IpPermissionList;
    /**
     * Any tags assigned to the security group.
     */
    Tags?: TagList;
    /**
     * [VPC only] The ID of the VPC for the security group.
     */
    VpcId?: String;
  }
  export type SecurityGroupId = string;
  export type SecurityGroupIdList = SecurityGroupId[];
  export type SecurityGroupIdStringList = SecurityGroupId[];
  export interface SecurityGroupIdentifier {
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * The name of the security group.
     */
    GroupName?: String;
  }
  export type SecurityGroupList = SecurityGroup[];
  export type SecurityGroupName = string;
  export interface SecurityGroupReference {
    /**
     * The ID of your security group.
     */
    GroupId?: String;
    /**
     * The ID of the VPC with the referencing security group.
     */
    ReferencingVpcId?: String;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId?: String;
  }
  export type SecurityGroupReferences = SecurityGroupReference[];
  export interface SecurityGroupRule {
    /**
     * The ID of the security group rule.
     */
    SecurityGroupRuleId?: SecurityGroupRuleId;
    /**
     * The ID of the security group.
     */
    GroupId?: SecurityGroupId;
    /**
     * The ID of the Amazon Web Services account that owns the security group. 
     */
    GroupOwnerId?: String;
    /**
     * Indicates whether the security group rule is an outbound rule.
     */
    IsEgress?: Boolean;
    /**
     * The IP protocol name (tcp, udp, icmp, icmpv6) or number (see Protocol Numbers).  Use -1 to specify all protocols.
     */
    IpProtocol?: String;
    /**
     * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the type number. A value of -1 indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    FromPort?: Integer;
    /**
     * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the type number. A value of -1 indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    ToPort?: Integer;
    /**
     * The IPv4 CIDR range.
     */
    CidrIpv4?: String;
    /**
     * The IPv6 CIDR range.
     */
    CidrIpv6?: String;
    /**
     * The ID of the prefix list.
     */
    PrefixListId?: PrefixListResourceId;
    /**
     * Describes the security group that is referenced in the rule.
     */
    ReferencedGroupInfo?: ReferencedSecurityGroup;
    /**
     * The security group rule description.
     */
    Description?: String;
    /**
     * The tags applied to the security group rule.
     */
    Tags?: TagList;
  }
  export interface SecurityGroupRuleDescription {
    /**
     * The ID of the security group rule.
     */
    SecurityGroupRuleId?: String;
    /**
     * The description of the security group rule.
     */
    Description?: String;
  }
  export type SecurityGroupRuleDescriptionList = SecurityGroupRuleDescription[];
  export type SecurityGroupRuleId = string;
  export type SecurityGroupRuleIdList = String[];
  export type SecurityGroupRuleList = SecurityGroupRule[];
  export interface SecurityGroupRuleRequest {
    /**
     * The IP protocol name (tcp, udp, icmp, icmpv6) or number (see Protocol Numbers).  Use -1 to specify all protocols.
     */
    IpProtocol?: String;
    /**
     * If the protocol is TCP or UDP, this is the start of the port range. If the protocol is ICMP or ICMPv6, this is the type number. A value of -1 indicates all ICMP/ICMPv6 types. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    FromPort?: Integer;
    /**
     * If the protocol is TCP or UDP, this is the end of the port range. If the protocol is ICMP or ICMPv6, this is the code. A value of -1 indicates all ICMP/ICMPv6 codes. If you specify all ICMP/ICMPv6 types, you must specify all ICMP/ICMPv6 codes.
     */
    ToPort?: Integer;
    /**
     * The IPv4 CIDR range. To specify a single IPv4 address, use the /32 prefix length. 
     */
    CidrIpv4?: String;
    /**
     * The IPv6 CIDR range. To specify a single IPv6 address, use the /128 prefix length.
     */
    CidrIpv6?: String;
    /**
     * The ID of the prefix list.
     */
    PrefixListId?: PrefixListResourceId;
    /**
     * The ID of the security group that is referenced in the security group rule.
     */
    ReferencedGroupId?: SecurityGroupId;
    /**
     * The description of the security group rule.
     */
    Description?: String;
  }
  export interface SecurityGroupRuleUpdate {
    /**
     * The ID of the security group rule.
     */
    SecurityGroupRuleId: SecurityGroupRuleId;
    /**
     * Information about the security group rule.
     */
    SecurityGroupRule?: SecurityGroupRuleRequest;
  }
  export type SecurityGroupRuleUpdateList = SecurityGroupRuleUpdate[];
  export type SecurityGroupStringList = SecurityGroupName[];
  export type SelfServicePortal = "enabled"|"disabled"|string;
  export interface SendDiagnosticInterruptRequest {
    /**
     * The ID of the instance.
     */
    InstanceId: InstanceId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export type SensitiveUserData = string;
  export interface ServiceConfiguration {
    /**
     * The type of service.
     */
    ServiceType?: ServiceTypeDetailSet;
    /**
     * The ID of the service.
     */
    ServiceId?: String;
    /**
     * The name of the service.
     */
    ServiceName?: String;
    /**
     * The service state.
     */
    ServiceState?: ServiceState;
    /**
     * The Availability Zones in which the service is available.
     */
    AvailabilityZones?: ValueStringList;
    /**
     * Indicates whether requests from other Amazon Web Services accounts to create an endpoint to the service must first be accepted.
     */
    AcceptanceRequired?: Boolean;
    /**
     * Indicates whether the service manages its VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
     */
    ManagesVpcEndpoints?: Boolean;
    /**
     * The Amazon Resource Names (ARNs) of the Network Load Balancers for the service.
     */
    NetworkLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
     */
    GatewayLoadBalancerArns?: ValueStringList;
    /**
     * The supported IP address types.
     */
    SupportedIpAddressTypes?: SupportedIpAddressTypes;
    /**
     * The DNS names for the service.
     */
    BaseEndpointDnsNames?: ValueStringList;
    /**
     * The private DNS name for the service.
     */
    PrivateDnsName?: String;
    /**
     * Information about the endpoint service private DNS name configuration.
     */
    PrivateDnsNameConfiguration?: PrivateDnsNameConfiguration;
    /**
     * The payer responsibility.
     */
    PayerResponsibility?: PayerResponsibility;
    /**
     * The tags assigned to the service.
     */
    Tags?: TagList;
  }
  export type ServiceConfigurationSet = ServiceConfiguration[];
  export type ServiceConnectivityType = "ipv4"|"ipv6"|string;
  export interface ServiceDetail {
    /**
     * The name of the service.
     */
    ServiceName?: String;
    /**
     * The ID of the endpoint service.
     */
    ServiceId?: String;
    /**
     * The type of service.
     */
    ServiceType?: ServiceTypeDetailSet;
    /**
     * The Availability Zones in which the service is available.
     */
    AvailabilityZones?: ValueStringList;
    /**
     * The Amazon Web Services account ID of the service owner.
     */
    Owner?: String;
    /**
     * The DNS names for the service.
     */
    BaseEndpointDnsNames?: ValueStringList;
    /**
     * The private DNS name for the service.
     */
    PrivateDnsName?: String;
    /**
     * The private DNS names assigned to the VPC endpoint service.
     */
    PrivateDnsNames?: PrivateDnsDetailsSet;
    /**
     * Indicates whether the service supports endpoint policies.
     */
    VpcEndpointPolicySupported?: Boolean;
    /**
     * Indicates whether VPC endpoint connection requests to the service must be accepted by the service owner.
     */
    AcceptanceRequired?: Boolean;
    /**
     * Indicates whether the service manages its VPC endpoints. Management of the service VPC endpoints using the VPC endpoint API is restricted.
     */
    ManagesVpcEndpoints?: Boolean;
    /**
     * The payer responsibility.
     */
    PayerResponsibility?: PayerResponsibility;
    /**
     * The tags assigned to the service.
     */
    Tags?: TagList;
    /**
     * The verification state of the VPC endpoint service. Consumers of the endpoint service cannot use the private name when the state is not verified.
     */
    PrivateDnsNameVerificationState?: DnsNameState;
    /**
     * The supported IP address types.
     */
    SupportedIpAddressTypes?: SupportedIpAddressTypes;
  }
  export type ServiceDetailSet = ServiceDetail[];
  export type ServiceState = "Pending"|"Available"|"Deleting"|"Deleted"|"Failed"|string;
  export type ServiceType = "Interface"|"Gateway"|"GatewayLoadBalancer"|string;
  export interface ServiceTypeDetail {
    /**
     * The type of service.
     */
    ServiceType?: ServiceType;
  }
  export type ServiceTypeDetailSet = ServiceTypeDetail[];
  export type ShutdownBehavior = "stop"|"terminate"|string;
  export interface SlotDateTimeRangeRequest {
    /**
     * The earliest date and time, in UTC, for the Scheduled Instance to start.
     */
    EarliestTime: DateTime;
    /**
     * The latest date and time, in UTC, for the Scheduled Instance to start. This value must be later than or equal to the earliest date and at most three months in the future.
     */
    LatestTime: DateTime;
  }
  export interface SlotStartTimeRangeRequest {
    /**
     * The earliest date and time, in UTC, for the Scheduled Instance to start.
     */
    EarliestTime?: DateTime;
    /**
     * The latest date and time, in UTC, for the Scheduled Instance to start.
     */
    LatestTime?: DateTime;
  }
  export interface Snapshot {
    /**
     * The data encryption key identifier for the snapshot. This value is a unique identifier that corresponds to the data encryption key that was used to encrypt the original volume or snapshot copy. Because data encryption keys are inherited by volumes created from snapshots, and vice versa, if snapshots share the same data encryption key identifier, then they belong to the same volume/snapshot lineage. This parameter is only returned by DescribeSnapshots.
     */
    DataEncryptionKeyId?: String;
    /**
     * The description for the snapshot.
     */
    Description?: String;
    /**
     * Indicates whether the snapshot is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Key Management Service (KMS) KMS key that was used to protect the volume encryption key for the parent volume.
     */
    KmsKeyId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the EBS snapshot.
     */
    OwnerId?: String;
    /**
     * The progress of the snapshot, as a percentage.
     */
    Progress?: String;
    /**
     * The ID of the snapshot. Each snapshot receives a unique identifier when it is created.
     */
    SnapshotId?: String;
    /**
     * The time stamp when the snapshot was initiated.
     */
    StartTime?: DateTime;
    /**
     * The snapshot state.
     */
    State?: SnapshotState;
    /**
     * Encrypted Amazon EBS snapshots are copied asynchronously. If a snapshot copy operation fails (for example, if the proper Key Management Service (KMS) permissions are not obtained) this field displays error state details to help you diagnose why the error occurred. This parameter is only returned by DescribeSnapshots.
     */
    StateMessage?: String;
    /**
     * The ID of the volume that was used to create the snapshot. Snapshots created by the CopySnapshot action have an arbitrary volume ID that should not be used for any purpose.
     */
    VolumeId?: String;
    /**
     * The size of the volume, in GiB.
     */
    VolumeSize?: Integer;
    /**
     * The Amazon Web Services owner alias, from an Amazon-maintained list (amazon). This is not the user-configured Amazon Web Services account alias set using the IAM console.
     */
    OwnerAlias?: String;
    /**
     * The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide.
     */
    OutpostArn?: String;
    /**
     * Any tags assigned to the snapshot.
     */
    Tags?: TagList;
    /**
     * The storage tier in which the snapshot is stored. standard indicates that the snapshot is stored in the standard snapshot storage tier and that it is ready for use. archive indicates that the snapshot is currently archived and that it must be restored before it can be used.
     */
    StorageTier?: StorageTier;
    /**
     * Only for archived snapshots that are temporarily restored. Indicates the date and time when a temporarily restored snapshot will be automatically re-archived.
     */
    RestoreExpiryTime?: MillisecondDateTime;
  }
  export type SnapshotAttributeName = "productCodes"|"createVolumePermission"|string;
  export interface SnapshotDetail {
    /**
     * A description for the snapshot.
     */
    Description?: String;
    /**
     * The block device mapping for the snapshot.
     */
    DeviceName?: String;
    /**
     * The size of the disk in the snapshot, in GiB.
     */
    DiskImageSize?: Double;
    /**
     * The format of the disk image from which the snapshot is created.
     */
    Format?: String;
    /**
     * The percentage of progress for the task.
     */
    Progress?: String;
    /**
     * The snapshot ID of the disk being imported.
     */
    SnapshotId?: String;
    /**
     * A brief status of the snapshot creation.
     */
    Status?: String;
    /**
     * A detailed status message for the snapshot creation.
     */
    StatusMessage?: String;
    /**
     * The URL used to access the disk image.
     */
    Url?: String;
    /**
     * The Amazon S3 bucket for the disk image.
     */
    UserBucket?: UserBucketDetails;
  }
  export type SnapshotDetailList = SnapshotDetail[];
  export interface SnapshotDiskContainer {
    /**
     * The description of the disk image being imported.
     */
    Description?: String;
    /**
     * The format of the disk image being imported. Valid values: VHD | VMDK | RAW 
     */
    Format?: String;
    /**
     * The URL to the Amazon S3-based disk image being imported. It can either be a https URL (https://..) or an Amazon S3 URL (s3://..).
     */
    Url?: String;
    /**
     * The Amazon S3 bucket for the disk image.
     */
    UserBucket?: UserBucket;
  }
  export type SnapshotId = string;
  export type SnapshotIdStringList = SnapshotId[];
  export interface SnapshotInfo {
    /**
     * Description specified by the CreateSnapshotRequest that has been applied to all snapshots.
     */
    Description?: String;
    /**
     * Tags associated with this snapshot.
     */
    Tags?: TagList;
    /**
     * Indicates whether the snapshot is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * Source volume from which this snapshot was created.
     */
    VolumeId?: String;
    /**
     * Current state of the snapshot.
     */
    State?: SnapshotState;
    /**
     * Size of the volume from which this snapshot was created.
     */
    VolumeSize?: Integer;
    /**
     * Time this snapshot was started. This is the same for all snapshots initiated by the same request.
     */
    StartTime?: MillisecondDateTime;
    /**
     * Progress this snapshot has made towards completing.
     */
    Progress?: String;
    /**
     * Account id used when creating this snapshot.
     */
    OwnerId?: String;
    /**
     * Snapshot id that can be used to describe this snapshot.
     */
    SnapshotId?: String;
    /**
     * The ARN of the Outpost on which the snapshot is stored. For more information, see Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide.
     */
    OutpostArn?: String;
  }
  export type SnapshotList = Snapshot[];
  export interface SnapshotRecycleBinInfo {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: String;
    /**
     * The date and time when the snaphsot entered the Recycle Bin.
     */
    RecycleBinEnterTime?: MillisecondDateTime;
    /**
     * The date and time when the snapshot is to be permanently deleted from the Recycle Bin.
     */
    RecycleBinExitTime?: MillisecondDateTime;
    /**
     * The description for the snapshot.
     */
    Description?: String;
    /**
     * The ID of the volume from which the snapshot was created.
     */
    VolumeId?: String;
  }
  export type SnapshotRecycleBinInfoList = SnapshotRecycleBinInfo[];
  export type SnapshotSet = SnapshotInfo[];
  export type SnapshotState = "pending"|"completed"|"error"|"recoverable"|"recovering"|string;
  export interface SnapshotTaskDetail {
    /**
     * The description of the snapshot.
     */
    Description?: String;
    /**
     * The size of the disk in the snapshot, in GiB.
     */
    DiskImageSize?: Double;
    /**
     * Indicates whether the snapshot is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The format of the disk image from which the snapshot is created.
     */
    Format?: String;
    /**
     * The identifier for the KMS key that was used to create the encrypted snapshot.
     */
    KmsKeyId?: String;
    /**
     * The percentage of completion for the import snapshot task.
     */
    Progress?: String;
    /**
     * The snapshot ID of the disk being imported.
     */
    SnapshotId?: String;
    /**
     * A brief status for the import snapshot task.
     */
    Status?: String;
    /**
     * A detailed status message for the import snapshot task.
     */
    StatusMessage?: String;
    /**
     * The URL of the disk image from which the snapshot is created.
     */
    Url?: String;
    /**
     * The Amazon S3 bucket for the disk image.
     */
    UserBucket?: UserBucketDetails;
  }
  export interface SnapshotTierStatus {
    /**
     * The ID of the snapshot.
     */
    SnapshotId?: SnapshotId;
    /**
     * The ID of the volume from which the snapshot was created.
     */
    VolumeId?: VolumeId;
    /**
     * The state of the snapshot.
     */
    Status?: SnapshotState;
    /**
     * The ID of the Amazon Web Services account that owns the snapshot.
     */
    OwnerId?: String;
    /**
     * The tags that are assigned to the snapshot.
     */
    Tags?: TagList;
    /**
     * The storage tier in which the snapshot is stored. standard indicates that the snapshot is stored in the standard snapshot storage tier and that it is ready for use. archive indicates that the snapshot is currently archived and that it must be restored before it can be used.
     */
    StorageTier?: StorageTier;
    /**
     * The date and time when the last archive or restore process was started.
     */
    LastTieringStartTime?: MillisecondDateTime;
    /**
     * The progress of the last archive or restore process, as a percentage.
     */
    LastTieringProgress?: Integer;
    /**
     * The status of the last archive or restore process.
     */
    LastTieringOperationStatus?: TieringOperationStatus;
    /**
     * A message describing the status of the last archive or restore process.
     */
    LastTieringOperationStatusDetail?: String;
    /**
     * The date and time when the last archive process was completed.
     */
    ArchivalCompleteTime?: MillisecondDateTime;
    /**
     * Only for archived snapshots that are temporarily restored. Indicates the date and time when a temporarily restored snapshot will be automatically re-archived.
     */
    RestoreExpiryTime?: MillisecondDateTime;
  }
  export type SpotAllocationStrategy = "lowest-price"|"diversified"|"capacity-optimized"|"capacity-optimized-prioritized"|"price-capacity-optimized"|string;
  export interface SpotCapacityRebalance {
    /**
     * The replacement strategy to use. Only available for fleets of type maintain.  launch - Spot Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet. Spot Fleet does not terminate the instances that receive a rebalance notification. You can terminate the old instances, or you can leave them running. You are charged for all instances while they are running.   launch-before-terminate - Spot Fleet launches a new replacement Spot Instance when a rebalance notification is emitted for an existing Spot Instance in the fleet, and then, after a delay that you specify (in TerminationDelay), terminates the instances that received a rebalance notification.
     */
    ReplacementStrategy?: ReplacementStrategy;
    /**
     * The amount of time (in seconds) that Amazon EC2 waits before terminating the old Spot Instance after launching a new replacement Spot Instance. Required when ReplacementStrategy is set to launch-before-terminate. Not valid when ReplacementStrategy is set to launch. Valid values: Minimum value of 120 seconds. Maximum value of 7200 seconds.
     */
    TerminationDelay?: Integer;
  }
  export interface SpotDatafeedSubscription {
    /**
     * The name of the Amazon S3 bucket where the Spot Instance data feed is located.
     */
    Bucket?: String;
    /**
     * The fault codes for the Spot Instance request, if any.
     */
    Fault?: SpotInstanceStateFault;
    /**
     * The Amazon Web Services account ID of the account.
     */
    OwnerId?: String;
    /**
     * The prefix for the data feed files.
     */
    Prefix?: String;
    /**
     * The state of the Spot Instance data feed subscription.
     */
    State?: DatafeedSubscriptionState;
  }
  export interface SpotFleetLaunchSpecification {
    /**
     * One or more security groups. When requesting instances in a VPC, you must specify the IDs of the security groups. When requesting instances in EC2-Classic, you can specify the names or the IDs of the security groups.
     */
    SecurityGroups?: GroupIdentifierList;
    /**
     * Deprecated.
     */
    AddressingType?: String;
    /**
     * One or more block devices that are mapped to the Spot Instances. You can't specify both a snapshot ID and an encryption value. This is because only blank volumes can be encrypted on creation. If a snapshot is the basis for a volume, it is not blank and its encryption status is used for the volume encryption status.
     */
    BlockDeviceMappings?: BlockDeviceMappingList;
    /**
     * Indicates whether the instances are optimized for EBS I/O. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal EBS I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS Optimized instance. Default: false 
     */
    EbsOptimized?: Boolean;
    /**
     * The IAM instance profile.
     */
    IamInstanceProfile?: IamInstanceProfileSpecification;
    /**
     * The ID of the AMI.
     */
    ImageId?: ImageId;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * The ID of the kernel.
     */
    KernelId?: String;
    /**
     * The name of the key pair.
     */
    KeyName?: KeyPairName;
    /**
     * Enable or disable monitoring for the instances.
     */
    Monitoring?: SpotFleetMonitoring;
    /**
     * One or more network interfaces. If you specify a network interface, you must specify subnet IDs and security group IDs using the network interface.   SpotFleetLaunchSpecification currently does not support Elastic Fabric Adapter (EFA). To specify an EFA, you must use LaunchTemplateConfig. 
     */
    NetworkInterfaces?: InstanceNetworkInterfaceSpecificationList;
    /**
     * The placement information.
     */
    Placement?: SpotPlacement;
    /**
     * The ID of the RAM disk. Some kernels require additional drivers at launch. Check the kernel requirements for information about whether you need to specify a RAM disk. To find kernel requirements, refer to the Amazon Web Services Resource Center and search for the kernel ID.
     */
    RamdiskId?: String;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The IDs of the subnets in which to launch the instances. To specify multiple subnets, separate them using commas; for example, "subnet-1234abcdeexample1, subnet-0987cdef6example2".
     */
    SubnetId?: SubnetId;
    /**
     * The base64-encoded user data that instances use when starting up. User data is limited to 16 KB.
     */
    UserData?: SensitiveUserData;
    /**
     * The number of units provided by the specified instance type. These are the same units that you chose to set the target capacity in terms of instances, or a performance characteristic such as vCPUs, memory, or I/O. If the target capacity divided by this value is not a whole number, Amazon EC2 rounds the number of instances to the next whole number. If this value is not specified, the default is 1.
     */
    WeightedCapacity?: Double;
    /**
     * The tags to apply during creation.
     */
    TagSpecifications?: SpotFleetTagSpecificationList;
    /**
     * The attributes for the instance types. When you specify instance attributes, Amazon EC2 will identify instance types with those attributes.  If you specify InstanceRequirements, you can't specify InstanceType. 
     */
    InstanceRequirements?: InstanceRequirements;
  }
  export interface SpotFleetMonitoring {
    /**
     * Enables monitoring for the instance. Default: false 
     */
    Enabled?: Boolean;
  }
  export interface SpotFleetRequestConfig {
    /**
     * The progress of the Spot Fleet request. If there is an error, the status is error. After all requests are placed, the status is pending_fulfillment. If the size of the fleet is equal to or greater than its target capacity, the status is fulfilled. If the size of the fleet is decreased, the status is pending_termination while Spot Instances are terminating.
     */
    ActivityStatus?: ActivityStatus;
    /**
     * The creation date and time of the request.
     */
    CreateTime?: MillisecondDateTime;
    /**
     * The configuration of the Spot Fleet request.
     */
    SpotFleetRequestConfig?: SpotFleetRequestConfigData;
    /**
     * The ID of the Spot Fleet request.
     */
    SpotFleetRequestId?: String;
    /**
     * The state of the Spot Fleet request.
     */
    SpotFleetRequestState?: BatchState;
    /**
     * The tags for a Spot Fleet resource.
     */
    Tags?: TagList;
  }
  export interface SpotFleetRequestConfigData {
    /**
     * The strategy that determines how to allocate the target Spot Instance capacity across the Spot Instance pools specified by the Spot Fleet launch configuration. For more information, see Allocation strategies for Spot Instances in the Amazon EC2 User Guide.  priceCapacityOptimized (recommended)  Spot Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. Spot Fleet then requests Spot Instances from the lowest priced of these pools.  capacityOptimized  Spot Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. To give certain instance types a higher chance of launching first, use capacityOptimizedPrioritized. Set a priority for each instance type by using the Priority parameter for LaunchTemplateOverrides. You can assign the same priority to different LaunchTemplateOverrides. EC2 implements the priorities on a best-effort basis, but optimizes for capacity first. capacityOptimizedPrioritized is supported only if your Spot Fleet uses a launch template. Note that if the OnDemandAllocationStrategy is set to prioritized, the same priority is applied when fulfilling On-Demand capacity.  diversified  Spot Fleet requests instances from all of the Spot Instance pools that you specify.  lowestPrice  Spot Fleet requests instances from the lowest priced Spot Instance pool that has available capacity. If the lowest priced pool doesn't have available capacity, the Spot Instances come from the next lowest priced pool that has available capacity. If a pool runs out of capacity before fulfilling your desired capacity, Spot Fleet will continue to fulfill your request by drawing from the next lowest priced pool. To ensure that your desired capacity is met, you might receive Spot Instances from several pools. Because this strategy only considers instance price and not capacity availability, it might lead to high interruption rates.   Default: lowestPrice 
     */
    AllocationStrategy?: AllocationStrategy;
    /**
     * The order of the launch template overrides to use in fulfilling On-Demand capacity. If you specify lowestPrice, Spot Fleet uses price to determine the order, launching the lowest price first. If you specify prioritized, Spot Fleet uses the priority that you assign to each Spot Fleet launch template override, launching the highest priority first. If you do not specify a value, Spot Fleet defaults to lowestPrice.
     */
    OnDemandAllocationStrategy?: OnDemandAllocationStrategy;
    /**
     * The strategies for managing your Spot Instances that are at an elevated risk of being interrupted.
     */
    SpotMaintenanceStrategies?: SpotMaintenanceStrategies;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of your listings. This helps to avoid duplicate listings. For more information, see Ensuring Idempotency.
     */
    ClientToken?: String;
    /**
     * Indicates whether running instances should be terminated if you decrease the target capacity of the Spot Fleet request below the current size of the Spot Fleet. Supported only for fleets of type maintain.
     */
    ExcessCapacityTerminationPolicy?: ExcessCapacityTerminationPolicy;
    /**
     * The number of units fulfilled by this request compared to the set target capacity. You cannot set this value.
     */
    FulfilledCapacity?: Double;
    /**
     * The number of On-Demand units fulfilled by this request compared to the set target On-Demand capacity.
     */
    OnDemandFulfilledCapacity?: Double;
    /**
     * The Amazon Resource Name (ARN) of an Identity and Access Management (IAM) role that grants the Spot Fleet the permission to request, launch, terminate, and tag instances on your behalf. For more information, see Spot Fleet prerequisites in the Amazon EC2 User Guide. Spot Fleet can terminate Spot Instances on your behalf when you cancel its Spot Fleet request using CancelSpotFleetRequests or when the Spot Fleet request expires, if you set TerminateInstancesWithExpiration.
     */
    IamFleetRole: String;
    /**
     * The launch specifications for the Spot Fleet request. If you specify LaunchSpecifications, you can't specify LaunchTemplateConfigs. If you include On-Demand capacity in your request, you must use LaunchTemplateConfigs.
     */
    LaunchSpecifications?: LaunchSpecsList;
    /**
     * The launch template and overrides. If you specify LaunchTemplateConfigs, you can't specify LaunchSpecifications. If you include On-Demand capacity in your request, you must use LaunchTemplateConfigs.
     */
    LaunchTemplateConfigs?: LaunchTemplateConfigList;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The number of units to request for the Spot Fleet. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is maintain, you can specify a target capacity of 0 and add capacity later.
     */
    TargetCapacity: Integer;
    /**
     * The number of On-Demand units to request. You can choose to set the target capacity in terms of instances or a performance characteristic that is important to your application workload, such as vCPUs, memory, or I/O. If the request type is maintain, you can specify a target capacity of 0 and add capacity later.
     */
    OnDemandTargetCapacity?: Integer;
    /**
     * The maximum amount per hour for On-Demand Instances that you're willing to pay. You can use the onDemandMaxTotalPrice parameter, the spotMaxTotalPrice parameter, or both parameters to ensure that your fleet cost does not exceed your budget. If you set a maximum price per hour for the On-Demand Instances and Spot Instances in your request, Spot Fleet will launch instances until it reaches the maximum amount you're willing to pay. When the maximum amount you're willing to pay is reached, the fleet stops launching instances even if it hasn’t met the target capacity.
     */
    OnDemandMaxTotalPrice?: String;
    /**
     * The maximum amount per hour for Spot Instances that you're willing to pay. You can use the spotdMaxTotalPrice parameter, the onDemandMaxTotalPrice parameter, or both parameters to ensure that your fleet cost does not exceed your budget. If you set a maximum price per hour for the On-Demand Instances and Spot Instances in your request, Spot Fleet will launch instances until it reaches the maximum amount you're willing to pay. When the maximum amount you're willing to pay is reached, the fleet stops launching instances even if it hasn’t met the target capacity.
     */
    SpotMaxTotalPrice?: String;
    /**
     * Indicates whether running Spot Instances are terminated when the Spot Fleet request expires.
     */
    TerminateInstancesWithExpiration?: Boolean;
    /**
     * The type of request. Indicates whether the Spot Fleet only requests the target capacity or also attempts to maintain it. When this value is request, the Spot Fleet only places the required requests. It does not attempt to replenish Spot Instances if capacity is diminished, nor does it submit requests in alternative Spot pools if capacity is not available. When this value is maintain, the Spot Fleet maintains the target capacity. The Spot Fleet places the required requests to meet capacity and automatically replenishes any interrupted instances. Default: maintain. instant is listed but is not used by Spot Fleet.
     */
    Type?: FleetType;
    /**
     * The start date and time of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ). By default, Amazon EC2 starts fulfilling the request immediately.
     */
    ValidFrom?: DateTime;
    /**
     * The end date and time of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ). After the end date and time, no new Spot Instance requests are placed or able to fulfill the request. If no value is specified, the Spot Fleet request remains until you cancel it.
     */
    ValidUntil?: DateTime;
    /**
     * Indicates whether Spot Fleet should replace unhealthy instances.
     */
    ReplaceUnhealthyInstances?: Boolean;
    /**
     * The behavior when a Spot Instance is interrupted. The default is terminate.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
    /**
     * One or more Classic Load Balancers and target groups to attach to the Spot Fleet request. Spot Fleet registers the running Spot Instances with the specified Classic Load Balancers and target groups. With Network Load Balancers, Spot Fleet cannot register instances that have the following instance types: C1, CC1, CC2, CG1, CG2, CR1, CS1, G1, G2, HI1, HS1, M1, M2, M3, and T1.
     */
    LoadBalancersConfig?: LoadBalancersConfig;
    /**
     * The number of Spot pools across which to allocate your target Spot capacity. Valid only when Spot AllocationStrategy is set to lowest-price. Spot Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify. Note that Spot Fleet attempts to draw Spot Instances from the number of pools that you specify on a best effort basis. If a pool runs out of Spot capacity before fulfilling your target capacity, Spot Fleet will continue to fulfill your request by drawing from the next cheapest pool. To ensure that your target capacity is met, you might receive Spot Instances from more than the number of pools that you specified. Similarly, if most of the pools have no Spot capacity, you might receive your full target capacity from fewer than the number of pools that you specified.
     */
    InstancePoolsToUseCount?: Integer;
    /**
     * Reserved.
     */
    Context?: String;
    /**
     * The unit for the target capacity. TargetCapacityUnitType can only be specified when InstanceRequirements is specified. Default: units (translates to number of instances)
     */
    TargetCapacityUnitType?: TargetCapacityUnitType;
    /**
     * The key-value pair for tagging the Spot Fleet request on creation. The value for ResourceType must be spot-fleet-request, otherwise the Spot Fleet request fails. To tag instances at launch, specify the tags in the launch template (valid only if you use LaunchTemplateConfigs) or in the  SpotFleetTagSpecification  (valid only if you use LaunchSpecifications). For information about tagging after launch, see Tagging Your Resources.
     */
    TagSpecifications?: TagSpecificationList;
  }
  export type SpotFleetRequestConfigSet = SpotFleetRequestConfig[];
  export type SpotFleetRequestId = string;
  export type SpotFleetRequestIdList = SpotFleetRequestId[];
  export interface SpotFleetTagSpecification {
    /**
     * The type of resource. Currently, the only resource type that is supported is instance. To tag the Spot Fleet request on creation, use the TagSpecifications parameter in  SpotFleetRequestConfigData .
     */
    ResourceType?: ResourceType;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type SpotFleetTagSpecificationList = SpotFleetTagSpecification[];
  export type SpotInstanceInterruptionBehavior = "hibernate"|"stop"|"terminate"|string;
  export interface SpotInstanceRequest {
    /**
     * Deprecated.
     */
    ActualBlockHourlyPrice?: String;
    /**
     * The Availability Zone group. If you specify the same Availability Zone group for all Spot Instance requests, all Spot Instances are launched in the same Availability Zone.
     */
    AvailabilityZoneGroup?: String;
    /**
     * Deprecated.
     */
    BlockDurationMinutes?: Integer;
    /**
     * The date and time when the Spot Instance request was created, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    CreateTime?: DateTime;
    /**
     * The fault codes for the Spot Instance request, if any.
     */
    Fault?: SpotInstanceStateFault;
    /**
     * The instance ID, if an instance has been launched to fulfill the Spot Instance request.
     */
    InstanceId?: InstanceId;
    /**
     * The instance launch group. Launch groups are Spot Instances that launch together and terminate together.
     */
    LaunchGroup?: String;
    /**
     * Additional information for launching instances.
     */
    LaunchSpecification?: LaunchSpecification;
    /**
     * The Availability Zone in which the request is launched.
     */
    LaunchedAvailabilityZone?: String;
    /**
     * The product description associated with the Spot Instance.
     */
    ProductDescription?: RIProductDescription;
    /**
     * The ID of the Spot Instance request.
     */
    SpotInstanceRequestId?: String;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The state of the Spot Instance request. Spot request status information helps track your Spot Instance requests. For more information, see Spot request status in the Amazon EC2 User Guide for Linux Instances.
     */
    State?: SpotInstanceState;
    /**
     * The status code and status message describing the Spot Instance request.
     */
    Status?: SpotInstanceStatus;
    /**
     * Any tags assigned to the resource.
     */
    Tags?: TagList;
    /**
     * The Spot Instance request type.
     */
    Type?: SpotInstanceType;
    /**
     * The start date of the request, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ). The request becomes active at this date and time.
     */
    ValidFrom?: DateTime;
    /**
     * The end date of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ).   For a persistent request, the request remains active until the validUntil date and time is reached. Otherwise, the request remains active until you cancel it.    For a one-time request, the request remains active until all instances launch, the request is canceled, or the validUntil date and time is reached. By default, the request is valid for 7 days from the date the request was created.  
     */
    ValidUntil?: DateTime;
    /**
     * The behavior when a Spot Instance is interrupted.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
  }
  export type SpotInstanceRequestId = string;
  export type SpotInstanceRequestIdList = SpotInstanceRequestId[];
  export type SpotInstanceRequestList = SpotInstanceRequest[];
  export type SpotInstanceState = "open"|"active"|"closed"|"cancelled"|"failed"|string;
  export interface SpotInstanceStateFault {
    /**
     * The reason code for the Spot Instance state change.
     */
    Code?: String;
    /**
     * The message for the Spot Instance state change.
     */
    Message?: String;
  }
  export interface SpotInstanceStatus {
    /**
     * The status code. For a list of status codes, see Spot request status codes in the Amazon EC2 User Guide for Linux Instances.
     */
    Code?: String;
    /**
     * The description for the status code.
     */
    Message?: String;
    /**
     * The date and time of the most recent status update, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    UpdateTime?: DateTime;
  }
  export type SpotInstanceType = "one-time"|"persistent"|string;
  export interface SpotMaintenanceStrategies {
    /**
     * The Spot Instance replacement strategy to use when Amazon EC2 emits a signal that your Spot Instance is at an elevated risk of being interrupted. For more information, see Capacity rebalancing in the Amazon EC2 User Guide for Linux Instances.
     */
    CapacityRebalance?: SpotCapacityRebalance;
  }
  export interface SpotMarketOptions {
    /**
     * The maximum hourly price that you're willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxPrice?: String;
    /**
     * The Spot Instance request type. For RunInstances, persistent Spot Instance requests are only supported when the instance interruption behavior is either hibernate or stop.
     */
    SpotInstanceType?: SpotInstanceType;
    /**
     * Deprecated.
     */
    BlockDurationMinutes?: Integer;
    /**
     * The end date of the request, in UTC format (YYYY-MM-DDTHH:MM:SSZ). Supported only for persistent requests.   For a persistent request, the request remains active until the ValidUntil date and time is reached. Otherwise, the request remains active until you cancel it.   For a one-time request, ValidUntil is not supported. The request remains active until all instances launch or you cancel the request.  
     */
    ValidUntil?: DateTime;
    /**
     * The behavior when a Spot Instance is interrupted. The default is terminate.
     */
    InstanceInterruptionBehavior?: InstanceInterruptionBehavior;
  }
  export interface SpotOptions {
    /**
     * The strategy that determines how to allocate the target Spot Instance capacity across the Spot Instance pools specified by the EC2 Fleet launch configuration. For more information, see Allocation strategies for Spot Instances in the Amazon EC2 User Guide.  price-capacity-optimized (recommended)  EC2 Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. EC2 Fleet then requests Spot Instances from the lowest priced of these pools.  capacity-optimized  EC2 Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. To give certain instance types a higher chance of launching first, use capacity-optimized-prioritized. Set a priority for each instance type by using the Priority parameter for LaunchTemplateOverrides. You can assign the same priority to different LaunchTemplateOverrides. EC2 implements the priorities on a best-effort basis, but optimizes for capacity first. capacity-optimized-prioritized is supported only if your EC2 Fleet uses a launch template. Note that if the On-Demand AllocationStrategy is set to prioritized, the same priority is applied when fulfilling On-Demand capacity.  diversified  EC2 Fleet requests instances from all of the Spot Instance pools that you specify.  lowest-price  EC2 Fleet requests instances from the lowest priced Spot Instance pool that has available capacity. If the lowest priced pool doesn't have available capacity, the Spot Instances come from the next lowest priced pool that has available capacity. If a pool runs out of capacity before fulfilling your desired capacity, EC2 Fleet will continue to fulfill your request by drawing from the next lowest priced pool. To ensure that your desired capacity is met, you might receive Spot Instances from several pools. Because this strategy only considers instance price and not capacity availability, it might lead to high interruption rates.   Default: lowest-price 
     */
    AllocationStrategy?: SpotAllocationStrategy;
    /**
     * The strategies for managing your workloads on your Spot Instances that will be interrupted. Currently only the capacity rebalance strategy is available.
     */
    MaintenanceStrategies?: FleetSpotMaintenanceStrategies;
    /**
     * The behavior when a Spot Instance is interrupted. Default: terminate 
     */
    InstanceInterruptionBehavior?: SpotInstanceInterruptionBehavior;
    /**
     * The number of Spot pools across which to allocate your target Spot capacity. Supported only when AllocationStrategy is set to lowest-price. EC2 Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify. Note that EC2 Fleet attempts to draw Spot Instances from the number of pools that you specify on a best effort basis. If a pool runs out of Spot capacity before fulfilling your target capacity, EC2 Fleet will continue to fulfill your request by drawing from the next cheapest pool. To ensure that your target capacity is met, you might receive Spot Instances from more than the number of pools that you specified. Similarly, if most of the pools have no Spot capacity, you might receive your full target capacity from fewer than the number of pools that you specified.
     */
    InstancePoolsToUseCount?: Integer;
    /**
     * Indicates that the fleet uses a single instance type to launch all Spot Instances in the fleet. Supported only for fleets of type instant.
     */
    SingleInstanceType?: Boolean;
    /**
     * Indicates that the fleet launches all Spot Instances into a single Availability Zone. Supported only for fleets of type instant.
     */
    SingleAvailabilityZone?: Boolean;
    /**
     * The minimum target capacity for Spot Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances. Supported only for fleets of type instant. At least one of the following must be specified: SingleAvailabilityZone | SingleInstanceType 
     */
    MinTargetCapacity?: Integer;
    /**
     * The maximum amount per hour for Spot Instances that you're willing to pay. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxTotalPrice?: String;
  }
  export interface SpotOptionsRequest {
    /**
     * The strategy that determines how to allocate the target Spot Instance capacity across the Spot Instance pools specified by the EC2 Fleet launch configuration. For more information, see Allocation strategies for Spot Instances in the Amazon EC2 User Guide.  price-capacity-optimized (recommended)  EC2 Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. EC2 Fleet then requests Spot Instances from the lowest priced of these pools.  capacity-optimized  EC2 Fleet identifies the pools with the highest capacity availability for the number of instances that are launching. This means that we will request Spot Instances from the pools that we believe have the lowest chance of interruption in the near term. To give certain instance types a higher chance of launching first, use capacity-optimized-prioritized. Set a priority for each instance type by using the Priority parameter for LaunchTemplateOverrides. You can assign the same priority to different LaunchTemplateOverrides. EC2 implements the priorities on a best-effort basis, but optimizes for capacity first. capacity-optimized-prioritized is supported only if your EC2 Fleet uses a launch template. Note that if the On-Demand AllocationStrategy is set to prioritized, the same priority is applied when fulfilling On-Demand capacity.  diversified  EC2 Fleet requests instances from all of the Spot Instance pools that you specify.  lowest-price  EC2 Fleet requests instances from the lowest priced Spot Instance pool that has available capacity. If the lowest priced pool doesn't have available capacity, the Spot Instances come from the next lowest priced pool that has available capacity. If a pool runs out of capacity before fulfilling your desired capacity, EC2 Fleet will continue to fulfill your request by drawing from the next lowest priced pool. To ensure that your desired capacity is met, you might receive Spot Instances from several pools. Because this strategy only considers instance price and not capacity availability, it might lead to high interruption rates.   Default: lowest-price 
     */
    AllocationStrategy?: SpotAllocationStrategy;
    /**
     * The strategies for managing your Spot Instances that are at an elevated risk of being interrupted.
     */
    MaintenanceStrategies?: FleetSpotMaintenanceStrategiesRequest;
    /**
     * The behavior when a Spot Instance is interrupted. Default: terminate 
     */
    InstanceInterruptionBehavior?: SpotInstanceInterruptionBehavior;
    /**
     * The number of Spot pools across which to allocate your target Spot capacity. Supported only when Spot AllocationStrategy is set to lowest-price. EC2 Fleet selects the cheapest Spot pools and evenly allocates your target Spot capacity across the number of Spot pools that you specify. Note that EC2 Fleet attempts to draw Spot Instances from the number of pools that you specify on a best effort basis. If a pool runs out of Spot capacity before fulfilling your target capacity, EC2 Fleet will continue to fulfill your request by drawing from the next cheapest pool. To ensure that your target capacity is met, you might receive Spot Instances from more than the number of pools that you specified. Similarly, if most of the pools have no Spot capacity, you might receive your full target capacity from fewer than the number of pools that you specified.
     */
    InstancePoolsToUseCount?: Integer;
    /**
     * Indicates that the fleet uses a single instance type to launch all Spot Instances in the fleet. Supported only for fleets of type instant.
     */
    SingleInstanceType?: Boolean;
    /**
     * Indicates that the fleet launches all Spot Instances into a single Availability Zone. Supported only for fleets of type instant.
     */
    SingleAvailabilityZone?: Boolean;
    /**
     * The minimum target capacity for Spot Instances in the fleet. If the minimum target capacity is not reached, the fleet launches no instances. Supported only for fleets of type instant. At least one of the following must be specified: SingleAvailabilityZone | SingleInstanceType 
     */
    MinTargetCapacity?: Integer;
    /**
     * The maximum amount per hour for Spot Instances that you're willing to pay. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your Spot Instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    MaxTotalPrice?: String;
  }
  export interface SpotPlacement {
    /**
     * The Availability Zone. [Spot Fleet only] To specify multiple Availability Zones, separate them using commas; for example, "us-west-2a, us-west-2b".
     */
    AvailabilityZone?: String;
    /**
     * The name of the placement group.
     */
    GroupName?: PlacementGroupName;
    /**
     * The tenancy of the instance (if the instance is running in a VPC). An instance with a tenancy of dedicated runs on single-tenant hardware. The host tenancy is not supported for Spot Instances.
     */
    Tenancy?: Tenancy;
  }
  export interface SpotPlacementScore {
    /**
     * The Region.
     */
    Region?: String;
    /**
     * The Availability Zone.
     */
    AvailabilityZoneId?: String;
    /**
     * The placement score, on a scale from 1 to 10. A score of 10 indicates that your Spot request is highly likely to succeed in this Region or Availability Zone. A score of 1 indicates that your Spot request is not likely to succeed. 
     */
    Score?: Integer;
  }
  export type SpotPlacementScores = SpotPlacementScore[];
  export type SpotPlacementScoresMaxResults = number;
  export type SpotPlacementScoresTargetCapacity = number;
  export interface SpotPrice {
    /**
     * The Availability Zone.
     */
    AvailabilityZone?: String;
    /**
     * The instance type.
     */
    InstanceType?: InstanceType;
    /**
     * A general description of the AMI.
     */
    ProductDescription?: RIProductDescription;
    /**
     * The maximum price per unit hour that you are willing to pay for a Spot Instance. We do not recommend using this parameter because it can lead to increased interruptions. If you do not specify this parameter, you will pay the current Spot price.  If you specify a maximum price, your instances will be interrupted more frequently than if you do not specify this parameter. 
     */
    SpotPrice?: String;
    /**
     * The date and time the request was created, in UTC format (for example, YYYY-MM-DDTHH:MM:SSZ).
     */
    Timestamp?: DateTime;
  }
  export type SpotPriceHistoryList = SpotPrice[];
  export type SpreadLevel = "host"|"rack"|string;
  export interface StaleIpPermission {
    /**
     * The start of the port range for the TCP and UDP protocols, or an ICMP type number. A value of -1 indicates all ICMP types. 
     */
    FromPort?: Integer;
    /**
     * The IP protocol name (for tcp, udp, and icmp) or number (see Protocol Numbers).
     */
    IpProtocol?: String;
    /**
     * The IP ranges. Not applicable for stale security group rules.
     */
    IpRanges?: IpRanges;
    /**
     * The prefix list IDs. Not applicable for stale security group rules.
     */
    PrefixListIds?: PrefixListIdSet;
    /**
     * The end of the port range for the TCP and UDP protocols, or an ICMP type number. A value of -1 indicates all ICMP types. 
     */
    ToPort?: Integer;
    /**
     * The security group pairs. Returns the ID of the referenced security group and VPC, and the ID and status of the VPC peering connection.
     */
    UserIdGroupPairs?: UserIdGroupPairSet;
  }
  export type StaleIpPermissionSet = StaleIpPermission[];
  export interface StaleSecurityGroup {
    /**
     * The description of the security group.
     */
    Description?: String;
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * The name of the security group.
     */
    GroupName?: String;
    /**
     * Information about the stale inbound rules in the security group.
     */
    StaleIpPermissions?: StaleIpPermissionSet;
    /**
     * Information about the stale outbound rules in the security group.
     */
    StaleIpPermissionsEgress?: StaleIpPermissionSet;
    /**
     * The ID of the VPC for the security group.
     */
    VpcId?: String;
  }
  export type StaleSecurityGroupSet = StaleSecurityGroup[];
  export interface StartInstancesRequest {
    /**
     * The IDs of the instances.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Reserved.
     */
    AdditionalInfo?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface StartInstancesResult {
    /**
     * Information about the started instances.
     */
    StartingInstances?: InstanceStateChangeList;
  }
  export interface StartNetworkInsightsAccessScopeAnalysisRequest {
    /**
     * The ID of the Network Access Scope.
     */
    NetworkInsightsAccessScopeId: NetworkInsightsAccessScopeId;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to apply.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken: String;
  }
  export interface StartNetworkInsightsAccessScopeAnalysisResult {
    /**
     * The Network Access Scope analysis.
     */
    NetworkInsightsAccessScopeAnalysis?: NetworkInsightsAccessScopeAnalysis;
  }
  export interface StartNetworkInsightsAnalysisRequest {
    /**
     * The ID of the path.
     */
    NetworkInsightsPathId: NetworkInsightsPathId;
    /**
     * The member accounts that contain resources that the path can traverse.
     */
    AdditionalAccounts?: ValueStringList;
    /**
     * The Amazon Resource Names (ARN) of the resources that the path must traverse.
     */
    FilterInArns?: ArnList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The tags to apply.
     */
    TagSpecifications?: TagSpecificationList;
    /**
     * Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see How to ensure idempotency.
     */
    ClientToken: String;
  }
  export interface StartNetworkInsightsAnalysisResult {
    /**
     * Information about the network insights analysis.
     */
    NetworkInsightsAnalysis?: NetworkInsightsAnalysis;
  }
  export interface StartVpcEndpointServicePrivateDnsVerificationRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the endpoint service.
     */
    ServiceId: VpcEndpointServiceId;
  }
  export interface StartVpcEndpointServicePrivateDnsVerificationResult {
    /**
     * Returns true if the request succeeds; otherwise, it returns an error.
     */
    ReturnValue?: Boolean;
  }
  export type State = "PendingAcceptance"|"Pending"|"Available"|"Deleting"|"Deleted"|"Rejected"|"Failed"|"Expired"|string;
  export interface StateReason {
    /**
     * The reason code for the state change.
     */
    Code?: String;
    /**
     * The message for the state change.    Server.InsufficientInstanceCapacity: There was insufficient capacity available to satisfy the launch request.    Server.InternalError: An internal error caused the instance to terminate during launch.    Server.ScheduledStop: The instance was stopped due to a scheduled retirement.    Server.SpotInstanceShutdown: The instance was stopped because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price.    Server.SpotInstanceTermination: The instance was terminated because the number of Spot requests with a maximum price equal to or higher than the Spot price exceeded available capacity or because of an increase in the Spot price.    Client.InstanceInitiatedShutdown: The instance was shut down using the shutdown -h command from the instance.    Client.InstanceTerminated: The instance was terminated or rebooted during AMI creation.    Client.InternalError: A client error caused the instance to terminate during launch.    Client.InvalidSnapshot.NotFound: The specified snapshot was not found.    Client.UserInitiatedHibernate: Hibernation was initiated on the instance.    Client.UserInitiatedShutdown: The instance was shut down using the Amazon EC2 API.    Client.VolumeLimitExceeded: The limit on the number of EBS volumes or total storage was exceeded. Decrease usage or request an increase in your account limits.  
     */
    Message?: String;
  }
  export type StaticSourcesSupportValue = "enable"|"disable"|string;
  export type StatisticType = "p50"|string;
  export type Status = "MoveInProgress"|"InVpc"|"InClassic"|string;
  export type StatusName = "reachability"|string;
  export type StatusType = "passed"|"failed"|"insufficient-data"|"initializing"|string;
  export interface StopInstancesRequest {
    /**
     * The IDs of the instances.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Hibernates the instance if the instance was enabled for hibernation at launch. If the instance cannot hibernate successfully, a normal shutdown occurs. For more information, see Hibernate your instance in the Amazon EC2 User Guide.  Default: false 
     */
    Hibernate?: Boolean;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * Forces the instances to stop. The instances do not have an opportunity to flush file system caches or file system metadata. If you use this option, you must perform file system check and repair procedures. This option is not recommended for Windows instances. Default: false 
     */
    Force?: Boolean;
  }
  export interface StopInstancesResult {
    /**
     * Information about the stopped instances.
     */
    StoppingInstances?: InstanceStateChangeList;
  }
  export interface Storage {
    /**
     * An Amazon S3 storage location.
     */
    S3?: S3Storage;
  }
  export interface StorageLocation {
    /**
     * The name of the S3 bucket.
     */
    Bucket?: String;
    /**
     * The key.
     */
    Key?: String;
  }
  export type StorageTier = "archive"|"standard"|string;
  export interface StoreImageTaskResult {
    /**
     * The ID of the AMI that is being stored.
     */
    AmiId?: String;
    /**
     * The time the task started.
     */
    TaskStartTime?: MillisecondDateTime;
    /**
     * The name of the Amazon S3 bucket that contains the stored AMI object.
     */
    Bucket?: String;
    /**
     * The name of the stored AMI object in the bucket.
     */
    S3objectKey?: String;
    /**
     * The progress of the task as a percentage.
     */
    ProgressPercentage?: Integer;
    /**
     * The state of the store task (InProgress, Completed, or Failed).
     */
    StoreTaskState?: String;
    /**
     * If the tasks fails, the reason for the failure is returned. If the task succeeds, null is returned.
     */
    StoreTaskFailureReason?: String;
  }
  export type StoreImageTaskResultSet = StoreImageTaskResult[];
  export type String = string;
  export type StringList = String[];
  export type StringType = string;
  export interface Subnet {
    /**
     * The Availability Zone of the subnet.
     */
    AvailabilityZone?: String;
    /**
     * The AZ ID of the subnet.
     */
    AvailabilityZoneId?: String;
    /**
     * The number of unused private IPv4 addresses in the subnet. The IPv4 addresses for any stopped instances are considered unavailable.
     */
    AvailableIpAddressCount?: Integer;
    /**
     * The IPv4 CIDR block assigned to the subnet.
     */
    CidrBlock?: String;
    /**
     * Indicates whether this is the default subnet for the Availability Zone.
     */
    DefaultForAz?: Boolean;
    /**
     *  Indicates the device position for local network interfaces in this subnet. For example, 1 indicates local network interfaces in this subnet are the secondary network interface (eth1). 
     */
    EnableLniAtDeviceIndex?: Integer;
    /**
     * Indicates whether instances launched in this subnet receive a public IPv4 address.
     */
    MapPublicIpOnLaunch?: Boolean;
    /**
     * Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives a customer-owned IPv4 address.
     */
    MapCustomerOwnedIpOnLaunch?: Boolean;
    /**
     * The customer-owned IPv4 address pool associated with the subnet.
     */
    CustomerOwnedIpv4Pool?: CoipPoolId;
    /**
     * The current state of the subnet.
     */
    State?: SubnetState;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
    /**
     * The ID of the VPC the subnet is in.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the subnet.
     */
    OwnerId?: String;
    /**
     * Indicates whether a network interface created in this subnet (including a network interface created by RunInstances) receives an IPv6 address.
     */
    AssignIpv6AddressOnCreation?: Boolean;
    /**
     * Information about the IPv6 CIDR blocks associated with the subnet.
     */
    Ipv6CidrBlockAssociationSet?: SubnetIpv6CidrBlockAssociationSet;
    /**
     * Any tags assigned to the subnet.
     */
    Tags?: TagList;
    /**
     * The Amazon Resource Name (ARN) of the subnet.
     */
    SubnetArn?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * Indicates whether DNS queries made to the Amazon-provided DNS Resolver in this subnet should return synthetic IPv6 addresses for IPv4-only destinations.
     */
    EnableDns64?: Boolean;
    /**
     * Indicates whether this is an IPv6 only subnet.
     */
    Ipv6Native?: Boolean;
    /**
     * The type of hostnames to assign to instances in the subnet at launch. An instance hostname is based on the IPv4 address or ID of the instance.
     */
    PrivateDnsNameOptionsOnLaunch?: PrivateDnsNameOptionsOnLaunch;
  }
  export interface SubnetAssociation {
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
    /**
     * The state of the subnet association.
     */
    State?: TransitGatewayMulitcastDomainAssociationState;
  }
  export type SubnetAssociationList = SubnetAssociation[];
  export type SubnetCidrAssociationId = string;
  export interface SubnetCidrBlockState {
    /**
     * The state of a CIDR block.
     */
    State?: SubnetCidrBlockStateCode;
    /**
     * A message about the status of the CIDR block, if applicable.
     */
    StatusMessage?: String;
  }
  export type SubnetCidrBlockStateCode = "associating"|"associated"|"disassociating"|"disassociated"|"failing"|"failed"|string;
  export interface SubnetCidrReservation {
    /**
     * The ID of the subnet CIDR reservation.
     */
    SubnetCidrReservationId?: SubnetCidrReservationId;
    /**
     * The ID of the subnet.
     */
    SubnetId?: SubnetId;
    /**
     * The CIDR that has been reserved.
     */
    Cidr?: String;
    /**
     * The type of reservation. 
     */
    ReservationType?: SubnetCidrReservationType;
    /**
     * The ID of the account that owns the subnet CIDR reservation. 
     */
    OwnerId?: String;
    /**
     * The description assigned to the subnet CIDR reservation.
     */
    Description?: String;
    /**
     * The tags assigned to the subnet CIDR reservation.
     */
    Tags?: TagList;
  }
  export type SubnetCidrReservationId = string;
  export type SubnetCidrReservationList = SubnetCidrReservation[];
  export type SubnetCidrReservationType = "prefix"|"explicit"|string;
  export type SubnetId = string;
  export type SubnetIdStringList = SubnetId[];
  export interface SubnetIpv6CidrBlockAssociation {
    /**
     * The ID of the association.
     */
    AssociationId?: SubnetCidrAssociationId;
    /**
     * The IPv6 CIDR block.
     */
    Ipv6CidrBlock?: String;
    /**
     * The state of the CIDR block.
     */
    Ipv6CidrBlockState?: SubnetCidrBlockState;
  }
  export type SubnetIpv6CidrBlockAssociationSet = SubnetIpv6CidrBlockAssociation[];
  export type SubnetList = Subnet[];
  export type SubnetState = "pending"|"available"|string;
  export interface Subscription {
    /**
     * The Region or Availability Zone that's the source for the subscription. For example, us-east-1.
     */
    Source?: String;
    /**
     * The Region or Availability Zone that's the target for the subscription. For example, eu-west-1.
     */
    Destination?: String;
    /**
     * The metric used for the subscription.
     */
    Metric?: MetricType;
    /**
     * The statistic used for the subscription.
     */
    Statistic?: StatisticType;
    /**
     * The data aggregation time for the subscription.
     */
    Period?: PeriodType;
  }
  export type SubscriptionList = Subscription[];
  export interface SuccessfulInstanceCreditSpecificationItem {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
  }
  export type SuccessfulInstanceCreditSpecificationSet = SuccessfulInstanceCreditSpecificationItem[];
  export interface SuccessfulQueuedPurchaseDeletion {
    /**
     * The ID of the Reserved Instance.
     */
    ReservedInstancesId?: String;
  }
  export type SuccessfulQueuedPurchaseDeletionSet = SuccessfulQueuedPurchaseDeletion[];
  export type SummaryStatus = "ok"|"impaired"|"insufficient-data"|"not-applicable"|"initializing"|string;
  export type SupportedIpAddressTypes = ServiceConnectivityType[];
  export interface Tag {
    /**
     * The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws:.
     */
    Key?: String;
    /**
     * The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 256 Unicode characters.
     */
    Value?: String;
  }
  export interface TagDescription {
    /**
     * The tag key.
     */
    Key?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The resource type.
     */
    ResourceType?: ResourceType;
    /**
     * The tag value.
     */
    Value?: String;
  }
  export type TagDescriptionList = TagDescription[];
  export type TagList = Tag[];
  export interface TagSpecification {
    /**
     * The type of resource to tag on creation.
     */
    ResourceType?: ResourceType;
    /**
     * The tags to apply to the resource.
     */
    Tags?: TagList;
  }
  export type TagSpecificationList = TagSpecification[];
  export type TaggableResourceId = string;
  export interface TargetCapacitySpecification {
    /**
     * The number of units to request, filled using DefaultTargetCapacityType.
     */
    TotalTargetCapacity?: Integer;
    /**
     * The number of On-Demand units to request. If you specify a target capacity for Spot units, you cannot specify a target capacity for On-Demand units.
     */
    OnDemandTargetCapacity?: Integer;
    /**
     * The maximum number of Spot units to launch. If you specify a target capacity for On-Demand units, you cannot specify a target capacity for Spot units.
     */
    SpotTargetCapacity?: Integer;
    /**
     * The default TotalTargetCapacity, which is either Spot or On-Demand.
     */
    DefaultTargetCapacityType?: DefaultTargetCapacityType;
    /**
     * The unit for the target capacity. TargetCapacityUnitType can only be specified when InstanceRequirements is specified. Default: units (translates to number of instances)
     */
    TargetCapacityUnitType?: TargetCapacityUnitType;
  }
  export interface TargetCapacitySpecificationRequest {
    /**
     * The number of units to request, filled using DefaultTargetCapacityType.
     */
    TotalTargetCapacity: Integer;
    /**
     * The number of On-Demand units to request.
     */
    OnDemandTargetCapacity?: Integer;
    /**
     * The number of Spot units to request.
     */
    SpotTargetCapacity?: Integer;
    /**
     * The default TotalTargetCapacity, which is either Spot or On-Demand.
     */
    DefaultTargetCapacityType?: DefaultTargetCapacityType;
    /**
     * The unit for the target capacity. TargetCapacityUnitType can only be specified when InstanceRequirements is specified. Default: units (translates to number of instances)
     */
    TargetCapacityUnitType?: TargetCapacityUnitType;
  }
  export type TargetCapacityUnitType = "vcpu"|"memory-mib"|"units"|string;
  export interface TargetConfiguration {
    /**
     * The number of instances the Convertible Reserved Instance offering can be applied to. This parameter is reserved and cannot be specified in a request
     */
    InstanceCount?: Integer;
    /**
     * The ID of the Convertible Reserved Instance offering.
     */
    OfferingId?: String;
  }
  export interface TargetConfigurationRequest {
    /**
     * The number of instances the Convertible Reserved Instance offering can be applied to. This parameter is reserved and cannot be specified in a request
     */
    InstanceCount?: Integer;
    /**
     * The Convertible Reserved Instance offering ID.
     */
    OfferingId: ReservedInstancesOfferingId;
  }
  export type TargetConfigurationRequestSet = TargetConfigurationRequest[];
  export interface TargetGroup {
    /**
     * The Amazon Resource Name (ARN) of the target group.
     */
    Arn?: String;
  }
  export type TargetGroups = TargetGroup[];
  export interface TargetGroupsConfig {
    /**
     * One or more target groups.
     */
    TargetGroups?: TargetGroups;
  }
  export interface TargetNetwork {
    /**
     * The ID of the association.
     */
    AssociationId?: String;
    /**
     * The ID of the VPC in which the target network (subnet) is located.
     */
    VpcId?: String;
    /**
     * The ID of the subnet specified as the target network.
     */
    TargetNetworkId?: String;
    /**
     * The ID of the Client VPN endpoint with which the target network is associated.
     */
    ClientVpnEndpointId?: String;
    /**
     * The current state of the target network association.
     */
    Status?: AssociationStatus;
    /**
     * The IDs of the security groups applied to the target network association.
     */
    SecurityGroups?: ValueStringList;
  }
  export type TargetNetworkSet = TargetNetwork[];
  export interface TargetReservationValue {
    /**
     * The total value of the Convertible Reserved Instances that make up the exchange. This is the sum of the list value, remaining upfront price, and additional upfront cost of the exchange.
     */
    ReservationValue?: ReservationValue;
    /**
     * The configuration of the Convertible Reserved Instances that make up the exchange.
     */
    TargetConfiguration?: TargetConfiguration;
  }
  export type TargetReservationValueSet = TargetReservationValue[];
  export type TargetStorageTier = "archive"|string;
  export type TelemetryStatus = "UP"|"DOWN"|string;
  export type Tenancy = "default"|"dedicated"|"host"|string;
  export interface TerminateClientVpnConnectionsRequest {
    /**
     * The ID of the Client VPN endpoint to which the client is connected.
     */
    ClientVpnEndpointId: ClientVpnEndpointId;
    /**
     * The ID of the client connection to be terminated.
     */
    ConnectionId?: VpnConnectionId;
    /**
     * The name of the user who initiated the connection. Use this option to terminate all active connections for the specified user. This option can only be used if the user has established up to five connections.
     */
    Username?: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface TerminateClientVpnConnectionsResult {
    /**
     * The ID of the Client VPN endpoint.
     */
    ClientVpnEndpointId?: String;
    /**
     * The user who established the terminated client connections.
     */
    Username?: String;
    /**
     * The current state of the client connections.
     */
    ConnectionStatuses?: TerminateConnectionStatusSet;
  }
  export interface TerminateConnectionStatus {
    /**
     * The ID of the client connection.
     */
    ConnectionId?: String;
    /**
     * The state of the client connection.
     */
    PreviousStatus?: ClientVpnConnectionStatus;
    /**
     * A message about the status of the client connection, if applicable.
     */
    CurrentStatus?: ClientVpnConnectionStatus;
  }
  export type TerminateConnectionStatusSet = TerminateConnectionStatus[];
  export interface TerminateInstancesRequest {
    /**
     * The IDs of the instances. Constraints: Up to 1000 instance IDs. We recommend breaking up this request into smaller batches.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface TerminateInstancesResult {
    /**
     * Information about the terminated instances.
     */
    TerminatingInstances?: InstanceStateChangeList;
  }
  export type ThreadsPerCore = number;
  export type ThreadsPerCoreList = ThreadsPerCore[];
  export interface ThroughResourcesStatement {
    /**
     * The resource statement.
     */
    ResourceStatement?: ResourceStatement;
  }
  export type ThroughResourcesStatementList = ThroughResourcesStatement[];
  export interface ThroughResourcesStatementRequest {
    /**
     * The resource statement.
     */
    ResourceStatement?: ResourceStatementRequest;
  }
  export type ThroughResourcesStatementRequestList = ThroughResourcesStatementRequest[];
  export type TieringOperationStatus = "archival-in-progress"|"archival-completed"|"archival-failed"|"temporary-restore-in-progress"|"temporary-restore-completed"|"temporary-restore-failed"|"permanent-restore-in-progress"|"permanent-restore-completed"|"permanent-restore-failed"|string;
  export interface TotalLocalStorageGB {
    /**
     * The minimum amount of total local storage, in GB. If this parameter is not specified, there is no minimum limit.
     */
    Min?: Double;
    /**
     * The maximum amount of total local storage, in GB. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Double;
  }
  export interface TotalLocalStorageGBRequest {
    /**
     * The minimum amount of total local storage, in GB. To specify no minimum limit, omit this parameter.
     */
    Min?: Double;
    /**
     * The maximum amount of total local storage, in GB. To specify no maximum limit, omit this parameter.
     */
    Max?: Double;
  }
  export type TpmSupportValues = "v2.0"|string;
  export type TrafficDirection = "ingress"|"egress"|string;
  export interface TrafficMirrorFilter {
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId?: String;
    /**
     * Information about the ingress rules that are associated with the Traffic Mirror filter.
     */
    IngressFilterRules?: TrafficMirrorFilterRuleList;
    /**
     * Information about the egress rules that are associated with the Traffic Mirror filter.
     */
    EgressFilterRules?: TrafficMirrorFilterRuleList;
    /**
     * The network service traffic that is associated with the Traffic Mirror filter.
     */
    NetworkServices?: TrafficMirrorNetworkServiceList;
    /**
     * The description of the Traffic Mirror filter.
     */
    Description?: String;
    /**
     * The tags assigned to the Traffic Mirror filter.
     */
    Tags?: TagList;
  }
  export type TrafficMirrorFilterId = string;
  export type TrafficMirrorFilterIdList = TrafficMirrorFilterId[];
  export interface TrafficMirrorFilterRule {
    /**
     * The ID of the Traffic Mirror rule.
     */
    TrafficMirrorFilterRuleId?: String;
    /**
     * The ID of the Traffic Mirror filter that the rule is associated with.
     */
    TrafficMirrorFilterId?: String;
    /**
     * The traffic direction assigned to the Traffic Mirror rule.
     */
    TrafficDirection?: TrafficDirection;
    /**
     * The rule number of the Traffic Mirror rule.
     */
    RuleNumber?: Integer;
    /**
     * The action assigned to the Traffic Mirror rule.
     */
    RuleAction?: TrafficMirrorRuleAction;
    /**
     * The protocol assigned to the Traffic Mirror rule.
     */
    Protocol?: Integer;
    /**
     * The destination port range assigned to the Traffic Mirror rule.
     */
    DestinationPortRange?: TrafficMirrorPortRange;
    /**
     * The source port range assigned to the Traffic Mirror rule.
     */
    SourcePortRange?: TrafficMirrorPortRange;
    /**
     * The destination CIDR block assigned to the Traffic Mirror rule.
     */
    DestinationCidrBlock?: String;
    /**
     * The source CIDR block assigned to the Traffic Mirror rule.
     */
    SourceCidrBlock?: String;
    /**
     * The description of the Traffic Mirror rule.
     */
    Description?: String;
  }
  export type TrafficMirrorFilterRuleField = "destination-port-range"|"source-port-range"|"protocol"|"description"|string;
  export type TrafficMirrorFilterRuleFieldList = TrafficMirrorFilterRuleField[];
  export type TrafficMirrorFilterRuleIdWithResolver = string;
  export type TrafficMirrorFilterRuleList = TrafficMirrorFilterRule[];
  export type TrafficMirrorFilterSet = TrafficMirrorFilter[];
  export type TrafficMirrorNetworkService = "amazon-dns"|string;
  export type TrafficMirrorNetworkServiceList = TrafficMirrorNetworkService[];
  export interface TrafficMirrorPortRange {
    /**
     * The start of the Traffic Mirror port range. This applies to the TCP and UDP protocols.
     */
    FromPort?: Integer;
    /**
     * The end of the Traffic Mirror port range. This applies to the TCP and UDP protocols.
     */
    ToPort?: Integer;
  }
  export interface TrafficMirrorPortRangeRequest {
    /**
     * The first port in the Traffic Mirror port range. This applies to the TCP and UDP protocols.
     */
    FromPort?: Integer;
    /**
     * The last port in the Traffic Mirror port range. This applies to the TCP and UDP protocols.
     */
    ToPort?: Integer;
  }
  export type TrafficMirrorRuleAction = "accept"|"reject"|string;
  export interface TrafficMirrorSession {
    /**
     * The ID for the Traffic Mirror session.
     */
    TrafficMirrorSessionId?: String;
    /**
     * The ID of the Traffic Mirror target.
     */
    TrafficMirrorTargetId?: String;
    /**
     * The ID of the Traffic Mirror filter.
     */
    TrafficMirrorFilterId?: String;
    /**
     * The ID of the Traffic Mirror session's network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The ID of the account that owns the Traffic Mirror session.
     */
    OwnerId?: String;
    /**
     * The number of bytes in each packet to mirror. These are the bytes after the VXLAN header. To mirror a subset, set this to the length (in bytes) to mirror. For example, if you set this value to 100, then the first 100 bytes that meet the filter criteria are copied to the target. Do not specify this parameter when you want to mirror the entire packet
     */
    PacketLength?: Integer;
    /**
     * The session number determines the order in which sessions are evaluated when an interface is used by multiple sessions. The first session with a matching filter is the one that mirrors the packets. Valid values are 1-32766.
     */
    SessionNumber?: Integer;
    /**
     * The virtual network ID associated with the Traffic Mirror session.
     */
    VirtualNetworkId?: Integer;
    /**
     * The description of the Traffic Mirror session.
     */
    Description?: String;
    /**
     * The tags assigned to the Traffic Mirror session.
     */
    Tags?: TagList;
  }
  export type TrafficMirrorSessionField = "packet-length"|"description"|"virtual-network-id"|string;
  export type TrafficMirrorSessionFieldList = TrafficMirrorSessionField[];
  export type TrafficMirrorSessionId = string;
  export type TrafficMirrorSessionIdList = TrafficMirrorSessionId[];
  export type TrafficMirrorSessionSet = TrafficMirrorSession[];
  export interface TrafficMirrorTarget {
    /**
     * The ID of the Traffic Mirror target.
     */
    TrafficMirrorTargetId?: String;
    /**
     * The network interface ID that is attached to the target.
     */
    NetworkInterfaceId?: String;
    /**
     * The Amazon Resource Name (ARN) of the Network Load Balancer.
     */
    NetworkLoadBalancerArn?: String;
    /**
     * The type of Traffic Mirror target.
     */
    Type?: TrafficMirrorTargetType;
    /**
     * Information about the Traffic Mirror target.
     */
    Description?: String;
    /**
     * The ID of the account that owns the Traffic Mirror target.
     */
    OwnerId?: String;
    /**
     * The tags assigned to the Traffic Mirror target.
     */
    Tags?: TagList;
    /**
     * The ID of the Gateway Load Balancer endpoint.
     */
    GatewayLoadBalancerEndpointId?: String;
  }
  export type TrafficMirrorTargetId = string;
  export type TrafficMirrorTargetIdList = TrafficMirrorTargetId[];
  export type TrafficMirrorTargetSet = TrafficMirrorTarget[];
  export type TrafficMirrorTargetType = "network-interface"|"network-load-balancer"|"gateway-load-balancer-endpoint"|string;
  export type TrafficMirroringMaxResults = number;
  export type TrafficType = "ACCEPT"|"REJECT"|"ALL"|string;
  export type TransitAssociationGatewayId = string;
  export interface TransitGateway {
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The Amazon Resource Name (ARN) of the transit gateway.
     */
    TransitGatewayArn?: String;
    /**
     * The state of the transit gateway.
     */
    State?: TransitGatewayState;
    /**
     * The ID of the Amazon Web Services account that owns the transit gateway.
     */
    OwnerId?: String;
    /**
     * The description of the transit gateway.
     */
    Description?: String;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * The transit gateway options.
     */
    Options?: TransitGatewayOptions;
    /**
     * The tags for the transit gateway.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayAssociation {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId?: TransitGatewayRouteTableId;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The state of the association.
     */
    State?: TransitGatewayAssociationState;
  }
  export type TransitGatewayAssociationState = "associating"|"associated"|"disassociating"|"disassociated"|string;
  export interface TransitGatewayAttachment {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the transit gateway.
     */
    TransitGatewayOwnerId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the resource.
     */
    ResourceOwnerId?: String;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The attachment state. Note that the initiating state has been deprecated.
     */
    State?: TransitGatewayAttachmentState;
    /**
     * The association.
     */
    Association?: TransitGatewayAttachmentAssociation;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * The tags for the attachment.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayAttachmentAssociation {
    /**
     * The ID of the route table for the transit gateway.
     */
    TransitGatewayRouteTableId?: String;
    /**
     * The state of the association.
     */
    State?: TransitGatewayAssociationState;
  }
  export interface TransitGatewayAttachmentBgpConfiguration {
    /**
     * The transit gateway Autonomous System Number (ASN).
     */
    TransitGatewayAsn?: Long;
    /**
     * The peer Autonomous System Number (ASN).
     */
    PeerAsn?: Long;
    /**
     * The interior BGP peer IP address for the transit gateway.
     */
    TransitGatewayAddress?: String;
    /**
     * The interior BGP peer IP address for the appliance.
     */
    PeerAddress?: String;
    /**
     * The BGP status.
     */
    BgpStatus?: BgpStatus;
  }
  export type TransitGatewayAttachmentBgpConfigurationList = TransitGatewayAttachmentBgpConfiguration[];
  export type TransitGatewayAttachmentId = string;
  export type TransitGatewayAttachmentIdStringList = TransitGatewayAttachmentId[];
  export type TransitGatewayAttachmentList = TransitGatewayAttachment[];
  export interface TransitGatewayAttachmentPropagation {
    /**
     * The ID of the propagation route table.
     */
    TransitGatewayRouteTableId?: String;
    /**
     * The state of the propagation route table.
     */
    State?: TransitGatewayPropagationState;
  }
  export type TransitGatewayAttachmentPropagationList = TransitGatewayAttachmentPropagation[];
  export type TransitGatewayAttachmentResourceType = "vpc"|"vpn"|"direct-connect-gateway"|"connect"|"peering"|"tgw-peering"|string;
  export type TransitGatewayAttachmentState = "initiating"|"initiatingRequest"|"pendingAcceptance"|"rollingBack"|"pending"|"available"|"modifying"|"deleting"|"deleted"|"failed"|"rejected"|"rejecting"|"failing"|string;
  export type TransitGatewayCidrBlockStringList = String[];
  export interface TransitGatewayConnect {
    /**
     * The ID of the Connect attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The ID of the attachment from which the Connect attachment was created.
     */
    TransportTransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The state of the attachment.
     */
    State?: TransitGatewayAttachmentState;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * The Connect attachment options.
     */
    Options?: TransitGatewayConnectOptions;
    /**
     * The tags for the attachment.
     */
    Tags?: TagList;
  }
  export type TransitGatewayConnectList = TransitGatewayConnect[];
  export interface TransitGatewayConnectOptions {
    /**
     * The tunnel protocol.
     */
    Protocol?: ProtocolValue;
  }
  export interface TransitGatewayConnectPeer {
    /**
     * The ID of the Connect attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The ID of the Connect peer.
     */
    TransitGatewayConnectPeerId?: TransitGatewayConnectPeerId;
    /**
     * The state of the Connect peer.
     */
    State?: TransitGatewayConnectPeerState;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * The Connect peer details.
     */
    ConnectPeerConfiguration?: TransitGatewayConnectPeerConfiguration;
    /**
     * The tags for the Connect peer.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayConnectPeerConfiguration {
    /**
     * The Connect peer IP address on the transit gateway side of the tunnel.
     */
    TransitGatewayAddress?: String;
    /**
     * The Connect peer IP address on the appliance side of the tunnel.
     */
    PeerAddress?: String;
    /**
     * The range of interior BGP peer IP addresses.
     */
    InsideCidrBlocks?: InsideCidrBlocksStringList;
    /**
     * The tunnel protocol.
     */
    Protocol?: ProtocolValue;
    /**
     * The BGP configuration details.
     */
    BgpConfigurations?: TransitGatewayAttachmentBgpConfigurationList;
  }
  export type TransitGatewayConnectPeerId = string;
  export type TransitGatewayConnectPeerIdStringList = TransitGatewayConnectPeerId[];
  export type TransitGatewayConnectPeerList = TransitGatewayConnectPeer[];
  export type TransitGatewayConnectPeerState = "pending"|"available"|"deleting"|"deleted"|string;
  export interface TransitGatewayConnectRequestBgpOptions {
    /**
     * The peer Autonomous System Number (ASN).
     */
    PeerAsn?: Long;
  }
  export type TransitGatewayId = string;
  export type TransitGatewayIdStringList = TransitGatewayId[];
  export type TransitGatewayList = TransitGateway[];
  export type TransitGatewayMaxResults = number;
  export type TransitGatewayMulitcastDomainAssociationState = "pendingAcceptance"|"associating"|"associated"|"disassociating"|"disassociated"|"rejected"|"failed"|string;
  export interface TransitGatewayMulticastDeregisteredGroupMembers {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The network interface IDs of the deregistered members.
     */
    DeregisteredNetworkInterfaceIds?: ValueStringList;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
  }
  export interface TransitGatewayMulticastDeregisteredGroupSources {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The network interface IDs of the non-registered members.
     */
    DeregisteredNetworkInterfaceIds?: ValueStringList;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
  }
  export interface TransitGatewayMulticastDomain {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The Amazon Resource Name (ARN) of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainArn?: String;
    /**
     *  The ID of the Amazon Web Services account that owns the transit gateway multicast domain.
     */
    OwnerId?: String;
    /**
     * The options for the transit gateway multicast domain.
     */
    Options?: TransitGatewayMulticastDomainOptions;
    /**
     * The state of the transit gateway multicast domain.
     */
    State?: TransitGatewayMulticastDomainState;
    /**
     * The time the transit gateway multicast domain was created.
     */
    CreationTime?: DateTime;
    /**
     * The tags for the transit gateway multicast domain.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayMulticastDomainAssociation {
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The type of resource, for example a VPC attachment.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     *  The ID of the Amazon Web Services account that owns the transit gateway multicast domain association resource.
     */
    ResourceOwnerId?: String;
    /**
     * The subnet associated with the transit gateway multicast domain.
     */
    Subnet?: SubnetAssociation;
  }
  export type TransitGatewayMulticastDomainAssociationList = TransitGatewayMulticastDomainAssociation[];
  export interface TransitGatewayMulticastDomainAssociations {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The type of resource, for example a VPC attachment.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     *  The ID of the Amazon Web Services account that owns the resource.
     */
    ResourceOwnerId?: String;
    /**
     * The subnets associated with the multicast domain.
     */
    Subnets?: SubnetAssociationList;
  }
  export type TransitGatewayMulticastDomainId = string;
  export type TransitGatewayMulticastDomainIdStringList = TransitGatewayMulticastDomainId[];
  export type TransitGatewayMulticastDomainList = TransitGatewayMulticastDomain[];
  export interface TransitGatewayMulticastDomainOptions {
    /**
     * Indicates whether Internet Group Management Protocol (IGMP) version 2 is turned on for the transit gateway multicast domain.
     */
    Igmpv2Support?: Igmpv2SupportValue;
    /**
     * Indicates whether support for statically configuring transit gateway multicast group sources is turned on.
     */
    StaticSourcesSupport?: StaticSourcesSupportValue;
    /**
     * Indicates whether to automatically cross-account subnet associations that are associated with the transit gateway multicast domain.
     */
    AutoAcceptSharedAssociations?: AutoAcceptSharedAssociationsValue;
  }
  export type TransitGatewayMulticastDomainState = "pending"|"available"|"deleting"|"deleted"|string;
  export interface TransitGatewayMulticastGroup {
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the subnet.
     */
    SubnetId?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The type of resource, for example a VPC attachment.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     *  The ID of the Amazon Web Services account that owns the transit gateway multicast domain group resource.
     */
    ResourceOwnerId?: String;
    /**
     * The ID of the transit gateway attachment.
     */
    NetworkInterfaceId?: String;
    /**
     * Indicates that the resource is a transit gateway multicast group member.
     */
    GroupMember?: Boolean;
    /**
     * Indicates that the resource is a transit gateway multicast group member.
     */
    GroupSource?: Boolean;
    /**
     * The member type (for example, static).
     */
    MemberType?: MembershipType;
    /**
     * The source type.
     */
    SourceType?: MembershipType;
  }
  export type TransitGatewayMulticastGroupList = TransitGatewayMulticastGroup[];
  export interface TransitGatewayMulticastRegisteredGroupMembers {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The ID of the registered network interfaces.
     */
    RegisteredNetworkInterfaceIds?: ValueStringList;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
  }
  export interface TransitGatewayMulticastRegisteredGroupSources {
    /**
     * The ID of the transit gateway multicast domain.
     */
    TransitGatewayMulticastDomainId?: String;
    /**
     * The IDs of the network interfaces members registered with the transit gateway multicast group.
     */
    RegisteredNetworkInterfaceIds?: ValueStringList;
    /**
     * The IP address assigned to the transit gateway multicast group.
     */
    GroupIpAddress?: String;
  }
  export type TransitGatewayNetworkInterfaceIdList = NetworkInterfaceId[];
  export interface TransitGatewayOptions {
    /**
     * A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs.
     */
    AmazonSideAsn?: Long;
    /**
     * The transit gateway CIDR blocks.
     */
    TransitGatewayCidrBlocks?: ValueStringList;
    /**
     * Indicates whether attachment requests are automatically accepted.
     */
    AutoAcceptSharedAttachments?: AutoAcceptSharedAttachmentsValue;
    /**
     * Indicates whether resource attachments are automatically associated with the default association route table.
     */
    DefaultRouteTableAssociation?: DefaultRouteTableAssociationValue;
    /**
     * The ID of the default association route table.
     */
    AssociationDefaultRouteTableId?: String;
    /**
     * Indicates whether resource attachments automatically propagate routes to the default propagation route table.
     */
    DefaultRouteTablePropagation?: DefaultRouteTablePropagationValue;
    /**
     * The ID of the default propagation route table.
     */
    PropagationDefaultRouteTableId?: String;
    /**
     * Indicates whether Equal Cost Multipath Protocol support is enabled.
     */
    VpnEcmpSupport?: VpnEcmpSupportValue;
    /**
     * Indicates whether DNS support is enabled.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Indicates whether multicast is enabled on the transit gateway
     */
    MulticastSupport?: MulticastSupportValue;
  }
  export interface TransitGatewayPeeringAttachment {
    /**
     * The ID of the transit gateway peering attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the accepter transit gateway attachment.
     */
    AccepterTransitGatewayAttachmentId?: String;
    /**
     * Information about the requester transit gateway.
     */
    RequesterTgwInfo?: PeeringTgwInfo;
    /**
     * Information about the accepter transit gateway.
     */
    AccepterTgwInfo?: PeeringTgwInfo;
    /**
     * Details about the transit gateway peering attachment.
     */
    Options?: TransitGatewayPeeringAttachmentOptions;
    /**
     * The status of the transit gateway peering attachment.
     */
    Status?: PeeringAttachmentStatus;
    /**
     * The state of the transit gateway peering attachment. Note that the initiating state has been deprecated.
     */
    State?: TransitGatewayAttachmentState;
    /**
     * The time the transit gateway peering attachment was created.
     */
    CreationTime?: DateTime;
    /**
     * The tags for the transit gateway peering attachment.
     */
    Tags?: TagList;
  }
  export type TransitGatewayPeeringAttachmentList = TransitGatewayPeeringAttachment[];
  export interface TransitGatewayPeeringAttachmentOptions {
    /**
     * Describes whether dynamic routing is enabled or disabled for the transit gateway peering attachment.
     */
    DynamicRouting?: DynamicRoutingValue;
  }
  export interface TransitGatewayPolicyRule {
    /**
     * The source CIDR block for the transit gateway policy rule.
     */
    SourceCidrBlock?: String;
    /**
     * The port range for the transit gateway policy rule. Currently this is set to * (all).
     */
    SourcePortRange?: String;
    /**
     * The destination CIDR block for the transit gateway policy rule.
     */
    DestinationCidrBlock?: String;
    /**
     * The port range for the transit gateway policy rule. Currently this is set to * (all).
     */
    DestinationPortRange?: String;
    /**
     * The protocol used by the transit gateway policy rule.
     */
    Protocol?: String;
    /**
     * The meta data tags used for the transit gateway policy rule.
     */
    MetaData?: TransitGatewayPolicyRuleMetaData;
  }
  export interface TransitGatewayPolicyRuleMetaData {
    /**
     * The key name for the transit gateway policy rule meta data tag.
     */
    MetaDataKey?: String;
    /**
     * The value of the key for the transit gateway policy rule meta data tag.
     */
    MetaDataValue?: String;
  }
  export interface TransitGatewayPolicyTable {
    /**
     * The ID of the transit gateway policy table.
     */
    TransitGatewayPolicyTableId?: TransitGatewayPolicyTableId;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The state of the transit gateway policy table
     */
    State?: TransitGatewayPolicyTableState;
    /**
     * The timestamp when the transit gateway policy table was created.
     */
    CreationTime?: DateTime;
    /**
     * he key-value pairs associated with the transit gateway policy table.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayPolicyTableAssociation {
    /**
     * The ID of the transit gateway policy table.
     */
    TransitGatewayPolicyTableId?: TransitGatewayPolicyTableId;
    /**
     * The ID of the transit gateway attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The resource ID of the transit gateway attachment.
     */
    ResourceId?: String;
    /**
     * The resource type for the transit gateway policy table association.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The state of the transit gateway policy table association.
     */
    State?: TransitGatewayAssociationState;
  }
  export type TransitGatewayPolicyTableAssociationList = TransitGatewayPolicyTableAssociation[];
  export interface TransitGatewayPolicyTableEntry {
    /**
     * The rule number for the transit gateway policy table entry.
     */
    PolicyRuleNumber?: String;
    /**
     * The policy rule associated with the transit gateway policy table.
     */
    PolicyRule?: TransitGatewayPolicyRule;
    /**
     * The ID of the target route table.
     */
    TargetRouteTableId?: TransitGatewayRouteTableId;
  }
  export type TransitGatewayPolicyTableEntryList = TransitGatewayPolicyTableEntry[];
  export type TransitGatewayPolicyTableId = string;
  export type TransitGatewayPolicyTableIdStringList = TransitGatewayPolicyTableId[];
  export type TransitGatewayPolicyTableList = TransitGatewayPolicyTable[];
  export type TransitGatewayPolicyTableState = "pending"|"available"|"deleting"|"deleted"|string;
  export interface TransitGatewayPrefixListAttachment {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
  }
  export interface TransitGatewayPrefixListReference {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId?: TransitGatewayRouteTableId;
    /**
     * The ID of the prefix list.
     */
    PrefixListId?: PrefixListResourceId;
    /**
     * The ID of the prefix list owner.
     */
    PrefixListOwnerId?: String;
    /**
     * The state of the prefix list reference.
     */
    State?: TransitGatewayPrefixListReferenceState;
    /**
     * Indicates whether traffic that matches this route is dropped.
     */
    Blackhole?: Boolean;
    /**
     * Information about the transit gateway attachment.
     */
    TransitGatewayAttachment?: TransitGatewayPrefixListAttachment;
  }
  export type TransitGatewayPrefixListReferenceSet = TransitGatewayPrefixListReference[];
  export type TransitGatewayPrefixListReferenceState = "pending"|"available"|"modifying"|"deleting"|string;
  export interface TransitGatewayPropagation {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId?: String;
    /**
     * The state.
     */
    State?: TransitGatewayPropagationState;
    /**
     * The ID of the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
  }
  export type TransitGatewayPropagationState = "enabling"|"enabled"|"disabling"|"disabled"|string;
  export interface TransitGatewayRequestOptions {
    /**
     * A private Autonomous System Number (ASN) for the Amazon side of a BGP session. The range is 64512 to 65534 for 16-bit ASNs and 4200000000 to 4294967294 for 32-bit ASNs. The default is 64512.
     */
    AmazonSideAsn?: Long;
    /**
     * Enable or disable automatic acceptance of attachment requests. Disabled by default.
     */
    AutoAcceptSharedAttachments?: AutoAcceptSharedAttachmentsValue;
    /**
     * Enable or disable automatic association with the default association route table. Enabled by default.
     */
    DefaultRouteTableAssociation?: DefaultRouteTableAssociationValue;
    /**
     * Enable or disable automatic propagation of routes to the default propagation route table. Enabled by default.
     */
    DefaultRouteTablePropagation?: DefaultRouteTablePropagationValue;
    /**
     * Enable or disable Equal Cost Multipath Protocol support. Enabled by default.
     */
    VpnEcmpSupport?: VpnEcmpSupportValue;
    /**
     * Enable or disable DNS support. Enabled by default.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Indicates whether multicast is enabled on the transit gateway
     */
    MulticastSupport?: MulticastSupportValue;
    /**
     * One or more IPv4 or IPv6 CIDR blocks for the transit gateway. Must be a size /24 CIDR block or larger for IPv4, or a size /64 CIDR block or larger for IPv6.
     */
    TransitGatewayCidrBlocks?: TransitGatewayCidrBlockStringList;
  }
  export interface TransitGatewayRoute {
    /**
     * The CIDR block used for destination matches.
     */
    DestinationCidrBlock?: String;
    /**
     * The ID of the prefix list used for destination matches.
     */
    PrefixListId?: PrefixListResourceId;
    /**
     * The ID of the transit gateway route table announcement. 
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
    /**
     * The attachments.
     */
    TransitGatewayAttachments?: TransitGatewayRouteAttachmentList;
    /**
     * The route type.
     */
    Type?: TransitGatewayRouteType;
    /**
     * The state of the route.
     */
    State?: TransitGatewayRouteState;
  }
  export interface TransitGatewayRouteAttachment {
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated. 
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
  }
  export type TransitGatewayRouteAttachmentList = TransitGatewayRouteAttachment[];
  export type TransitGatewayRouteList = TransitGatewayRoute[];
  export type TransitGatewayRouteState = "pending"|"active"|"blackhole"|"deleting"|"deleted"|string;
  export interface TransitGatewayRouteTable {
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId?: String;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The state of the transit gateway route table.
     */
    State?: TransitGatewayRouteTableState;
    /**
     * Indicates whether this is the default association route table for the transit gateway.
     */
    DefaultAssociationRouteTable?: Boolean;
    /**
     * Indicates whether this is the default propagation route table for the transit gateway.
     */
    DefaultPropagationRouteTable?: Boolean;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * Any tags assigned to the route table.
     */
    Tags?: TagList;
  }
  export interface TransitGatewayRouteTableAnnouncement {
    /**
     * The ID of the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the core network for the transit gateway route table announcement.
     */
    CoreNetworkId?: String;
    /**
     * The ID of the peer transit gateway.
     */
    PeerTransitGatewayId?: TransitGatewayId;
    /**
     * The ID of the core network ID for the peer.
     */
    PeerCoreNetworkId?: String;
    /**
     * The ID of the peering attachment.
     */
    PeeringAttachmentId?: TransitGatewayAttachmentId;
    /**
     * The direction for the route table announcement.
     */
    AnnouncementDirection?: TransitGatewayRouteTableAnnouncementDirection;
    /**
     * The ID of the transit gateway route table.
     */
    TransitGatewayRouteTableId?: TransitGatewayRouteTableId;
    /**
     * The state of the transit gateway announcement.
     */
    State?: TransitGatewayRouteTableAnnouncementState;
    /**
     * The timestamp when the transit gateway route table announcement was created.
     */
    CreationTime?: DateTime;
    /**
     * The key-value pairs associated with the route table announcement.
     */
    Tags?: TagList;
  }
  export type TransitGatewayRouteTableAnnouncementDirection = "outgoing"|"incoming"|string;
  export type TransitGatewayRouteTableAnnouncementId = string;
  export type TransitGatewayRouteTableAnnouncementIdStringList = TransitGatewayRouteTableAnnouncementId[];
  export type TransitGatewayRouteTableAnnouncementList = TransitGatewayRouteTableAnnouncement[];
  export type TransitGatewayRouteTableAnnouncementState = "available"|"pending"|"failing"|"failed"|"deleting"|"deleted"|string;
  export interface TransitGatewayRouteTableAssociation {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The resource type. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The state of the association.
     */
    State?: TransitGatewayAssociationState;
  }
  export type TransitGatewayRouteTableAssociationList = TransitGatewayRouteTableAssociation[];
  export type TransitGatewayRouteTableId = string;
  export type TransitGatewayRouteTableIdStringList = TransitGatewayRouteTableId[];
  export type TransitGatewayRouteTableList = TransitGatewayRouteTable[];
  export interface TransitGatewayRouteTablePropagation {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
    /**
     * The type of resource. Note that the tgw-peering resource type has been deprecated.
     */
    ResourceType?: TransitGatewayAttachmentResourceType;
    /**
     * The state of the resource.
     */
    State?: TransitGatewayPropagationState;
    /**
     * The ID of the transit gateway route table announcement.
     */
    TransitGatewayRouteTableAnnouncementId?: TransitGatewayRouteTableAnnouncementId;
  }
  export type TransitGatewayRouteTablePropagationList = TransitGatewayRouteTablePropagation[];
  export interface TransitGatewayRouteTableRoute {
    /**
     * The CIDR block used for destination matches.
     */
    DestinationCidr?: String;
    /**
     * The state of the route.
     */
    State?: String;
    /**
     * The route origin. The following are the possible values:   static   propagated  
     */
    RouteOrigin?: String;
    /**
     * The ID of the prefix list.
     */
    PrefixListId?: String;
    /**
     * The ID of the route attachment.
     */
    AttachmentId?: String;
    /**
     * The ID of the resource for the route attachment.
     */
    ResourceId?: String;
    /**
     * The resource type for the route attachment.
     */
    ResourceType?: String;
  }
  export type TransitGatewayRouteTableState = "pending"|"available"|"deleting"|"deleted"|string;
  export type TransitGatewayRouteType = "static"|"propagated"|string;
  export type TransitGatewayState = "pending"|"available"|"modifying"|"deleting"|"deleted"|string;
  export type TransitGatewaySubnetIdList = SubnetId[];
  export interface TransitGatewayVpcAttachment {
    /**
     * The ID of the attachment.
     */
    TransitGatewayAttachmentId?: String;
    /**
     * The ID of the transit gateway.
     */
    TransitGatewayId?: String;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the VPC.
     */
    VpcOwnerId?: String;
    /**
     * The state of the VPC attachment. Note that the initiating state has been deprecated.
     */
    State?: TransitGatewayAttachmentState;
    /**
     * The IDs of the subnets.
     */
    SubnetIds?: ValueStringList;
    /**
     * The creation time.
     */
    CreationTime?: DateTime;
    /**
     * The VPC attachment options.
     */
    Options?: TransitGatewayVpcAttachmentOptions;
    /**
     * The tags for the VPC attachment.
     */
    Tags?: TagList;
  }
  export type TransitGatewayVpcAttachmentList = TransitGatewayVpcAttachment[];
  export interface TransitGatewayVpcAttachmentOptions {
    /**
     * Indicates whether DNS support is enabled.
     */
    DnsSupport?: DnsSupportValue;
    /**
     * Indicates whether IPv6 support is disabled.
     */
    Ipv6Support?: Ipv6SupportValue;
    /**
     * Indicates whether appliance mode support is enabled.
     */
    ApplianceModeSupport?: ApplianceModeSupportValue;
  }
  export type TransportProtocol = "tcp"|"udp"|string;
  export interface TrunkInterfaceAssociation {
    /**
     * The ID of the association.
     */
    AssociationId?: TrunkInterfaceAssociationId;
    /**
     * The ID of the branch network interface.
     */
    BranchInterfaceId?: String;
    /**
     * The ID of the trunk network interface.
     */
    TrunkInterfaceId?: String;
    /**
     * The interface protocol. Valid values are VLAN and GRE.
     */
    InterfaceProtocol?: InterfaceProtocolType;
    /**
     * The ID of the VLAN when you use the VLAN protocol.
     */
    VlanId?: Integer;
    /**
     * The application key when you use the GRE protocol.
     */
    GreKey?: Integer;
    /**
     * The tags for the trunk interface association.
     */
    Tags?: TagList;
  }
  export type TrunkInterfaceAssociationId = string;
  export type TrunkInterfaceAssociationIdList = TrunkInterfaceAssociationId[];
  export type TrunkInterfaceAssociationList = TrunkInterfaceAssociation[];
  export type TrustProviderType = "user"|"device"|string;
  export type TunnelInsideIpVersion = "ipv4"|"ipv6"|string;
  export interface TunnelOption {
    /**
     * The external IP address of the VPN tunnel.
     */
    OutsideIpAddress?: String;
    /**
     * The range of inside IPv4 addresses for the tunnel.
     */
    TunnelInsideCidr?: String;
    /**
     * The range of inside IPv6 addresses for the tunnel.
     */
    TunnelInsideIpv6Cidr?: String;
    /**
     * The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and the customer gateway.
     */
    PreSharedKey?: String;
    /**
     * The lifetime for phase 1 of the IKE negotiation, in seconds.
     */
    Phase1LifetimeSeconds?: Integer;
    /**
     * The lifetime for phase 2 of the IKE negotiation, in seconds.
     */
    Phase2LifetimeSeconds?: Integer;
    /**
     * The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey.
     */
    RekeyMarginTimeSeconds?: Integer;
    /**
     * The percentage of the rekey window determined by RekeyMarginTimeSeconds during which the rekey time is randomly selected.
     */
    RekeyFuzzPercentage?: Integer;
    /**
     * The number of packets in an IKE replay window.
     */
    ReplayWindowSize?: Integer;
    /**
     * The number of seconds after which a DPD timeout occurs.
     */
    DpdTimeoutSeconds?: Integer;
    /**
     * The action to take after a DPD timeout occurs.
     */
    DpdTimeoutAction?: String;
    /**
     * The permitted encryption algorithms for the VPN tunnel for phase 1 IKE negotiations.
     */
    Phase1EncryptionAlgorithms?: Phase1EncryptionAlgorithmsList;
    /**
     * The permitted encryption algorithms for the VPN tunnel for phase 2 IKE negotiations.
     */
    Phase2EncryptionAlgorithms?: Phase2EncryptionAlgorithmsList;
    /**
     * The permitted integrity algorithms for the VPN tunnel for phase 1 IKE negotiations.
     */
    Phase1IntegrityAlgorithms?: Phase1IntegrityAlgorithmsList;
    /**
     * The permitted integrity algorithms for the VPN tunnel for phase 2 IKE negotiations.
     */
    Phase2IntegrityAlgorithms?: Phase2IntegrityAlgorithmsList;
    /**
     * The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 1 IKE negotiations.
     */
    Phase1DHGroupNumbers?: Phase1DHGroupNumbersList;
    /**
     * The permitted Diffie-Hellman group numbers for the VPN tunnel for phase 2 IKE negotiations.
     */
    Phase2DHGroupNumbers?: Phase2DHGroupNumbersList;
    /**
     * The IKE versions that are permitted for the VPN tunnel.
     */
    IkeVersions?: IKEVersionsList;
    /**
     * The action to take when the establishing the VPN tunnels for a VPN connection.
     */
    StartupAction?: String;
    /**
     * Options for logging VPN tunnel activity.
     */
    LogOptions?: VpnTunnelLogOptions;
    /**
     * Status of tunnel endpoint lifecycle control feature.
     */
    EnableTunnelLifecycleControl?: Boolean;
  }
  export type TunnelOptionsList = TunnelOption[];
  export interface UnassignIpv6AddressesRequest {
    /**
     * The IPv6 addresses to unassign from the network interface.
     */
    Ipv6Addresses?: Ipv6AddressList;
    /**
     * The IPv6 prefixes to unassign from the network interface.
     */
    Ipv6Prefixes?: IpPrefixList;
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
  }
  export interface UnassignIpv6AddressesResult {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: String;
    /**
     * The IPv6 addresses that have been unassigned from the network interface.
     */
    UnassignedIpv6Addresses?: Ipv6AddressList;
    /**
     * The IPv4 prefixes that have been unassigned from the network interface.
     */
    UnassignedIpv6Prefixes?: IpPrefixList;
  }
  export interface UnassignPrivateIpAddressesRequest {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId: NetworkInterfaceId;
    /**
     * The secondary private IP addresses to unassign from the network interface. You can specify this option multiple times to unassign more than one IP address.
     */
    PrivateIpAddresses?: PrivateIpAddressStringList;
    /**
     * The IPv4 prefixes to unassign from the network interface.
     */
    Ipv4Prefixes?: IpPrefixList;
  }
  export interface UnassignPrivateNatGatewayAddressRequest {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId: NatGatewayId;
    /**
     * The private IPv4 addresses you want to unassign.
     */
    PrivateIpAddresses: IpList;
    /**
     * The maximum amount of time to wait (in seconds) before forcibly releasing the IP addresses if connections are still in progress. Default value is 350 seconds.
     */
    MaxDrainDurationSeconds?: DrainSeconds;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface UnassignPrivateNatGatewayAddressResult {
    /**
     * The NAT gateway ID.
     */
    NatGatewayId?: NatGatewayId;
    /**
     * Information about the NAT gateway IP addresses.
     */
    NatGatewayAddresses?: NatGatewayAddressList;
  }
  export type UnlimitedSupportedInstanceFamily = "t2"|"t3"|"t3a"|"t4g"|string;
  export interface UnmonitorInstancesRequest {
    /**
     * The IDs of the instances.
     */
    InstanceIds: InstanceIdStringList;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface UnmonitorInstancesResult {
    /**
     * The monitoring information.
     */
    InstanceMonitorings?: InstanceMonitoringList;
  }
  export type UnsuccessfulInstanceCreditSpecificationErrorCode = "InvalidInstanceID.Malformed"|"InvalidInstanceID.NotFound"|"IncorrectInstanceState"|"InstanceCreditSpecification.NotSupported"|string;
  export interface UnsuccessfulInstanceCreditSpecificationItem {
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The applicable error for the burstable performance instance whose credit option for CPU usage was not modified.
     */
    Error?: UnsuccessfulInstanceCreditSpecificationItemError;
  }
  export interface UnsuccessfulInstanceCreditSpecificationItemError {
    /**
     * The error code.
     */
    Code?: UnsuccessfulInstanceCreditSpecificationErrorCode;
    /**
     * The applicable error message.
     */
    Message?: String;
  }
  export type UnsuccessfulInstanceCreditSpecificationSet = UnsuccessfulInstanceCreditSpecificationItem[];
  export interface UnsuccessfulItem {
    /**
     * Information about the error.
     */
    Error?: UnsuccessfulItemError;
    /**
     * The ID of the resource.
     */
    ResourceId?: String;
  }
  export interface UnsuccessfulItemError {
    /**
     * The error code.
     */
    Code?: String;
    /**
     * The error message accompanying the error code.
     */
    Message?: String;
  }
  export type UnsuccessfulItemList = UnsuccessfulItem[];
  export type UnsuccessfulItemSet = UnsuccessfulItem[];
  export interface UpdateSecurityGroupRuleDescriptionsEgressRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupId?: SecurityGroupId;
    /**
     * [Default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request.
     */
    GroupName?: SecurityGroupName;
    /**
     * The IP permissions for the security group rule. You must specify either the IP permissions or the description.
     */
    IpPermissions?: IpPermissionList;
    /**
     * The description for the egress security group rules. You must specify either the description or the IP permissions.
     */
    SecurityGroupRuleDescriptions?: SecurityGroupRuleDescriptionList;
  }
  export interface UpdateSecurityGroupRuleDescriptionsEgressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
  }
  export interface UpdateSecurityGroupRuleDescriptionsIngressRequest {
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
    /**
     * The ID of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupId?: SecurityGroupId;
    /**
     * [EC2-Classic, default VPC] The name of the security group. You must specify either the security group ID or the security group name in the request. For security groups in a nondefault VPC, you must specify the security group ID.
     */
    GroupName?: SecurityGroupName;
    /**
     * The IP permissions for the security group rule. You must specify either IP permissions or a description.
     */
    IpPermissions?: IpPermissionList;
    /**
     * [VPC only] The description for the ingress security group rules. You must specify either a description or IP permissions.
     */
    SecurityGroupRuleDescriptions?: SecurityGroupRuleDescriptionList;
  }
  export interface UpdateSecurityGroupRuleDescriptionsIngressResult {
    /**
     * Returns true if the request succeeds; otherwise, returns an error.
     */
    Return?: Boolean;
  }
  export type UsageClassType = "spot"|"on-demand"|string;
  export type UsageClassTypeList = UsageClassType[];
  export interface UserBucket {
    /**
     * The name of the Amazon S3 bucket where the disk image is located.
     */
    S3Bucket?: String;
    /**
     * The file name of the disk image.
     */
    S3Key?: String;
  }
  export interface UserBucketDetails {
    /**
     * The Amazon S3 bucket from which the disk image was created.
     */
    S3Bucket?: String;
    /**
     * The file name of the disk image.
     */
    S3Key?: String;
  }
  export interface UserData {
    /**
     * The user data. If you are using an Amazon Web Services SDK or command line tool, Base64-encoding is performed for you, and you can load the text from a file. Otherwise, you must provide Base64-encoded text.
     */
    Data?: String;
  }
  export type UserGroupStringList = String[];
  export interface UserIdGroupPair {
    /**
     * A description for the security group rule that references this user ID group pair. Constraints: Up to 255 characters in length. Allowed characters are a-z, A-Z, 0-9, spaces, and ._-:/()#,@[]+=;{}!$*
     */
    Description?: String;
    /**
     * The ID of the security group.
     */
    GroupId?: String;
    /**
     * The name of the security group. In a request, use this parameter for a security group in EC2-Classic or a default VPC only. For a security group in a nondefault VPC, use the security group ID.  For a referenced security group in another VPC, this value is not returned if the referenced security group is deleted.
     */
    GroupName?: String;
    /**
     * The status of a VPC peering connection, if applicable.
     */
    PeeringStatus?: String;
    /**
     * The ID of an Amazon Web Services account. For a referenced security group in another VPC, the account ID of the referenced security group is returned in the response. If the referenced security group is deleted, this value is not returned. [EC2-Classic] Required when adding or removing rules that reference a security group in another Amazon Web Services account.
     */
    UserId?: String;
    /**
     * The ID of the VPC for the referenced security group, if applicable.
     */
    VpcId?: String;
    /**
     * The ID of the VPC peering connection, if applicable.
     */
    VpcPeeringConnectionId?: String;
  }
  export type UserIdGroupPairList = UserIdGroupPair[];
  export type UserIdGroupPairSet = UserIdGroupPair[];
  export type UserIdStringList = String[];
  export type UserTrustProviderType = "iam-identity-center"|"oidc"|string;
  export type VCpuCount = number;
  export interface VCpuCountRange {
    /**
     * The minimum number of vCPUs. If the value is 0, there is no minimum limit.
     */
    Min?: Integer;
    /**
     * The maximum number of vCPUs. If this parameter is not specified, there is no maximum limit.
     */
    Max?: Integer;
  }
  export interface VCpuCountRangeRequest {
    /**
     * The minimum number of vCPUs. To specify no minimum limit, specify 0.
     */
    Min: Integer;
    /**
     * The maximum number of vCPUs. To specify no maximum limit, omit this parameter.
     */
    Max?: Integer;
  }
  export interface VCpuInfo {
    /**
     * The default number of vCPUs for the instance type.
     */
    DefaultVCpus?: VCpuCount;
    /**
     * The default number of cores for the instance type.
     */
    DefaultCores?: CoreCount;
    /**
     * The default number of threads per core for the instance type.
     */
    DefaultThreadsPerCore?: ThreadsPerCore;
    /**
     * The valid number of cores that can be configured for the instance type.
     */
    ValidCores?: CoreCountList;
    /**
     * The valid number of threads per core that can be configured for the instance type.
     */
    ValidThreadsPerCore?: ThreadsPerCoreList;
  }
  export interface ValidationError {
    /**
     * The error code that indicates why the parameter or parameter combination is not valid. For more information about error codes, see Error codes.
     */
    Code?: String;
    /**
     * The error message that describes why the parameter or parameter combination is not valid. For more information about error messages, see Error codes.
     */
    Message?: String;
  }
  export interface ValidationWarning {
    /**
     * The error codes and error messages.
     */
    Errors?: ErrorSet;
  }
  export type ValueStringList = String[];
  export interface VerifiedAccessEndpoint {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: String;
    /**
     * The ID of the Amazon Web Services Verified Access group.
     */
    VerifiedAccessGroupId?: String;
    /**
     * The ID of the Amazon Web Services Verified Access endpoint.
     */
    VerifiedAccessEndpointId?: String;
    /**
     * The DNS name for users to reach your application.
     */
    ApplicationDomain?: String;
    /**
     * The type of Amazon Web Services Verified Access endpoint. Incoming application requests will be sent to an IP address, load balancer or a network interface depending on the endpoint type specified.
     */
    EndpointType?: VerifiedAccessEndpointType;
    /**
     * The type of attachment used to provide connectivity between the Amazon Web Services Verified Access endpoint and the application.
     */
    AttachmentType?: VerifiedAccessEndpointAttachmentType;
    /**
     * The ARN of a public TLS/SSL certificate imported into or created with ACM.
     */
    DomainCertificateArn?: String;
    /**
     * A DNS name that is generated for the endpoint.
     */
    EndpointDomain?: String;
    /**
     * Returned if endpoint has a device trust provider attached.
     */
    DeviceValidationDomain?: String;
    /**
     * The IDs of the security groups for the endpoint.
     */
    SecurityGroupIds?: SecurityGroupIdList;
    /**
     * The load balancer details if creating the Amazon Web Services Verified Access endpoint as load-balancertype.
     */
    LoadBalancerOptions?: VerifiedAccessEndpointLoadBalancerOptions;
    /**
     * The options for network-interface type endpoint.
     */
    NetworkInterfaceOptions?: VerifiedAccessEndpointEniOptions;
    /**
     * The endpoint status.
     */
    Status?: VerifiedAccessEndpointStatus;
    /**
     * A description for the Amazon Web Services Verified Access endpoint.
     */
    Description?: String;
    /**
     * The creation time.
     */
    CreationTime?: String;
    /**
     * The last updated time.
     */
    LastUpdatedTime?: String;
    /**
     * The deletion time.
     */
    DeletionTime?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type VerifiedAccessEndpointAttachmentType = "vpc"|string;
  export interface VerifiedAccessEndpointEniOptions {
    /**
     * The ID of the network interface.
     */
    NetworkInterfaceId?: NetworkInterfaceId;
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
  }
  export type VerifiedAccessEndpointId = string;
  export type VerifiedAccessEndpointIdList = VerifiedAccessEndpointId[];
  export type VerifiedAccessEndpointList = VerifiedAccessEndpoint[];
  export interface VerifiedAccessEndpointLoadBalancerOptions {
    /**
     * The IP protocol.
     */
    Protocol?: VerifiedAccessEndpointProtocol;
    /**
     * The IP port number.
     */
    Port?: VerifiedAccessEndpointPortNumber;
    /**
     * The ARN of the load balancer.
     */
    LoadBalancerArn?: String;
    /**
     * The IDs of the subnets.
     */
    SubnetIds?: VerifiedAccessEndpointSubnetIdList;
  }
  export type VerifiedAccessEndpointPortNumber = number;
  export type VerifiedAccessEndpointProtocol = "http"|"https"|string;
  export interface VerifiedAccessEndpointStatus {
    /**
     * The status code of the Verified Access endpoint.
     */
    Code?: VerifiedAccessEndpointStatusCode;
    /**
     * The status message of the Verified Access endpoint.
     */
    Message?: String;
  }
  export type VerifiedAccessEndpointStatusCode = "pending"|"active"|"updating"|"deleting"|"deleted"|string;
  export type VerifiedAccessEndpointSubnetIdList = SubnetId[];
  export type VerifiedAccessEndpointType = "load-balancer"|"network-interface"|string;
  export interface VerifiedAccessGroup {
    /**
     * The ID of the Verified Access group.
     */
    VerifiedAccessGroupId?: String;
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: String;
    /**
     * A description for the Amazon Web Services Verified Access group.
     */
    Description?: String;
    /**
     * The Amazon Web Services account number that owns the group.
     */
    Owner?: String;
    /**
     * The ARN of the Verified Access group.
     */
    VerifiedAccessGroupArn?: String;
    /**
     * The creation time.
     */
    CreationTime?: String;
    /**
     * The last updated time.
     */
    LastUpdatedTime?: String;
    /**
     * The deletion time.
     */
    DeletionTime?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type VerifiedAccessGroupId = string;
  export type VerifiedAccessGroupIdList = VerifiedAccessGroupId[];
  export type VerifiedAccessGroupList = VerifiedAccessGroup[];
  export interface VerifiedAccessInstance {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: String;
    /**
     * A description for the Amazon Web Services Verified Access instance.
     */
    Description?: String;
    /**
     * The IDs of the Amazon Web Services Verified Access trust providers.
     */
    VerifiedAccessTrustProviders?: VerifiedAccessTrustProviderCondensedList;
    /**
     * The creation time.
     */
    CreationTime?: String;
    /**
     * The last updated time.
     */
    LastUpdatedTime?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type VerifiedAccessInstanceId = string;
  export type VerifiedAccessInstanceIdList = VerifiedAccessInstanceId[];
  export type VerifiedAccessInstanceList = VerifiedAccessInstance[];
  export interface VerifiedAccessInstanceLoggingConfiguration {
    /**
     * The ID of the Amazon Web Services Verified Access instance.
     */
    VerifiedAccessInstanceId?: String;
    /**
     * Details about the logging options.
     */
    AccessLogs?: VerifiedAccessLogs;
  }
  export type VerifiedAccessInstanceLoggingConfigurationList = VerifiedAccessInstanceLoggingConfiguration[];
  export interface VerifiedAccessLogCloudWatchLogsDestination {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled?: Boolean;
    /**
     * The delivery status for access logs.
     */
    DeliveryStatus?: VerifiedAccessLogDeliveryStatus;
    /**
     * The ID of the CloudWatch Logs log group.
     */
    LogGroup?: String;
  }
  export interface VerifiedAccessLogCloudWatchLogsDestinationOptions {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled: Boolean;
    /**
     * The ID of the CloudWatch Logs log group.
     */
    LogGroup?: String;
  }
  export interface VerifiedAccessLogDeliveryStatus {
    /**
     * The status code.
     */
    Code?: VerifiedAccessLogDeliveryStatusCode;
    /**
     * The status message.
     */
    Message?: String;
  }
  export type VerifiedAccessLogDeliveryStatusCode = "success"|"failed"|string;
  export interface VerifiedAccessLogKinesisDataFirehoseDestination {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled?: Boolean;
    /**
     * The delivery status.
     */
    DeliveryStatus?: VerifiedAccessLogDeliveryStatus;
    /**
     * The ID of the delivery stream.
     */
    DeliveryStream?: String;
  }
  export interface VerifiedAccessLogKinesisDataFirehoseDestinationOptions {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled: Boolean;
    /**
     * The ID of the delivery stream.
     */
    DeliveryStream?: String;
  }
  export interface VerifiedAccessLogOptions {
    /**
     * Sends Verified Access logs to Amazon S3.
     */
    S3?: VerifiedAccessLogS3DestinationOptions;
    /**
     * Sends Verified Access logs to CloudWatch Logs.
     */
    CloudWatchLogs?: VerifiedAccessLogCloudWatchLogsDestinationOptions;
    /**
     * Sends Verified Access logs to Kinesis.
     */
    KinesisDataFirehose?: VerifiedAccessLogKinesisDataFirehoseDestinationOptions;
  }
  export interface VerifiedAccessLogS3Destination {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled?: Boolean;
    /**
     * The delivery status.
     */
    DeliveryStatus?: VerifiedAccessLogDeliveryStatus;
    /**
     * The bucket name.
     */
    BucketName?: String;
    /**
     * The bucket prefix.
     */
    Prefix?: String;
    /**
     * The Amazon Web Services account number that owns the bucket.
     */
    BucketOwner?: String;
  }
  export interface VerifiedAccessLogS3DestinationOptions {
    /**
     * Indicates whether logging is enabled.
     */
    Enabled: Boolean;
    /**
     * The bucket name.
     */
    BucketName?: String;
    /**
     * The bucket prefix.
     */
    Prefix?: String;
    /**
     * The ID of the Amazon Web Services account that owns the Amazon S3 bucket.
     */
    BucketOwner?: String;
  }
  export interface VerifiedAccessLogs {
    /**
     * Amazon S3 logging options.
     */
    S3?: VerifiedAccessLogS3Destination;
    /**
     * CloudWatch Logs logging destination.
     */
    CloudWatchLogs?: VerifiedAccessLogCloudWatchLogsDestination;
    /**
     * Kinesis logging destination.
     */
    KinesisDataFirehose?: VerifiedAccessLogKinesisDataFirehoseDestination;
  }
  export interface VerifiedAccessTrustProvider {
    /**
     * The ID of the Amazon Web Services Verified Access trust provider.
     */
    VerifiedAccessTrustProviderId?: String;
    /**
     * A description for the Amazon Web Services Verified Access trust provider.
     */
    Description?: String;
    /**
     * The type of Verified Access trust provider.
     */
    TrustProviderType?: TrustProviderType;
    /**
     * The type of user-based trust provider.
     */
    UserTrustProviderType?: UserTrustProviderType;
    /**
     * The type of device-based trust provider.
     */
    DeviceTrustProviderType?: DeviceTrustProviderType;
    /**
     * The OpenID Connect details for an oidc-type, user-identity based trust provider.
     */
    OidcOptions?: OidcOptions;
    /**
     * The options for device-identity type trust provider.
     */
    DeviceOptions?: DeviceOptions;
    /**
     * The identifier to be used when working with policy rules.
     */
    PolicyReferenceName?: String;
    /**
     * The creation time.
     */
    CreationTime?: String;
    /**
     * The last updated time.
     */
    LastUpdatedTime?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export interface VerifiedAccessTrustProviderCondensed {
    /**
     * The ID of the trust provider.
     */
    VerifiedAccessTrustProviderId?: String;
    /**
     * The description of trust provider.
     */
    Description?: String;
    /**
     * The type of trust provider (user- or device-based).
     */
    TrustProviderType?: TrustProviderType;
    /**
     * The type of user-based trust provider.
     */
    UserTrustProviderType?: UserTrustProviderType;
    /**
     * The type of device-based trust provider.
     */
    DeviceTrustProviderType?: DeviceTrustProviderType;
  }
  export type VerifiedAccessTrustProviderCondensedList = VerifiedAccessTrustProviderCondensed[];
  export type VerifiedAccessTrustProviderId = string;
  export type VerifiedAccessTrustProviderIdList = VerifiedAccessTrustProviderId[];
  export type VerifiedAccessTrustProviderList = VerifiedAccessTrustProvider[];
  export type VersionDescription = string;
  export type VersionStringList = String[];
  export interface VgwTelemetry {
    /**
     * The number of accepted routes.
     */
    AcceptedRouteCount?: Integer;
    /**
     * The date and time of the last change in status.
     */
    LastStatusChange?: DateTime;
    /**
     * The Internet-routable IP address of the virtual private gateway's outside interface.
     */
    OutsideIpAddress?: String;
    /**
     * The status of the VPN tunnel.
     */
    Status?: TelemetryStatus;
    /**
     * If an error occurs, a description of the error.
     */
    StatusMessage?: String;
    /**
     * The Amazon Resource Name (ARN) of the VPN tunnel endpoint certificate.
     */
    CertificateArn?: String;
  }
  export type VgwTelemetryList = VgwTelemetry[];
  export type VirtualizationType = "hvm"|"paravirtual"|string;
  export type VirtualizationTypeList = VirtualizationType[];
  export type VirtualizationTypeSet = VirtualizationType[];
  export interface Volume {
    /**
     * Information about the volume attachments.
     */
    Attachments?: VolumeAttachmentList;
    /**
     * The Availability Zone for the volume.
     */
    AvailabilityZone?: String;
    /**
     * The time stamp when volume creation was initiated.
     */
    CreateTime?: DateTime;
    /**
     * Indicates whether the volume is encrypted.
     */
    Encrypted?: Boolean;
    /**
     * The Amazon Resource Name (ARN) of the Key Management Service (KMS) KMS key that was used to protect the volume encryption key for the volume.
     */
    KmsKeyId?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * The size of the volume, in GiBs.
     */
    Size?: Integer;
    /**
     * The snapshot from which the volume was created, if applicable.
     */
    SnapshotId?: String;
    /**
     * The volume state.
     */
    State?: VolumeState;
    /**
     * The ID of the volume.
     */
    VolumeId?: String;
    /**
     * The number of I/O operations per second (IOPS). For gp3, io1, and io2 volumes, this represents the number of IOPS that are provisioned for the volume. For gp2 volumes, this represents the baseline performance of the volume and the rate at which the volume accumulates I/O credits for bursting.
     */
    Iops?: Integer;
    /**
     * Any tags assigned to the volume.
     */
    Tags?: TagList;
    /**
     * The volume type.
     */
    VolumeType?: VolumeType;
    /**
     * Indicates whether the volume was created using fast snapshot restore.
     */
    FastRestored?: Boolean;
    /**
     * Indicates whether Amazon EBS Multi-Attach is enabled.
     */
    MultiAttachEnabled?: Boolean;
    /**
     * The throughput that the volume supports, in MiB/s.
     */
    Throughput?: Integer;
  }
  export interface VolumeAttachment {
    /**
     * The time stamp when the attachment initiated.
     */
    AttachTime?: DateTime;
    /**
     * The device name.
     */
    Device?: String;
    /**
     * The ID of the instance.
     */
    InstanceId?: String;
    /**
     * The attachment state of the volume.
     */
    State?: VolumeAttachmentState;
    /**
     * The ID of the volume.
     */
    VolumeId?: String;
    /**
     * Indicates whether the EBS volume is deleted on instance termination.
     */
    DeleteOnTermination?: Boolean;
  }
  export type VolumeAttachmentList = VolumeAttachment[];
  export type VolumeAttachmentState = "attaching"|"attached"|"detaching"|"detached"|"busy"|string;
  export type VolumeAttributeName = "autoEnableIO"|"productCodes"|string;
  export interface VolumeDetail {
    /**
     * The size of the volume, in GiB.
     */
    Size: Long;
  }
  export type VolumeId = string;
  export type VolumeIdStringList = VolumeId[];
  export type VolumeIdWithResolver = string;
  export type VolumeList = Volume[];
  export interface VolumeModification {
    /**
     * The ID of the volume.
     */
    VolumeId?: String;
    /**
     * The current modification state. The modification state is null for unmodified volumes.
     */
    ModificationState?: VolumeModificationState;
    /**
     * A status message about the modification progress or failure.
     */
    StatusMessage?: String;
    /**
     * The target size of the volume, in GiB.
     */
    TargetSize?: Integer;
    /**
     * The target IOPS rate of the volume.
     */
    TargetIops?: Integer;
    /**
     * The target EBS volume type of the volume.
     */
    TargetVolumeType?: VolumeType;
    /**
     * The target throughput of the volume, in MiB/s.
     */
    TargetThroughput?: Integer;
    /**
     * The target setting for Amazon EBS Multi-Attach.
     */
    TargetMultiAttachEnabled?: Boolean;
    /**
     * The original size of the volume, in GiB.
     */
    OriginalSize?: Integer;
    /**
     * The original IOPS rate of the volume.
     */
    OriginalIops?: Integer;
    /**
     * The original EBS volume type of the volume.
     */
    OriginalVolumeType?: VolumeType;
    /**
     * The original throughput of the volume, in MiB/s.
     */
    OriginalThroughput?: Integer;
    /**
     * The original setting for Amazon EBS Multi-Attach.
     */
    OriginalMultiAttachEnabled?: Boolean;
    /**
     * The modification progress, from 0 to 100 percent complete.
     */
    Progress?: Long;
    /**
     * The modification start time.
     */
    StartTime?: DateTime;
    /**
     * The modification completion or failure time.
     */
    EndTime?: DateTime;
  }
  export type VolumeModificationList = VolumeModification[];
  export type VolumeModificationState = "modifying"|"optimizing"|"completed"|"failed"|string;
  export type VolumeState = "creating"|"available"|"in-use"|"deleting"|"deleted"|"error"|string;
  export interface VolumeStatusAction {
    /**
     * The code identifying the operation, for example, enable-volume-io.
     */
    Code?: String;
    /**
     * A description of the operation.
     */
    Description?: String;
    /**
     * The ID of the event associated with this operation.
     */
    EventId?: String;
    /**
     * The event type associated with this operation.
     */
    EventType?: String;
  }
  export type VolumeStatusActionsList = VolumeStatusAction[];
  export interface VolumeStatusAttachmentStatus {
    /**
     * The maximum IOPS supported by the attached instance.
     */
    IoPerformance?: String;
    /**
     * The ID of the attached instance.
     */
    InstanceId?: String;
  }
  export type VolumeStatusAttachmentStatusList = VolumeStatusAttachmentStatus[];
  export interface VolumeStatusDetails {
    /**
     * The name of the volume status.
     */
    Name?: VolumeStatusName;
    /**
     * The intended status of the volume status.
     */
    Status?: String;
  }
  export type VolumeStatusDetailsList = VolumeStatusDetails[];
  export interface VolumeStatusEvent {
    /**
     * A description of the event.
     */
    Description?: String;
    /**
     * The ID of this event.
     */
    EventId?: String;
    /**
     * The type of this event.
     */
    EventType?: String;
    /**
     * The latest end time of the event.
     */
    NotAfter?: MillisecondDateTime;
    /**
     * The earliest start time of the event.
     */
    NotBefore?: MillisecondDateTime;
    /**
     * The ID of the instance associated with the event.
     */
    InstanceId?: String;
  }
  export type VolumeStatusEventsList = VolumeStatusEvent[];
  export interface VolumeStatusInfo {
    /**
     * The details of the volume status.
     */
    Details?: VolumeStatusDetailsList;
    /**
     * The status of the volume.
     */
    Status?: VolumeStatusInfoStatus;
  }
  export type VolumeStatusInfoStatus = "ok"|"impaired"|"insufficient-data"|string;
  export interface VolumeStatusItem {
    /**
     * The details of the operation.
     */
    Actions?: VolumeStatusActionsList;
    /**
     * The Availability Zone of the volume.
     */
    AvailabilityZone?: String;
    /**
     * The Amazon Resource Name (ARN) of the Outpost.
     */
    OutpostArn?: String;
    /**
     * A list of events associated with the volume.
     */
    Events?: VolumeStatusEventsList;
    /**
     * The volume ID.
     */
    VolumeId?: String;
    /**
     * The volume status.
     */
    VolumeStatus?: VolumeStatusInfo;
    /**
     * Information about the instances to which the volume is attached.
     */
    AttachmentStatuses?: VolumeStatusAttachmentStatusList;
  }
  export type VolumeStatusList = VolumeStatusItem[];
  export type VolumeStatusName = "io-enabled"|"io-performance"|string;
  export type VolumeType = "standard"|"io1"|"io2"|"gp2"|"sc1"|"st1"|"gp3"|string;
  export interface Vpc {
    /**
     * The primary IPv4 CIDR block for the VPC.
     */
    CidrBlock?: String;
    /**
     * The ID of the set of DHCP options you've associated with the VPC.
     */
    DhcpOptionsId?: String;
    /**
     * The current state of the VPC.
     */
    State?: VpcState;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the VPC.
     */
    OwnerId?: String;
    /**
     * The allowed tenancy of instances launched into the VPC.
     */
    InstanceTenancy?: Tenancy;
    /**
     * Information about the IPv6 CIDR blocks associated with the VPC.
     */
    Ipv6CidrBlockAssociationSet?: VpcIpv6CidrBlockAssociationSet;
    /**
     * Information about the IPv4 CIDR blocks associated with the VPC.
     */
    CidrBlockAssociationSet?: VpcCidrBlockAssociationSet;
    /**
     * Indicates whether the VPC is the default VPC.
     */
    IsDefault?: Boolean;
    /**
     * Any tags assigned to the VPC.
     */
    Tags?: TagList;
  }
  export interface VpcAttachment {
    /**
     * The current state of the attachment.
     */
    State?: AttachmentStatus;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type VpcAttachmentList = VpcAttachment[];
  export type VpcAttributeName = "enableDnsSupport"|"enableDnsHostnames"|"enableNetworkAddressUsageMetrics"|string;
  export type VpcCidrAssociationId = string;
  export interface VpcCidrBlockAssociation {
    /**
     * The association ID for the IPv4 CIDR block.
     */
    AssociationId?: String;
    /**
     * The IPv4 CIDR block.
     */
    CidrBlock?: String;
    /**
     * Information about the state of the CIDR block.
     */
    CidrBlockState?: VpcCidrBlockState;
  }
  export type VpcCidrBlockAssociationSet = VpcCidrBlockAssociation[];
  export interface VpcCidrBlockState {
    /**
     * The state of the CIDR block.
     */
    State?: VpcCidrBlockStateCode;
    /**
     * A message about the status of the CIDR block, if applicable.
     */
    StatusMessage?: String;
  }
  export type VpcCidrBlockStateCode = "associating"|"associated"|"disassociating"|"disassociated"|"failing"|"failed"|string;
  export interface VpcClassicLink {
    /**
     * Indicates whether the VPC is enabled for ClassicLink.
     */
    ClassicLinkEnabled?: Boolean;
    /**
     * Any tags assigned to the VPC.
     */
    Tags?: TagList;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
  }
  export type VpcClassicLinkIdList = VpcId[];
  export type VpcClassicLinkList = VpcClassicLink[];
  export interface VpcEndpoint {
    /**
     * The ID of the endpoint.
     */
    VpcEndpointId?: String;
    /**
     * The type of endpoint.
     */
    VpcEndpointType?: VpcEndpointType;
    /**
     * The ID of the VPC to which the endpoint is associated.
     */
    VpcId?: String;
    /**
     * The name of the service to which the endpoint is associated.
     */
    ServiceName?: String;
    /**
     * The state of the endpoint.
     */
    State?: State;
    /**
     * The policy document associated with the endpoint, if applicable.
     */
    PolicyDocument?: String;
    /**
     * (Gateway endpoint) The IDs of the route tables associated with the endpoint.
     */
    RouteTableIds?: ValueStringList;
    /**
     * (Interface endpoint) The subnets for the endpoint.
     */
    SubnetIds?: ValueStringList;
    /**
     * (Interface endpoint) Information about the security groups that are associated with the network interface.
     */
    Groups?: GroupIdentifierSet;
    /**
     * The IP address type for the endpoint.
     */
    IpAddressType?: IpAddressType;
    /**
     * The DNS options for the endpoint.
     */
    DnsOptions?: DnsOptions;
    /**
     * (Interface endpoint) Indicates whether the VPC is associated with a private hosted zone.
     */
    PrivateDnsEnabled?: Boolean;
    /**
     * Indicates whether the endpoint is being managed by its service.
     */
    RequesterManaged?: Boolean;
    /**
     * (Interface endpoint) The network interfaces for the endpoint.
     */
    NetworkInterfaceIds?: ValueStringList;
    /**
     * (Interface endpoint) The DNS entries for the endpoint.
     */
    DnsEntries?: DnsEntrySet;
    /**
     * The date and time that the endpoint was created.
     */
    CreationTimestamp?: MillisecondDateTime;
    /**
     * The tags assigned to the endpoint.
     */
    Tags?: TagList;
    /**
     * The ID of the Amazon Web Services account that owns the endpoint.
     */
    OwnerId?: String;
    /**
     * The last error that occurred for endpoint.
     */
    LastError?: LastError;
  }
  export interface VpcEndpointConnection {
    /**
     * The ID of the service to which the endpoint is connected.
     */
    ServiceId?: String;
    /**
     * The ID of the VPC endpoint.
     */
    VpcEndpointId?: String;
    /**
     * The ID of the Amazon Web Services account that owns the VPC endpoint.
     */
    VpcEndpointOwner?: String;
    /**
     * The state of the VPC endpoint.
     */
    VpcEndpointState?: State;
    /**
     * The date and time that the VPC endpoint was created.
     */
    CreationTimestamp?: MillisecondDateTime;
    /**
     * The DNS entries for the VPC endpoint.
     */
    DnsEntries?: DnsEntrySet;
    /**
     * The Amazon Resource Names (ARNs) of the network load balancers for the service.
     */
    NetworkLoadBalancerArns?: ValueStringList;
    /**
     * The Amazon Resource Names (ARNs) of the Gateway Load Balancers for the service.
     */
    GatewayLoadBalancerArns?: ValueStringList;
    /**
     * The IP address type for the endpoint.
     */
    IpAddressType?: IpAddressType;
    /**
     * The ID of the VPC endpoint connection.
     */
    VpcEndpointConnectionId?: String;
    /**
     * The tags.
     */
    Tags?: TagList;
  }
  export type VpcEndpointConnectionSet = VpcEndpointConnection[];
  export type VpcEndpointId = string;
  export type VpcEndpointIdList = VpcEndpointId[];
  export type VpcEndpointRouteTableIdList = RouteTableId[];
  export type VpcEndpointSecurityGroupIdList = SecurityGroupId[];
  export type VpcEndpointServiceId = string;
  export type VpcEndpointServiceIdList = VpcEndpointServiceId[];
  export type VpcEndpointSet = VpcEndpoint[];
  export type VpcEndpointSubnetIdList = SubnetId[];
  export type VpcEndpointType = "Interface"|"Gateway"|"GatewayLoadBalancer"|string;
  export type VpcFlowLogId = string;
  export type VpcId = string;
  export type VpcIdStringList = VpcId[];
  export interface VpcIpv6CidrBlockAssociation {
    /**
     * The association ID for the IPv6 CIDR block.
     */
    AssociationId?: String;
    /**
     * The IPv6 CIDR block.
     */
    Ipv6CidrBlock?: String;
    /**
     * Information about the state of the CIDR block.
     */
    Ipv6CidrBlockState?: VpcCidrBlockState;
    /**
     * The name of the unique set of Availability Zones, Local Zones, or Wavelength Zones from which Amazon Web Services advertises IP addresses, for example, us-east-1-wl1-bos-wlz-1.
     */
    NetworkBorderGroup?: String;
    /**
     * The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.
     */
    Ipv6Pool?: String;
  }
  export type VpcIpv6CidrBlockAssociationSet = VpcIpv6CidrBlockAssociation[];
  export type VpcList = Vpc[];
  export interface VpcPeeringConnection {
    /**
     * Information about the accepter VPC. CIDR block information is only returned when describing an active VPC peering connection.
     */
    AccepterVpcInfo?: VpcPeeringConnectionVpcInfo;
    /**
     * The time that an unaccepted VPC peering connection will expire.
     */
    ExpirationTime?: DateTime;
    /**
     * Information about the requester VPC. CIDR block information is only returned when describing an active VPC peering connection.
     */
    RequesterVpcInfo?: VpcPeeringConnectionVpcInfo;
    /**
     * The status of the VPC peering connection.
     */
    Status?: VpcPeeringConnectionStateReason;
    /**
     * Any tags assigned to the resource.
     */
    Tags?: TagList;
    /**
     * The ID of the VPC peering connection.
     */
    VpcPeeringConnectionId?: String;
  }
  export type VpcPeeringConnectionId = string;
  export type VpcPeeringConnectionIdList = VpcPeeringConnectionId[];
  export type VpcPeeringConnectionIdWithResolver = string;
  export type VpcPeeringConnectionList = VpcPeeringConnection[];
  export interface VpcPeeringConnectionOptionsDescription {
    /**
     * Indicates whether a local VPC can resolve public DNS hostnames to private IP addresses when queried from instances in a peer VPC.
     */
    AllowDnsResolutionFromRemoteVpc?: Boolean;
    /**
     * Indicates whether a local ClassicLink connection can communicate with the peer VPC over the VPC peering connection.
     */
    AllowEgressFromLocalClassicLinkToRemoteVpc?: Boolean;
    /**
     * Indicates whether a local VPC can communicate with a ClassicLink connection in the peer VPC over the VPC peering connection.
     */
    AllowEgressFromLocalVpcToRemoteClassicLink?: Boolean;
  }
  export interface VpcPeeringConnectionStateReason {
    /**
     * The status of the VPC peering connection.
     */
    Code?: VpcPeeringConnectionStateReasonCode;
    /**
     * A message that provides more information about the status, if applicable.
     */
    Message?: String;
  }
  export type VpcPeeringConnectionStateReasonCode = "initiating-request"|"pending-acceptance"|"active"|"deleted"|"rejected"|"failed"|"expired"|"provisioning"|"deleting"|string;
  export interface VpcPeeringConnectionVpcInfo {
    /**
     * The IPv4 CIDR block for the VPC.
     */
    CidrBlock?: String;
    /**
     * The IPv6 CIDR block for the VPC.
     */
    Ipv6CidrBlockSet?: Ipv6CidrBlockSet;
    /**
     * Information about the IPv4 CIDR blocks for the VPC.
     */
    CidrBlockSet?: CidrBlockSet;
    /**
     * The ID of the Amazon Web Services account that owns the VPC.
     */
    OwnerId?: String;
    /**
     * Information about the VPC peering connection options for the accepter or requester VPC.
     */
    PeeringOptions?: VpcPeeringConnectionOptionsDescription;
    /**
     * The ID of the VPC.
     */
    VpcId?: String;
    /**
     * The Region in which the VPC is located.
     */
    Region?: String;
  }
  export type VpcState = "pending"|"available"|string;
  export type VpcTenancy = "default"|string;
  export interface VpnConnection {
    /**
     * The configuration information for the VPN connection's customer gateway (in the native XML format). This element is always present in the CreateVpnConnection response; however, it's present in the DescribeVpnConnections response only if the VPN connection is in the pending or available state.
     */
    CustomerGatewayConfiguration?: String;
    /**
     * The ID of the customer gateway at your end of the VPN connection.
     */
    CustomerGatewayId?: String;
    /**
     * The category of the VPN connection. A value of VPN indicates an Amazon Web Services VPN connection. A value of VPN-Classic indicates an Amazon Web Services Classic VPN connection.
     */
    Category?: String;
    /**
     * The current state of the VPN connection.
     */
    State?: VpnState;
    /**
     * The type of VPN connection.
     */
    Type?: GatewayType;
    /**
     * The ID of the VPN connection.
     */
    VpnConnectionId?: String;
    /**
     * The ID of the virtual private gateway at the Amazon Web Services side of the VPN connection.
     */
    VpnGatewayId?: String;
    /**
     * The ID of the transit gateway associated with the VPN connection.
     */
    TransitGatewayId?: String;
    /**
     * The ARN of the core network.
     */
    CoreNetworkArn?: String;
    /**
     * The ARN of the core network attachment.
     */
    CoreNetworkAttachmentArn?: String;
    /**
     * The current state of the gateway association.
     */
    GatewayAssociationState?: GatewayAssociationState;
    /**
     * The VPN connection options.
     */
    Options?: VpnConnectionOptions;
    /**
     * The static routes associated with the VPN connection.
     */
    Routes?: VpnStaticRouteList;
    /**
     * Any tags assigned to the VPN connection.
     */
    Tags?: TagList;
    /**
     * Information about the VPN tunnel.
     */
    VgwTelemetry?: VgwTelemetryList;
  }
  export type VpnConnectionDeviceSampleConfiguration = string;
  export interface VpnConnectionDeviceType {
    /**
     * Customer gateway device identifier.
     */
    VpnConnectionDeviceTypeId?: String;
    /**
     * Customer gateway device vendor.
     */
    Vendor?: String;
    /**
     * Customer gateway device platform.
     */
    Platform?: String;
    /**
     * Customer gateway device software version.
     */
    Software?: String;
  }
  export type VpnConnectionDeviceTypeId = string;
  export type VpnConnectionDeviceTypeList = VpnConnectionDeviceType[];
  export type VpnConnectionId = string;
  export type VpnConnectionIdStringList = VpnConnectionId[];
  export type VpnConnectionList = VpnConnection[];
  export interface VpnConnectionOptions {
    /**
     * Indicates whether acceleration is enabled for the VPN connection.
     */
    EnableAcceleration?: Boolean;
    /**
     * Indicates whether the VPN connection uses static routes only. Static routes must be used for devices that don't support BGP.
     */
    StaticRoutesOnly?: Boolean;
    /**
     * The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection.
     */
    LocalIpv4NetworkCidr?: String;
    /**
     * The IPv4 CIDR on the Amazon Web Services side of the VPN connection.
     */
    RemoteIpv4NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection.
     */
    LocalIpv6NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the Amazon Web Services side of the VPN connection.
     */
    RemoteIpv6NetworkCidr?: String;
    /**
     * The type of IPv4 address assigned to the outside interface of the customer gateway. Valid values: PrivateIpv4 | PublicIpv4  Default: PublicIpv4 
     */
    OutsideIpAddressType?: String;
    /**
     * The transit gateway attachment ID in use for the VPN tunnel.
     */
    TransportTransitGatewayAttachmentId?: String;
    /**
     * Indicates whether the VPN tunnels process IPv4 or IPv6 traffic.
     */
    TunnelInsideIpVersion?: TunnelInsideIpVersion;
    /**
     * Indicates the VPN tunnel options.
     */
    TunnelOptions?: TunnelOptionsList;
  }
  export interface VpnConnectionOptionsSpecification {
    /**
     * Indicate whether to enable acceleration for the VPN connection. Default: false 
     */
    EnableAcceleration?: Boolean;
    /**
     * Indicate whether the VPN connection uses static routes only. If you are creating a VPN connection for a device that does not support BGP, you must specify true. Use CreateVpnConnectionRoute to create a static route. Default: false 
     */
    StaticRoutesOnly?: Boolean;
    /**
     * Indicate whether the VPN tunnels process IPv4 or IPv6 traffic. Default: ipv4 
     */
    TunnelInsideIpVersion?: TunnelInsideIpVersion;
    /**
     * The tunnel options for the VPN connection.
     */
    TunnelOptions?: VpnTunnelOptionsSpecificationsList;
    /**
     * The IPv4 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: 0.0.0.0/0 
     */
    LocalIpv4NetworkCidr?: String;
    /**
     * The IPv4 CIDR on the Amazon Web Services side of the VPN connection. Default: 0.0.0.0/0 
     */
    RemoteIpv4NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the customer gateway (on-premises) side of the VPN connection. Default: ::/0 
     */
    LocalIpv6NetworkCidr?: String;
    /**
     * The IPv6 CIDR on the Amazon Web Services side of the VPN connection. Default: ::/0 
     */
    RemoteIpv6NetworkCidr?: String;
    /**
     * The type of IPv4 address assigned to the outside interface of the customer gateway device. Valid values: PrivateIpv4 | PublicIpv4  Default: PublicIpv4 
     */
    OutsideIpAddressType?: String;
    /**
     * The transit gateway attachment ID to use for the VPN tunnel. Required if OutsideIpAddressType is set to PrivateIpv4.
     */
    TransportTransitGatewayAttachmentId?: TransitGatewayAttachmentId;
  }
  export type VpnEcmpSupportValue = "enable"|"disable"|string;
  export interface VpnGateway {
    /**
     * The Availability Zone where the virtual private gateway was created, if applicable. This field may be empty or not returned.
     */
    AvailabilityZone?: String;
    /**
     * The current state of the virtual private gateway.
     */
    State?: VpnState;
    /**
     * The type of VPN connection the virtual private gateway supports.
     */
    Type?: GatewayType;
    /**
     * Any VPCs attached to the virtual private gateway.
     */
    VpcAttachments?: VpcAttachmentList;
    /**
     * The ID of the virtual private gateway.
     */
    VpnGatewayId?: String;
    /**
     * The private Autonomous System Number (ASN) for the Amazon side of a BGP session.
     */
    AmazonSideAsn?: Long;
    /**
     * Any tags assigned to the virtual private gateway.
     */
    Tags?: TagList;
  }
  export type VpnGatewayId = string;
  export type VpnGatewayIdStringList = VpnGatewayId[];
  export type VpnGatewayList = VpnGateway[];
  export type VpnProtocol = "openvpn"|string;
  export type VpnState = "pending"|"available"|"deleting"|"deleted"|string;
  export interface VpnStaticRoute {
    /**
     * The CIDR block associated with the local subnet of the customer data center.
     */
    DestinationCidrBlock?: String;
    /**
     * Indicates how the routes were provided.
     */
    Source?: VpnStaticRouteSource;
    /**
     * The current state of the static route.
     */
    State?: VpnState;
  }
  export type VpnStaticRouteList = VpnStaticRoute[];
  export type VpnStaticRouteSource = "Static"|string;
  export interface VpnTunnelLogOptions {
    /**
     * Options for sending VPN tunnel logs to CloudWatch.
     */
    CloudWatchLogOptions?: CloudWatchLogOptions;
  }
  export interface VpnTunnelLogOptionsSpecification {
    /**
     * Options for sending VPN tunnel logs to CloudWatch.
     */
    CloudWatchLogOptions?: CloudWatchLogOptionsSpecification;
  }
  export interface VpnTunnelOptionsSpecification {
    /**
     * The range of inside IPv4 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same virtual private gateway.  Constraints: A size /30 CIDR block from the 169.254.0.0/16 range. The following CIDR blocks are reserved and cannot be used:    169.254.0.0/30     169.254.1.0/30     169.254.2.0/30     169.254.3.0/30     169.254.4.0/30     169.254.5.0/30     169.254.169.252/30   
     */
    TunnelInsideCidr?: String;
    /**
     * The range of inside IPv6 addresses for the tunnel. Any specified CIDR blocks must be unique across all VPN connections that use the same transit gateway. Constraints: A size /126 CIDR block from the local fd00::/8 range.
     */
    TunnelInsideIpv6Cidr?: String;
    /**
     * The pre-shared key (PSK) to establish initial authentication between the virtual private gateway and customer gateway. Constraints: Allowed characters are alphanumeric characters, periods (.), and underscores (_). Must be between 8 and 64 characters in length and cannot start with zero (0).
     */
    PreSharedKey?: String;
    /**
     * The lifetime for phase 1 of the IKE negotiation, in seconds. Constraints: A value between 900 and 28,800. Default: 28800 
     */
    Phase1LifetimeSeconds?: Integer;
    /**
     * The lifetime for phase 2 of the IKE negotiation, in seconds. Constraints: A value between 900 and 3,600. The value must be less than the value for Phase1LifetimeSeconds. Default: 3600 
     */
    Phase2LifetimeSeconds?: Integer;
    /**
     * The margin time, in seconds, before the phase 2 lifetime expires, during which the Amazon Web Services side of the VPN connection performs an IKE rekey. The exact time of the rekey is randomly selected based on the value for RekeyFuzzPercentage. Constraints: A value between 60 and half of Phase2LifetimeSeconds. Default: 540 
     */
    RekeyMarginTimeSeconds?: Integer;
    /**
     * The percentage of the rekey window (determined by RekeyMarginTimeSeconds) during which the rekey time is randomly selected. Constraints: A value between 0 and 100. Default: 100 
     */
    RekeyFuzzPercentage?: Integer;
    /**
     * The number of packets in an IKE replay window. Constraints: A value between 64 and 2048. Default: 1024 
     */
    ReplayWindowSize?: Integer;
    /**
     * The number of seconds after which a DPD timeout occurs. Constraints: A value greater than or equal to 30. Default: 30 
     */
    DPDTimeoutSeconds?: Integer;
    /**
     * The action to take after DPD timeout occurs. Specify restart to restart the IKE initiation. Specify clear to end the IKE session. Valid Values: clear | none | restart  Default: clear 
     */
    DPDTimeoutAction?: String;
    /**
     * One or more encryption algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: AES128 | AES256 | AES128-GCM-16 | AES256-GCM-16 
     */
    Phase1EncryptionAlgorithms?: Phase1EncryptionAlgorithmsRequestList;
    /**
     * One or more encryption algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: AES128 | AES256 | AES128-GCM-16 | AES256-GCM-16 
     */
    Phase2EncryptionAlgorithms?: Phase2EncryptionAlgorithmsRequestList;
    /**
     * One or more integrity algorithms that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: SHA1 | SHA2-256 | SHA2-384 | SHA2-512 
     */
    Phase1IntegrityAlgorithms?: Phase1IntegrityAlgorithmsRequestList;
    /**
     * One or more integrity algorithms that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: SHA1 | SHA2-256 | SHA2-384 | SHA2-512 
     */
    Phase2IntegrityAlgorithms?: Phase2IntegrityAlgorithmsRequestList;
    /**
     * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 1 IKE negotiations. Valid values: 2 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 | 24 
     */
    Phase1DHGroupNumbers?: Phase1DHGroupNumbersRequestList;
    /**
     * One or more Diffie-Hellman group numbers that are permitted for the VPN tunnel for phase 2 IKE negotiations. Valid values: 2 | 5 | 14 | 15 | 16 | 17 | 18 | 19 | 20 | 21 | 22 | 23 | 24 
     */
    Phase2DHGroupNumbers?: Phase2DHGroupNumbersRequestList;
    /**
     * The IKE versions that are permitted for the VPN tunnel. Valid values: ikev1 | ikev2 
     */
    IKEVersions?: IKEVersionsRequestList;
    /**
     * The action to take when the establishing the tunnel for the VPN connection. By default, your customer gateway device must initiate the IKE negotiation and bring up the tunnel. Specify start for Amazon Web Services to initiate the IKE negotiation. Valid Values: add | start  Default: add 
     */
    StartupAction?: String;
    /**
     * Options for logging VPN tunnel activity.
     */
    LogOptions?: VpnTunnelLogOptionsSpecification;
    /**
     * Turn on or off tunnel endpoint lifecycle control feature.
     */
    EnableTunnelLifecycleControl?: Boolean;
  }
  export type VpnTunnelOptionsSpecificationsList = VpnTunnelOptionsSpecification[];
  export type WeekDay = "sunday"|"monday"|"tuesday"|"wednesday"|"thursday"|"friday"|"saturday"|string;
  export interface WithdrawByoipCidrRequest {
    /**
     * The address range, in CIDR notation.
     */
    Cidr: String;
    /**
     * Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation.
     */
    DryRun?: Boolean;
  }
  export interface WithdrawByoipCidrResult {
    /**
     * Information about the address pool.
     */
    ByoipCidr?: ByoipCidr;
  }
  export type ZoneIdStringList = String[];
  export type ZoneNameStringList = String[];
  export type scope = "Availability Zone"|"Region"|string;
  export type snapshotTierStatusSet = SnapshotTierStatus[];
  export type totalFpgaMemory = number;
  export type totalGpuMemory = number;
  /**
   * A string in YYYY-MM-DD format that represents the latest possible API version that can be used in this service. Specify 'latest' to use the latest possible version.
   */
  export type apiVersion = "2013-06-15"|"2013-10-15"|"2014-02-01"|"2014-05-01"|"2014-06-15"|"2014-09-01"|"2014-10-01"|"2015-03-01"|"2015-04-15"|"2015-10-01"|"2016-04-01"|"2016-09-15"|"2016-11-15"|"latest"|string;
  export interface ClientApiVersions {
    /**
     * A string in YYYY-MM-DD format that represents the latest possible API version that can be used in this service. Specify 'latest' to use the latest possible version.
     */
    apiVersion?: apiVersion;
  }
  export type ClientConfiguration = ServiceConfigurationOptions & ClientApiVersions;
  /**
   * Contains interfaces for use with the EC2 client.
   */
  export import Types = EC2;
}
export = EC2;
